(* Bimetric equations in the case of spherical symmetry *)
(* Exported:  2018-09-09T13:17:51                       *)
(* Reference: Geometric mean of bimetric spacetimes     *)
(*            https://arxiv.org/abs/1803.09752          *)

(* Auxiliary equations *)

eq$Lt[t_,r_] := Sqrt[1 + p[t, r]^2]

eq$v[t_,r_] := p[t, r]/Lt[t, r]

(* Shifted elementary symmetric polynomials *)

$Vsign = -1;

eq$esP[n_,k_,v_] := Sum[ $Vsign \[Beta][i+k] * SymmetricPolynomial[ i, Table[v,n] ], {i, 0, n} ]

(* Regularized gB and fB *)

(* Shift vectors *)

eqn$gBet[t_,r_] := q[t, r] + (gAlp[t, r]*v[t, r])/gA[t, r]

eqn$fBet[t_,r_] := q[t, r] - (fAlp[t, r]*v[t, r])/fA[t, r]

(* Projections of the bimeric stress-energy tensor in the g-sector *)

eqn$gV$\[Rho][t_,r_] := -P[2, 0, R[t, r]] - (fA[t, r]*Lt[t, r]*P[2, 1, R[t, r]])/gA[t, r]

eqn$gV$j[t_,r_] := -(fA[t, r]*p[t, r]*P[2, 1, R[t, r]])

eqn$gV$JK1[t_,r_] := -(2*Lt[t, r]*(gA[t, r]*gAlp[t, r]*P[1, 0, R[t, r]] + fA[t, r]*fAlp[t, r]*P[1, 2, R[t, r]]) + (fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*(2*P[1, 1, R[t, r]] - P[2, 1, R[t, r]]) + 2*fA[t, r]*gAlp[t, r]*Lt[t, r]^2*P[2, 1, R[t, r]])/(2*gA[t, r]*gAlp[t, r]*Lt[t, r])

eqn$gV$JK2[t_,r_] := -P[2, 0, R[t, r]] - ((fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*P[2, 1, R[t, r]])/(2*gA[t, r]*gAlp[t, r]*Lt[t, r])

(* Projections of the bimeric stress-energy tensor in the g-sector *)

eqn$fV$\[Rho][t_,r_] := -((gA[t, r]*Lt[t, r]*P[2, 1, R[t, r]])/(fA[t, r]*R[t, r]^2)) - P[2, 2, R[t, r]]/R[t, r]^2

eqn$fV$j[t_,r_] := (gA[t, r]*gB[t, r]^2*p[t, r]*P[2, 1, R[t, r]])/fB[t, r]^2

eqn$fV$JK1[t_,r_] := (-2*fAlp[t, r]*gA[t, r]*Lt[t, r]^2*P[2, 1, R[t, r]] - 2*Lt[t, r]*(gA[t, r]*gAlp[t, r]*P[1, 1, R[t, r]] + fA[t, r]*fAlp[t, r]*P[1, 3, R[t, r]])*R[t, r] + (fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*(P[2, 1, R[t, r]] - 2*P[1, 2, R[t, r]]*R[t, r]))/(2*fA[t, r]*fAlp[t, r]*Lt[t, r]*R[t, r]^2)

eqn$fV$JK2[t_,r_] := -(((fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*P[2, 1, R[t, r]])/(fA[t, r]*fAlp[t, r]*Lt[t, r]) + 2*P[2, 2, R[t, r]])/(2*R[t, r]^2)

(* Scalar constraints *)

eqn$gC$\[Rho][t_,r_] := gB[t, r]^(-2) + 2*gK1[t, r]*gK2[t, r] + gK2[t, r]^2 + (2*Derivative[0, 1][gA][t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]^3*gB[t, r]) - Derivative[0, 1][gB][t, r]^2/(gA[t, r]^2*gB[t, r]^2) - (2*Derivative[0, 2][gB][t, r])/(gA[t, r]^2*gB[t, r])

eqn$fC$\[Rho][t_,r_] := fB[t, r]^(-2) + 2*fK1[t, r]*fK2[t, r] + fK2[t, r]^2 + (2*Derivative[0, 1][fA][t, r]*Derivative[0, 1][fB][t, r])/(fA[t, r]^3*fB[t, r]) - Derivative[0, 1][fB][t, r]^2/(fA[t, r]^2*fB[t, r]^2) - (2*Derivative[0, 2][fB][t, r])/(fA[t, r]^2*fB[t, r])

(* Vector constraints *)

eqn$gC$j[t_,r_] := (2*gK1[t, r]*Derivative[0, 1][gB][t, r])/gB[t, r] - (2*gK2[t, r]*Derivative[0, 1][gB][t, r])/gB[t, r] - 2*Derivative[0, 1][gK2][t, r]

eqn$fC$j[t_,r_] := (2*fK1[t, r]*Derivative[0, 1][fB][t, r])/fB[t, r] - (2*fK2[t, r]*Derivative[0, 1][fB][t, r])/fB[t, r] - 2*Derivative[0, 1][fK2][t, r]

(* The solved p and its time evolution *)

eqn$p[t_,r_] := (-2*(gK1[t, r]*Derivative[0, 1][gB][t, r] - gK2[t, r]*Derivative[0, 1][gB][t, r] - gB[t, r]*Derivative[0, 1][gK2][t, r]))/(fA[t, r]*gB[t, r]*P[2, 1, R[t, r]])

evol$eqn$p[t_,r_] := (2*fAlp[t, r]*P[1, 2, R[t, r]]*(gA[t, r]*Lt[t, r]*Derivative[0, 1][fB][t, r] - fA[t, r]*Derivative[0, 1][gB][t, r]) + P[1, 1, R[t, r]]*(-2*fA[t, r]*fAlp[t, r]*fK2[t, r]*gA[t, r]*gB[t, r]*p[t, r] + 2*gAlp[t, r]*(gA[t, r]*Derivative[0, 1][fB][t, r] + fA[t, r]*(gA[t, r]*gB[t, r]*gK2[t, r]*p[t, r] - Lt[t, r]*Derivative[0, 1][gB][t, r]))) + gB[t, r]*P[2, 1, R[t, r]]*(fA[t, r]*fAlp[t, r]*(fK1[t, r] + 2*fK2[t, r])*gA[t, r]*p[t, r] + gA[t, r]*Lt[t, r]*Derivative[0, 1][fAlp][t, r] + fA[t, r]*(gA[t, r]*gAlp[t, r]*gK1[t, r]*p[t, r] - Lt[t, r]*Derivative[0, 1][gAlp][t, r] + gA[t, r]*q[t, r]*Derivative[0, 1][p][t, r])))/(fA[t, r]*gA[t, r]*gB[t, r]*P[2, 1, R[t, r]])

(* Bimetric conservation law *)

eqn$bimConsLaw[t_,r_] := -(gA[t, r]*(gK1[t, r]*P[2, 1, R[t, r]] + 2*P[1, 1, R[t, r]]*(gK2[t, r] - fK2[t, r]*Lt[t, r]*R[t, r]))) + (2*gA[t, r]*p[t, r]*P[1, 1, R[t, r]]*Derivative[0, 1][fB][t, r])/(fA[t, r]*gB[t, r]) + fA[t, r]*(fK1[t, r]*P[2, 1, R[t, r]] + 2*fK2[t, r]*(-P[1, 1, R[t, r]] + P[2, 1, R[t, r]]) + 2*P[1, 2, R[t, r]]*(-(gK2[t, r]*Lt[t, r]) + (p[t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]*gB[t, r]))) + (P[2, 1, R[t, r]]*Derivative[0, 1][p][t, r])/Lt[t, r]

(* Evolution equations in the g-Sector (including sources) *)

evol$eqn$gA[t_,r_] := -(gA[t, r]*gAlp[t, r]*gK1[t, r]) + gBet[t, r]*Derivative[0, 1][gA][t, r] + gA[t, r]*Derivative[0, 1][gBet][t, r]

evol$eqn$gB[t_,r_] := -(gAlp[t, r]*gB[t, r]*gK2[t, r]) + gBet[t, r]*Derivative[0, 1][gB][t, r]

evol$eqn$gK1[t_,r_] := gAlp[t, r]*gK1[t, r]^2 + 2*gAlp[t, r]*gK1[t, r]*gK2[t, r] - k$g*gAlp[t, r]*g$JK1[t, r] + (Derivative[0, 1][gA][t, r]*Derivative[0, 1][gAlp][t, r])/gA[t, r]^3 + (2*gAlp[t, r]*Derivative[0, 1][gA][t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]^3*gB[t, r]) + gBet[t, r]*Derivative[0, 1][gK1][t, r] - Derivative[0, 2][gAlp][t, r]/gA[t, r]^2 - (2*gAlp[t, r]*Derivative[0, 2][gB][t, r])/(gA[t, r]^2*gB[t, r])

evol$eqn$gK2[t_,r_] := gAlp[t, r]/gB[t, r]^2 + gAlp[t, r]*gK1[t, r]*gK2[t, r] + 2*gAlp[t, r]*gK2[t, r]^2 - k$g*gAlp[t, r]*g$JK2[t, r] + (gAlp[t, r]*Derivative[0, 1][gA][t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]^3*gB[t, r]) - (Derivative[0, 1][gAlp][t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]^2*gB[t, r]) - (gAlp[t, r]*Derivative[0, 1][gB][t, r]^2)/(gA[t, r]^2*gB[t, r]^2) + gBet[t, r]*Derivative[0, 1][gK2][t, r] - (gAlp[t, r]*Derivative[0, 2][gB][t, r])/(gA[t, r]^2*gB[t, r])

(* Evolution equations in the f-Sector (including sources) *)

evol$eqn$fA[t_,r_] := -(fA[t, r]*fAlp[t, r]*fK1[t, r]) + fBet[t, r]*Derivative[0, 1][fA][t, r] + fA[t, r]*Derivative[0, 1][fBet][t, r]

evol$eqn$fB[t_,r_] := -(fAlp[t, r]*fB[t, r]*fK2[t, r]) + fBet[t, r]*Derivative[0, 1][fB][t, r]

evol$eqn$fK1[t_,r_] := fAlp[t, r]*fK1[t, r]^2 + 2*fAlp[t, r]*fK1[t, r]*fK2[t, r] - k$f*fAlp[t, r]*f$JK1[t, r] + (Derivative[0, 1][fA][t, r]*Derivative[0, 1][fAlp][t, r])/fA[t, r]^3 + (2*fAlp[t, r]*Derivative[0, 1][fA][t, r]*Derivative[0, 1][fB][t, r])/(fA[t, r]^3*fB[t, r]) + fBet[t, r]*Derivative[0, 1][fK1][t, r] - Derivative[0, 2][fAlp][t, r]/fA[t, r]^2 - (2*fAlp[t, r]*Derivative[0, 2][fB][t, r])/(fA[t, r]^2*fB[t, r])

evol$eqn$fK2[t_,r_] := fAlp[t, r]/fB[t, r]^2 + fAlp[t, r]*fK1[t, r]*fK2[t, r] + 2*fAlp[t, r]*fK2[t, r]^2 - k$f*fAlp[t, r]*f$JK2[t, r] + (fAlp[t, r]*Derivative[0, 1][fA][t, r]*Derivative[0, 1][fB][t, r])/(fA[t, r]^3*fB[t, r]) - (Derivative[0, 1][fAlp][t, r]*Derivative[0, 1][fB][t, r])/(fA[t, r]^2*fB[t, r]) - (fAlp[t, r]*Derivative[0, 1][fB][t, r]^2)/(fA[t, r]^2*fB[t, r]^2) + fBet[t, r]*Derivative[0, 1][fK2][t, r] - (fAlp[t, r]*Derivative[0, 2][fB][t, r])/(fA[t, r]^2*fB[t, r])

useEqn$[] := Block[{}, eq$gBet = eqn$gBet; eq$fBet = eqn$fBet; eq$gV$\[Rho] = eqn$gV$\[Rho]; eq$gV$j = eqn$gV$j; eq$gV$JK1 = eqn$gV$JK1; eq$gV$JK2 = eqn$gV$JK2; eq$fV$\[Rho] = eqn$fV$\[Rho]; eq$fV$j = eqn$fV$j; eq$fV$JK1 = eqn$fV$JK1; eq$fV$JK2 = eqn$fV$JK2; eq$gC$\[Rho] = eqn$gC$\[Rho]; eq$fC$\[Rho] = eqn$fC$\[Rho]; eq$gC$j = eqn$gC$j; eq$fC$j = eqn$fC$j; eq$p = eqn$p; evol$eq$p = evol$eqn$p; eq$bimConsLaw = eqn$bimConsLaw; evol$eq$gA = evol$eqn$gA; evol$eq$gB = evol$eqn$gB; evol$eq$gK1 = evol$eqn$gK1; evol$eq$gK2 = evol$eqn$gK2; evol$eq$fA = evol$eqn$fA; evol$eq$fB = evol$eqn$fB; evol$eq$fK1 = evol$eqn$fK1; evol$eq$fK2 = evol$eqn$fK2; eq$gW = eqn$gW; eq$fW = eqn$fW; eq$cW = eqn$cW; ]

(* Usual gB and fB *)

(* Shift vectors *)

eqr$gBet[t_,r_] := q[t, r] + (gAlp[t, r]*v[t, r])/gA[t, r]

eqr$fBet[t_,r_] := q[t, r] - (fAlp[t, r]*v[t, r])/fA[t, r]

(* Projections of the bimeric stress-energy tensor in the g-sector *)

eqr$gV$\[Rho][t_,r_] := -P[2, 0, R[t, r]] - (fA[t, r]*Lt[t, r]*P[2, 1, R[t, r]])/gA[t, r]

eqr$gV$j[t_,r_] := -(fA[t, r]*p[t, r]*P[2, 1, R[t, r]])

eqr$gV$JK1[t_,r_] := -(2*Lt[t, r]*(gA[t, r]*gAlp[t, r]*P[1, 0, R[t, r]] + fA[t, r]*fAlp[t, r]*P[1, 2, R[t, r]]) + (fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*(2*P[1, 1, R[t, r]] - P[2, 1, R[t, r]]) + 2*fA[t, r]*gAlp[t, r]*Lt[t, r]^2*P[2, 1, R[t, r]])/(2*gA[t, r]*gAlp[t, r]*Lt[t, r])

eqr$gV$JK2[t_,r_] := -P[2, 0, R[t, r]] - ((fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*P[2, 1, R[t, r]])/(2*gA[t, r]*gAlp[t, r]*Lt[t, r])

(* Projections of the bimeric stress-energy tensor in the g-sector *)

eqr$fV$\[Rho][t_,r_] := -((gA[t, r]*Lt[t, r]*P[2, 1, R[t, r]] + fA[t, r]*P[2, 2, R[t, r]])/(fA[t, r]*R[t, r]^2))

eqr$fV$j[t_,r_] := (gA[t, r]*gB[t, r]^2*p[t, r]*P[2, 1, R[t, r]])/fB[t, r]^2

eqr$fV$JK1[t_,r_] := (-2*fAlp[t, r]*gA[t, r]*Lt[t, r]^2*P[2, 1, R[t, r]] - 2*Lt[t, r]*(gA[t, r]*gAlp[t, r]*P[1, 1, R[t, r]] + fA[t, r]*fAlp[t, r]*P[1, 3, R[t, r]])*R[t, r] + (fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*(P[2, 1, R[t, r]] - 2*P[1, 2, R[t, r]]*R[t, r]))/(2*fA[t, r]*fAlp[t, r]*Lt[t, r]*R[t, r]^2)

eqr$fV$JK2[t_,r_] := -(((fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*P[2, 1, R[t, r]])/(fA[t, r]*fAlp[t, r]*Lt[t, r]) + 2*P[2, 2, R[t, r]])/(2*R[t, r]^2)

(* Scalar constraints *)

eqr$gC$\[Rho][t_,r_] := (gA[t, r]^3*(1 + r^2*gB[t, r]^2*gK2[t, r]*(2*gK1[t, r] + gK2[t, r])) + 2*r*gB[t, r]*Derivative[0, 1][gA][t, r]*(gB[t, r] + r*Derivative[0, 1][gB][t, r]) - gA[t, r]*(gB[t, r]^2 + r^2*Derivative[0, 1][gB][t, r]^2 + 2*r*gB[t, r]*(3*Derivative[0, 1][gB][t, r] + r*Derivative[0, 2][gB][t, r])))/(r^2*gA[t, r]^3*gB[t, r]^2)

eqr$fC$\[Rho][t_,r_] := (fA[t, r]^3*(1 + r^2*fB[t, r]^2*fK2[t, r]*(2*fK1[t, r] + fK2[t, r])) + 2*r*fB[t, r]*Derivative[0, 1][fA][t, r]*(fB[t, r] + r*Derivative[0, 1][fB][t, r]) - fA[t, r]*(fB[t, r]^2 + r^2*Derivative[0, 1][fB][t, r]^2 + 2*r*fB[t, r]*(3*Derivative[0, 1][fB][t, r] + r*Derivative[0, 2][fB][t, r])))/(r^2*fA[t, r]^3*fB[t, r]^2)

(* Vector constraints *)

eqr$gC$j[t_,r_] := (-2*(r*(-gK1[t, r] + gK2[t, r])*Derivative[0, 1][gB][t, r] + gB[t, r]*(-gK1[t, r] + gK2[t, r] + r*Derivative[0, 1][gK2][t, r])))/(r*gB[t, r])

eqr$fC$j[t_,r_] := (-2*(r*(-fK1[t, r] + fK2[t, r])*Derivative[0, 1][fB][t, r] + fB[t, r]*(-fK1[t, r] + fK2[t, r] + r*Derivative[0, 1][fK2][t, r])))/(r*fB[t, r])

(* The solved p and its time evolution *)

eqr$p[t_,r_] := (2*(r*(-gK1[t, r] + gK2[t, r])*Derivative[0, 1][gB][t, r] + gB[t, r]*(-gK1[t, r] + gK2[t, r] + r*Derivative[0, 1][gK2][t, r])))/(r*fA[t, r]*gB[t, r]*P[2, 1, R[t, r]])

evol$eqr$p[t_,r_] := (2*fAlp[t, r]*P[1, 2, R[t, r]]*(gA[t, r]*Lt[t, r]*(fB[t, r] + r*Derivative[0, 1][fB][t, r]) - fA[t, r]*(gB[t, r] + r*Derivative[0, 1][gB][t, r])) + P[1, 1, R[t, r]]*(-2*r*fA[t, r]*fAlp[t, r]*fK2[t, r]*gA[t, r]*gB[t, r]*p[t, r] + 2*gAlp[t, r]*(gA[t, r]*(fB[t, r] + r*Derivative[0, 1][fB][t, r]) + fA[t, r]*(r*gA[t, r]*gB[t, r]*gK2[t, r]*p[t, r] - Lt[t, r]*(gB[t, r] + r*Derivative[0, 1][gB][t, r])))) + r*gB[t, r]*P[2, 1, R[t, r]]*(gA[t, r]*Lt[t, r]*Derivative[0, 1][fAlp][t, r] + fA[t, r]*(fAlp[t, r]*(fK1[t, r] + 2*fK2[t, r])*gA[t, r]*p[t, r] - Lt[t, r]*Derivative[0, 1][gAlp][t, r] + gA[t, r]*(gAlp[t, r]*gK1[t, r]*p[t, r] + q[t, r]*Derivative[0, 1][p][t, r]))))/(r*fA[t, r]*gA[t, r]*gB[t, r]*P[2, 1, R[t, r]])

(* Bimetric conservation law *)

eqr$bimConsLaw[t_,r_] := -(gA[t, r]*(gK1[t, r]*P[2, 1, R[t, r]] + 2*P[1, 1, R[t, r]]*(gK2[t, r] - fK2[t, r]*Lt[t, r]*R[t, r]))) + (2*gA[t, r]*p[t, r]*P[1, 1, R[t, r]]*(fB[t, r] + r*Derivative[0, 1][fB][t, r]))/(r*fA[t, r]*gB[t, r]) + fA[t, r]*(fK1[t, r]*P[2, 1, R[t, r]] + 2*fK2[t, r]*(-P[1, 1, R[t, r]] + P[2, 1, R[t, r]]) + 2*P[1, 2, R[t, r]]*(-(gK2[t, r]*Lt[t, r]) + (p[t, r]*(gB[t, r] + r*Derivative[0, 1][gB][t, r]))/(r*gA[t, r]*gB[t, r]))) + (P[2, 1, R[t, r]]*Derivative[0, 1][p][t, r])/Lt[t, r]

(* Evolution equations in the g-Sector (including sources) *)

evol$eqr$gA[t_,r_] := gBet[t, r]*Derivative[0, 1][gA][t, r] + gA[t, r]*(-(gAlp[t, r]*gK1[t, r]) + Derivative[0, 1][gBet][t, r])

evol$eqr$gB[t_,r_] := gB[t, r]*(gBet[t, r]/r - gAlp[t, r]*gK2[t, r]) + gBet[t, r]*Derivative[0, 1][gB][t, r]

evol$eqr$gK1[t_,r_] := (Derivative[0, 1][gA][t, r]*(r*gB[t, r]*Derivative[0, 1][gAlp][t, r] + 2*gAlp[t, r]*(gB[t, r] + r*Derivative[0, 1][gB][t, r])) + r*gA[t, r]^3*gB[t, r]*(gAlp[t, r]*(gK1[t, r]^2 + 2*gK1[t, r]*gK2[t, r] - k$g*g$JK1[t, r]) + gBet[t, r]*Derivative[0, 1][gK1][t, r]) - gA[t, r]*(r*gB[t, r]*Derivative[0, 2][gAlp][t, r] + 2*gAlp[t, r]*(2*Derivative[0, 1][gB][t, r] + r*Derivative[0, 2][gB][t, r])))/(r*gA[t, r]^3*gB[t, r])

evol$eqr$gK2[t_,r_] := (r*gAlp[t, r]*gB[t, r]*Derivative[0, 1][gA][t, r]*(gB[t, r] + r*Derivative[0, 1][gB][t, r]) + gA[t, r]^3*(gAlp[t, r]*(1 + r^2*gB[t, r]^2*(gK1[t, r]*gK2[t, r] + 2*gK2[t, r]^2 - k$g*g$JK2[t, r])) + r^2*gB[t, r]^2*gBet[t, r]*Derivative[0, 1][gK2][t, r]) - gA[t, r]*(r*gB[t, r]*Derivative[0, 1][gAlp][t, r]*(gB[t, r] + r*Derivative[0, 1][gB][t, r]) + gAlp[t, r]*(gB[t, r]^2 + r^2*Derivative[0, 1][gB][t, r]^2 + r*gB[t, r]*(4*Derivative[0, 1][gB][t, r] + r*Derivative[0, 2][gB][t, r]))))/(r^2*gA[t, r]^3*gB[t, r]^2)

(* Evolution equations in the f-Sector (including sources) *)

evol$eqr$fA[t_,r_] := fBet[t, r]*Derivative[0, 1][fA][t, r] + fA[t, r]*(-(fAlp[t, r]*fK1[t, r]) + Derivative[0, 1][fBet][t, r])

evol$eqr$fB[t_,r_] := fB[t, r]*(fBet[t, r]/r - fAlp[t, r]*fK2[t, r]) + fBet[t, r]*Derivative[0, 1][fB][t, r]

evol$eqr$fK1[t_,r_] := (Derivative[0, 1][fA][t, r]*(r*fB[t, r]*Derivative[0, 1][fAlp][t, r] + 2*fAlp[t, r]*(fB[t, r] + r*Derivative[0, 1][fB][t, r])) + r*fA[t, r]^3*fB[t, r]*(fAlp[t, r]*(fK1[t, r]^2 + 2*fK1[t, r]*fK2[t, r] - k$f*f$JK1[t, r]) + fBet[t, r]*Derivative[0, 1][fK1][t, r]) - fA[t, r]*(r*fB[t, r]*Derivative[0, 2][fAlp][t, r] + 2*fAlp[t, r]*(2*Derivative[0, 1][fB][t, r] + r*Derivative[0, 2][fB][t, r])))/(r*fA[t, r]^3*fB[t, r])

evol$eqr$fK2[t_,r_] := (r*fAlp[t, r]*fB[t, r]*Derivative[0, 1][fA][t, r]*(fB[t, r] + r*Derivative[0, 1][fB][t, r]) + fA[t, r]^3*(fAlp[t, r]*(1 + r^2*fB[t, r]^2*(fK1[t, r]*fK2[t, r] + 2*fK2[t, r]^2 - k$f*f$JK2[t, r])) + r^2*fB[t, r]^2*fBet[t, r]*Derivative[0, 1][fK2][t, r]) - fA[t, r]*(r*fB[t, r]*Derivative[0, 1][fAlp][t, r]*(fB[t, r] + r*Derivative[0, 1][fB][t, r]) + fAlp[t, r]*(fB[t, r]^2 + r^2*Derivative[0, 1][fB][t, r]^2 + r*fB[t, r]*(4*Derivative[0, 1][fB][t, r] + r*Derivative[0, 2][fB][t, r]))))/(r^2*fA[t, r]^3*fB[t, r]^2)

useEqr$[] := Block[{}, eq$gBet = eqr$gBet; eq$fBet = eqr$fBet; eq$gV$\[Rho] = eqr$gV$\[Rho]; eq$gV$j = eqr$gV$j; eq$gV$JK1 = eqr$gV$JK1; eq$gV$JK2 = eqr$gV$JK2; eq$fV$\[Rho] = eqr$fV$\[Rho]; eq$fV$j = eqr$fV$j; eq$fV$JK1 = eqr$fV$JK1; eq$fV$JK2 = eqr$fV$JK2; eq$gC$\[Rho] = eqr$gC$\[Rho]; eq$fC$\[Rho] = eqr$fC$\[Rho]; eq$gC$j = eqr$gC$j; eq$fC$j = eqr$fC$j; eq$p = eqr$p; evol$eq$p = evol$eqr$p; eq$bimConsLaw = eqr$bimConsLaw; evol$eq$gA = evol$eqr$gA; evol$eq$gB = evol$eqr$gB; evol$eq$gK1 = evol$eqr$gK1; evol$eq$gK2 = evol$eqr$gK2; evol$eq$fA = evol$eqr$fA; evol$eq$fB = evol$eqr$fB; evol$eq$fK1 = evol$eqr$fK1; evol$eq$fK2 = evol$eqr$fK2; eq$gW = eqr$gW; eq$fW = eqr$fW; eq$cW = eqr$cW; ]

