(* Bimetric equations in the case of spherical symmetry *)
(* Exported:  2018-06-19T16:31:52                       *)
(* Reference: Geometric mean of bimetric spacetimes     *)
(*            https://arxiv.org/abs/1803.09752          *)

(* Auxiliary equations *)

eq$gBet[t_,r_] := q[t, r] + (gAlp[t, r]*v[t, r])/gA[t, r]

eq$fBet[t_,r_] := q[t, r] - (fAlp[t, r]*v[t, r])/fA[t, r]

eq$Lt[t_,r_] := Sqrt[1 + p[t, r]^2]

eq$v[t_,r_] := p[t, r]/Lt[t, r]

(* Shifted elementary symmetric polynomials *)

$Vsign = -1

eq$esP[n_,k_,v_] := Sum[ $Vsign \[Beta][i+k] * SymmetricPolynomial[ i, Table[v,n] ], {i, 0, n} ]

(* Projections of the bimeric stress-energy tensor in the g-sector *)

eq$gV$\[Rho][t_,r_] := -P[2, 0, R[t, r]] - (fA[t, r]*Lt[t, r]*P[2, 1, R[t, r]])/gA[t, r]

eq$gV$j[t_,r_] := -(fA[t, r]*p[t, r]*P[2, 1, R[t, r]])

eq$gV$JK1[t_,r_] := -(2*Lt[t, r]*(gA[t, r]*gAlp[t, r]*P[1, 0, R[t, r]] + fA[t, r]*fAlp[t, r]*P[1, 2, R[t, r]]) + (fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*(2*P[1, 1, R[t, r]] - P[2, 1, R[t, r]]) + 2*fA[t, r]*gAlp[t, r]*Lt[t, r]^2*P[2, 1, R[t, r]])/(2*gA[t, r]*gAlp[t, r]*Lt[t, r])

eq$gV$JK2[t_,r_] := -P[2, 0, R[t, r]] - ((fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*P[2, 1, R[t, r]])/(2*gA[t, r]*gAlp[t, r]*Lt[t, r])

(* Projections of the bimeric stress-energy tensor in the g-sector *)

eq$fV$\[Rho][t_,r_] := -((gA[t, r]*Lt[t, r]*P[2, 1, R[t, r]])/(fA[t, r]*R[t, r]^2)) - P[2, 2, R[t, r]]/R[t, r]^2

eq$fV$j[t_,r_] := (gA[t, r]*gB[t, r]^2*p[t, r]*P[2, 1, R[t, r]])/fB[t, r]^2

eq$fV$JK1[t_,r_] := (-2*fAlp[t, r]*gA[t, r]*Lt[t, r]^2*P[2, 1, R[t, r]] - 2*Lt[t, r]*(gA[t, r]*gAlp[t, r]*P[1, 1, R[t, r]] + fA[t, r]*fAlp[t, r]*P[1, 3, R[t, r]])*R[t, r] + (fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*(P[2, 1, R[t, r]] - 2*P[1, 2, R[t, r]]*R[t, r]))/(2*fA[t, r]*fAlp[t, r]*Lt[t, r]*R[t, r]^2)

eq$fV$JK2[t_,r_] := -(((fAlp[t, r]*gA[t, r] + fA[t, r]*gAlp[t, r])*P[2, 1, R[t, r]])/(fA[t, r]*fAlp[t, r]*Lt[t, r]) + 2*P[2, 2, R[t, r]])/(2*R[t, r]^2)

(* Scalar constraints *)

eq$gC$\[Rho][t_,r_] := gB[t, r]^(-2) + 2*gK1[t, r]*gK2[t, r] + gK2[t, r]^2 + (2*Derivative[0, 1][gA][t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]^3*gB[t, r]) - Derivative[0, 1][gB][t, r]^2/(gA[t, r]^2*gB[t, r]^2) - (2*Derivative[0, 2][gB][t, r])/(gA[t, r]^2*gB[t, r])

eq$fC$\[Rho][t_,r_] := fB[t, r]^(-2) + 2*fK1[t, r]*fK2[t, r] + fK2[t, r]^2 + (2*Derivative[0, 1][fA][t, r]*Derivative[0, 1][fB][t, r])/(fA[t, r]^3*fB[t, r]) - Derivative[0, 1][fB][t, r]^2/(fA[t, r]^2*fB[t, r]^2) - (2*Derivative[0, 2][fB][t, r])/(fA[t, r]^2*fB[t, r])

(* Vector constraints *)

eq$gC$j[t_,r_] := (2*gK1[t, r]*Derivative[0, 1][gB][t, r])/gB[t, r] - (2*gK2[t, r]*Derivative[0, 1][gB][t, r])/gB[t, r] - 2*Derivative[0, 1][gK2][t, r]

eq$fC$j[t_,r_] := (2*fK1[t, r]*Derivative[0, 1][fB][t, r])/fB[t, r] - (2*fK2[t, r]*Derivative[0, 1][fB][t, r])/fB[t, r] - 2*Derivative[0, 1][fK2][t, r]

(* The solved p and its time evolution *)

eq$p[t_,r_] := (-2*(gK1[t, r]*Derivative[0, 1][gB][t, r] - gK2[t, r]*Derivative[0, 1][gB][t, r] - gB[t, r]*Derivative[0, 1][gK2][t, r]))/(fA[t, r]*gB[t, r]*P[2, 1, R[t, r]])

evol$eq$p[t_,r_] := (2*fAlp[t, r]*P[1, 2, R[t, r]]*(gA[t, r]*Lt[t, r]*Derivative[0, 1][fB][t, r] - fA[t, r]*Derivative[0, 1][gB][t, r]) + P[1, 1, R[t, r]]*(-2*fA[t, r]*fAlp[t, r]*fK2[t, r]*gA[t, r]*gB[t, r]*p[t, r] + 2*gAlp[t, r]*(gA[t, r]*Derivative[0, 1][fB][t, r] + fA[t, r]*(gA[t, r]*gB[t, r]*gK2[t, r]*p[t, r] - Lt[t, r]*Derivative[0, 1][gB][t, r]))) + gB[t, r]*P[2, 1, R[t, r]]*(fA[t, r]*fAlp[t, r]*(fK1[t, r] + 2*fK2[t, r])*gA[t, r]*p[t, r] + gA[t, r]*Lt[t, r]*Derivative[0, 1][fAlp][t, r] + fA[t, r]*(gA[t, r]*gAlp[t, r]*gK1[t, r]*p[t, r] - Lt[t, r]*Derivative[0, 1][gAlp][t, r] + gA[t, r]*q[t, r]*Derivative[0, 1][p][t, r])))/(fA[t, r]*gA[t, r]*gB[t, r]*P[2, 1, R[t, r]])

(* Bimetric conservation law *)

eq$bimConsLaw[t_,r_] := -(gA[t, r]*(gK1[t, r]*P[2, 1, R[t, r]] + 2*P[1, 1, R[t, r]]*(gK2[t, r] - fK2[t, r]*Lt[t, r]*R[t, r]))) + (2*gA[t, r]*p[t, r]*P[1, 1, R[t, r]]*Derivative[0, 1][fB][t, r])/(fA[t, r]*gB[t, r]) + fA[t, r]*(fK1[t, r]*P[2, 1, R[t, r]] + 2*fK2[t, r]*(-P[1, 1, R[t, r]] + P[2, 1, R[t, r]]) + 2*P[1, 2, R[t, r]]*(-(gK2[t, r]*Lt[t, r]) + (p[t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]*gB[t, r]))) + (P[2, 1, R[t, r]]*Derivative[0, 1][p][t, r])/Lt[t, r]

(* Evolution equations in the g-Sector (including sources) *)

evol$eq$gA[t_,r_] := -(gA[t, r]*gAlp[t, r]*gK1[t, r]) + gBet[t, r]*Derivative[0, 1][gA][t, r] + gA[t, r]*Derivative[0, 1][gBet][t, r]

evol$eq$gB[t_,r_] := -(gAlp[t, r]*gB[t, r]*gK2[t, r]) + gBet[t, r]*Derivative[0, 1][gB][t, r]

evol$eq$gK1[t_,r_] := gAlp[t, r]*gK1[t, r]^2 + 2*gAlp[t, r]*gK1[t, r]*gK2[t, r] - k$g*gAlp[t, r]*g$JK1[t, r] + (Derivative[0, 1][gA][t, r]*Derivative[0, 1][gAlp][t, r])/gA[t, r]^3 + (2*gAlp[t, r]*Derivative[0, 1][gA][t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]^3*gB[t, r]) + gBet[t, r]*Derivative[0, 1][gK1][t, r] - Derivative[0, 2][gAlp][t, r]/gA[t, r]^2 - (2*gAlp[t, r]*Derivative[0, 2][gB][t, r])/(gA[t, r]^2*gB[t, r])

evol$eq$gK2[t_,r_] := gAlp[t, r]/gB[t, r]^2 + gAlp[t, r]*gK1[t, r]*gK2[t, r] + 2*gAlp[t, r]*gK2[t, r]^2 - k$g*gAlp[t, r]*g$JK2[t, r] + (gAlp[t, r]*Derivative[0, 1][gA][t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]^3*gB[t, r]) - (Derivative[0, 1][gAlp][t, r]*Derivative[0, 1][gB][t, r])/(gA[t, r]^2*gB[t, r]) - (gAlp[t, r]*Derivative[0, 1][gB][t, r]^2)/(gA[t, r]^2*gB[t, r]^2) + gBet[t, r]*Derivative[0, 1][gK2][t, r] - (gAlp[t, r]*Derivative[0, 2][gB][t, r])/(gA[t, r]^2*gB[t, r])

(* Evolution equations in the f-Sector (including sources) *)

evol$eq$fA[t_,r_] := -(fA[t, r]*fAlp[t, r]*fK1[t, r]) + fBet[t, r]*Derivative[0, 1][fA][t, r] + fA[t, r]*Derivative[0, 1][fBet][t, r]

evol$eq$fB[t_,r_] := -(fAlp[t, r]*fB[t, r]*fK2[t, r]) + fBet[t, r]*Derivative[0, 1][fB][t, r]

evol$eq$fK1[t_,r_] := fAlp[t, r]*fK1[t, r]^2 + 2*fAlp[t, r]*fK1[t, r]*fK2[t, r] - k$f*fAlp[t, r]*f$JK1[t, r] + (Derivative[0, 1][fA][t, r]*Derivative[0, 1][fAlp][t, r])/fA[t, r]^3 + (2*fAlp[t, r]*Derivative[0, 1][fA][t, r]*Derivative[0, 1][fB][t, r])/(fA[t, r]^3*fB[t, r]) + fBet[t, r]*Derivative[0, 1][fK1][t, r] - Derivative[0, 2][fAlp][t, r]/fA[t, r]^2 - (2*fAlp[t, r]*Derivative[0, 2][fB][t, r])/(fA[t, r]^2*fB[t, r])

evol$eq$fK2[t_,r_] := fAlp[t, r]/fB[t, r]^2 + fAlp[t, r]*fK1[t, r]*fK2[t, r] + 2*fAlp[t, r]*fK2[t, r]^2 - k$f*fAlp[t, r]*f$JK2[t, r] + (fAlp[t, r]*Derivative[0, 1][fA][t, r]*Derivative[0, 1][fB][t, r])/(fA[t, r]^3*fB[t, r]) - (Derivative[0, 1][fAlp][t, r]*Derivative[0, 1][fB][t, r])/(fA[t, r]^2*fB[t, r]) - (fAlp[t, r]*Derivative[0, 1][fB][t, r]^2)/(fA[t, r]^2*fB[t, r]^2) + fBet[t, r]*Derivative[0, 1][fK2][t, r] - (fAlp[t, r]*Derivative[0, 2][fB][t, r])/(fA[t, r]^2*fB[t, r])

