(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   2007746,      54433]
NotebookOptionsPosition[   1992681,      54028]
NotebookOutlinePosition[   1998626,      54180]
CellTagsIndexPosition[   1998020,      54160]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Bimetric equations in standard 3+1 form \nreduced to spherical symmetry ",
 StyleBox["(equations dump)",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell["Mikica Kocic", "Text"],

Cell["Created 2018-02-08, Last modified 2018-08-03", "Text"],

Cell[TextData[{
 StyleBox["Requirements",
  FontWeight->"Bold"],
 ":"
}], "Text"],

Cell["\<\
Evaluate first the main notebook: \[OpenCurlyDoubleQuote]bimetric-ss-in-3+1 \
(cpp solver)\[CloseCurlyDoubleQuote]\
\>", "Text"],

Cell[TextData[{
 StyleBox["Changelog",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.720329745571742*^9, 3.7203297456965427`*^9}, {
  3.7203297847600107`*^9, 3.7203297956508303`*^9}, {3.7205583336652308`*^9, 
  3.7205583361144347`*^9}, {3.7207192650993385`*^9, 3.7207192738041534`*^9}, {
  3.720804920912696*^9, 3.7208050456419153`*^9}, {3.7208050794959755`*^9, 
  3.720805104705619*^9}, {3.720805135145273*^9, 3.720805252292879*^9}}],

Cell["2018-08-03  Separated from the main notebook.", "Text"],

Cell[CellGroupData[{

Cell["Utilities to dump the EoM", "Subsubsection"],

Cell["A collection of all the equations:", "Text"],

Cell[BoxData[
 RowBox[{"all$EoM", ":=", 
  RowBox[{"Join", "[", "\[IndentingNewLine]", 
   RowBox[{
   "EoM$gEvol", ",", "EoM$fEvol", ",", "EoM$mEvol", ",", 
    "\[IndentingNewLine]", "EoM$constr1", ",", "EoM$constr2", ",", 
    "\[IndentingNewLine]", "EoM$sources", ",", "EoM$pEqs", ",", 
    "\[IndentingNewLine]", "EoM$horizonFinders", ",", "EoM$lapseRatios", ",", 
    "\[IndentingNewLine]", "EoM$shifts", ",", "\[IndentingNewLine]", 
    "EoM$gaugeFunctions"}], "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell["Dump all of the equations,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dumpCppEquations", "[", "show_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{"show", ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Echo", "@", 
        RowBox[{"printNice", "[", 
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "\[Rule]", 
            RowBox[{
            "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
           ",", "14"}], "]"}], "]"}]}], "&"}], "/@", 
      RowBox[{"all$EoM", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}]}], 
     ";"}]}], "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell["Dump the equations of motion using printNice,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dumpEoM", "[", 
   RowBox[{"title_", ",", "eom_"}], "]"}], ":=", 
  RowBox[{"showOutHideCode", "[", 
   RowBox[{
    RowBox[{"Grid", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"title", ",", "Bold"}], "]"}], ",", "SpanFromLeft", ",", 
          "SpanFromLeft", ",", "SpanFromLeft"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"printNice", "@", 
             RowBox[{"{", 
              RowBox[{"\"\< \>\"", ",", 
               RowBox[{
               "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               ",", "\"\< \[Equal] \>\"", ",", 
               RowBox[{
               "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
              "}"}]}], "&"}], "/@", 
           RowBox[{"eom", "\[LeftDoubleBracket]", 
            RowBox[{"All", ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}]}], 
          ")"}]}]}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Alignment", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Left", ",", "Right", ",", 
          RowBox[{"{", "Left", "}"}]}], "}"}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Output\>\"", ",", "14"}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Spacings", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1.1"}], "}"}]}], "}"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"\"\<dump_\>\"", "<>", 
     RowBox[{"eom", "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
    RowBox[{"GeneratedCell", "\[Rule]", "False"}]}], "]"}]}]], "Input"],

Cell["Dump the lapse ratios,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dumpWgf", "[", 
   RowBox[{"label_", ",", "eq_"}], "]"}], ":=", 
  RowBox[{"Grid", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"i", "\[Equal]", "1"}], ",", "label", ",", "\"\<\>\""}],
              "]"}], ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"i", "\[Equal]", "1"}], ",", "\"\<\[Equal]\>\"", ",", 
              "\"\<+\>\""}], "]"}], ",", 
            RowBox[{
            "#", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "@", "#"}]}], "}"}]}], "]"}], "&"}], "@", 
       RowBox[{"(", 
        RowBox[{"List", "@@", "eq"}], ")"}]}], "/.", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"q", "\[Rule]", 
         RowBox[{"Framed", "[", 
          RowBox[{"q", ",", 
           RowBox[{"Background", "\[Rule]", "LightGreen"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"k$g", "\[Rule]", 
         RowBox[{"Framed", "[", 
          RowBox[{"k$g", ",", 
           RowBox[{"Background", "\[Rule]", "LightBlue"}]}], "]"}]}], ",", 
        RowBox[{"k$f", "\[Rule]", 
         RowBox[{"Framed", "[", 
          RowBox[{"k$f", ",", 
           RowBox[{"Background", "\[Rule]", "LightRed"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"0", ",", "1"}], "]"}], "[", "f_", "]"}], "[", 
          RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
         RowBox[{"Framed", "@", 
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "f", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"0", ",", "n_"}], "]"}], "[", "f_", "]"}], "[", 
          RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
         RowBox[{"Framed", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", 
              RowBox[{"0", ",", "n"}], "]"}], "[", "f", "]"}], "[", 
            RowBox[{"t", ",", "r"}], "]"}], ",", 
           RowBox[{"Background", "\[Rule]", "LightMagenta"}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "}"}]}], "//", "printNice"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Alignment", "\[Rule]", "Left"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions that will be exported to C++", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpCppEquations", "[", "True", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gA_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       SuperscriptBox[
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "2"], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]]}], "+", 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], "+", 
       RowBox[{
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox["D", "\[Alpha]"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gB_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], "r"], "+", 
    RowBox[{
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      SubscriptBox["D", "B"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox["D", "B"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gK1_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["K",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "+", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}]}], ")"}], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "+", 
        RowBox[{"2", " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}]}], ")"}], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{"3", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "-", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "+", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     FrameBox[
      SubscriptBox["gJK", "1"],
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gK2_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["K",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], ")"}], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}], ")"}], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{"3", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         StyleBox["\[Sigma]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          RowBox[{"4", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "-", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     FrameBox[
      SubscriptBox["gJK", "2"],
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gDA_t\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "rr"], 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}],
     HoldForm], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox["D", "A"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], ")"}], "2"]}], "+", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "4"]}], "-", 
        RowBox[{
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "4"], " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "+", 
        RowBox[{
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "4"], " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "5"]}]], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "rr"], 
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}],
          HoldForm], "-", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], " ", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "3"]}]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "-", 
          RowBox[{"2", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "-", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "+", 
             RowBox[{"2", " ", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gDB_t\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      FractionBox[
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "r"]}],
     HoldForm], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]}]], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox["D", "B"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "+", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
     RowBox[{"r", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "-", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           FractionBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "r"]}],
          HoldForm], "+", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], " ", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "3"]}]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], "+", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gK_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["K",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["\[Sigma]",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["D", "A"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            RowBox[{"6", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "+", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FrameBox[
          SubscriptBox["gJK", "1"],
          Background->RGBColor[0.87, 0.94, 1],
          BaseStyle->RGBColor[0, 0, 1],
          FrameMargins->Tiny,
          StripOnInput->False]}], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "-", 
       RowBox[{"2", " ", 
        FrameBox[
         SubscriptBox["gJK", "2"],
         Background->RGBColor[0.87, 0.94, 1],
         BaseStyle->RGBColor[0, 0, 1],
         FrameMargins->Tiny,
         StripOnInput->False], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gKD_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["B",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           StyleBox["\[Sigma]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
       RowBox[{
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FrameBox[
          SubscriptBox["gJK", "1"],
          Background->RGBColor[0.87, 0.94, 1],
          BaseStyle->RGBColor[0, 0, 1],
          FrameMargins->Tiny,
          StripOnInput->False]}], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{
        FrameBox[
         SubscriptBox["gJK", "2"],
         Background->RGBColor[0.87, 0.94, 1],
         BaseStyle->RGBColor[0, 0, 1],
         FrameMargins->Tiny,
         StripOnInput->False], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gSig_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      FractionBox[
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       RowBox[{
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          FractionBox[
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "r"]}],
         HoldForm], 
        RowBox[{
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "3"]}]], "+", 
       FractionBox[
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "+", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "+", 
           RowBox[{"3", " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{"2", " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}]], "-", 
    FractionBox[
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "3"]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fA_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], " ", 
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], "+", 
       RowBox[{
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "\[Alpha]"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}],
          HoldForm], 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]]}], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fB_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], "r"], "+", 
    RowBox[{
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "B"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "-", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "B"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fK1_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["K", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}]}], ")"}], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "+", 
        RowBox[{"2", " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}]}], ")"}], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{"3", " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "-", 
    RowBox[{
     FrameBox[
      SubscriptBox["fJK", "1"],
      Background->RGBColor[1, 0.85, 0.85],
      BaseStyle->RGBColor[1, 0, 0],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "-", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"]}]], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fK2_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["K", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], ")"}], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], ")"}], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{"3", " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "-", 
    RowBox[{
     FrameBox[
      SubscriptBox["fJK", "2"],
      Background->RGBColor[1, 0.85, 0.85],
      BaseStyle->RGBColor[1, 0, 0],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          RowBox[{"4", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fDA_t\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "rr"], 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}],
     HoldForm], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "A"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], ")"}], "2"]}], "-", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "4"]}], "+", 
        RowBox[{
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "4"], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "4"], " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], 
     RowBox[{
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "5"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "rr"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm]}], "+", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], 
        RowBox[{
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "3"], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "-", 
          RowBox[{"2", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "-", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "+", 
             RowBox[{"2", " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fDB_t\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      FractionBox[
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "r"]}],
     HoldForm], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "B"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "-", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
     RowBox[{"r", " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "-", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "-", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
     RowBox[{
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            FractionBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "r"]}],
           HoldForm], "+", 
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], 
         RowBox[{
          SuperscriptBox[
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "3"], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "+", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], "+", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fK_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        OverscriptBox["K", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FrameBox[
          SubscriptBox["fJK", "1"],
          Background->RGBColor[1, 0.85, 0.85],
          BaseStyle->RGBColor[1, 0, 0],
          FrameMargins->Tiny,
          StripOnInput->False]}], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "-", 
       RowBox[{"2", " ", 
        FrameBox[
         SubscriptBox["fJK", "2"],
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             OverscriptBox["\[Sigma]", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "A"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            RowBox[{"6", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fKD_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FrameBox[
          SubscriptBox["fJK", "1"],
          Background->RGBColor[1, 0.85, 0.85],
          BaseStyle->RGBColor[1, 0, 0],
          FrameMargins->Tiny,
          StripOnInput->False]}], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       RowBox[{
        FrameBox[
         SubscriptBox["fJK", "2"],
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            OverscriptBox["\[Sigma]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
       RowBox[{
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fSig_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "f"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    FractionBox[
     RowBox[{
      FractionBox[
       RowBox[{
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], "r"], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           FractionBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "r"]}],
          HoldForm], 
         RowBox[{
          SuperscriptBox[
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "3"], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
       FractionBox[
        RowBox[{
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "+", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "+", 
           RowBox[{"3", " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_D_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], " ", 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["D", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      RowBox[{"2", " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["D", "^"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}],
          HoldForm]}], " ", 
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_S_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], " ", 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{"2", " ", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["S", "^"], "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      RowBox[{"2", " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["S", "^"], "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}],
          HoldForm]}], " ", 
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
       RowBox[{
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], "+", 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], "+", 
          RowBox[{
           StyleBox[
            SuperscriptBox["v", "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["S", "^"], "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_tau_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], " ", 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Tau]", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      RowBox[{"2", " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["\[Tau]", "^"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}],
          HoldForm]}], " ", 
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "-", 
       FractionBox[
        RowBox[{
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
       RowBox[{
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_v\"\>", "\[Rule]", 
   FractionBox[
    StyleBox[
     SubscriptBox[
      OverscriptBox["S", "^"], "r"],
     StripOnInput->False,
     LineColor->RGBColor[0.5, 0, 0.5],
     FrontFaceColor->RGBColor[0.5, 0, 0.5],
     BackFaceColor->RGBColor[0.5, 0, 0.5],
     GraphicsColor->RGBColor[0.5, 0, 0.5],
     FontColor->RGBColor[0.5, 0, 0.5]], 
    RowBox[{
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], "+", 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_V\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     StyleBox[
      SuperscriptBox["v", "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "-", 
    StyleBox["\[Beta]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_v_r\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}],
       HoldForm], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm]}], ")"}], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}], " ", 
      StyleBox[
       SubscriptBox["D", "A"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_rho\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["D", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "+", 
     StyleBox[
      OverscriptBox["\[Tau]", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_j\"\>", "\[Rule]", 
   FractionBox[
    StyleBox[
     SubscriptBox[
      OverscriptBox["S", "^"], "r"],
     StripOnInput->False,
     LineColor->RGBColor[0.5, 0, 0.5],
     FrontFaceColor->RGBColor[0.5, 0, 0.5],
     BackFaceColor->RGBColor[0.5, 0, 0.5],
     GraphicsColor->RGBColor[0.5, 0, 0.5],
     FontColor->RGBColor[0.5, 0, 0.5]], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_J1\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     StyleBox[
      SuperscriptBox["v", "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["S", "^"], "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_J2\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gC_rho\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      FractionBox[
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Sigma]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "+", 
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]}], 
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], "-", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fC_rho\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      FractionBox[
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Sigma]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "+", 
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}]}], 
     SuperscriptBox[
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"], "-", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gC_j\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      StyleBox[
       SubscriptBox["K", "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], "r"], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "+", 
       RowBox[{"3", " ", 
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fC_j\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], "r"], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{"3", " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_bimConsLaw\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], " ", 
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm]}], 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "1"],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}], 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
            "1"],
           HoldForm], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
           "1"],
          HoldForm], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm]}], "+", 
          RowBox[{"3", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]}]}], ")"}], " ", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], "+", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "3"]}], " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["2", "3"], " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
         HoldForm], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], "+", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_1\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      FractionBox[
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Sigma]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "+", 
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]}], 
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], "-", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], "-", 
    RowBox[{
     FrameBox["g\[Rho]",
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_2\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FrameBox["f\[Rho]",
       Background->RGBColor[1, 0.85, 0.85],
       BaseStyle->RGBColor[1, 0, 0],
       FrameMargins->Tiny,
       StripOnInput->False]}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      FractionBox[
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Sigma]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "+", 
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}]}], 
     SuperscriptBox[
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"], "-", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_3\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          RowBox[{"3", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
       FractionBox[
        RowBox[{
         StyleBox[
          SubscriptBox["\[Kappa]", "g"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}]]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       SuperscriptBox[
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "2"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], "r"], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     SuperscriptBox[
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], "2"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{"3", " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_4\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], " ", 
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm]}], 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "1"],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}], 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
            "1"],
           HoldForm], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
           "1"],
          HoldForm], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm]}], "+", 
          RowBox[{"3", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]}]}], ")"}], " ", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], "+", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "3"]}], " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["2", "3"], " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
         HoldForm], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], "+", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_g_rho\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "0", "2"],
      HoldForm]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["D", "^"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], "+", 
      StyleBox[
       OverscriptBox["\[Tau]", "^"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_g_j\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm]}], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["S", "^"], "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_g_JK1\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "0", "1"],
      HoldForm]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm]}], "+", 
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    FractionBox[
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm]}], "+", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "2"],
           HoldForm]}], ")"}], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"2", " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]]}], 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["D", "^"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], "+", 
      StyleBox[
       OverscriptBox["\[Tau]", "^"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], "+", 
      RowBox[{
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_g_JK2\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "0", "2"],
      HoldForm]}], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{"2", " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["D", "^"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], "+", 
      StyleBox[
       OverscriptBox["\[Tau]", "^"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], "-", 
      RowBox[{
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_f_rho\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "2"],
       HoldForm], 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"]]}], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}], 
     RowBox[{
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_f_j\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], 
    SuperscriptBox[
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "2"]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_f_JK1\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "3", "1"],
       HoldForm], 
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
           "1"],
          HoldForm], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]]}], "+", 
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], "-", 
         RowBox[{"2", " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
            "1"],
           HoldForm], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["\[Alpha]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]], "-", 
       FractionBox[
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        RowBox[{
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          OverscriptBox["\[Alpha]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_f_JK2\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "2"],
       HoldForm], 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"]]}], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_p_g\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], 
      RowBox[{"r", " ", 
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]]}], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "+", 
        RowBox[{"3", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
     RowBox[{"3", " ", 
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}]], "+", 
    FractionBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["S", "^"], "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], 
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_p_f\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{"r", " ", 
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "f"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "+", 
        RowBox[{"3", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
     RowBox[{"3", " ", 
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "f"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_p_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["\[Alpha]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}], ")"}], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
            "1"],
           HoldForm], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         RowBox[{
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "2"],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "r"], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}], " ", 
              StyleBox["\[Sigma]",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], "+", 
             StyleBox[
              OverscriptBox["\[Sigma]", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
            "1"],
           HoldForm], " ", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm]]}], ")"}]}], 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox["\[Sigma]",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "-", 
             RowBox[{
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              StyleBox[
               OverscriptBox["\[Sigma]", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]], "+", 
         RowBox[{
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm]]}], "-", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], 
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
            "1"],
           HoldForm], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm]], "+", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]], "+", 
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{
         StyleBox[
          OverscriptBox["\[Alpha]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm]}], "+", 
              RowBox[{"3", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm]}]}], ")"}], " ", 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "+", 
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm]}]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gHorz\"\>", "\[Rule]", 
   RowBox[{
    FractionBox["1", "r"], "+", 
    StyleBox[
     SubscriptBox["D", "B"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fHorz\"\>", "\[Rule]", 
   RowBox[{
    FractionBox["1", "r"], "+", 
    StyleBox[
     SubscriptBox[
      OverscriptBox["D", "~"], "B"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gW\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"2", " ", 
     StyleBox["R",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 1],
      FrontFaceColor->RGBColor[1, 0, 1],
      BackFaceColor->RGBColor[1, 0, 1],
      GraphicsColor->RGBColor[1, 0, 1],
      FontColor->RGBColor[1, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], "-", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox["p",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}], "-", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "3", "0"],
                  HoldForm], " ", 
                 SuperscriptBox[
                  StyleBox["p",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "-", 
             RowBox[{"4", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              SuperscriptBox[
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "1"],
           HoldForm], ")"}], "2"], " ", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "3"], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "3"], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm], ")"}], "2"]}], "+", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm]}], "+", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
              SuperscriptBox[
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "0"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm], "+", 
                RowBox[{"4", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm]}], "+", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]}], ")"}], " ", 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm]}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm], "-", 
                   RowBox[{"2", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
                RowBox[{"4", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm], "-", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm]}], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm]}], "+", 
                RowBox[{"4", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm]}]}], ")"}], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     FractionBox["4", "3"], " ", "r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     SuperscriptBox[
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], "2"], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "0"],
               HoldForm]}], "-", 
             RowBox[{"4", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "-", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                   StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm]}], "+", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], ")"}]}], "+", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm]}], "+", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm]}], ")"}]}], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "0"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "-", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], ")"}], "2"], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "-", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}], "+", 
          RowBox[{
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                   StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], "-", 
                   RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}]}], ")"}], " ", 
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], "+", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "3", "0"],
                  HoldForm], " ", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                   StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "-", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm], " ", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "2"], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm], "+", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm], "-", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "2"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "f"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "2"], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "0", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "0", "1"],
                  HoldForm]}], "+", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "0", "2"],
                 HoldForm]}], ")"}], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm]}]}], ")"}], " ", 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}], "+", 
          RowBox[{"4", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              StyleBox[
               OverscriptBox["D", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
             StyleBox[
              OverscriptBox["\[Tau]", "^"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              StyleBox[
               OverscriptBox["A", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox[
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}], ")"}], " ", 
              StyleBox[
               OverscriptBox["D", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
             StyleBox[
              OverscriptBox["\[Tau]", "^"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]], "+", 
             RowBox[{
              SuperscriptBox[
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox[
                 OverscriptBox["\[Tau]", "^"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], "-", 
                RowBox[{
                 StyleBox[
                  SuperscriptBox["v", "r"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["S", "^"], "r"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], ")"}]}], 
          "+", 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm]}], "+", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], ")"}]}], "-", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "0", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm]}]}], ")"}], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              StyleBox[
               OverscriptBox["A", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm]}], "-", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm]}], ")"}], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox[
                 OverscriptBox["D", "^"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], "+", 
                StyleBox[
                 OverscriptBox["\[Tau]", "^"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], "-", 
                RowBox[{
                 StyleBox[
                  SuperscriptBox["v", "r"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["S", "^"], "r"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], ")"}]}]}],
          ")"}]}], "+", 
       RowBox[{
        FractionBox["2", "9"], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           RowBox[{"(", 
            RowBox[{
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], "-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], ")"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm]}], "+", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]}], ")"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}], "2"]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm]}], "+", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm], "-", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "-", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], ")"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "-", 
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm]}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm], "+", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "+", 
                RowBox[{"2", " ", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           SuperscriptBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "-", 
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "+", 
                RowBox[{"2", " ", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "-", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              TagBox[
               RowBox[{
                SubscriptBox["\[PartialD]", "r"], 
                StyleBox["p",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]]}],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], " ", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                   StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              StyleBox[
               OverscriptBox["A", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}], "+", 
                    RowBox[{"2", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SuperscriptBox[
                    StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], "2"]}], "+", 
                RowBox[{"3", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "+", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
                RowBox[{"2", " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                   StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], "-", 
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}]}], ")"}]}], " ", 
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "+", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fW\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm]}], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], ")"}], "2"], " ", 
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           SuperscriptBox[
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "2"], " ", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "3"], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "0"],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}], "-", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           RowBox[{"(", 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm], "-", 
             RowBox[{"4", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              SuperscriptBox[
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm]}], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "2", "1"],
                 HoldForm], ")"}], "2"], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "3", "0"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm]}], "-", 
             RowBox[{
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], ")"}], "2"], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}], "-", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "3", "0"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], "-", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm]}], "-", 
                RowBox[{"4", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], ")"}], "2"], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}], "+", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "3", "0"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], "+", 
             RowBox[{"2", " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], ")"}], "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "+", 
                   SuperscriptBox[
                    StyleBox["p",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}], ")"}]}], "-", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "3", "0"],
                  HoldForm], " ", 
                 SuperscriptBox[
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     FractionBox["4", "3"], " ", "r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     SuperscriptBox[
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], "2"], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "-", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "1"],
                 HoldForm], "-", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm]}], ")"}], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm]}], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "3", "0"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "-", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], ")"}], "2"], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "0"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}], "-", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "-", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "0"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "-", 
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "+", 
                RowBox[{"2", " ", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "+", 
                RowBox[{"2", " ", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          RowBox[{
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm]}], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm]}], "+", 
                RowBox[{"4", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm]}]}], ")"}], " ", 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
             RowBox[{
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm]}], "+", 
                   RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}]}], ")"}], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], " ", 
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], ")"}], "2"]}], "-", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                    HoldForm]}]}], ")"}], " ", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                   StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], " ", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "2"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm], ")"}], "2"]}], "+", 
             RowBox[{"4", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}], "+", 
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "2"],
               HoldForm], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm]}], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "2"],
               HoldForm]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "2"],
                  HoldForm]}], "+", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "3", "1"],
                  HoldForm]}]}], ")"}], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           SuperscriptBox[
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              StyleBox["A",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "1"],
                 HoldForm], "-", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm], "+", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
              StyleBox[
               OverscriptBox["A", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "f"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "2"], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm]}], "+", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "0", "2"],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm]}]}], ")"}], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]}], "+", 
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              OverscriptBox["D", "^"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]], "+", 
             StyleBox[
              OverscriptBox["\[Tau]", "^"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]], "-", 
             RowBox[{"3", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              StyleBox[
               OverscriptBox["A", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{
        FractionBox["2", "9"], " ", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           RowBox[{"(", 
            RowBox[{
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm], "-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm]}], ")"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"]}], "-", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              SuperscriptBox[
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
             RowBox[{"3", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              SuperscriptBox[
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "2", "0"],
                 HoldForm], "+", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "2", "1"],
                 HoldForm]}], ")"}], " ", 
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "2", "0"],
                 HoldForm], "-", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm]}]}], ")"}], " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
             RowBox[{
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm]}], "+", 
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm], " ", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 SuperscriptBox[
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "-", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}], "2"]}]}], ")"}]}], 
          "+", 
          RowBox[{"4", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm]}], "+", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]}], ")"}], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "2"], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           SuperscriptBox[
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "-", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm]}], "-", 
                RowBox[{"3", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm]}]}], ")"}], " ", 
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], "-", 
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "6"}], " ", 
              TagBox[
               RowBox[{
                SubscriptBox["\[PartialD]", "r"], 
                StyleBox["p",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]]}],
               HoldForm], " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], "+", 
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "+", 
                RowBox[{
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "2"], " ", 
              StyleBox[
               OverscriptBox["A", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm]}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                   RowBox[{"7", " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm]}], "-", 
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}]}], ")"}], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "6"}], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm]}], "+", 
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}]}], ")"}], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
                RowBox[{"2", " ", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                   StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_cW\"\>", "\[Rule]", 
   RowBox[{"2", " ", 
    SuperscriptBox["r", "2"], " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
     HoldForm], " ", 
    SuperscriptBox[
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], "2"], " ", 
    SuperscriptBox[
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], "2"], " ", 
    SuperscriptBox[
     StyleBox["R",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 1],
      FrontFaceColor->RGBColor[1, 0, 1],
      BackFaceColor->RGBColor[1, 0, 1],
      GraphicsColor->RGBColor[1, 0, 1],
      FontColor->RGBColor[1, 0, 1]], "2"], " ", 
    SuperscriptBox[
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], "3"], " ", 
    SuperscriptBox[
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "2"]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gBet\"\>", "\[Rule]", 
   RowBox[{
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fBet\"\>", "\[Rule]", 
   RowBox[{
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], "-", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gBet_r\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}],
     HoldForm], "+", 
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "+", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fBet_r\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}],
     HoldForm], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "-", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
     RowBox[{
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gBetr_r\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      FractionBox[
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "r"]}],
     HoldForm], "+", 
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "+", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
     RowBox[{"r", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fBetr_r\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      FractionBox[
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "r"]}],
     HoldForm], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "-", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
     RowBox[{"r", " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_q\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gAlp\"\>", "\[Rule]", "1"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fAlp\"\>", "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"gW", " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], "fW"]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The GR equations (the EoM where the two sectors are decoupled)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Echo", "@", 
     RowBox[{"printNice", "[", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "\[Rule]", 
         RowBox[{
         "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
        "14"}], "]"}], "]"}]}], "&"}], "/@", 
   RowBox[{"Quiet", "@", 
    RowBox[{"Block", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"P", ",", "\[Beta]", ",", "Ltp", ",", "p", ",", "pr"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "=", "eq$esP"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Beta]", "[", "n_", "]"}], ":=", "0"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"p", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pr", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Ltp", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"all$EoM", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}], "/.", 
        RowBox[{
         RowBox[{"HoldForm", "[", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", 
              RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
          "]"}], "\[Rule]", "0"}]}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gA_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], "+", 
       RowBox[{
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "-", 
       RowBox[{"2", " ", 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gB_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}], "r"], "+", 
    RowBox[{
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      SubscriptBox["D", "B"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gK1_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["K",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "+", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}]}], ")"}], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "-", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "+", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     FrameBox[
      SubscriptBox["gJK", "1"],
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gK2_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["K",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], ")"}], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         StyleBox["\[Sigma]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          RowBox[{"4", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "-", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     FrameBox[
      SubscriptBox["gJK", "2"],
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gDA_t\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "rr"], 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}],
     HoldForm], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox["D", "A"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}], "-", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}], "-", 
       RowBox[{
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gDB_t\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      FractionBox[
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "r"]}],
     HoldForm], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox["D", "B"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "+", 
       RowBox[{
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gK_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["K",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["\[Sigma]",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["D", "A"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            RowBox[{"6", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "+", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FrameBox[
          SubscriptBox["gJK", "1"],
          Background->RGBColor[0.87, 0.94, 1],
          BaseStyle->RGBColor[0, 0, 1],
          FrameMargins->Tiny,
          StripOnInput->False]}], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "-", 
       RowBox[{"2", " ", 
        FrameBox[
         SubscriptBox["gJK", "2"],
         Background->RGBColor[0.87, 0.94, 1],
         BaseStyle->RGBColor[0, 0, 1],
         FrameMargins->Tiny,
         StripOnInput->False], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gKD_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["B",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           StyleBox["\[Sigma]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
       RowBox[{
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FrameBox[
          SubscriptBox["gJK", "1"],
          Background->RGBColor[0.87, 0.94, 1],
          BaseStyle->RGBColor[0, 0, 1],
          FrameMargins->Tiny,
          StripOnInput->False]}], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{
        FrameBox[
         SubscriptBox["gJK", "2"],
         Background->RGBColor[0.87, 0.94, 1],
         BaseStyle->RGBColor[0, 0, 1],
         FrameMargins->Tiny,
         StripOnInput->False], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gSig_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "-", 
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
     RowBox[{"r", " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "+", 
        RowBox[{"3", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
     RowBox[{"3", " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}]], "-", 
    FractionBox[
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "3"]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fA_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], "+", 
       RowBox[{
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "-", 
       RowBox[{"2", " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fB_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], "r"], "+", 
    RowBox[{
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "B"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fK1_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["K", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}]}], ")"}], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "-", 
    RowBox[{
     FrameBox[
      SubscriptBox["fJK", "1"],
      Background->RGBColor[1, 0.85, 0.85],
      BaseStyle->RGBColor[1, 0, 0],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "-", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"]}]], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fK2_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["K", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], ")"}], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "-", 
    RowBox[{
     FrameBox[
      SubscriptBox["fJK", "2"],
      Background->RGBColor[1, 0.85, 0.85],
      BaseStyle->RGBColor[1, 0, 0],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          RowBox[{"4", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fDA_t\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "rr"], 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}],
     HoldForm], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "A"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "-", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "-", 
       RowBox[{
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fDB_t\"\>", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      FractionBox[
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "r"]}],
     HoldForm], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "B"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fK_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        OverscriptBox["K", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FrameBox[
          SubscriptBox["fJK", "1"],
          Background->RGBColor[1, 0.85, 0.85],
          BaseStyle->RGBColor[1, 0, 0],
          FrameMargins->Tiny,
          StripOnInput->False]}], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "-", 
       RowBox[{"2", " ", 
        FrameBox[
         SubscriptBox["fJK", "2"],
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             OverscriptBox["\[Sigma]", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "A"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            RowBox[{"6", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fKD_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FrameBox[
          SubscriptBox["fJK", "1"],
          Background->RGBColor[1, 0.85, 0.85],
          BaseStyle->RGBColor[1, 0, 0],
          FrameMargins->Tiny,
          StripOnInput->False]}], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       RowBox[{
        FrameBox[
         SubscriptBox["fJK", "2"],
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            OverscriptBox["\[Sigma]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "+", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
       RowBox[{
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fSig_t\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]], "+", 
    FractionBox[
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "-", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
     RowBox[{"r", " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "+", 
        RowBox[{"3", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
     RowBox[{"3", " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_D_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], " ", 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["D", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      RowBox[{"2", " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["D", "^"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}],
          HoldForm]}], " ", 
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_S_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], " ", 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{"2", " ", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["S", "^"], "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      RowBox[{"2", " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["S", "^"], "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}],
          HoldForm]}], " ", 
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
       RowBox[{
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], "+", 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], "+", 
          RowBox[{
           StyleBox[
            SuperscriptBox["v", "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["S", "^"], "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_tau_t\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], " ", 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Tau]", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      RowBox[{"2", " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["\[Tau]", "^"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}],
          HoldForm]}], " ", 
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "-", 
       FractionBox[
        RowBox[{
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
       RowBox[{
        StyleBox[
         SuperscriptBox["v", "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], " ", 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_v\"\>", "\[Rule]", 
   FractionBox[
    StyleBox[
     SubscriptBox[
      OverscriptBox["S", "^"], "r"],
     StripOnInput->False,
     LineColor->RGBColor[0.5, 0, 0.5],
     FrontFaceColor->RGBColor[0.5, 0, 0.5],
     BackFaceColor->RGBColor[0.5, 0, 0.5],
     GraphicsColor->RGBColor[0.5, 0, 0.5],
     FontColor->RGBColor[0.5, 0, 0.5]], 
    RowBox[{
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], "+", 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_V\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     StyleBox[
      SuperscriptBox["v", "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "-", 
    StyleBox["\[Beta]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_v_r\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}],
       HoldForm], " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm]}], ")"}], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}], " ", 
      StyleBox[
       SubscriptBox["D", "A"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_rho\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["D", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "+", 
     StyleBox[
      OverscriptBox["\[Tau]", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_j\"\>", "\[Rule]", 
   FractionBox[
    StyleBox[
     SubscriptBox[
      OverscriptBox["S", "^"], "r"],
     StripOnInput->False,
     LineColor->RGBColor[0.5, 0, 0.5],
     FrontFaceColor->RGBColor[0.5, 0, 0.5],
     BackFaceColor->RGBColor[0.5, 0, 0.5],
     GraphicsColor->RGBColor[0.5, 0, 0.5],
     FontColor->RGBColor[0.5, 0, 0.5]], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_J1\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     StyleBox[
      SuperscriptBox["v", "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["S", "^"], "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_pf_J2\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gC_rho\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      FractionBox[
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Sigma]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "+", 
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]}], 
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], "-", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fC_rho\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      FractionBox[
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Sigma]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "+", 
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}]}], 
     SuperscriptBox[
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"], "-", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gC_j\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      StyleBox[
       SubscriptBox["K", "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], "r"], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "+", 
       RowBox[{"3", " ", 
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fC_j\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], "r"], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{"3", " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_bimConsLaw\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_1\"\>", "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      FractionBox[
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Sigma]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "+", 
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]}], 
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], "-", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], "-", 
    RowBox[{
     FrameBox["g\[Rho]",
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_2\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FrameBox["f\[Rho]",
       Background->RGBColor[1, 0.85, 0.85],
       BaseStyle->RGBColor[1, 0, 0],
       FrameMargins->Tiny,
       StripOnInput->False]}], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      FractionBox[
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Sigma]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "+", 
      RowBox[{"2", " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}]}], 
     SuperscriptBox[
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"], "-", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_3\"\>", "\[Rule]", 
   RowBox[{
    RowBox[{
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "3"], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          RowBox[{"3", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
       FractionBox[
        RowBox[{
         StyleBox[
          SubscriptBox["\[Kappa]", "g"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}]]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       SuperscriptBox[
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "2"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], "r"], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     SuperscriptBox[
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], "2"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{"3", " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_C_4\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_g_rho\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["D", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "+", 
     StyleBox[
      OverscriptBox["\[Tau]", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_g_j\"\>", "\[Rule]", 
   FractionBox[
    StyleBox[
     SubscriptBox[
      OverscriptBox["S", "^"], "r"],
     StripOnInput->False,
     LineColor->RGBColor[0.5, 0, 0.5],
     FrontFaceColor->RGBColor[0.5, 0, 0.5],
     BackFaceColor->RGBColor[0.5, 0, 0.5],
     GraphicsColor->RGBColor[0.5, 0, 0.5],
     FontColor->RGBColor[0.5, 0, 0.5]], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_g_JK1\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["D", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "+", 
     StyleBox[
      OverscriptBox["\[Tau]", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "+", 
     RowBox[{
      StyleBox[
       SuperscriptBox["v", "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
    RowBox[{"2", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_g_JK2\"\>", "\[Rule]", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["D", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "+", 
     StyleBox[
      OverscriptBox["\[Tau]", "^"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "-", 
     RowBox[{
      StyleBox[
       SuperscriptBox["v", "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
    RowBox[{"2", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_f_rho\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_f_j\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_f_JK1\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_f_JK2\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_p_g\"\>", "\[Rule]", "Indeterminate"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_p_f\"\>", "\[Rule]", "Indeterminate"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_p_t\"\>", "\[Rule]", "Indeterminate"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gHorz\"\>", "\[Rule]", 
   RowBox[{
    FractionBox["1", "r"], "+", 
    StyleBox[
     SubscriptBox["D", "B"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fHorz\"\>", "\[Rule]", 
   RowBox[{
    FractionBox["1", "r"], "+", 
    StyleBox[
     SubscriptBox[
      OverscriptBox["D", "~"], "B"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gW\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fW\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_cW\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gBet\"\>", "\[Rule]", 
   StyleBox["q",
    StripOnInput->False,
    LineColor->RGBColor[0, 
      Rational[2, 3], 0],
    FrontFaceColor->RGBColor[0, 
      Rational[2, 3], 0],
    BackFaceColor->RGBColor[0, 
      Rational[2, 3], 0],
    GraphicsColor->RGBColor[0, 
      Rational[2, 3], 0],
    FontColor->RGBColor[0, 
      Rational[2, 3], 0]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fBet\"\>", "\[Rule]", 
   StyleBox["q",
    StripOnInput->False,
    LineColor->RGBColor[0, 
      Rational[2, 3], 0],
    FrontFaceColor->RGBColor[0, 
      Rational[2, 3], 0],
    BackFaceColor->RGBColor[0, 
      Rational[2, 3], 0],
    GraphicsColor->RGBColor[0, 
      Rational[2, 3], 0],
    FontColor->RGBColor[0, 
      Rational[2, 3], 0]]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gBet_r\"\>", "\[Rule]", 
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fBet_r\"\>", "\[Rule]", 
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gBetr_r\"\>", "\[Rule]", 
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     FractionBox[
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "r"]}],
    HoldForm]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fBetr_r\"\>", "\[Rule]", 
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     FractionBox[
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "r"]}],
    HoldForm]}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_q\"\>", "\[Rule]", "0"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_gAlp\"\>", "\[Rule]", "1"}],
  StripOnInput->False,
  FontSize->14]], "Echo"],

Cell[BoxData[
 StyleBox[
  RowBox[{"\<\"eq_fAlp\"\>", "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"gW", " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], "fW"]}]}],
  StripOnInput->False,
  FontSize->14]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equations of Motion", "Subsubsection",
 PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{"\"\<The evolution equations for g\>\"", ",", "EoM$gEvol"}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The evolution equations for g\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}],
          HoldForm], " ", 
         SuperscriptBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]]}], "+", 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["q",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}],
          HoldForm], "+", 
         RowBox[{
          StyleBox["q",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], 
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}], "+", 
        FractionBox[
         RowBox[{
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}]]}], "r"], "+", 
      RowBox[{
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "+", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}]}], ")"}], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          RowBox[{"2", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}]}], ")"}], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{"3", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       FrameBox[
        SubscriptBox["gJK", "1"],
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], ")"}], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], ")"}], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{"3", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           StyleBox["\[Sigma]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], 
           RowBox[{
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]], "+", 
          FractionBox[
           RowBox[{
            StyleBox["\[Sigma]",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "-", 
            RowBox[{"4", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "-", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       FrameBox[
        SubscriptBox["gJK", "2"],
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "rr"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}],
              HoldForm], ")"}], "2"]}], "+", 
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"]}], "-", 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"], " ", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"], " ", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "5"]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "rr"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], "-", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           RowBox[{"2", " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]}], 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "3"]}]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], "-", 
            RowBox[{"2", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], "-", 
            RowBox[{
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "+", 
               RowBox[{"2", " ", 
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       RowBox[{"r", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "-", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             FractionBox[
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], "r"]}],
            HoldForm], "+", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]}], 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "3"]}]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], "+", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm], "+", 
            RowBox[{
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["K",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["K",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            StyleBox["\[Sigma]",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], 
           RowBox[{
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["\[Sigma]",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "+", 
              RowBox[{"2", " ", 
               StyleBox[
                SubscriptBox["D", "A"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "-", 
              RowBox[{"6", " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "-", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
           RowBox[{"2", " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FrameBox[
            SubscriptBox["gJK", "1"],
            Background->RGBColor[0.87, 0.94, 1],
            BaseStyle->RGBColor[0, 0, 1],
            FrameMargins->Tiny,
            StripOnInput->False]}], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         RowBox[{"2", " ", 
          FrameBox[
           SubscriptBox["gJK", "2"],
           Background->RGBColor[0.87, 0.94, 1],
           BaseStyle->RGBColor[0, 0, 1],
           FrameMargins->Tiny,
           StripOnInput->False], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            StyleBox["\[Sigma]",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], 
            RowBox[{
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]]}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"-", 
             StyleBox["\[Sigma]",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "+", 
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "+", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FrameBox[
            SubscriptBox["gJK", "1"],
            Background->RGBColor[0.87, 0.94, 1],
            BaseStyle->RGBColor[0, 0, 1],
            FrameMargins->Tiny,
            StripOnInput->False]}], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         RowBox[{
          FrameBox[
           SubscriptBox["gJK", "2"],
           Background->RGBColor[0.87, 0.94, 1],
           BaseStyle->RGBColor[0, 0, 1],
           FrameMargins->Tiny,
           StripOnInput->False], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          FractionBox[
           StyleBox["q",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "r"]}],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["q",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "-", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]], "+", 
        FractionBox[
         RowBox[{
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "+", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
         RowBox[{
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}]]}], "r"], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            FractionBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "r"]}],
           HoldForm], 
          RowBox[{
           StyleBox["B",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "3"]}]], "+", 
         FractionBox[
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              TagBox[
               RowBox[{
                SubscriptBox["\[PartialD]", "r"], 
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}],
               HoldForm]}], "+", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], "+", 
             RowBox[{"3", " ", 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], " ", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
          RowBox[{"3", " ", 
           StyleBox["B",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{"2", " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "-", 
      FractionBox[
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "3"]}]]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_gA_t"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{
  "\"\<The evolution equations for g (in split form)\>\"", ",", 
   "splitEoM$gEvol"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The evolution equations for g (in split form)\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "2"], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       SuperscriptBox[
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "3"]], "+", 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["D", "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], 
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"],
        HoldForm], " ", 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "r"],
         HoldForm], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm]}], "\<\" \[Equal] \"\>", 
     FractionBox[
      RowBox[{"2", " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "-", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "+", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}]}], ")"}], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          RowBox[{"2", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}]}], ")"}], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{"3", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       FrameBox[
        SubscriptBox["gJK", "1"],
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        StyleBox[
         SubscriptBox["K", "2"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         StyleBox["\[Sigma]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          RowBox[{"4", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "-", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], ")"}], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], ")"}], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{"3", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "-", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       FrameBox[
        SubscriptBox["gJK", "2"],
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "rr"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}],
              HoldForm], ")"}], "2"]}], "+", 
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"]}], "-", 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"], " ", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"], " ", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "5"]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "rr"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], "-", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           RowBox[{"2", " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]}], 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "3"]}]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], "-", 
            RowBox[{"2", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], "-", 
            RowBox[{
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "+", 
               RowBox[{"2", " ", 
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           FractionBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "r"],
           HoldForm], ")"}], "2"], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "r"],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "-", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             FractionBox[
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], "r"]}],
            HoldForm], "+", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]}], 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "3"]}]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], "+", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm], "+", 
            RowBox[{
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        StyleBox["K",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["\[Sigma]",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["D", "A"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            RowBox[{"6", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "-", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["K",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["K",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
           RowBox[{"2", " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FrameBox[
            SubscriptBox["gJK", "1"],
            Background->RGBColor[0.87, 0.94, 1],
            BaseStyle->RGBColor[0, 0, 1],
            FrameMargins->Tiny,
            StripOnInput->False]}], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         RowBox[{"2", " ", 
          FrameBox[
           SubscriptBox["gJK", "2"],
           Background->RGBColor[0.87, 0.94, 1],
           BaseStyle->RGBColor[0, 0, 1],
           FrameMargins->Tiny,
           StripOnInput->False], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["B",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           StyleBox["\[Sigma]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "+", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
         RowBox[{
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FrameBox[
            SubscriptBox["gJK", "1"],
            Background->RGBColor[0.87, 0.94, 1],
            BaseStyle->RGBColor[0, 0, 1],
            FrameMargins->Tiny,
            StripOnInput->False]}], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         RowBox[{
          FrameBox[
           SubscriptBox["gJK", "2"],
           Background->RGBColor[0.87, 0.94, 1],
           BaseStyle->RGBColor[0, 0, 1],
           FrameMargins->Tiny,
           StripOnInput->False], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          FractionBox[
           StyleBox["q",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "r"]}],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           FractionBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "r"],
           HoldForm], ")"}], "2"], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["q",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "r"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "r"],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       RowBox[{
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            FractionBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "r"]}],
           HoldForm], 
          RowBox[{
           StyleBox["B",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "3"]}]], "+", 
         FractionBox[
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              TagBox[
               RowBox[{
                SubscriptBox["\[PartialD]", "r"], 
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}],
               HoldForm]}], "+", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], "+", 
             RowBox[{"3", " ", 
              StyleBox[
               SubscriptBox["D", "B"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], " ", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
          RowBox[{"3", " ", 
           StyleBox["B",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{"2", " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "-", 
      FractionBox[
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "3"]}]]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_gA_t"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{"\"\<The evolution equations for f\>\"", ",", "EoM$fEvol"}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The evolution equations for f\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "2"], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       SuperscriptBox[
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "3"]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["q",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}],
          HoldForm], "+", 
         RowBox[{
          StyleBox["q",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        FractionBox[
         RowBox[{
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         RowBox[{
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]]}], "r"], "+", 
      RowBox[{
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "+", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}]}], ")"}], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "+", 
          RowBox[{"2", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}]}], ")"}], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"3", " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      RowBox[{
       FrameBox[
        SubscriptBox["fJK", "1"],
        Background->RGBColor[1, 0.85, 0.85],
        BaseStyle->RGBColor[1, 0, 0],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]}]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "B"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], ")"}], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], ")"}], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"3", " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      RowBox[{
       FrameBox[
        SubscriptBox["fJK", "2"],
        Background->RGBColor[1, 0.85, 0.85],
        BaseStyle->RGBColor[1, 0, 0],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           StyleBox[
            OverscriptBox["\[Sigma]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], 
           RowBox[{
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]], "+", 
          FractionBox[
           RowBox[{
            StyleBox[
             OverscriptBox["\[Sigma]", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "-", 
            RowBox[{"4", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           SuperscriptBox[
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "-", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "rr"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}],
              HoldForm], ")"}], "2"]}], "-", 
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"]}], "+", 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"], " ", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "5"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "rr"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm]}], "+", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           RowBox[{"2", " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "3"], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm]}], "-", 
            RowBox[{"2", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm]}], "-", 
            RowBox[{
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], "+", 
               RowBox[{"2", " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       RowBox[{"r", " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "-", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              FractionBox[
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "r"]}],
             HoldForm], "+", 
            RowBox[{
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}],
              HoldForm], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], 
           RowBox[{
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "3"], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm]}], "+", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["K", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["K", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FrameBox[
            SubscriptBox["fJK", "1"],
            Background->RGBColor[1, 0.85, 0.85],
            BaseStyle->RGBColor[1, 0, 0],
            FrameMargins->Tiny,
            StripOnInput->False]}], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          FrameBox[
           SubscriptBox["fJK", "2"],
           Background->RGBColor[1, 0.85, 0.85],
           BaseStyle->RGBColor[1, 0, 0],
           FrameMargins->Tiny,
           StripOnInput->False], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            StyleBox[
             OverscriptBox["\[Sigma]", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           RowBox[{
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["\[Sigma]", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "+", 
              RowBox[{"2", " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "A"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "-", 
              RowBox[{"6", " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "B"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
           SuperscriptBox[
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
           RowBox[{"2", " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "B"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FrameBox[
            SubscriptBox["fJK", "1"],
            Background->RGBColor[1, 0.85, 0.85],
            BaseStyle->RGBColor[1, 0, 0],
            FrameMargins->Tiny,
            StripOnInput->False]}], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{
          FrameBox[
           SubscriptBox["fJK", "2"],
           Background->RGBColor[1, 0.85, 0.85],
           BaseStyle->RGBColor[1, 0, 0],
           FrameMargins->Tiny,
           StripOnInput->False], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            StyleBox[
             OverscriptBox["\[Sigma]", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             StyleBox[
              OverscriptBox["B", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"-", 
             StyleBox[
              OverscriptBox["\[Sigma]", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           SuperscriptBox[
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "+", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
         RowBox[{
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          FractionBox[
           StyleBox["q",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "r"]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "f"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          StyleBox["q",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "-", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]], "+", 
        FractionBox[
         RowBox[{
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "-", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
         RowBox[{
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]]}], "r"], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             FractionBox[
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], "r"]}],
            HoldForm], 
           RowBox[{
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "3"], " ", 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
         FractionBox[
          RowBox[{
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              TagBox[
               RowBox[{
                SubscriptBox["\[PartialD]", "r"], 
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}],
               HoldForm]}], "+", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm], "+", 
             RowBox[{"3", " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
          RowBox[{"3", " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_fA_t"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{
  "\"\<The evolution equations for f (in split form)\>\"", ",", 
   "splitEoM$fEvol"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The evolution equations for f (in split form)\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "2"], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       SuperscriptBox[
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "3"]], "+", 
      RowBox[{
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "r"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "1"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm]}], "\<\" \[Equal] \"\>", 
     FractionBox[
      RowBox[{"2", " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "-", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"]]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "+", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}]}], ")"}], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "+", 
          RowBox[{"2", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}]}], ")"}], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"3", " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      RowBox[{
       FrameBox[
        SubscriptBox["fJK", "1"],
        Background->RGBColor[1, 0.85, 0.85],
        BaseStyle->RGBColor[1, 0, 0],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "B"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "2"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          RowBox[{"4", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], ")"}], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], ")"}], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"3", " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      RowBox[{
       FrameBox[
        SubscriptBox["fJK", "2"],
        Background->RGBColor[1, 0.85, 0.85],
        BaseStyle->RGBColor[1, 0, 0],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "-", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "rr"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}],
              HoldForm], ")"}], "2"]}], "-", 
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], " ", 
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"]}], "+", 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "4"], " ", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "5"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "rr"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm]}], "+", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           RowBox[{"2", " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], 
          RowBox[{
           SuperscriptBox[
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "3"], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm]}], "-", 
            RowBox[{"2", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm]}], "-", 
            RowBox[{
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], "+", 
               RowBox[{"2", " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           FractionBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "r"],
           HoldForm], ")"}], "2"], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "B"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "r"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "-", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              FractionBox[
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "r"]}],
             HoldForm], "+", 
            RowBox[{
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}],
              HoldForm], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], 
           RowBox[{
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "3"], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm]}], "+", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        StyleBox[
         OverscriptBox["K", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             OverscriptBox["\[Sigma]", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "A"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            RowBox[{"6", " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "-", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["K", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["K", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FrameBox[
            SubscriptBox["fJK", "1"],
            Background->RGBColor[1, 0.85, 0.85],
            BaseStyle->RGBColor[1, 0, 0],
            FrameMargins->Tiny,
            StripOnInput->False]}], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          FrameBox[
           SubscriptBox["fJK", "2"],
           Background->RGBColor[1, 0.85, 0.85],
           BaseStyle->RGBColor[1, 0, 0],
           FrameMargins->Tiny,
           StripOnInput->False], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "B"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
           RowBox[{"2", " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "B"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            OverscriptBox["\[Sigma]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FrameBox[
            SubscriptBox["fJK", "1"],
            Background->RGBColor[1, 0.85, 0.85],
            BaseStyle->RGBColor[1, 0, 0],
            FrameMargins->Tiny,
            StripOnInput->False]}], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{
          FrameBox[
           SubscriptBox["fJK", "2"],
           Background->RGBColor[1, 0.85, 0.85],
           BaseStyle->RGBColor[1, 0, 0],
           FrameMargins->Tiny,
           StripOnInput->False], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm]}], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "\[Alpha]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           SuperscriptBox[
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "+", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
         RowBox[{
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          FractionBox[
           StyleBox["q",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "r"]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           FractionBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "r"],
           HoldForm], ")"}], "2"], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "f"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["q",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "r"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "r"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             FractionBox[
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], "r"]}],
            HoldForm], 
           RowBox[{
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "3"], " ", 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
         FractionBox[
          RowBox[{
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              TagBox[
               RowBox[{
                SubscriptBox["\[PartialD]", "r"], 
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}],
               HoldForm]}], "+", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm], "+", 
             RowBox[{"3", " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["D", "~"], "B"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
          RowBox[{"3", " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_fA_t"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{
  "\"\<The evolution equation for the perfect fluid / dust\>\"", ",", 
   "EoM$mEvol"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The evolution equation for the perfect fluid / dust\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["D", "^"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}],
        HoldForm], " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["\[Beta]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         StyleBox[
          SuperscriptBox["v", "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          OverscriptBox["D", "^"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
        RowBox[{"2", " ", 
         StyleBox["\[Beta]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          OverscriptBox["D", "^"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["D", "^"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]]}],
            HoldForm]}], " ", 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SuperscriptBox["v", "r"],
             StripOnInput->False,
             LineColor->RGBColor[0.5, 0, 0.5],
             FrontFaceColor->RGBColor[0.5, 0, 0.5],
             BackFaceColor->RGBColor[0.5, 0, 0.5],
             GraphicsColor->RGBColor[0.5, 0, 0.5],
             FontColor->RGBColor[0.5, 0, 0.5]]}],
           HoldForm], " ", 
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
         RowBox[{
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], " ", 
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}],
        HoldForm], " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      RowBox[{"2", " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["\[Beta]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         StyleBox[
          SuperscriptBox["v", "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
        RowBox[{"2", " ", 
         StyleBox["\[Beta]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["S", "^"], "r"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]]}],
            HoldForm]}], " ", 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SuperscriptBox["v", "r"],
             StripOnInput->False,
             LineColor->RGBColor[0.5, 0, 0.5],
             FrontFaceColor->RGBColor[0.5, 0, 0.5],
             BackFaceColor->RGBColor[0.5, 0, 0.5],
             GraphicsColor->RGBColor[0.5, 0, 0.5],
             FontColor->RGBColor[0.5, 0, 0.5]]}],
           HoldForm], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["S", "^"], "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
         RowBox[{
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], " ", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["S", "^"], "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox[
             OverscriptBox["D", "^"],
             StripOnInput->False,
             LineColor->RGBColor[0.5, 0, 0.5],
             FrontFaceColor->RGBColor[0.5, 0, 0.5],
             BackFaceColor->RGBColor[0.5, 0, 0.5],
             GraphicsColor->RGBColor[0.5, 0, 0.5],
             FontColor->RGBColor[0.5, 0, 0.5]], "+", 
            StyleBox[
             OverscriptBox["\[Tau]", "^"],
             StripOnInput->False,
             LineColor->RGBColor[0.5, 0, 0.5],
             FrontFaceColor->RGBColor[0.5, 0, 0.5],
             BackFaceColor->RGBColor[0.5, 0, 0.5],
             GraphicsColor->RGBColor[0.5, 0, 0.5],
             FontColor->RGBColor[0.5, 0, 0.5]], "+", 
            RowBox[{
             StyleBox[
              SuperscriptBox["v", "r"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["S", "^"], "r"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["\[Tau]", "^"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}],
        HoldForm], " ", 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["\[Beta]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         StyleBox[
          SuperscriptBox["v", "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          OverscriptBox["\[Tau]", "^"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], "+", 
        RowBox[{"2", " ", 
         StyleBox["\[Beta]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          OverscriptBox["\[Tau]", "^"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}]}], "r"], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["\[Tau]", "^"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]]}],
            HoldForm]}], " ", 
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SuperscriptBox["v", "r"],
             StripOnInput->False,
             LineColor->RGBColor[0.5, 0, 0.5],
             FrontFaceColor->RGBColor[0.5, 0, 0.5],
             BackFaceColor->RGBColor[0.5, 0, 0.5],
             GraphicsColor->RGBColor[0.5, 0, 0.5],
             FontColor->RGBColor[0.5, 0, 0.5]]}],
           HoldForm], " ", 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
         RowBox[{
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], " ", 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], " ", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         FractionBox[
          RowBox[{
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["S", "^"], "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}], 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
         RowBox[{
          StyleBox[
           SuperscriptBox["v", "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], " ", 
          StyleBox[
           SubscriptBox["K", "1"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["S", "^"], "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     StyleBox[
      SuperscriptBox["v", "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "\<\" \[Equal] \"\>", 
     FractionBox[
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], 
      RowBox[{
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          OverscriptBox["D", "^"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]], "+", 
         StyleBox[
          OverscriptBox["\[Tau]", "^"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}]}]]},
    {"\<\" \"\>", 
     StyleBox[
      SuperscriptBox["V", "r"],
      StripOnInput->False,
      LineColor->RGBColor[0.5, 0, 0.5],
      FrontFaceColor->RGBColor[0.5, 0, 0.5],
      BackFaceColor->RGBColor[0.5, 0, 0.5],
      GraphicsColor->RGBColor[0.5, 0, 0.5],
      FontColor->RGBColor[0.5, 0, 0.5]], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      StyleBox["\[Beta]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     FractionBox[
      RowBox[{
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["S", "^"], "r"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}],
         HoldForm], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], "+", 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["D", "^"],
             StripOnInput->False,
             LineColor->RGBColor[0.5, 0, 0.5],
             FrontFaceColor->RGBColor[0.5, 0, 0.5],
             BackFaceColor->RGBColor[0.5, 0, 0.5],
             GraphicsColor->RGBColor[0.5, 0, 0.5],
             FontColor->RGBColor[0.5, 0, 0.5]]}],
           HoldForm], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["\[Tau]", "^"],
             StripOnInput->False,
             LineColor->RGBColor[0.5, 0, 0.5],
             FrontFaceColor->RGBColor[0.5, 0, 0.5],
             BackFaceColor->RGBColor[0.5, 0, 0.5],
             GraphicsColor->RGBColor[0.5, 0, 0.5],
             FontColor->RGBColor[0.5, 0, 0.5]]}],
           HoldForm]}], ")"}], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], "+", 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}], " ", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["S", "^"], "r"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
      RowBox[{
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           OverscriptBox["D", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]], "+", 
          StyleBox[
           OverscriptBox["\[Tau]", "^"],
           StripOnInput->False,
           LineColor->RGBColor[0.5, 0, 0.5],
           FrontFaceColor->RGBColor[0.5, 0, 0.5],
           BackFaceColor->RGBColor[0.5, 0, 0.5],
           GraphicsColor->RGBColor[0.5, 0, 0.5],
           FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}], "2"]}]]},
    {"\<\" \"\>", 
     FrameBox["pf\[Rho]",
      Background->RGBColor[1, 0.9, 0.8],
      BaseStyle->RGBColor[1, 0.5, 0],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     FractionBox[
      RowBox[{
       StyleBox[
        OverscriptBox["D", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], "+", 
       StyleBox[
        OverscriptBox["\[Tau]", "^"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       SuperscriptBox[
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]]},
    {"\<\" \"\>", 
     FrameBox["pfj",
      Background->RGBColor[1, 0.9, 0.8],
      BaseStyle->RGBColor[1, 0.5, 0],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     FractionBox[
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]], 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       SuperscriptBox[
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]]},
    {"\<\" \"\>", 
     FrameBox[
      SubscriptBox["pfJ", "1"],
      Background->RGBColor[1, 0.9, 0.8],
      BaseStyle->RGBColor[1, 0.5, 0],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     FractionBox[
      RowBox[{
       StyleBox[
        SuperscriptBox["v", "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]]}], 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       SuperscriptBox[
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]]},
    {"\<\" \"\>", 
     FrameBox[
      SubscriptBox["pfJ", "2"],
      Background->RGBColor[1, 0.9, 0.8],
      BaseStyle->RGBColor[1, 0.5, 0],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", "0"}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_pf_D_t"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{
  "\"\<The constraint equations (without sources)\>\"", ",", "EoM$constr1"}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The constraint equations (without sources)\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     SubscriptBox["C", 
      RowBox[{"g", ",", "sc"}]], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         StyleBox["\[Sigma]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "-", 
          RowBox[{"6", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], "r"], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", 
      RowBox[{"f", ",", "sc"}]], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          RowBox[{"6", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], "r"], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", 
      RowBox[{"g", ",", "vec"}]], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "r"], "+", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm]}], "+", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], "+", 
         RowBox[{"3", " ", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", 
      RowBox[{"f", ",", "vec"}]], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "r"], "+", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "+", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "+", 
         RowBox[{"3", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "bim"], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}], 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]]}], ")"}]}], "r"], "+", 
      RowBox[{
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm]}], "+", 
            RowBox[{"3", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "3"]}], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "2"],
           HoldForm], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "1"],
           HoldForm], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "-", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_gC_rho"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{
  "\"\<The constraint equations (without sources)(split form)\>\"", ",", 
   "splitEoM$constr1"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The constraint equations (without sources)(split form)\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox["C", 
       RowBox[{"g", ",", "sc"}]]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Sigma]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", 
      RowBox[{"g", ",", "sc"}]], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox["C", 
       RowBox[{"f", ",", "sc"}]]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Sigma]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", 
      RowBox[{"f", ",", "sc"}]], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox["C", 
       RowBox[{"g", ",", "vec"}]]}], "\<\" \[Equal] \"\>", 
     RowBox[{"2", " ", 
      StyleBox[
       SubscriptBox["K", "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", 
      RowBox[{"g", ",", "vec"}]], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["K",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "+", 
        RowBox[{"3", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox["C", 
       RowBox[{"f", ",", "vec"}]]}], "\<\" \[Equal] \"\>", 
     RowBox[{"2", " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", 
      RowBox[{"f", ",", "vec"}]], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["K", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "+", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "+", 
        RowBox[{"3", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "bim"], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]], "+", 
      RowBox[{
       TagBox[
        FractionBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"],
        HoldForm], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}], 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]]}], ")"}]}], "+", 
      RowBox[{
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm]}], "+", 
            RowBox[{"3", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "3"]}], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "2"],
           HoldForm], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "1"],
           HoldForm], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "-", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_invr_gC_rho"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{"\"\<The g-sources\>\"", ",", 
   RowBox[{"EoM$sources", "\[LeftDoubleBracket]", 
    RowBox[{";;", "4"}], "\[RightDoubleBracket]"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The g-sources\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     FrameBox["g\[Rho]",
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "0", "2"],
        HoldForm]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]}]], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]]}]},
    {"\<\" \"\>", 
     FrameBox["gj",
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm]}], " ", 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]}]]}]},
    {"\<\" \"\>", 
     FrameBox[
      SubscriptBox["gJK", "1"],
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "0", "1"],
        HoldForm]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"2", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm]}], "+", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         RowBox[{"2", " ", 
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}]], "-", 
        FractionBox[
         RowBox[{
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
            "1"],
           HoldForm], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]]}], 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        RowBox[{
         StyleBox[
          SuperscriptBox["v", "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
       RowBox[{"2", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]}]]}]},
    {"\<\" \"\>", 
     FrameBox[
      SubscriptBox["gJK", "2"],
      Background->RGBColor[0.87, 0.94, 1],
      BaseStyle->RGBColor[0, 0, 1],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "0", "2"],
        HoldForm]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"2", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"2", " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["D", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "+", 
        StyleBox[
         OverscriptBox["\[Tau]", "^"],
         StripOnInput->False,
         LineColor->RGBColor[0.5, 0, 0.5],
         FrontFaceColor->RGBColor[0.5, 0, 0.5],
         BackFaceColor->RGBColor[0.5, 0, 0.5],
         GraphicsColor->RGBColor[0.5, 0, 0.5],
         FontColor->RGBColor[0.5, 0, 0.5]], "-", 
        RowBox[{
         StyleBox[
          SuperscriptBox["v", "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
       RowBox[{"2", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]}]]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_g_rho"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{"\"\<The f-sources\>\"", ",", 
   RowBox[{"EoM$sources", "\[LeftDoubleBracket]", 
    RowBox[{
     RowBox[{"-", "4"}], ";;"}], "\[RightDoubleBracket]"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The f-sources\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     FrameBox["f\[Rho]",
      Background->RGBColor[1, 0.85, 0.85],
      BaseStyle->RGBColor[1, 0, 0],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "2"],
         HoldForm], 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"]]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}]},
    {"\<\" \"\>", 
     FrameBox["fj",
      Background->RGBColor[1, 0.85, 0.85],
      BaseStyle->RGBColor[1, 0, 0],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     FractionBox[
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
        HoldForm], " ", 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       SuperscriptBox[
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], " ", 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["B", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"]]},
    {"\<\" \"\>", 
     FrameBox[
      SubscriptBox["fJK", "1"],
      Background->RGBColor[1, 0.85, 0.85],
      BaseStyle->RGBColor[1, 0, 0],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "3", "1"],
         HoldForm], 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], "-", 
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox[
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "2"], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]], "-", 
         FractionBox[
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], 
          RowBox[{
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}]}]},
    {"\<\" \"\>", 
     FrameBox[
      SubscriptBox["fJK", "2"],
      Background->RGBColor[1, 0.85, 0.85],
      BaseStyle->RGBColor[1, 0, 0],
      FrameMargins->Tiny,
      StripOnInput->False], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "2"],
         HoldForm], 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"]]}], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_f_rho"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{"\"\<The constraint equations\>\"", ",", "EoM$constr2"}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The constraint equations\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     SubscriptBox["C", "1"], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         StyleBox["\[Sigma]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "-", 
          RowBox[{"6", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], "r"], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], "-", 
      RowBox[{
       FrameBox["g\[Rho]",
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "2"], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox["f\[Rho]",
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]], "+", 
        FractionBox[
         RowBox[{
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "+", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          RowBox[{"6", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], "r"], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "3"], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], "+", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm], "+", 
            RowBox[{"3", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
         FractionBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Kappa]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["S", "^"], "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}], 
          RowBox[{"2", " ", 
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["\[Kappa]", "f"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "+", 
        RowBox[{
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox["\[Kappa]", "g"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], "r"], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       SuperscriptBox[
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "2"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "+", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "+", 
         RowBox[{"3", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "4"], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}], 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]]}], ")"}]}], "r"], "+", 
      RowBox[{
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm]}], "+", 
            RowBox[{"3", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "3"]}], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "2"],
           HoldForm], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "1"],
           HoldForm], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "-", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_C_1"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{
  "\"\<The constraint equations (split form)\>\"", ",", "splitEoM$constr2"}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The constraint equations (split form)\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox["C", "1"]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Sigma]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "1"], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox["K",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["K", "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], "-", 
      RowBox[{
       FrameBox["g\[Rho]",
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox["C", "2"]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Sigma]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"6", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "2"], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox["f\[Rho]",
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "+", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], "-", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox["C", "3"]}], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       SuperscriptBox[
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "2"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "3"], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm]}], "+", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm], "+", 
            RowBox[{"3", " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
         FractionBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Kappa]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["S", "^"], "r"],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]]}], 
          RowBox[{"2", " ", 
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"]}]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       SuperscriptBox[
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "2"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "+", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "+", 
         RowBox[{"3", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]},
    {"\<\" \"\>", 
     SubscriptBox["C", "4"], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]], "+", 
      RowBox[{
       TagBox[
        FractionBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"],
        HoldForm], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}], 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]]}], ")"}]}], "+", 
      RowBox[{
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm]}], "+", 
            RowBox[{"3", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["K", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "3"]}], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "2"],
           HoldForm], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "1"],
           HoldForm], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "-", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            RowBox[{
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_invr_C_1"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{"\"\<The p-equations\>\"", ",", "EoM$pEqs"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The p-equations\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     SubscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "g"], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["K", "\[CapitalDelta]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        RowBox[{"r", " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox["\[Kappa]", "g"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          RowBox[{"3", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["K", "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
       RowBox[{"3", " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]], "+", 
      FractionBox[
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}]},
    {"\<\" \"\>", 
     SubscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "f"], "\<\" \[Equal] \"\>", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{"r", " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "f"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "+", 
          RowBox[{"3", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
       RowBox[{"3", " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "f"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             StyleBox["\[Alpha]",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox[
              OverscriptBox["B", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm], " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}], ")"}], " ", 
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             OverscriptBox["\[Alpha]", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}], ")"}], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "r"], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], " ", 
             StyleBox[
              OverscriptBox["B", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]]}], " ", 
                StyleBox["\[Sigma]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               StyleBox[
                OverscriptBox["\[Sigma]", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm], " ", 
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]]}], "-", 
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]]}], ")"}]}], 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             StyleBox[
              OverscriptBox["B", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox["\[Sigma]",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "-", 
               RowBox[{
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], " ", 
                StyleBox[
                 OverscriptBox["\[Sigma]", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm], " ", 
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]], "+", 
           RowBox[{
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 StyleBox[
                  SubscriptBox["D", "B"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm]]}], "-", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]], "+", 
      RowBox[{
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            FractionBox[
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "-", 
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm]}], "+", 
                RowBox[{"3", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm]}]}], ")"}], " ", 
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], "+", 
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
          RowBox[{"3", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]}]]}], ")"}]}]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_p_g"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{"\"\<The p-equations (split form)\>\"", ",", "splitEoM$pEqs"}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The p-equations (split form)\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "g"]}], "\<\" \[Equal] \"\>", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox[
         SubscriptBox["\[Kappa]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]]}]},
    {"\<\" \"\>", 
     SubscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "g"], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "+", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "+", 
           RowBox[{"3", " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox["\[Kappa]", "g"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]]}], "+", 
      FractionBox[
       StyleBox[
        SubscriptBox[
         OverscriptBox["S", "^"], "r"],
        StripOnInput->False,
        LineColor->RGBColor[0.5, 0, 0.5],
        FrontFaceColor->RGBColor[0.5, 0, 0.5],
        BackFaceColor->RGBColor[0.5, 0, 0.5],
        GraphicsColor->RGBColor[0.5, 0, 0.5],
        FontColor->RGBColor[0.5, 0, 0.5]], 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}]},
    {"\<\" \"\>", 
     RowBox[{"r", " ", 
      SubscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "f"]}], "\<\" \[Equal] \"\>", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], 
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
        HoldForm], " ", 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       SuperscriptBox[
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]]},
    {"\<\" \"\>", 
     SubscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "f"], "\<\" \[Equal] \"\>", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm]}], "+", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "\[CapitalDelta]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], "+", 
         RowBox[{"3", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "\[CapitalDelta]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
      RowBox[{"3", " ", 
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
        HoldForm], " ", 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       SuperscriptBox[
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"], " ", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], "+", 
      RowBox[{
       TagBox[
        FractionBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"],
        HoldForm], " ", 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            StyleBox["\[Alpha]",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}], ")"}], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}], ")"}], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], " ", 
             StyleBox[
              OverscriptBox["B", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]]}], " ", 
                StyleBox["\[Sigma]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               StyleBox[
                OverscriptBox["\[Sigma]", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm], " ", 
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]]}], "-", 
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]]}], ")"}]}], 
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]], "+", 
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             StyleBox[
              OverscriptBox["B", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox["\[Sigma]",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "-", 
               RowBox[{
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], " ", 
                StyleBox[
                 OverscriptBox["\[Sigma]", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm], " ", 
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]], "+", 
           RowBox[{
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"2", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], " ", 
                 StyleBox[
                  SubscriptBox["D", "B"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm]]}], "-", 
              StyleBox[
               SubscriptBox["D", "\[Alpha]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]], "+", 
      RowBox[{
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "3"], " ", 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "+", 
            FractionBox[
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              RowBox[{"(", 
               RowBox[{
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "-", 
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm]], "+", 
            RowBox[{"2", " ", 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm]}], "+", 
                RowBox[{"3", " ", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm]}]}], ")"}], " ", 
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], "+", 
             RowBox[{"2", " ", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
          RowBox[{"3", " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm]}]]}], ")"}]}]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_invr_p_g"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{"\"\<The shifts\>\"", ",", "EoM$shifts"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The shifts\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], "\<\" \[Equal] \"\>", 
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}]},
    {"\<\" \"\>", 
     StyleBox[
      OverscriptBox["\[Beta]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "\<\" \[Equal] \"\>", 
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["\[Beta]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        OverscriptBox["\[Beta]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        UnderscriptBox[
         StyleBox["\[Beta]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "_"], "r"]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          FractionBox[
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "r"]}],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       RowBox[{"r", " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}]},
    {"\<\" \"\>", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        UnderscriptBox[
         StyleBox[
          OverscriptBox["\[Beta]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "_"], "r"]}],
      HoldForm], "\<\" \[Equal] \"\>", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        FractionBox[
         StyleBox["q",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"]}],
       HoldForm], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          FractionBox[
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "r"]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       RowBox[{"r", " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_gBet"]
}, {2}]],

Cell[TextData[{
 "The lapse factors ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "g"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "f"], TraditionalForm]]],
 " such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", "\[VeryThinSpace]", 
        SubscriptBox["W", "g"]}], "+", "\[VeryThinSpace]", 
       RowBox[{
        OverscriptBox["\[Alpha]", "~"], 
        SubscriptBox["W", "f"]}]}], ")"}], "/", 
     SubscriptBox["W", "c"]}], "=", "0"}], TraditionalForm]]],
 "."
}], "Text",
 PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showOutHideCode", "[", 
  RowBox[{
   RowBox[{"dumpWgf", "[", 
    RowBox[{"\"\<\!\(\*SubscriptBox[\"W\", 
StyleBox[\"g\",
FontColor->RGBColor[0, 0, 1]]]\)\>\"", ",", 
     RowBox[{"EoM$lapseRatios", "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "]"}], ",", 
   "\"\<dumpWg\>\"", ",", 
   RowBox[{"GeneratedCell", "\[Rule]", "False"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\\!\\(\\*SubscriptBox[\\\"W\\\", \\n \
StyleBox[\\\"g\\\",\\nFontColor->RGBColor[0, 0, 1]]]\\)\"\>", "\<\"\[Equal]\"\
\>", 
     RowBox[{"2", " ", 
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], "-", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox["p",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}], "-", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                   HoldForm], " ", 
                  SuperscriptBox[
                   StyleBox["p",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "-", 
              RowBox[{"4", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               SuperscriptBox[
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], ")"}], "2"], " ", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "3"], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "3"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
        RowBox[{
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm], ")"}], "2"]}], "+", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm]}], "+", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
               SuperscriptBox[
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "0"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], "+", 
                 RowBox[{"4", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm]}], "+", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm]}], ")"}], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm], "-", 
                    RowBox[{"2", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
                 RowBox[{"4", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm], "-", 
                    RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                   HoldForm]}], "+", 
                 RowBox[{"4", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm]}]}], ")"}], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "B"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}]},
    {"\<\"\"\>", "\<\"+\"\>", 
     RowBox[{
      FractionBox["4", "3"], " ", "r", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "0"],
                HoldForm]}], "-", 
              RowBox[{"4", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           RowBox[{
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "2", "1"],
                 HoldForm]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], 
              "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm]}], "+", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], ")"}]}], "+", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "-", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm]}], "+", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm]}], ")"}]}], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "0"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], ")"}], "2"], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            FrameBox[
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}],
              HoldForm],
             StripOnInput->False], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}], "+", 
           RowBox[{
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], 
              "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], "-", 
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}]}], ")"}], " ", 
                  StyleBox[
                   OverscriptBox["K", "~"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}], "+", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                   HoldForm], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "-", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                   HoldForm], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}]},
    {"\<\"\"\>", "\<\"+\"\>", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FrameBox[
          StyleBox[
           SubscriptBox["\[Kappa]", "f"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]],
          Background->RGBColor[1, 0.85, 0.85],
          StripOnInput->False], " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], "+", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], "-", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "2"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
        RowBox[{
         FrameBox[
          StyleBox[
           SubscriptBox["\[Kappa]", "g"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]],
          Background->RGBColor[0.87, 0.94, 1],
          StripOnInput->False], " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "0", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "0", "1"],
                   HoldForm]}], "+", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "0", "2"],
                  HoldForm]}], ")"}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm]}]}], ")"}], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}], "+", 
           RowBox[{"4", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            SuperscriptBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
              StyleBox[
               OverscriptBox["\[Tau]", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               SuperscriptBox[
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                OverscriptBox["A", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}], ")"}], " ", 
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
              StyleBox[
               OverscriptBox["\[Tau]", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]], "+", 
              RowBox[{
               SuperscriptBox[
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["\[Tau]", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], "-", 
                 RowBox[{
                  StyleBox[
                   SuperscriptBox["v", "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["S", "^"], "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], ")"}]}], 
           "+", 
           RowBox[{
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm]}], "+", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], ")"}]}], "-", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "0", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm]}]}], ")"}], " ", 
               SuperscriptBox[
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"], " ", 
               StyleBox[
                OverscriptBox["A", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm]}], "-", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm]}], ")"}], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["D", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], "+", 
                 StyleBox[
                  OverscriptBox["\[Tau]", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], "-", 
                 RowBox[{
                  StyleBox[
                   SuperscriptBox["v", "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["S", "^"], "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["2", "9"], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            RowBox[{"(", 
             RowBox[{
              FrameBox[
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}],
                HoldForm],
               StripOnInput->False], "-", 
              FrameBox[
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}],
                HoldForm],
               StripOnInput->False]}], ")"}], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm]}], "+", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm]}], ")"}], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "-", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], ")"}], "2"]}], "+", 
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm]}], "+", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], "-", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  StyleBox["K",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], "-", 
                  StyleBox[
                   SubscriptBox["K", "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}], ")"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "-", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm], "+", 
                    RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "+", 
                 RowBox[{"2", " ", 
                  StyleBox[
                   SubscriptBox["K", "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "-", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "-", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "+", 
                 RowBox[{"2", " ", 
                  StyleBox[
                   SubscriptBox["K", "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", 
               FrameBox[
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox["p",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]]}],
                 HoldForm],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                OverscriptBox["A", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}], "+", 
                    RowBox[{"2", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SuperscriptBox[
                    StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "+", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
                 RowBox[{"2", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], "-", 
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}]}], ")"}]}], " ", 
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "+", 
                    RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm], " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}]}]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dumpWg"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showOutHideCode", "[", 
  RowBox[{
   RowBox[{"dumpWgf", "[", 
    RowBox[{"\"\<\!\(\*SubscriptBox[\"W\", 
StyleBox[\"f\",
FontColor->RGBColor[1, 0, 0]]]\)\>\"", ",", 
     RowBox[{"EoM$lapseRatios", "\[LeftDoubleBracket]", 
      RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], "]"}], ",", 
   "\"\<dumpWf\>\"", ",", 
   RowBox[{"GeneratedCell", "\[Rule]", "False"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\\!\\(\\*SubscriptBox[\\\"W\\\", \\n \
StyleBox[\\\"f\\\",\\nFontColor->RGBColor[1, 0, 0]]]\\)\"\>", "\<\"\[Equal]\"\
\>", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm]}], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], ")"}], "2"], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "3"], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "0"],
             HoldForm], " ", 
            SuperscriptBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}], "-", 
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            RowBox[{"(", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm], "-", 
              RowBox[{"4", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SuperscriptBox[
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm]}], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm], ")"}], "2"], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "3", "0"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm]}], "-", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm]}], "+", 
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], ")"}], "2"], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}], "-", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "1"],
               HoldForm], "-", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], ")"}], "2"], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}], "+", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              RowBox[{"2", " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], ")"}], "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox["p",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}], ")"}]}], "-", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                   HoldForm], " ", 
                  SuperscriptBox[
                   StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "B"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}]},
    {"\<\"\"\>", "\<\"+\"\>", 
     RowBox[{
      FractionBox["4", "3"], " ", "r", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "2", "1"],
               HoldForm], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], "-", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm]}], ")"}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm]}], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "3", "0"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "1"],
                 HoldForm], ")"}], "2"], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "0"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}], "-", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "0"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "-", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "+", 
                 RowBox[{"2", " ", 
                  StyleBox[
                   SubscriptBox["K", "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "+", 
                 RowBox[{"2", " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}], "-", 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            FrameBox[
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["p",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}],
              HoldForm],
             StripOnInput->False], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "+", 
           RowBox[{
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                   HoldForm]}], "+", 
                 RowBox[{"4", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm]}]}], ")"}], " ", 
               StyleBox[
                SubscriptBox["D", "B"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "-", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
              RowBox[{
               StyleBox[
                SubscriptBox[
                 OverscriptBox["D", "~"], "B"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm]}], "+", 
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}]}], ")"}], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm], " ", 
                  StyleBox[
                   OverscriptBox["K", "~"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], ")"}], "2"]}], "-", 
                    RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                    HoldForm]}]}], ")"}], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}]},
    {"\<\"\"\>", "\<\"+\"\>", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FrameBox[
          StyleBox[
           SubscriptBox["\[Kappa]", "f"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]],
          Background->RGBColor[1, 0.85, 0.85],
          StripOnInput->False], " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox[
                RowBox[{"(", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], ")"}], "2"]}], "+", 
              RowBox[{"4", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}], "+", 
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "2"],
                HoldForm], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "1"],
                 HoldForm]}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "2"],
                HoldForm]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "2"],
                   HoldForm]}], "+", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "1"],
                   HoldForm]}]}], ")"}], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            SuperscriptBox[
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               StyleBox["A",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "1"],
                  HoldForm], "-", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm], "+", 
                 RowBox[{
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
               StyleBox[
                OverscriptBox["A", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         FrameBox[
          StyleBox[
           SubscriptBox["\[Kappa]", "g"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]],
          Background->RGBColor[0.87, 0.94, 1],
          StripOnInput->False], " ", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "2"],
          HoldForm], " ", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm]}], "+", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "1", "2"],
                  HoldForm]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "0", "2"],
                HoldForm], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm]}]}], ")"}], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "+", 
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["D", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]], "+", 
              StyleBox[
               OverscriptBox["\[Tau]", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]], "-", 
              RowBox[{"3", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "2"],
                HoldForm], " ", 
               SuperscriptBox[
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                OverscriptBox["A", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["2", "9"], " ", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            RowBox[{"(", 
             RowBox[{
              FrameBox[
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}],
                HoldForm],
               StripOnInput->False], "-", 
              FrameBox[
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}],
                HoldForm],
               StripOnInput->False]}], ")"}], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"]}], "-", 
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               SuperscriptBox[
                StyleBox["K",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
              RowBox[{"3", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               SuperscriptBox[
                StyleBox[
                 SubscriptBox["K", "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm], "+", 
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "1"],
                  HoldForm]}], ")"}], " ", 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "-", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 TagBox[
                  SubsuperscriptBox[
                   RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                   "2", "0"],
                  HoldForm], "-", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                   HoldForm]}]}], ")"}], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "-", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm]}], "+", 
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                   HoldForm], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SuperscriptBox[
                   StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  StyleBox[
                   OverscriptBox["K", "~"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]], "-", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}], ")"}], "2"]}]}], ")"}]}], 
           "+", 
           RowBox[{"4", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "1"],
             HoldForm], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm]}], "+", 
              TagBox[
               SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                "1", "2"],
               HoldForm]}], ")"}], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], "-", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
              "1"],
             HoldForm], " ", 
            SuperscriptBox[
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            SuperscriptBox[
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                   HoldForm]}], "-", 
                 RowBox[{"3", " ", 
                  TagBox[
                   SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                   HoldForm]}]}], ")"}], " ", 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "-", 
              RowBox[{"2", " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "1", "1"],
                HoldForm], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "6"}], " ", 
               FrameBox[
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox["p",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]]}],
                 HoldForm],
                StripOnInput->False], " ", 
               TagBox[
                SubsuperscriptBox[
                 RowBox[{"\[LeftAngleBracket]", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                 "2", "1"],
                HoldForm], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  StyleBox["K",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}], "+", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], "2"], " ", 
               StyleBox[
                OverscriptBox["A", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "1"],
                    HoldForm]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    RowBox[{"7", " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm]}], "-", 
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}]}], ")"}], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "6"}], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "1", "2"],
                    HoldForm]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "0"],
                    HoldForm]}], "+", 
                    RowBox[{"3", " ", 
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm]}]}], ")"}], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
                 RowBox[{"2", " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "3", "0"],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
                    RowBox[{
                    TagBox[
                    SubsuperscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                    "2", "1"],
                    HoldForm], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dumpWf"]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dumpEoM", "[", 
  RowBox[{
  "\"\<The common denominator \!\(\*SubscriptBox[\(W\), \(c\)]\)\>\"", ",", 
   RowBox[{"EoM$lapseRatios", "\[LeftDoubleBracket]", 
    RowBox[{
     RowBox[{"3", ";;", "3"}], ",", "All"}], "\[RightDoubleBracket]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"The common denominator \\!\\(\\*SubscriptBox[\\(W\\), \\(c\
\\)]\\)\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]", 
     "\[SpanFromLeft]"},
    {"\<\" \"\>", 
     SubscriptBox["W", "c"], "\<\" \[Equal] \"\>", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"]}]}
   },
   AutoDelete->False,
   BaseStyle->{"Output", 14},
   GridBoxAlignment->{"Columns" -> {Left, Right, {Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {1, 1.1}}],
  "Grid"]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 GeneratedCell->False,
 CellTags->"dump_eq_cW"]
}, {2}]],

Cell[TextData[{
 "Dependency graph of EoM for ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " (here, ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]]],
 " denotes a set of dynamical variables and ",
 Cell[BoxData[
  FormBox["V", TraditionalForm]]],
 " denotes a set of the stress-enrergy projections):"
}], "Text",
 PageBreakAbove->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dep$list", "=", 
   RowBox[{
    RowBox[{"Join", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "\[Rule]", 
          RowBox[{"Sort", "[", 
           RowBox[{"Variables", "@", 
            RowBox[{
            "#", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
           "]"}]}], "]"}], "&"}], "/@", "EoM$gEvol"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "#", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
          RowBox[{"#", "[", 
           RowBox[{"t", ",", "r"}], "]"}]}], ")"}], "&"}], "/@", 
       RowBox[{"{", 
        RowBox[{
        "gA", ",", "gB", ",", "gK", ",", "gKD", ",", "gDA", ",", "gDB", ",", 
         "g\[Sigma]", ",", "fA", ",", "fB", ",", "fK1", ",", "fK2", ",", 
         "f\[Sigma]", ",", "q", ",", "gAlp", ",", "gDAlp", ",", "fAlp", ",", 
         "p"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "2"}], "]"}], "[", "#", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
          RowBox[{"#", "[", 
           RowBox[{"t", ",", "r"}], "]"}]}], ")"}], "&"}], "/@", 
       RowBox[{"{", 
        RowBox[{
        "gA", ",", "gB", ",", "gK", ",", "gKD", ",", "gDA", ",", "gDB", ",", 
         "g\[Sigma]", ",", "fA", ",", "fB", ",", "fK1", ",", "fK2", ",", 
         "f\[Sigma]", ",", "q", ",", "gAlp", ",", "gDAlp", ",", "fAlp", ",", 
         "p"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"V", "\[Rule]", "F"}], ",", 
        RowBox[{"Thread", "[", 
         RowBox[{
          UnderscriptBox["fAlp", "_"], "\[Rule]", 
          RowBox[{"Variables", "@", 
           UnderscriptBox["eq$fAlp", "_"]}]}], "]"}], ",", 
        RowBox[{"Thread", "[", 
         RowBox[{
          UnderscriptBox["gW", "_"], "\[Rule]", 
          RowBox[{"Variables", "@", 
           UnderscriptBox["eq$gW", "_"]}]}], "]"}], ",", 
        RowBox[{"Thread", "[", 
         RowBox[{
          UnderscriptBox["fW", "_"], "\[Rule]", 
          RowBox[{"Variables", "@", 
           UnderscriptBox["eq$fW", "_"]}]}], "]"}]}], "}"}]}], 
     "\[IndentingNewLine]", "]"}], "//", "Flatten"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dep$list", "=", 
   RowBox[{
    RowBox[{"dep$list", "//.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"P", "[", 
         RowBox[{"n_", ",", "k_", ",", "R_"}], "]"}], "\[RuleDelayed]", "R"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"gA", "\[Rule]", "F"}], ",", 
       RowBox[{"gB", "\[Rule]", "F"}], ",", 
       RowBox[{"gK1", "\[Rule]", "F"}], ",", 
       RowBox[{"gK2", "\[Rule]", "F"}], ",", 
       RowBox[{"gK", "\[Rule]", "F"}], ",", 
       RowBox[{"gKD", "\[Rule]", "F"}], ",", 
       RowBox[{"gDA", "\[Rule]", "F"}], ",", 
       RowBox[{"gDB", "\[Rule]", "F"}], ",", 
       RowBox[{"g\[Sigma]", "\[Rule]", "F"}], ",", 
       RowBox[{"gDAlp", "\[Rule]", "F"}], ",", 
       RowBox[{"fDAlp", "\[Rule]", "F"}], ",", "\[IndentingNewLine]", 
       RowBox[{"fA", "\[Rule]", "F"}], ",", 
       RowBox[{"fB", "\[Rule]", "F"}], ",", 
       RowBox[{"fK1", "\[Rule]", "F"}], ",", 
       RowBox[{"fK2", "\[Rule]", "F"}], ",", 
       RowBox[{"R", "\[Rule]", "F"}], ",", 
       RowBox[{"fDA", "\[Rule]", "F"}], ",", 
       RowBox[{"fDB", "\[Rule]", "F"}], ",", 
       RowBox[{"f\[Sigma]", "\[Rule]", "F"}], ",", "\[IndentingNewLine]", 
       RowBox[{"pfD", "\[Rule]", "F"}], ",", 
       RowBox[{"pf\[Tau]", "\[Rule]", "F"}], ",", 
       RowBox[{"pfS", "\[Rule]", "F"}], ",", 
       RowBox[{"pfv", "\[Rule]", "F"}], ",", 
       RowBox[{"pf$\[Rho]", "\[Rule]", "F"}], ",", 
       RowBox[{"pf$J1", "\[Rule]", "F"}], ",", 
       RowBox[{"pf$J2", "\[Rule]", "F"}], ",", 
       RowBox[{"pf$j", "\[Rule]", "F"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Lt", "\[Rule]", "p"}], ",", 
       RowBox[{"v", "\[Rule]", "p"}], ",", 
       RowBox[{"g$\[Rho]", "\[Rule]", "V"}], ",", 
       RowBox[{"g$JK1", "\[Rule]", "V"}], ",", 
       RowBox[{"g$JK2", "\[Rule]", "V"}], ",", 
       RowBox[{"f$\[Rho]", "\[Rule]", "V"}], ",", 
       RowBox[{"f$JK1", "\[Rule]", "V"}], ",", 
       RowBox[{"f$JK2", "\[Rule]", "V"}], ",", 
       RowBox[{"gW", "\[Rule]", "W"}], ",", 
       RowBox[{"fW", "\[Rule]", "W"}]}], "}"}]}], "//", "Union"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dep$list", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dep$list", ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "=!=", "k$g"}], "&&", 
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "=!=", "k$f"}]}], "&"}]}], "]"}], "//", "printNice"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"dep$list", "/.", 
     RowBox[{
      RowBox[{"HoldForm", "[", 
       RowBox[{"D", "[", 
        RowBox[{"U_", ",", "rr"}], "]"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"HoldForm", "[", 
         RowBox[{"D", "[", 
          RowBox[{"U", ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "Purple"}], 
       "]"}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{"\"\<Name\>\"", ",", "Center"}], "]"}]}], ",", 
    RowBox[{"VertexSize", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0.22", ",", "0.42"}], "}"}]}], ",", 
    RowBox[{"VertexShapeFunction", "\[Rule]", "\"\<RoundedRectangle\>\""}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"VertexLabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Cambria\>\""}], ",", " ", 
       RowBox[{"FontSize", "\[Rule]", 
        RowBox[{"Scaled", "[", "0.014", "]"}]}]}], "]"}]}], ",", 
    RowBox[{"VertexStyle", "\[Rule]", "LightYellow"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"EdgeStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"Hue", "[", 
        RowBox[{"0.6", ",", " ", "0.8", ",", " ", "0.8"}], "]"}], ",", 
       RowBox[{"Arrowheads", "[", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{".01", ",", ".8"}], "}"}], "}"}], "]"}]}], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ImageSize", "\[Rule]", 
     RowBox[{"Scaled", "[", "1", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutHideCode", "[", 
  RowBox[{"%", ",", "\"\<depGraph1\>\""}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{$CellContext`V, $CellContext`F, 
       Style[
        OverTilde[$CellContext`\[Alpha]], 
        RGBColor[1, 0, 0]], 
       Style[$CellContext`\[Alpha], 
        RGBColor[0, 0, 1]], $CellContext`W, $CellContext`r, 
       Style[$CellContext`p, 
        RGBColor[0, 
         Rational[2, 3], 0]], 
       HoldForm[
        D[$CellContext`F, $CellContext`r]], 
       HoldForm[
        D[
         Style[$CellContext`p, 
          RGBColor[0, 
           Rational[2, 3], 0]], $CellContext`r]], 
       HoldForm[
        D[
         Style[
          OverTilde[$CellContext`\[Alpha]], 
          RGBColor[1, 0, 0]], $CellContext`r]], 
       HoldForm[
        D[
         Style[$CellContext`\[Alpha], 
          RGBColor[0, 0, 1]], $CellContext`r]], 
       HoldForm[
        D[
         Style[$CellContext`q, 
          RGBColor[0, 
           Rational[2, 3], 0]], $CellContext`r]], 
       Style[$CellContext`q, 
        RGBColor[0, 
         Rational[2, 3], 0]], 
       Style[
        HoldForm[
         D[$CellContext`F, {$CellContext`r, 2}]], 
        RGBColor[0.5, 0, 0.5]], 
       Style[
        HoldForm[
         D[
          Style[
           OverTilde[$CellContext`\[Alpha]], 
           RGBColor[1, 0, 0]], {$CellContext`r, 2}]], 
        RGBColor[0.5, 0, 0.5]], 
       Style[
        HoldForm[
         D[
          Style[$CellContext`\[Alpha], 
           RGBColor[0, 0, 1]], {$CellContext`r, 2}]], 
        RGBColor[0.5, 0, 0.5]], 
       Style[
        HoldForm[
         D[
          Style[$CellContext`p, 
           RGBColor[0, 
            Rational[2, 3], 0]], {$CellContext`r, 2}]], 
        RGBColor[0.5, 0, 0.5]], 
       Style[
        HoldForm[
         D[
          Style[$CellContext`q, 
           RGBColor[0, 
            Rational[2, 3], 0]], {$CellContext`r, 2}]], 
        RGBColor[0.5, 0, 0.5]], 
       HoldForm[
        D[$CellContext`F, $CellContext`t]], 
       HoldForm[
        D[Style[$CellContext`p, 
           RGBColor[0, 
            Rational[2, 3], 0]]/$CellContext`r, $CellContext`r]], 
       HoldForm[
        D[Style[$CellContext`q, 
           RGBColor[0, 
            Rational[2, 3], 0]]/$CellContext`r, $CellContext`r]]}, {{{1, 2}, {
       3, 4}, {3, 5}, {5, 6}, {5, 2}, {5, 7}, {5, 8}, {5, 9}, {8, 2}, {10, 
       3}, {11, 4}, {9, 7}, {12, 13}, {14, 2}, {15, 3}, {16, 4}, {17, 7}, {18,
        13}, {19, 6}, {19, 2}, {19, 4}, {19, 20}, {19, 21}, {19, 7}, {19, 
       13}, {19, 1}, {19, 8}, {19, 9}, {19, 12}, {19, 17}, {19, 18}}, Null}, {
      EdgeStyle -> {
         Directive[
          Hue[0.6, 0.8, 0.8], 
          Arrowheads[{{0.01, 0.8}}]]}, ImageSize -> Scaled[1], VertexLabels -> {
         Placed["Name", Center]}, VertexLabelStyle -> {
         Directive[FontFamily -> "Cambria", FontSize -> Scaled[0.014]]}, 
       VertexShapeFunction -> {"RoundedRectangle"}, 
       VertexSize -> {{0.22, 0.42}}, VertexStyle -> {
         RGBColor[1, 1, 0.85]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.8, 0.8], Opacity[0.7], Arrowheads[{{0.01, 0.8}}], 
        ArrowBox[{{0., 1.}, {-2., 0.}}, 0.22], 
        ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQECByA0h0PYDGFZLgOBAyHnbxx9PZ/dYXn058NK
qQIHNnlIVuwyZXf46jn/i+d8gQPiOQfFcg6yOdgmi6+vvydwoM3y4kIGZzaH
JrAGwQN/N4A0sDocEgMpFDxQd0m99pI6q8MfsLjgAY55eWf5u1kcTMo+/nrO
K3RgJsjaJ8wOaWAgdMDEGASYHUTB9ggduALSXsvkcLxQBoiED4Cp44wOFeUg
IHxASBAEGB00QMouCR/YyBq9gTWaweFGky4QiRxY8AXk8P/2HWAgcuDeXRD4
a2/V99ii77HIAVmwwX/sX022eznZTvRAzAaQAb/tZ80EAdEDEPqn/ZlOPlaJ
T6IHwMFj/sOexX/7s3ZXsQOgUHrw8pu9w0uQAWIH2EHWb/hqXx+xhMfmLpAP
9u8X+8NzXgQ0KIof+NoTu+df5Wd7nm0J3NsSxA+Ag6f2kz1Y+SzxA2DlUz7a
r0p/8+jrefEDEYl+JRoHPthD4kkCGl8f7AHHhsVy
         "]], 0.22], ArrowBox[{{-4., 3.}, {-4., 2.}}, 0.22], 
        ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQECB6AMh7AZwrJcBgIHls/b2H3d/r/98ujPh5VS
BQ4kTTT6UJL9z/6r5/wvnvMFDujdaNK90fTX3jZZfH39PYEDPMWLnBnb/tg3
gTUIHviVCNLw2/6QWM5BsRwgf4k/CNn/2eAhWbFL8ACPzd1Z8mI/7U3KPv56
zit0wFDdSiThxHf7NDAQOgChv9k76ZzaN2Wr0AFZ0zl8daxf7auK7NNF3god
OHFOtOvTrs/23JbH4p/yCB/IML5843DbJ/sv9XEr2EWFD3xPuvLrY8ZHe3N3
DsdqVuED1bGSH2oSP9hf6Tus6XBP6MBDV5fCkw/e2Z8Km5AUNl/owJa0uyuC
tN/aS83Pe73XQ+hAtuy/tqmLXtsfTo87UnZL8ABH1jLuSW6v7OMz9fdnOwkc
CMqrW1HC9szes2P968VTeA8kJthbtUo/slf9sO5C0BOuAykNlxrbue/aB3LF
6j4p5jjQJv2jIqHrmv3FazsZI5zZDuhPeh85dfMF+0WhR33XBbEc2HWi0NOH
77j90bZ6wecLmQ5YegSkeovssbfKeuHDZMh4QPsWx77bWSvtofEEiy8GAORz
yxM=
         "]], 0.22], ArrowBox[{{-4., 2.}, {-3., 1.}}, 0.22], 
        ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQECB6AMBxh/+byN3dft/9vD+EkTjT6UZP+zZ4Ty
9W406d5o+guX5yle5MzY9gfO/5UI0vAbwV/iD0II9TZ3Z8mL/YTzDdWtRBJO
fIfz08Dgm337h+Wvvn3lP7Dl+5U2dp6v9oqH5q+6fZ3/gMrNH1kSVz/bnyx5
br9uKf+BbVyXhGYe/GRfz1G/Ki+e/0BqT0Jd58WP9m61aa9kWPkPmMctWfuS
5aO93OW5/3dM4zug0TB3wc7oD/ZsXKqvnET4DpQ9mb7u0+r39v8U/6zcVct7
4HZG/OLA5+/sWaSV7RUu8xxo6p0oPyHznX1b8f7OxGlMBw7tvH/EwPulfU/F
8/9TCj7tV7730151zhN7iRX/zFOkt+9f+Ov+hNyYB/YabfnOm+a/ti+TU8kX
lrhpbzRhv75kyG/75+YKGZ9DL9nn7PP+3NLL7KDZnCH57ckJ+5Yj8otDJ3E4
fHzbULxy2177hFvRy+t28Diw6yoe5bJZBQsfB1jMAQD1MLhb
         "]], 0.22], ArrowBox[{{-4., 2.}, {-2., 1.}}, 0.22], 
        ArrowBox[{{-4., 2.}, {-1., 1.}}, 0.22], 
        ArrowBox[{{-2., 1.}, {-2., 0.}}, 0.22], 
        ArrowBox[{{-1., 1.}, {4., 0.}}, 0.22], 
        ArrowBox[{{-5., 4.}, {-4., 3.}}, 0.22], 
        ArrowBox[{{-7., 2.}, {-6., 1.}}, 0.22], 
        ArrowBox[{{6., 1.}, {7., 0.}}, 0.22], 
        ArrowBox[{{-7., 1.}, {-2., 0.}}, 0.22], 
        ArrowBox[{{-4., 4.}, {-4., 3.}}, 0.22], 
        ArrowBox[{{-6., 2.}, {-6., 1.}}, 0.22], 
        ArrowBox[{{4., 1.}, {4., 0.}}, 0.22], 
        ArrowBox[{{7., 1.}, {7., 0.}}, 0.22], 
        ArrowBox[{{2., 2.}, {0., 1.}}, 0.22], 
        ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQUOMHq1gbqVSAKDw/J5G7uv2/+399/+rN31FIND
0kSjDyXZ/+xfTbZ7OdmO0UHvRpPujaa/9tXH9OL+72F04Cle5MzY9seeGayB
yeFXIkjDb/tmXZBCIH+JPwjZ/wSLMzvw2NydJS/20z7jzaOv56VZHAxB1p74
bn8GDFgc0sDgm336jC2btmSxOiwzf7ToLcdX+6on/xeF3mB1eHND9/aGE5/t
mTaum7telM3BwsuTf8PST/b//x5YdEiJzaGt28T+9fyP9kWnzTb1/Wd1uDXn
fVbS9g/2MZICZ4TXsDqk/Pmion3jvf2u5z4fAjVYHeTiV2Vz1ryzn2D2Vs6z
hMXhceL/lfFRb+1vsX4M/9nP7LCe5ct93eI39j/s9v+ZE/3b/uSm+tN2+57b
/7s778fUvg/2ZyJ4/lrnPLbnWMzcV/b4ln3WW+OXXr/u2d9jvSqSoHNwP4tk
YMq3h9ftv9ekf/aVfLI/y6Qgu6r/on1VwSnH4j8f9tvVK/1dy3rCfs+2e7c+
fPm2v/TVhTKDD3vsbSd+OCL/7fd+T+2TbudurLSHxtMBWMQBAEhV2ck=
         "]], 0.22], ArrowBox[{{2., 2.}, {-6., 1.}}, 0.22], 
        ArrowBox[{{2., 2.}, {-3., 1.}}, 0.22], 
        ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQUOMNoy64UPkyGjg95OfqWVJv/tj7bVCz5fyORQ
+3uV5267f/aLQ4/6rgticXh17GKZmdxf+4vXdjJGOLM5lEq3rJS6/Ns+iCtW
90kxh4Pcz4MP02N/2at8WHch6AmXw4v4bnm5vT/sPTvWv148hdfhgv+DJNtP
3+zjM/X3ZzsJOFw/cWD10T9f7A+nxx0puyXo8OeUzq9tdz7ZS87Pe73XQ8jB
62ODzVa9T/anwiYkhc0XcljuM3F1WNZH+yt9hzUd7gk5CNyNdZ/d/8He3J3D
sZpV2IHb9aw8m+17+y/1cSvYRYUdhKzCuWT03tpzWR6Lf8oj7GA0M9Kv4tMr
+6oi+3SRt0IOeUlXXkt1vbB30Tm1b8pWIYcjU48/Yv761D4NDIQcjMHgsb1J
2cdfz3mFHOZt7L5un//A/u8GD8mKXYIO5/i7pzQuv21/SCznoFiOoIM4iDp4
zb5pefTnw0qCDkBFpvY6l+ztksXX198TcFiR/ubR1/On7b94zgciAYcpdi8n
2708bL8CpDxVwOHBy2t/NnjstA+bISzLZSDg8E/rTCcf6wp7SDQJwOKLAQC7
zcH3
         "]], 0.22], ArrowBox[{{2., 2.}, {-2., 1.}}, 0.22], 
        ArrowBox[{{2., 2.}, {-1., 1.}}, 0.22], 
        ArrowBox[{{2., 2.}, {6., 1.}}, 0.22], 
        ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQUOMFpPzlGJJ5/JwdX7lWegwX/7cpMDLm/KWR1u
Oou+jNb9Z3/TqTZ9gRSnw86XDXflv/+xD/as6NII53V4aqOrPrf3t/2XxTfC
DokJOsTZSh27/OGnvZf8lIxb54QdVF677zqs8MN+7bS8qjuXxRzM3bYx58p+
s5fjyug5oSrlMN0vddH5Z5/tZ1U2zJt3RNbBhSV02uuaj/a9CzblVZvLOXCV
qxrvl/ho/zxdoFp+kpwDv3O6T9vUD/bLz8883HVFzmHGBZMjjc/e25+67uex
95+cQ+fZ2hd3k9/ZBzXoc24XkHf4VLOSVXHxG3v7k9ZsFVzyDpfubZf2XvLK
ftKmYnuGN3IOap9XaMWkv7D3srm+xX+rnMOnnTVGIW+e2qeBgZyDMRg8tjcu
+/jrOa+cw7yN3dft8x/Y/9ngIVmxS9bhHH/3lMblt+0PieUcFMuRdRAHUQev
2Tctj/58WEnWAajI1F7nkr1Nsvj6+nsyDivS3zz6ev60/VfP+V8858s4TLF7
Odnu5WH7FSDlqTIOD15eAxq90z5shrAsl4GMwz+tM518rCvsIdEkA4svBgAc
i8FF
         "]], 0.22], ArrowBox[{{2., 2.}, {4., 1.}}, 0.22], 
        ArrowBox[{{2., 2.}, {7., 1.}}, 0.22], 
        ArrowBox[{{2., 2.}, {1., 1.}}, 0.22], 
        ArrowBox[{{2., 2.}, {2., 1.}}, 0.22]}, 
       {RGBColor[1, 1, 0.85], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-0.17254908, 
          0.67058812}, {0.17254908, 0.67058812}, {0.2588234, 0.67058812}, {
          0.2588234, 0.8352940600000001}, {0.2588234, 1.16470594}, {0.2588234,
           1.3294118799999999`}, {0.17254908, 
          1.3294118799999999`}, {-0.17254908, 
          1.3294118799999999`}, {-0.2588234, 
          1.3294118799999999`}, {-0.2588234, 1.16470594}, {-0.2588234, 
          0.8352940600000001}, {-0.2588234, 0.67058812}, {-0.17254908, 
          0.67058812}}}], InsetBox[
          StyleBox["V",
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {0., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, {{{-2.17254908, -0.32941188}, {-1.82745092, -0.32941188}, \
{-1.7411766, -0.32941188}, {-1.7411766, -0.16470594}, {-1.7411766, 
          0.16470594}, {-1.7411766, 0.32941188}, {-1.82745092, 
          0.32941188}, {-2.17254908, 0.32941188}, {-2.2588234, 
          0.32941188}, {-2.2588234, 
          0.16470594}, {-2.2588234, -0.16470594}, {-2.2588234, -0.32941188}, \
{-2.17254908, -0.32941188}}}], InsetBox[
          StyleBox["F",
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-2., 0.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-4.17254908, 
          2.67058812}, {-3.82745092, 2.67058812}, {-3.7411766, 
          2.67058812}, {-3.7411766, 2.83529406}, {-3.7411766, 
          3.16470594}, {-3.7411766, 3.32941188}, {-3.82745092, 
          3.32941188}, {-4.17254908, 3.32941188}, {-4.2588234, 
          3.32941188}, {-4.2588234, 3.16470594}, {-4.2588234, 
          2.83529406}, {-4.2588234, 2.67058812}, {-4.17254908, 2.67058812}}}],
          InsetBox[
          StyleBox[
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-4., 3.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-6.17254908, 
          0.67058812}, {-5.82745092, 0.67058812}, {-5.7411766, 
          0.67058812}, {-5.7411766, 0.8352940600000001}, {-5.7411766, 
          1.16470594}, {-5.7411766, 1.3294118799999999`}, {-5.82745092, 
          1.3294118799999999`}, {-6.17254908, 
          1.3294118799999999`}, {-6.2588234, 
          1.3294118799999999`}, {-6.2588234, 1.16470594}, {-6.2588234, 
          0.8352940600000001}, {-6.2588234, 0.67058812}, {-6.17254908, 
          0.67058812}}}], InsetBox[
          StyleBox[
           StyleBox["\[Alpha]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-6., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-4.17254908, 
          1.6705881200000001`}, {-3.82745092, 
          1.6705881200000001`}, {-3.7411766, 
          1.6705881200000001`}, {-3.7411766, 1.83529406}, {-3.7411766, 
          2.16470594}, {-3.7411766, 2.32941188}, {-3.82745092, 
          2.32941188}, {-4.17254908, 2.32941188}, {-4.2588234, 
          2.32941188}, {-4.2588234, 2.16470594}, {-4.2588234, 
          1.83529406}, {-4.2588234, 1.6705881200000001`}, {-4.17254908, 
          1.6705881200000001`}}}], InsetBox[
          StyleBox["W",
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-4., 2.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-3.17254908, 
          0.67058812}, {-2.82745092, 0.67058812}, {-2.7411766, 
          0.67058812}, {-2.7411766, 0.8352940600000001}, {-2.7411766, 
          1.16470594}, {-2.7411766, 1.3294118799999999`}, {-2.82745092, 
          1.3294118799999999`}, {-3.17254908, 
          1.3294118799999999`}, {-3.2588234, 
          1.3294118799999999`}, {-3.2588234, 1.16470594}, {-3.2588234, 
          0.8352940600000001}, {-3.2588234, 0.67058812}, {-3.17254908, 
          0.67058812}}}], InsetBox[
          StyleBox["r",
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-3., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{
          3.82745092, -0.32941188}, {4.17254908, -0.32941188}, {
          4.2588234, -0.32941188}, {4.2588234, -0.16470594}, {4.2588234, 
          0.16470594}, {4.2588234, 0.32941188}, {4.17254908, 0.32941188}, {
          3.82745092, 0.32941188}, {3.7411766, 0.32941188}, {3.7411766, 
          0.16470594}, {3.7411766, -0.16470594}, {3.7411766, -0.32941188}, {
          3.82745092, -0.32941188}}}], InsetBox[
          StyleBox[
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {4., 0.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-2.17254908, 
          0.67058812}, {-1.82745092, 0.67058812}, {-1.7411766, 
          0.67058812}, {-1.7411766, 0.8352940600000001}, {-1.7411766, 
          1.16470594}, {-1.7411766, 1.3294118799999999`}, {-1.82745092, 
          1.3294118799999999`}, {-2.17254908, 
          1.3294118799999999`}, {-2.2588234, 
          1.3294118799999999`}, {-2.2588234, 1.16470594}, {-2.2588234, 
          0.8352940600000001}, {-2.2588234, 0.67058812}, {-2.17254908, 
          0.67058812}}}], InsetBox[
          StyleBox[
           FractionBox[
            RowBox[{"\[PartialD]", "F"}], 
            RowBox[{"\[PartialD]", "r"}],
            MultilineFunction->None],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-2., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-1.17254908, 
          0.67058812}, {-0.82745092, 0.67058812}, {-0.7411766, 
          0.67058812}, {-0.7411766, 0.8352940600000001}, {-0.7411766, 
          1.16470594}, {-0.7411766, 1.3294118799999999`}, {-0.82745092, 
          1.3294118799999999`}, {-1.17254908, 
          1.3294118799999999`}, {-1.2588234, 
          1.3294118799999999`}, {-1.2588234, 1.16470594}, {-1.2588234, 
          0.8352940600000001}, {-1.2588234, 0.67058812}, {-1.17254908, 
          0.67058812}}}], InsetBox[
          StyleBox[
           FractionBox[
            RowBox[{"\[PartialD]", 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}], 
            RowBox[{"\[PartialD]", "r"}],
            MultilineFunction->None],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-1., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-5.17254908, 
          3.67058812}, {-4.82745092, 3.67058812}, {-4.7411766, 
          3.67058812}, {-4.7411766, 3.83529406}, {-4.7411766, 
          4.16470594}, {-4.7411766, 4.32941188}, {-4.82745092, 
          4.32941188}, {-5.17254908, 4.32941188}, {-5.2588234, 
          4.32941188}, {-5.2588234, 4.16470594}, {-5.2588234, 
          3.83529406}, {-5.2588234, 3.67058812}, {-5.17254908, 3.67058812}}}],
          InsetBox[
          StyleBox[
           FractionBox[
            RowBox[{"\[PartialD]", 
             StyleBox[
              OverscriptBox["\[Alpha]", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], 
            RowBox[{"\[PartialD]", "r"}],
            MultilineFunction->None],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-5., 4.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-7.17254908, 
          1.6705881200000001`}, {-6.82745092, 
          1.6705881200000001`}, {-6.7411766, 
          1.6705881200000001`}, {-6.7411766, 1.83529406}, {-6.7411766, 
          2.16470594}, {-6.7411766, 2.32941188}, {-6.82745092, 
          2.32941188}, {-7.17254908, 2.32941188}, {-7.2588234, 
          2.32941188}, {-7.2588234, 2.16470594}, {-7.2588234, 
          1.83529406}, {-7.2588234, 1.6705881200000001`}, {-7.17254908, 
          1.6705881200000001`}}}], InsetBox[
          StyleBox[
           FractionBox[
            RowBox[{"\[PartialD]", 
             StyleBox["\[Alpha]",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], 
            RowBox[{"\[PartialD]", "r"}],
            MultilineFunction->None],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-7., 2.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{5.82745092, 0.67058812}, {
          6.17254908, 0.67058812}, {6.2588234, 0.67058812}, {6.2588234, 
          0.8352940600000001}, {6.2588234, 1.16470594}, {6.2588234, 
          1.3294118799999999`}, {6.17254908, 1.3294118799999999`}, {
          5.82745092, 1.3294118799999999`}, {5.7411766, 
          1.3294118799999999`}, {5.7411766, 1.16470594}, {5.7411766, 
          0.8352940600000001}, {5.7411766, 0.67058812}, {5.82745092, 
          0.67058812}}}], InsetBox[
          StyleBox[
           FractionBox[
            RowBox[{"\[PartialD]", 
             StyleBox["q",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}], 
            RowBox[{"\[PartialD]", "r"}],
            MultilineFunction->None],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {6., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{
          6.82745092, -0.32941188}, {7.17254908, -0.32941188}, {
          7.2588234, -0.32941188}, {7.2588234, -0.16470594}, {7.2588234, 
          0.16470594}, {7.2588234, 0.32941188}, {7.17254908, 0.32941188}, {
          6.82745092, 0.32941188}, {6.7411766, 0.32941188}, {6.7411766, 
          0.16470594}, {6.7411766, -0.16470594}, {6.7411766, -0.32941188}, {
          6.82745092, -0.32941188}}}], InsetBox[
          StyleBox[
           StyleBox["q",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {7., 0.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-7.17254908, 
          0.67058812}, {-6.82745092, 0.67058812}, {-6.7411766, 
          0.67058812}, {-6.7411766, 0.8352940600000001}, {-6.7411766, 
          1.16470594}, {-6.7411766, 1.3294118799999999`}, {-6.82745092, 
          1.3294118799999999`}, {-7.17254908, 
          1.3294118799999999`}, {-7.2588234, 
          1.3294118799999999`}, {-7.2588234, 1.16470594}, {-7.2588234, 
          0.8352940600000001}, {-7.2588234, 0.67058812}, {-7.17254908, 
          0.67058812}}}], InsetBox[
          StyleBox[
           StyleBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], "F"}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["r", "2"]}],
             MultilineFunction->None],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-7., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-4.17254908, 
          3.67058812}, {-3.82745092, 3.67058812}, {-3.7411766, 
          3.67058812}, {-3.7411766, 3.83529406}, {-3.7411766, 
          4.16470594}, {-3.7411766, 4.32941188}, {-3.82745092, 
          4.32941188}, {-4.17254908, 4.32941188}, {-4.2588234, 
          4.32941188}, {-4.2588234, 4.16470594}, {-4.2588234, 
          3.83529406}, {-4.2588234, 3.67058812}, {-4.17254908, 3.67058812}}}],
          InsetBox[
          StyleBox[
           StyleBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], 
              StyleBox[
               OverscriptBox["\[Alpha]", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["r", "2"]}],
             MultilineFunction->None],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-4., 4.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{-6.17254908, 
          1.6705881200000001`}, {-5.82745092, 
          1.6705881200000001`}, {-5.7411766, 
          1.6705881200000001`}, {-5.7411766, 1.83529406}, {-5.7411766, 
          2.16470594}, {-5.7411766, 2.32941188}, {-5.82745092, 
          2.32941188}, {-6.17254908, 2.32941188}, {-6.2588234, 
          2.32941188}, {-6.2588234, 2.16470594}, {-6.2588234, 
          1.83529406}, {-6.2588234, 1.6705881200000001`}, {-6.17254908, 
          1.6705881200000001`}}}], InsetBox[
          StyleBox[
           StyleBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], 
              StyleBox["\[Alpha]",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["r", "2"]}],
             MultilineFunction->None],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {-6., 2.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{3.82745092, 0.67058812}, {
          4.17254908, 0.67058812}, {4.2588234, 0.67058812}, {4.2588234, 
          0.8352940600000001}, {4.2588234, 1.16470594}, {4.2588234, 
          1.3294118799999999`}, {4.17254908, 1.3294118799999999`}, {
          3.82745092, 1.3294118799999999`}, {3.7411766, 
          1.3294118799999999`}, {3.7411766, 1.16470594}, {3.7411766, 
          0.8352940600000001}, {3.7411766, 0.67058812}, {3.82745092, 
          0.67058812}}}], InsetBox[
          StyleBox[
           StyleBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["r", "2"]}],
             MultilineFunction->None],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {4., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{6.82745092, 0.67058812}, {
          7.17254908, 0.67058812}, {7.2588234, 0.67058812}, {7.2588234, 
          0.8352940600000001}, {7.2588234, 1.16470594}, {7.2588234, 
          1.3294118799999999`}, {7.17254908, 1.3294118799999999`}, {
          6.82745092, 1.3294118799999999`}, {6.7411766, 
          1.3294118799999999`}, {6.7411766, 1.16470594}, {6.7411766, 
          0.8352940600000001}, {6.7411766, 0.67058812}, {6.82745092, 
          0.67058812}}}], InsetBox[
          StyleBox[
           StyleBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["\[PartialD]", "2"], 
              StyleBox["q",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}], 
             RowBox[{"\[PartialD]", 
              SuperscriptBox["r", "2"]}],
             MultilineFunction->None],
            StripOnInput->False,
            LineColor->RGBColor[0.5, 0, 0.5],
            FrontFaceColor->RGBColor[0.5, 0, 0.5],
            BackFaceColor->RGBColor[0.5, 0, 0.5],
            GraphicsColor->RGBColor[0.5, 0, 0.5],
            FontColor->RGBColor[0.5, 0, 0.5]],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {7., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{1.82745092, 
          1.6705881200000001`}, {2.17254908, 1.6705881200000001`}, {2.2588234,
           1.6705881200000001`}, {2.2588234, 1.83529406}, {2.2588234, 
          2.16470594}, {2.2588234, 2.32941188}, {2.17254908, 2.32941188}, {
          1.82745092, 2.32941188}, {1.7411766, 2.32941188}, {1.7411766, 
          2.16470594}, {1.7411766, 1.83529406}, {1.7411766, 
          1.6705881200000001`}, {1.82745092, 1.6705881200000001`}}}], InsetBox[
          StyleBox[
           FractionBox[
            RowBox[{"\[PartialD]", "F"}], 
            RowBox[{"\[PartialD]", "t"}],
            MultilineFunction->None],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {2., 2.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{0.82745092, 0.67058812}, {
          1.17254908, 0.67058812}, {1.2588234, 0.67058812}, {1.2588234, 
          0.8352940600000001}, {1.2588234, 1.16470594}, {1.2588234, 
          1.3294118799999999`}, {1.17254908, 1.3294118799999999`}, {
          0.82745092, 1.3294118799999999`}, {0.7411766, 
          1.3294118799999999`}, {0.7411766, 1.16470594}, {0.7411766, 
          0.8352940600000001}, {0.7411766, 0.67058812}, {0.82745092, 
          0.67058812}}}], InsetBox[
          StyleBox[
           TagBox[
            RowBox[{
             FractionBox["\[PartialD]", 
              RowBox[{"\[PartialD]", "r"}]], 
             FractionBox[
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], "r"]}],
            D],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {1., 1.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}}}, {{{1.82745092, 0.67058812}, {
          2.17254908, 0.67058812}, {2.2588234, 0.67058812}, {2.2588234, 
          0.8352940600000001}, {2.2588234, 1.16470594}, {2.2588234, 
          1.3294118799999999`}, {2.17254908, 1.3294118799999999`}, {
          1.82745092, 1.3294118799999999`}, {1.7411766, 
          1.3294118799999999`}, {1.7411766, 1.16470594}, {1.7411766, 
          0.8352940600000001}, {1.7411766, 0.67058812}, {1.82745092, 
          0.67058812}}}], InsetBox[
          StyleBox[
           TagBox[
            RowBox[{
             FractionBox["\[PartialD]", 
              RowBox[{"\[PartialD]", "r"}]], 
             FractionBox[
              StyleBox["q",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], "r"]}],
            D],
           StripOnInput->False,
           FontFamily->"Cambria",
           FontSize->Scaled[0.014]], {2., 1.},
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Scaled[1]]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 CellTags->"depGraph1"]
}, {2}]]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1347, 915},
WindowMargins->{{402, Automatic}, {Automatic, 136}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "depGraph1"->{
  Cell[1958532, 53284, 34124, 740, 432, "Output",
   CellTags->"depGraph1"]},
 "dumpWf"->{
  Cell[1803428, 49529, 144499, 3461, 493, "Output",
   CellTags->"dumpWf"]},
 "dumpWg"->{
  Cell[1656011, 46006, 146963, 3506, 457, "Output",
   CellTags->"dumpWg"]},
 "dump_eq_cW"->{
  Cell[1948253, 53004, 2756, 79, 77, "Output",
   CellTags->"dump_eq_cW"]},
 "dump_eq_C_1"->{
  Cell[1463833, 40769, 37706, 1012, 282, "Output",
   CellTags->"dump_eq_C_1"]},
 "dump_eq_fA_t"->{
  Cell[1098669, 30615, 109880, 3060, 496, "Output",
   CellTags->"dump_eq_fA_t"],
  Cell[1208744, 33686, 112231, 3162, 598, "Output",
   CellTags->"dump_eq_fA_t"]},
 "dump_eq_f_rho"->{
  Cell[1445092, 40247, 18577, 512, 204, "Output",
   CellTags->"dump_eq_f_rho"]},
 "dump_eq_gA_t"->{
  Cell[887652, 24720, 104222, 2889, 447, "Output",
   CellTags->"dump_eq_gA_t"],
  Cell[992069, 27620, 106430, 2985, 550, "Output",
   CellTags->"dump_eq_gA_t"]},
 "dump_eq_gBet"->{
  Cell[1628284, 45169, 26658, 794, 268, "Output",
   CellTags->"dump_eq_gBet"]},
 "dump_eq_gC_rho"->{
  Cell[1358317, 37865, 32666, 881, 306, "Output",
   CellTags->"dump_eq_gC_rho"]},
 "dump_eq_g_rho"->{
  Cell[1424064, 39661, 20768, 574, 218, "Output",
   CellTags->"dump_eq_g_rho"]},
 "dump_eq_invr_C_1"->{
  Cell[1501724, 41792, 37540, 1020, 341, "Output",
   CellTags->"dump_eq_invr_C_1"]},
 "dump_eq_invr_gC_rho"->{
  Cell[1391186, 38757, 32639, 893, 382, "Output",
   CellTags->"dump_eq_invr_gC_rho"]},
 "dump_eq_invr_p_g"->{
  Cell[1583333, 43974, 44805, 1186, 364, "Output",
   CellTags->"dump_eq_invr_p_g"]},
 "dump_eq_pf_D_t"->{
  Cell[1321171, 36859, 36961, 995, 436, "Output",
   CellTags->"dump_eq_pf_D_t"]},
 "dump_eq_p_g"->{
  Cell[1539413, 42821, 43750, 1143, 279, "Output",
   CellTags->"dump_eq_p_g"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"depGraph1", 1996238, 54105},
 {"dumpWf", 1996329, 54108},
 {"dumpWg", 1996419, 54111},
 {"dump_eq_cW", 1996513, 54114},
 {"dump_eq_C_1", 1996607, 54117},
 {"dump_eq_fA_t", 1996707, 54120},
 {"dump_eq_f_rho", 1996892, 54125},
 {"dump_eq_gA_t", 1996993, 54128},
 {"dump_eq_gBet", 1997175, 54133},
 {"dump_eq_gC_rho", 1997277, 54136},
 {"dump_eq_g_rho", 1997380, 54139},
 {"dump_eq_invr_C_1", 1997485, 54142},
 {"dump_eq_invr_gC_rho", 1997597, 54145},
 {"dump_eq_invr_p_g", 1997708, 54148},
 {"dump_eq_pf_D_t", 1997815, 54151},
 {"dump_eq_p_g", 1997916, 54154}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 202, 6, 93, "Text"],
Cell[763, 28, 28, 0, 38, "Text"],
Cell[794, 30, 60, 0, 38, "Text"],
Cell[857, 32, 81, 4, 38, "Text"],
Cell[941, 38, 138, 3, 38, "Text"],
Cell[1082, 43, 450, 9, 38, "Text"],
Cell[1535, 54, 61, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[1621, 58, 50, 0, 42, "Subsubsection"],
Cell[1674, 60, 50, 0, 72, "Text"],
Cell[1727, 62, 509, 9, 385, "Input"],
Cell[2239, 73, 42, 0, 72, "Text"],
Cell[2284, 75, 827, 23, 160, "Input"],
Cell[3114, 100, 61, 0, 72, "Text"],
Cell[3178, 102, 2043, 52, 385, "Input"],
Cell[5224, 156, 38, 0, 72, "Text"],
Cell[5265, 158, 2827, 75, 431, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[8129, 238, 63, 0, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[8217, 242, 72, 1, 36, "Input"],
Cell[CellGroupData[{
Cell[8314, 247, 6893, 212, 54, "Echo"],
Cell[15210, 461, 6378, 193, 60, "Echo"],
Cell[21591, 656, 10039, 291, 81, "Echo"],
Cell[31633, 949, 10868, 311, 62, "Echo"],
Cell[42504, 1262, 12520, 370, 85, "Echo"],
Cell[55027, 1634, 13192, 396, 90, "Echo"],
Cell[68222, 2032, 11276, 319, 89, "Echo"],
Cell[79501, 2353, 10711, 306, 62, "Echo"],
Cell[90215, 2661, 13659, 397, 67, "Echo"],
Cell[103877, 3060, 7141, 221, 54, "Echo"],
Cell[111021, 3283, 6779, 207, 65, "Echo"],
Cell[117803, 3492, 10766, 314, 94, "Echo"],
Cell[128572, 3808, 11756, 339, 72, "Echo"],
Cell[140331, 4149, 13082, 387, 87, "Echo"],
Cell[153416, 4538, 13966, 419, 91, "Echo"],
Cell[167385, 4959, 12142, 346, 108, "Echo"],
Cell[179530, 5307, 11535, 332, 73, "Echo"],
Cell[191068, 5641, 13437, 392, 73, "Echo"],
Cell[204508, 6035, 5874, 166, 53, "Echo"],
Cell[210385, 6203, 7862, 218, 53, "Echo"],
Cell[218250, 6423, 7896, 219, 56, "Echo"],
Cell[226149, 6644, 1394, 41, 63, "Echo"],
Cell[227546, 6687, 931, 28, 31, "Echo"],
Cell[228480, 6717, 4867, 138, 67, "Echo"],
Cell[233350, 6857, 1271, 38, 56, "Echo"],
Cell[234624, 6897, 974, 30, 56, "Echo"],
Cell[235601, 6929, 1293, 39, 56, "Echo"],
Cell[236897, 6970, 121, 4, 31, "Echo"],
Cell[237021, 6976, 4710, 137, 61, "Echo"],
Cell[241734, 7115, 5135, 151, 67, "Echo"],
Cell[246872, 7268, 2013, 60, 48, "Echo"],
Cell[248888, 7330, 2168, 65, 52, "Echo"],
Cell[251059, 7397, 16435, 455, 117, "Echo"],
Cell[267497, 7854, 5165, 151, 61, "Echo"],
Cell[272665, 8007, 5616, 166, 67, "Echo"],
Cell[278284, 8175, 8097, 229, 61, "Echo"],
Cell[286384, 8406, 16426, 455, 117, "Echo"],
Cell[302813, 8863, 3077, 91, 55, "Echo"],
Cell[305893, 8956, 2087, 64, 56, "Echo"],
Cell[307983, 9022, 8412, 240, 68, "Echo"],
Cell[316398, 9264, 5173, 151, 55, "Echo"],
Cell[321574, 9417, 2508, 75, 55, "Echo"],
Cell[324085, 9494, 1715, 53, 56, "Echo"],
Cell[325803, 9549, 8276, 233, 57, "Echo"],
Cell[334082, 9784, 4194, 124, 55, "Echo"],
Cell[338279, 9910, 5679, 162, 60, "Echo"],
Cell[343961, 10074, 5354, 153, 63, "Echo"],
Cell[349318, 10229, 28973, 777, 168, "Echo"],
Cell[378294, 11008, 1352, 41, 48, "Echo"],
Cell[379649, 11051, 1466, 45, 48, "Echo"],
Cell[381118, 11098, 143401, 3480, 540, "Echo"],
Cell[524522, 14580, 140846, 3435, 552, "Echo"],
Cell[665371, 18017, 2060, 63, 34, "Echo"],
Cell[667434, 18082, 1770, 58, 46, "Echo"],
Cell[669207, 18142, 1826, 60, 53, "Echo"],
Cell[671036, 18204, 4016, 127, 51, "Echo"],
Cell[675055, 18333, 4158, 132, 57, "Echo"],
Cell[679216, 18467, 5523, 173, 58, "Echo"],
Cell[684742, 18642, 5721, 180, 58, "Echo"],
Cell[690466, 18824, 117, 4, 31, "Echo"],
Cell[690586, 18830, 120, 4, 31, "Echo"],
Cell[690709, 18836, 440, 14, 47, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[691210, 18857, 95, 2, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[691330, 18863, 1763, 50, 221, "Input"],
Cell[CellGroupData[{
Cell[693118, 18917, 2854, 87, 48, "Echo"],
Cell[695975, 19006, 2856, 88, 48, "Echo"],
Cell[698834, 19096, 7832, 224, 55, "Echo"],
Cell[706669, 19322, 8702, 245, 62, "Echo"],
Cell[715374, 19569, 4304, 134, 48, "Echo"],
Cell[719681, 19705, 4294, 134, 48, "Echo"],
Cell[723978, 19841, 9614, 267, 62, "Echo"],
Cell[733595, 20110, 9006, 253, 62, "Echo"],
Cell[742604, 20365, 6324, 187, 58, "Echo"],
Cell[748931, 20554, 3027, 93, 48, "Echo"],
Cell[751961, 20649, 3053, 95, 52, "Echo"],
Cell[755017, 20746, 8437, 243, 65, "Echo"],
Cell[763457, 20991, 9433, 268, 72, "Echo"],
Cell[772893, 21261, 4551, 142, 48, "Echo"],
Cell[777447, 21405, 4540, 142, 48, "Echo"],
Cell[781990, 21549, 10394, 291, 78, "Echo"],
Cell[792387, 21842, 9743, 276, 73, "Echo"],
Cell[802133, 22120, 5492, 165, 59, "Echo"],
Cell[807628, 22287, 5874, 166, 53, "Echo"],
Cell[813505, 22455, 7862, 218, 53, "Echo"],
Cell[821370, 22675, 7896, 219, 56, "Echo"],
Cell[829269, 22896, 1394, 41, 63, "Echo"],
Cell[830666, 22939, 931, 28, 31, "Echo"],
Cell[831600, 22969, 4867, 138, 67, "Echo"],
Cell[836470, 23109, 1271, 38, 56, "Echo"],
Cell[837744, 23149, 974, 30, 56, "Echo"],
Cell[838721, 23181, 1293, 39, 56, "Echo"],
Cell[840017, 23222, 121, 4, 31, "Echo"],
Cell[840141, 23228, 4710, 137, 61, "Echo"],
Cell[844854, 23367, 5135, 151, 67, "Echo"],
Cell[849992, 23520, 2013, 60, 48, "Echo"],
Cell[852008, 23582, 2168, 65, 52, "Echo"],
Cell[854179, 23649, 128, 4, 31, "Echo"],
Cell[854310, 23655, 5165, 151, 61, "Echo"],
Cell[859478, 23808, 5616, 166, 67, "Echo"],
Cell[865097, 23976, 8097, 229, 61, "Echo"],
Cell[873197, 24207, 119, 4, 31, "Echo"],
Cell[873319, 24213, 1270, 38, 56, "Echo"],
Cell[874592, 24253, 973, 30, 56, "Echo"],
Cell[875568, 24285, 1927, 56, 56, "Echo"],
Cell[877498, 24343, 1927, 56, 56, "Echo"],
Cell[879428, 24401, 121, 4, 31, "Echo"],
Cell[879552, 24407, 119, 4, 31, "Echo"],
Cell[879674, 24413, 121, 4, 31, "Echo"],
Cell[879798, 24419, 121, 4, 31, "Echo"],
Cell[879922, 24425, 131, 4, 31, "Echo"],
Cell[880056, 24431, 131, 4, 31, "Echo"],
Cell[880190, 24437, 131, 4, 31, "Echo"],
Cell[880324, 24443, 1352, 41, 48, "Echo"],
Cell[881679, 24486, 1466, 45, 48, "Echo"],
Cell[883148, 24533, 118, 4, 31, "Echo"],
Cell[883269, 24539, 118, 4, 31, "Echo"],
Cell[883390, 24545, 118, 4, 31, "Echo"],
Cell[883511, 24551, 442, 16, 31, "Echo"],
Cell[883956, 24569, 442, 16, 31, "Echo"],
Cell[884401, 24587, 549, 20, 31, "Echo"],
Cell[884953, 24609, 549, 20, 31, "Echo"],
Cell[885505, 24631, 586, 21, 45, "Echo"],
Cell[886094, 24654, 586, 21, 45, "Echo"],
Cell[886683, 24677, 117, 4, 31, "Echo"],
Cell[886803, 24683, 120, 4, 31, "Echo"],
Cell[886926, 24689, 440, 14, 47, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[887427, 24710, 67, 1, 42, "Subsubsection",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[887519, 24715, 130, 3, 36, "Input"],
Cell[887652, 24720, 104222, 2889, 447, "Output",
 CellTags->"dump_eq_gA_t"]
}, Open  ]],
Cell[CellGroupData[{
Cell[991911, 27614, 155, 4, 36, "Input"],
Cell[992069, 27620, 106430, 2985, 550, "Output",
 CellTags->"dump_eq_gA_t"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1098536, 30610, 130, 3, 36, "Input"],
Cell[1098669, 30615, 109880, 3060, 496, "Output",
 CellTags->"dump_eq_fA_t"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1208586, 33680, 155, 4, 36, "Input"],
Cell[1208744, 33686, 112231, 3162, 598, "Output",
 CellTags->"dump_eq_fA_t"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1321012, 36853, 156, 4, 36, "Input"],
Cell[1321171, 36859, 36961, 995, 436, "Output",
 CellTags->"dump_eq_pf_D_t"]
}, {2}]],
Cell[CellGroupData[{
Cell[1358166, 37859, 148, 4, 36, "Input"],
Cell[1358317, 37865, 32666, 881, 306, "Output",
 CellTags->"dump_eq_gC_rho"]
}, {2}]],
Cell[CellGroupData[{
Cell[1391017, 38751, 166, 4, 36, "Input"],
Cell[1391186, 38757, 32639, 893, 382, "Output",
 CellTags->"dump_eq_invr_gC_rho"]
}, {2}]],
Cell[CellGroupData[{
Cell[1423859, 39655, 202, 4, 36, "Input"],
Cell[1424064, 39661, 20768, 574, 218, "Output",
 CellTags->"dump_eq_g_rho"]
}, {2}]],
Cell[CellGroupData[{
Cell[1444866, 40240, 223, 5, 36, "Input"],
Cell[1445092, 40247, 18577, 512, 204, "Output",
 CellTags->"dump_eq_f_rho"]
}, {2}]],
Cell[CellGroupData[{
Cell[1463703, 40764, 127, 3, 36, "Input"],
Cell[1463833, 40769, 37706, 1012, 282, "Output",
 CellTags->"dump_eq_C_1"]
}, {2}]],
Cell[CellGroupData[{
Cell[1501573, 41786, 148, 4, 36, "Input"],
Cell[1501724, 41792, 37540, 1020, 341, "Output",
 CellTags->"dump_eq_invr_C_1"]
}, {2}]],
Cell[CellGroupData[{
Cell[1539298, 42817, 112, 2, 36, "Input"],
Cell[1539413, 42821, 43750, 1143, 279, "Output",
 CellTags->"dump_eq_p_g"]
}, {2}]],
Cell[CellGroupData[{
Cell[1583197, 43969, 133, 3, 36, "Input"],
Cell[1583333, 43974, 44805, 1186, 364, "Output",
 CellTags->"dump_eq_invr_p_g"]
}, {2}]],
Cell[CellGroupData[{
Cell[1628172, 45165, 109, 2, 36, "Input"],
Cell[1628284, 45169, 26658, 794, 268, "Output",
 CellTags->"dump_eq_gBet"]
}, {2}]],
Cell[1654954, 45966, 612, 24, 42, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[1655591, 45994, 417, 10, 36, "Input"],
Cell[1656011, 46006, 146963, 3506, 457, "Output",
 CellTags->"dumpWg"]
}, {2}]],
Cell[CellGroupData[{
Cell[1803008, 49517, 417, 10, 36, "Input"],
Cell[1803428, 49529, 144499, 3461, 493, "Output",
 CellTags->"dumpWf"]
}, {2}]],
Cell[CellGroupData[{
Cell[1947961, 52995, 289, 7, 36, "Input"],
Cell[1948253, 53004, 2756, 79, 77, "Output",
 CellTags->"dump_eq_cW"]
}, {2}]],
Cell[1951021, 53086, 347, 12, 38, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[1951393, 53102, 7136, 180, 478, "Input"],
Cell[1958532, 53284, 34124, 740, 432, "Output",
 CellTags->"depGraph1"]
}, {2}]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
