(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     19605,        563]
NotebookOptionsPosition[     15399,        462]
NotebookOutlinePosition[     19005,        544]
CellTagsIndexPosition[     18962,        541]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Initial Data: Bimetric proportional Minkowski", "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"id$setup", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"id$title", "=", "\"\<Minkowski solution\>\""}], ";"}], 
  " "}]}], "Input"],

Cell["Setup the gauge,", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eq$q", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$gAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$fAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"gAlp", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"gW", "[", 
      RowBox[{"t", ",", "r"}], "]"}], "/", 
     RowBox[{"fW", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";"}]}], "Input"],

Cell["The constraints,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "\[IndentingNewLine]", "fA",
      ",", "fB", ",", "fK1", ",", "fK2", ",", "\[IndentingNewLine]", "gAlp", 
     ",", "fAlp", ",", "\[IndentingNewLine]", "pfD", ",", "pfS", ",", 
     "pf\[Tau]", ",", "\[IndentingNewLine]", "Lt", ",", "p", ",", "q", ",", 
     "R", ",", "\[IndentingNewLine]", "P", ",", "\[Beta]", ",", "sol$\[Beta]",
      ",", "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",", "g$JK2", ",",
      "f$\[Rho]", ",", "f$JK1", ",", "f$JK2", ",", "\[IndentingNewLine]", 
     RowBox[{"$Assumptions", "=", 
      RowBox[{"r", ">", "0"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "id$gA", ",", "id$gB", ",", "id$gK1", ",", "id$gK2", ",", "id$fA", ",", 
      "id$fB", ",", "id$fK1", ",", "id$fK2", ",", "id$p", ",", "id$pfD", ",", 
      "id$pfS", ",", "id$pf\[Tau]"}], "]"}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gA", "[", "r_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gB", "[", "r_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK1", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK2", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fA", "[", "r_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fB", "[", "r_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK1", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK2", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$p", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfD", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfS", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pf\[Tau]", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"P", "[", 
      RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
     RowBox[{"eq$esP", "[", 
      RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfD", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfD", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfS", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfS", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pf\[Tau]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"fB", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "/", 
      RowBox[{"gB", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$p", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Lt", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"p", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
      RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c$1", ",", "c$2", ",", "c$3", ",", "c$4", ",", "c$p"}], "}"}], 
     "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          UnderscriptBox["eq$C1", "_"], ",", 
          UnderscriptBox["eq$C2", "_"], ",", 
          UnderscriptBox["eq$C3", "_"], ",", 
          UnderscriptBox["eq$C4", "_"], ",", 
          UnderscriptBox["eq$p$g", "_"]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", "Expand"}],
       "//", "Simplify"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Echo", "/@", 
     RowBox[{"printNice", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$p \[Equal] \>\"", ",", "c$p"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$1 \[Equal] \>\"", ",", "c$1"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$2 \[Equal] \>\"", ",", "c$2"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$3 \[Equal] \>\"", ",", "c$3"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$4 \[Equal] \>\"", ",", "c$4"}], "}"}]}]}], 
        "\[IndentingNewLine]", "}"}], ",", "$disabledESP$"}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"sol$\[Beta]", "=", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c$1", "\[Equal]", "0"}], "&&", 
         RowBox[{"c$2", "\[Equal]", "0"}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
          RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Echo", "@", 
     RowBox[{"printNice", "[", 
      RowBox[{"sol$\[Beta]", ",", "$disabledESP$"}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"with", " ", "some", " ", "random", " ", "parameters"}], 
      "..."}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"id$modelParams", "=", 
     RowBox[{
      RowBox[{"modelParamNames", "/.", "sol$\[Beta]"}], "/.", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"k$g", "\[Rule]", "1"}], ",", 
        RowBox[{"k$f", "\[Rule]", "1"}], ",", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "1", "]"}], "\[Rule]", 
         RowBox[{"1", "/", "10"}]}], ",", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "2", "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "20"}]}], ",", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "3", "]"}], "\[Rule]", 
         RowBox[{"1", "/", "5"}]}]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"c$1", "\[Equal]", "0"}], "&&", 
       RowBox[{"c$2", "\[Equal]", "0"}]}], "/.", 
      RowBox[{"Thread", "[", 
       RowBox[{"modelParamNames", "\[Rule]", "id$modelParams"}], "]"}]}], "//",
      "Echo"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["W", "g"], "\[Rule]", 
        UnderscriptBox["eq$gW", "_"]}], "/.", 
       RowBox[{"Thread", "[", 
        RowBox[{"modelParamNames", "\[Rule]", "id$modelParams"}], "]"}]}], "//",
       "Simplify"}], "//", "Echo"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["W", "f"], "\[Rule]", 
        UnderscriptBox["eq$fW", "_"]}], "/.", 
       RowBox[{"Thread", "[", 
        RowBox[{"modelParamNames", "\[Rule]", "id$modelParams"}], "]"}]}], "//",
       "Simplify"}], "//", "Echo"}], ";"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{"\"c$p \[Equal] \"","0"},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 TemplateBox[{"\"c$1 \[Equal] \"",RowBox[{
     RowBox[{"-", 
       StyleBox[
        SubscriptBox["\[Kappa]", "g"], 
        RGBColor[0, 0, 1], StripOnInput -> False]}], " ", 
     RowBox[{"(", 
       RowBox[{
         SubscriptBox["\[Beta]", "0"], "+", 
         RowBox[{"3", " ", 
           SubscriptBox["\[Beta]", "1"]}], "+", 
         RowBox[{"3", " ", 
           SubscriptBox["\[Beta]", "2"]}], "+", 
         SubscriptBox["\[Beta]", "3"]}], ")"}]}]},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 TemplateBox[{"\"c$2 \[Equal] \"",RowBox[{
     RowBox[{"-", 
       StyleBox[
        SubscriptBox["\[Kappa]", "f"], 
        RGBColor[1, 0, 0], StripOnInput -> False]}], " ", 
     RowBox[{"(", 
       RowBox[{
         SubscriptBox["\[Beta]", "1"], "+", 
         RowBox[{"3", " ", 
           SubscriptBox["\[Beta]", "2"]}], "+", 
         RowBox[{"3", " ", 
           SubscriptBox["\[Beta]", "3"]}], "+", 
         SubscriptBox["\[Beta]", "4"]}], ")"}]}]},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 TemplateBox[{"\"c$3 \[Equal] \"","0"},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 TemplateBox[{"\"c$4 \[Equal] \"","0"},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "0"], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SubscriptBox["\[Beta]", "1"]}], "-", 
     RowBox[{"3", " ", 
      SubscriptBox["\[Beta]", "2"]}], "-", 
     SubscriptBox["\[Beta]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Beta]", "4"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Beta]", "1"]}], "-", 
     RowBox[{"3", " ", 
      SubscriptBox["\[Beta]", "2"]}], "-", 
     RowBox[{"3", " ", 
      SubscriptBox["\[Beta]", "3"]}]}]}]}], "}"}]], "Echo"],

Cell[BoxData["True"], "Echo"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["W", "g"], "\[Rule]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     SuperscriptBox["r", "2"]}], "125"]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["W", "f"], "\[Rule]", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox["r", "2"]}], "125"]}]], "Echo"]
}, Open  ]]
}, Open  ]],

Cell["The default integration parameters for this case,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r1", "=", "100"}], ";", 
  RowBox[{"nLen", "=", 
   RowBox[{"100", "r1"}]}], ";", 
  RowBox[{"nOut", "=", "nLen"}], ";", 
  RowBox[{"nSkip", "=", "1"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", "=", "1"}], ";", 
  RowBox[{"\[CapitalDelta]t", "=", "0.001"}], ";", 
  RowBox[{"mSkip", "=", "10"}], ";", " ", 
  RowBox[{"iMethod", "=", "\"\<RK3\>\""}], ";"}]], "Input"]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1334, 1053},
WindowMargins->{{266, Automatic}, {Automatic, 11}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 97, 2, 53, "Text"],
Cell[658, 24, 198, 6, 60, "Input"],
Cell[859, 32, 32, 0, 38, "Text"],
Cell[894, 34, 645, 23, 83, "Input"],
Cell[1542, 59, 32, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[1599, 63, 11045, 293, 1749, "Input"],
Cell[CellGroupData[{
Cell[12669, 360, 79, 2, 29, "Echo"],
Cell[12751, 364, 502, 14, 29, "Echo"],
Cell[13256, 380, 502, 14, 29, "Echo"],
Cell[13761, 396, 79, 2, 29, "Echo"],
Cell[13843, 400, 79, 2, 29, "Echo"],
Cell[13925, 404, 599, 20, 29, "Echo"],
Cell[14527, 426, 29, 0, 29, "Echo"],
Cell[14559, 428, 170, 6, 48, "Echo"],
Cell[14732, 436, 149, 5, 48, "Echo"]
}, Open  ]]
}, Open  ]],
Cell[14908, 445, 65, 0, 38, "Text"],
Cell[14976, 447, 204, 6, 36, "Input"],
Cell[15183, 455, 212, 5, 36, "Input"]
}
]
*)

(* End of internal cache information *)
