(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    161199,       3596]
NotebookOptionsPosition[    155585,       3454]
NotebookOutlinePosition[    159190,       3536]
CellTagsIndexPosition[    159147,       3533]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Initial Data: Bimetric FLRW", "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell["The initial data is based on:", "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Cosmological Solutions in Bimetric Gravity and their Observational \
Tests",
  FontSlant->"Italic"],
 "\n\tMikael von Strauss, Angnis Schmidt-May, Jonas Enander, Edvard Mortsell, \
S. F. Hassan,\n\t",
 ButtonBox["arXiv:1111.1655v2",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1111.1655"], None},
  ButtonNote->"https://arxiv.org/abs/1111.1655"]
}], "Text"],

Cell[CellGroupData[{

Cell["Identification", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"id$setup", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"id$title", "=", "\"\<FLRW solution\>\""}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$debugMode", "=", "True"}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$usersPrintNiceMap", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f_", "]"}], "[", "t", 
       "]"}], "\[RuleDelayed]", 
      OverscriptBox["f", "."]}], ",", 
     RowBox[{
      RowBox[{"f_", "[", "t", "]"}], "\[RuleDelayed]", "f"}], ",", 
     RowBox[{"\[Rho]\[FivePointedStar]", "\[Rule]", 
      SubscriptBox["\[Rho]", "\[FivePointedStar]"]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"a$0", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{
        SubscriptBox["a", "0"], ",", "Brown", ",", "Bold"}], "]"}]}], ",", 
     RowBox[{"Y$0", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{
        SubscriptBox["Y", "0"], ",", "Brown", ",", "Bold"}], "]"}]}], ",", 
     RowBox[{"R$0", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{
        SubscriptBox["R", "0"], ",", "Brown", ",", "Bold"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Rho]\[FivePointedStar]$0", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{
        SubscriptBox["\[Rho]", "\[FivePointedStar]"], ",", "Purple", ",", 
        "Bold"}], "]"}]}], ",", 
     RowBox[{"gK$0", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{
        SubscriptBox["K", "0"], ",", "Brown", ",", "Bold"}], "]"}]}], ",", 
     RowBox[{"fK$0", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["K", "~"], "0"], ",", "Brown", ",", "Bold"}], 
       "]"}]}]}], "}"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gauge", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eq$q", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$gAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$fAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"gAlp", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"gW", "[", 
      RowBox[{"t", ",", "r"}], "]"}], "/", 
     RowBox[{"fW", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preview of the equations of motion from the paper", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqs", "=", 
   RowBox[{"Block", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "gAlp", ",", "gBet", ",", 
       "fA", ",", "fB", ",", "fK1", ",", "fK2", ",", "fAlp", ",", "fBet", ",",
        "\[IndentingNewLine]", "P", ",", "\[Beta]", ",", "g$\[Rho]", ",", 
       "g$j", ",", "g$JK1", ",", "g$JK2", ",", "f$\[Rho]", ",", "f$j", ",", 
       "f$JK1", ",", "f$JK2"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"gAlp", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gBet", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gA", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "/", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"k", " ", 
            RowBox[{"r", "^", "2"}]}]}], ")"}], 
         RowBox[{"1", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gB", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"a", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fAlp", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"X", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fBet", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fA", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"Y", "[", "t", "]"}], "/", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"k", " ", 
            RowBox[{"r", "^", "2"}]}]}], ")"}], 
         RowBox[{"1", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fB", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"Y", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["gA", "_"], ",", "t"}], "]"}], "-", 
           UnderscriptBox["evol$eq$gA", "_"]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["gB", "_"], ",", "t"}], "]"}], "-", 
           UnderscriptBox["evol$eq$gB", "_"]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["gK1", "_"], ",", "t"}], "]"}], "-", 
           UnderscriptBox["evol$eq$gK1", "_"]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["gK2", "_"], ",", "t"}], "]"}], "-", 
           UnderscriptBox["evol$eq$gK2", "_"]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["fA", "_"], ",", "t"}], "]"}], "-", 
           UnderscriptBox["evol$eq$fA", "_"]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["fB", "_"], ",", "t"}], "]"}], "-", 
           UnderscriptBox["evol$eq$fB", "_"]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["fK1", "_"], ",", "t"}], "]"}], "-", 
           UnderscriptBox["evol$eq$fK1", "_"]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["fK2", "_"], ",", "t"}], "]"}], "-", 
           UnderscriptBox["evol$eq$fK2", "_"]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           UnderscriptBox["eq$gC$\[Rho]", "_"], "-", 
           RowBox[{"k$g", 
            UnderscriptBox["g$\[Rho]", "_"]}]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           UnderscriptBox["eq$gC$j", "_"], "-", 
           RowBox[{"k$g", 
            UnderscriptBox["g$j", "_"]}]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           UnderscriptBox["eq$fC$\[Rho]", "_"], "-", 
           RowBox[{"k$f", 
            UnderscriptBox["f$\[Rho]", "_"]}]}], "//", "Simplify"}], "//", 
         "echoNice"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           UnderscriptBox["eq$fC$j", "_"], "-", 
           RowBox[{"k$f", 
            UnderscriptBox["f$j", "_"]}]}], "//", "Simplify"}], "//", 
         "echoNice"}]}], "\[IndentingNewLine]", "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The constraint equations", "Subsubsection"],

Cell[TextData[{
 "In the following, we analyze a pressureless fluid where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Rho]", "\[FivePointedStar]"], " ", "=", " ", 
    RowBox[{"\[Rho]", "/", 
     RowBox[{"(", 
      RowBox[{"3", 
       SuperscriptBox[
        SubscriptBox["M", "g"], "2"], 
       SuperscriptBox["m", "2"]}], ")"}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Block", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "fA", ",", "fB", ",", "fK1",
      ",", "fK2", ",", "\[IndentingNewLine]", "gAlp", ",", "fAlp", ",", "pfD",
      ",", "pfS", ",", "pf\[Tau]", ",", "\[IndentingNewLine]", "Lt", ",", "p",
      ",", "q", ",", "R", ",", "P", ",", "\[Beta]", ",", 
     "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",", "g$JK2", ",", 
     "f$\[Rho]", ",", "f$JK1", ",", "f$JK2"}], "\[IndentingNewLine]", "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "id$gA", ",", "id$gB", ",", "id$gK1", ",", "id$gK2", ",", "id$fA", ",", 
      "id$fB", ",", "id$fK1", ",", "id$fK2", ",", "id$p", ",", "id$pfD", ",", 
      "id$pfS", ",", "id$pf\[Tau]"}], "]"}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"P", "[", 
      RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
     RowBox[{"eq$esP", "[", 
      RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"fB", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "/", 
      RowBox[{"gB", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Lt", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"p", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
      RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gA", "[", "r_", "]"}], ":=", 
     RowBox[{"a$0", "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"k", " ", 
          RowBox[{"r", "^", "2"}]}]}], ")"}], 
       RowBox[{"1", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gB", "[", "r_", "]"}], ":=", "a$0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK1", "[", "r_", "]"}], ":=", 
     RowBox[{"gK", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK2", "[", "r_", "]"}], ":=", 
     RowBox[{"gK", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fA", "[", "r_", "]"}], ":=", 
     RowBox[{"Y$0", "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"k", " ", 
          RowBox[{"r", "^", "2"}]}]}], ")"}], 
       RowBox[{"1", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fB", "[", "r_", "]"}], ":=", "Y$0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK1", "[", "r_", "]"}], ":=", 
     RowBox[{"fK", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK2", "[", "r_", "]"}], ":=", 
     RowBox[{"fK", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$p", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfD", "[", "r_", "]"}], ":=", 
     RowBox[{"3", "\[Rho]\[FivePointedStar]$0", " ", 
      RowBox[{"id$gA", "[", "r", "]"}], 
      SuperscriptBox[
       RowBox[{"id$gB", "[", "r", "]"}], "2"]}]}], ";", "   ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"where", " ", 
       SubscriptBox["\[Rho]", "\[FivePointedStar]"]}], " ", "=", " ", 
      RowBox[{"\[Rho]", "/", 
       RowBox[{"(", 
        RowBox[{"3", 
         SuperscriptBox[
          SubscriptBox["M", "g"], "2"], 
         SuperscriptBox["m", "2"]}], ")"}]}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfS", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pf\[Tau]", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfD", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfD", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfS", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfS", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pf\[Tau]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$p", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c$1", ",", "c$2", ",", "c$3", ",", "c$4", ",", "c$p"}], "}"}], 
     "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          UnderscriptBox["eq$C1", "_"], ",", 
          UnderscriptBox["eq$C2", "_"], ",", 
          UnderscriptBox["eq$C3", "_"], ",", 
          UnderscriptBox["eq$C4", "_"], ",", 
          UnderscriptBox["eq$p$g", "_"]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", "Expand"}],
       "//", "Simplify"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Echo", "/@", 
     RowBox[{"printNice", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$p \[Equal] \>\"", ",", "c$p"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$1 \[Equal] \>\"", ",", "c$1"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$2 \[Equal] \>\"", ",", "c$2"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$3 \[Equal] \>\"", ",", "c$3"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$4 \[Equal] \>\"", ",", "c$4"}], "}"}]}]}], 
        "\[IndentingNewLine]", "}"}], ",", "$disabledESP$"}], "]"}]}], 
    ";"}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[TextData[{
 "The constraints suggest ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["K", "1"], "=", 
    RowBox[{
     SubscriptBox["K", "2"], "=", 
     RowBox[{"K", "(", 
      SubscriptBox["t", "0"], ")"}]}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["K", "~"], "1"], "=", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["K", "~"], "2"], "=", 
     RowBox[{
      OverscriptBox["K", "~"], "(", 
      SubscriptBox["t", "0"], ")"}]}]}], TraditionalForm]]],
 " as the initial data.  The other initial values are ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "(", 
    SubscriptBox["t", "0"], ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Y", "(", 
    SubscriptBox["t", "0"], ")"}], TraditionalForm]]],
 " (as we seek for ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["Y", TraditionalForm]]],
 " which are not dependent on ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the constraint equations (this gives the so-called \
\[OpenCurlyQuote]quartic equation\[CloseCurlyQuote])\
\>", "Subsubsection"],

Cell[TextData[{
 "Introduce the ratio ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "=", 
    RowBox[{
     RowBox[{
      OverscriptBox["B", "~"], "/", "B"}], "=", 
     RowBox[{"Y", "/", "a"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (capital upsilon \[CapitalUpsilon] in the original paper), then relate the \
extrinsic curvatures,"
}], "Text"],

Cell[BoxData[
 RowBox[{"\t", 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzt3W1MW3e+4PGj3X2xL84bv+RFJFYWkl9EQhHiBQiNYCWiVkgQpUKIpEIQ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     "], {{0, 132}, {1189, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->{376.2999999999993, Automatic},
   ImageSizeRaw->{1189, 132},
   PlotRange->{{0, 1189}, {0, 132}}]}]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Y$0", ",", "gK", ",", "fK", ",", "$Assumptions"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Y$0", "=", 
      RowBox[{"R$0", " ", "a$0"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gK", "[", "r_", "]"}], ":=", "gK$0"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fK", "[", "r_", "]"}], ":=", 
      RowBox[{"gK$0", "/", " ", "R$0"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"$Assumptions", "=", 
      RowBox[{
       RowBox[{"a$0", ">", "0"}], "&&", 
       RowBox[{"R$0", ">", "0"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"eqs", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "c$1"}], "/", "3"}], "/", "k$g"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"-", "c$2"}], "/", "3"}], "/", "k$g"}], " ", 
           SuperscriptBox["R$0", "2"]}], ",", "c$3", ",", "c$4", ",", "c$p"}],
          "}"}], "//", "FullSimplify"}], "//", "Expand"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"echoNice", "/@", "eqs"}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input"],

Cell[TextData[{
 "From the above we get the quartic equation in ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ","
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eqs2", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"0", "\[Equal]", 
      RowBox[{"eqs", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
      ",", 
     RowBox[{"0", "\[Equal]", 
      RowBox[{"eqs", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
      ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"0", "\[Equal]", 
       RowBox[{"R$0", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
          "eqs", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "-", 
          RowBox[{
          "eqs", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}]}]}], "//", 
      RowBox[{
       RowBox[{"Collect", "[", 
        RowBox[{"#", ",", "R$0", ",", "Simplify"}], "]"}], "&"}]}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"echoNice", "/@", "eqs2"}], ";"}]}], "Input"],

Cell[TextData[{
 "Compare to the paper, recalling that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       OverscriptBox["a", "."], "(", "t", ")"}], "/", 
      RowBox[{"a", "(", "t", ")"}]}], "=", 
     RowBox[{"-", 
      RowBox[{"K", "(", "t", ")"}]}]}]}], TraditionalForm]]],
 "  and  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     SubscriptBox["M", "\[FivePointedStar]"], "2"], "=", 
    RowBox[{
     SubscriptBox["k", "g"], "/", 
     SubscriptBox["k", "f"]}]}], TraditionalForm]]],
 ","
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzt3W9MG2e+L/DR/SPdF/PGL3mBxJVliRdIKLL8AoRW5kqgVJYgaoUsmgiZ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     "], {{0, 145}, {1429, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->{491.4599999999986, Automatic},
   ImageSizeRaw->{1429, 145},
   PlotRange->{{0, 1429}, {0, 145}}]], "Input"],
 "\n\t",
 Cell[BoxData[
  StyleBox[
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJzt3W9MG2e+L/DR/SPdF/PGL3mBxJVliReRUGT5BRFamSuBWlmCqBWySCJk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      "], {{0, 147}, {1460, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
     Selectable->False],
    BaseStyle->"ImageGraphics",
    ImageSize->{487.4599999999996, Automatic},
    ImageSizeRaw->{1460, 147},
    PlotRange->{{0, 1460}, {0, 147}}], "Text"]], "Input"],
 "\n\t",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzt3W9MG1feL/DRvVdX98W88UteIHGFLPEiUhQhXoDQCq5ElMoSjrJCFkmF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     "], {{0, 154}, {1736, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->{556.2599999999993, Automatic},
   ImageSizeRaw->{1736, 154},
   PlotRange->{{0, 1736}, {0, 154}}]], "Input"]
}], "Text"],

Cell[TextData[{
 "Hence, the initial conditions consist of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Rho]", "\[FivePointedStar]"], "(", 
    SubscriptBox["t", "0"], ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "(", 
    SubscriptBox["t", "0"], ")"}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"K", "(", 
    SubscriptBox["t", "0"], ")"}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "(", 
    SubscriptBox["t", "0"], ")"}], TraditionalForm]]],
 " is determined by the quartic equation."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preservation of bidiagonality", "Subsubsection"],

Cell[TextData[{
 "Since we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["K", "1"], "=", 
    RowBox[{
     SubscriptBox["K", "2"], "=", "K"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox["K", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is constant accross ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " across ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ","
}], "Text"],

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "fA", ",", "fB", ",", "fK1",
      ",", "fK2", ",", "gAlp", ",", "q", ",", "p", ",", "Lt"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     UnderscriptBox["eq$p$g", "_"], "//", "echoNice"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     UnderscriptBox["eq$p$f", "_"], "//", "echoNice"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], 
      RowBox[{"f", "[", "r", "]"}]}]}], ";", 
    RowBox[{
     RowBox[{"gB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"a", "[", "t", "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"gK1", "[", 
      RowBox[{
       RowBox[{"1", "t_"}], ",", "r_"}], "]"}], ":=", 
     RowBox[{"gK", "[", "t", "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"gK2", "[", 
      RowBox[{
       RowBox[{"1", "t_"}], ",", "r_"}], "]"}], ":=", 
     RowBox[{"gK", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Y", "[", "t", "]"}], 
      RowBox[{"f", "[", "r", "]"}]}]}], ";", 
    RowBox[{
     RowBox[{"fB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"Y", "[", "t", "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"fK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"fK", "[", "t", "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"fK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"fK", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     UnderscriptBox["eq$p$g", "_"], "//", "echoNice"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     UnderscriptBox["eq$p$f", "_"], "//", "echoNice"}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[TextData[{
 "Also ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], "p"}], TraditionalForm]]],
 "  stays ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], "p"}], "=", "0"}], TraditionalForm]]],
 ", if ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " was initially set to 0 and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Alpha]", "~"], TraditionalForm]]],
 " does not depend on ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 ","
}], "Text"],

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "fA", ",", "fB", ",", "fK1",
      ",", "fK2", ",", "gAlp", ",", "q", ",", "p", ",", "Lt"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     UnderscriptBox["evol$eq$p", "_"], "//", "echoNice"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], 
      RowBox[{"f", "[", "r", "]"}]}]}], ";", 
    RowBox[{
     RowBox[{"gB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"a", "[", "t", "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"gK1", "[", 
      RowBox[{
       RowBox[{"1", "t_"}], ",", "r_"}], "]"}], ":=", 
     RowBox[{"gK", "[", "t", "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"gK2", "[", 
      RowBox[{
       RowBox[{"1", "t_"}], ",", "r_"}], "]"}], ":=", 
     RowBox[{"gK", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Y", "[", "t", "]"}], 
      RowBox[{"f", "[", "r", "]"}]}]}], ";", 
    RowBox[{
     RowBox[{"fB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"Y", "[", "t", "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"fK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"fK", "[", "t", "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"fK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"fK", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     UnderscriptBox["evol$eq$p", "_"], "//", "echoNice"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gAlp", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
    RowBox[{
     RowBox[{"Lt", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     UnderscriptBox["evol$eq$p", "_"], "//", "echoNice"}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup the initial data (using manipulator)", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Block", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
      "\[Beta]", ",", "k$g", ",", "k$f", ",", "\[Rho]\[FivePointedStar]$0", 
       ",", "k", ",", "R$0", ",", "a$0", ",", "gK$0", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"t$0", "=", "0"}], ",", "gA", ",", "gB", ",", "gK1", ",", 
       "gK2", ",", "fA", ",", "fB", ",", "fK1", ",", "fK2", ",", 
       "\[IndentingNewLine]", "gAlp", ",", "fAlp", ",", "gBet", ",", "fBet", 
       ",", "\[IndentingNewLine]", "pfD", ",", "pfS", ",", "pf\[Tau]", ",", 
       "Lt", ",", "p", ",", "q", ",", "R", ",", "P", ",", 
       "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",", "g$JK2", ",", 
       "f$\[Rho]", ",", "f$JK1", ",", "f$JK2", ",", "\[IndentingNewLine]", 
       "a", ",", "gK", ",", "Y", ",", "fK", ",", "\[Rho]\[FivePointedStar]", 
       ",", "X"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Initial", " ", "conditions"}], " ", "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"k$g", "=", 
       RowBox[{"Rationalize", "@", "c$kg"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"k$f", "=", 
       RowBox[{"Rationalize", "@", "c$kf"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "0", "]"}], ":=", 
       RowBox[{"Rationalize", "@", "b$0"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "1", "]"}], ":=", 
       RowBox[{"Rationalize", "@", "b$1"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "2", "]"}], ":=", 
       RowBox[{"Rationalize", "@", "b$2"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "3", "]"}], ":=", 
       RowBox[{"Rationalize", "@", "b$3"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "4", "]"}], ":=", 
       RowBox[{"Rationalize", "@", "b$4"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"id$modelParams", "=", 
       RowBox[{"{", 
        RowBox[{"k$g", ",", "k$f", ",", 
         RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
         RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
         RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
         RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
         RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"id$\[Rho]\[FivePointedStar]", "=", 
       RowBox[{"\[Rho]\[FivePointedStar]$0", "=", 
        RowBox[{"Rationalize", "@", "c$\[Rho]\[FivePointedStar]$0"}]}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"id$k", "=", 
       RowBox[{"k", "=", 
        RowBox[{"Rationalize", "@", "c$k"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"id$a", "=", 
       RowBox[{"a$0", "=", 
        RowBox[{"Rationalize", "@", "c$a$0"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"id$R", "=", 
       RowBox[{
        RowBox[{"R$0", "/.", 
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "eqs2", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "\[And]", 
             RowBox[{"R$0", "\[Element]", "Reals"}], "\[And]", 
             RowBox[{"R$0", ">", "0"}]}], ",", "R$0", ",", 
            RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "//", 
        "Quiet"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"id$gK", "=", 
       RowBox[{
        RowBox[{"gK$0", "/.", 
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{"eqs2", "/.", 
              RowBox[{"R$0", "\[Rule]", "id$R"}]}], "]"}], ",", "gK$0", ",", 
            "Reals", ",", 
            RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "//", 
        "Quiet"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"id$Y", "=", 
       RowBox[{"id$R", " ", "id$a"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Equations", " ", "of", " ", "motion"}], " ", "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
       RowBox[{"eq$esP", "[", 
        RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"g$\[Rho]", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"eq$gV$\[Rho]", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "+", 
        RowBox[{"gT$\[Rho]", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"g$JK1", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"eq$gV$JK1", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "+", 
        RowBox[{"gT$JK1", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"g$JK2", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"eq$gV$JK2", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "+", 
        RowBox[{"gT$JK2", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f$\[Rho]", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"eq$fV$\[Rho]", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "+", 
        RowBox[{"fT$\[Rho]", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f$JK1", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"eq$fV$JK1", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "+", 
        RowBox[{"fT$JK1", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f$JK2", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"eq$fV$JK2", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "+", 
        RowBox[{"fT$JK2", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"R", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"fB", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "/", 
        RowBox[{"gB", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Lt", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"p", "[", 
           RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
        RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gA", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "/", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"k", " ", 
            RowBox[{"r", "^", "2"}]}]}], ")"}], 
         RowBox[{"1", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gB", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"a", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gK1", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"gK", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gK2", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"gK", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fA", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"Y", "[", "t", "]"}], "/", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"k", " ", 
            RowBox[{"r", "^", "2"}]}]}], ")"}], 
         RowBox[{"1", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fB", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"Y", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fK1", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"fK", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fK2", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"fK", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pfD", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"3", 
        RowBox[{"\[Rho]\[FivePointedStar]", "[", "t", "]"}], " ", 
        RowBox[{"gA", "[", 
         RowBox[{"t", ",", "r"}], "]"}], 
        SuperscriptBox[
         RowBox[{"gB", "[", 
          RowBox[{"t", ",", "r"}], "]"}], "2"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pfS", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pf\[Tau]", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"p", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "We", " ", "can", " ", "have", " ", "this", " ", "since", " ", "all", 
        " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], "K"}], " ", "are", " ", "zero"}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gBet", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fBet", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gAlp", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"fAlp", "[", 
        RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
       RowBox[{"X", "[", "t", "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Keep", " ", "X", " ", "uninstantiated"}], " ", "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"It", " ", "is", " ", "slower", " ", "to", " ", "have", " ", 
        RowBox[{"id$X", "[", "t_", "]"}], " ", 
        RowBox[{"below", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"id$X", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"gAlp", "[", 
           RowBox[{"t", ",", "r"}], "]"}]}], 
         RowBox[{
          RowBox[{"eq$gW", "[", 
           RowBox[{"t", ",", "r"}], "]"}], "/", 
          RowBox[{"eq$fW", "[", 
           RowBox[{"t", ",", "r"}], "]"}]}]}], "//", "Simplify"}]}], ";", " ",
       "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id$gW", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "=", 
       RowBox[{"eq$gW", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id$fW", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "=", 
       RowBox[{"eq$fW", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"id$eom", "=", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["gB", "_"], ",", "t"}], "]"}], "\[Equal]", 
          RowBox[{"(", 
           RowBox[{
            UnderscriptBox["evol$eq$gB", "_"], "//", "Simplify"}], ")"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["gK1", "_"], ",", "t"}], "]"}], "\[Equal]", 
          RowBox[{"(", 
           RowBox[{
            UnderscriptBox["evol$eq$gK1", "_"], "//", "Simplify"}], ")"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["fB", "_"], ",", "t"}], "]"}], "\[Equal]", 
          RowBox[{"(", 
           RowBox[{
            UnderscriptBox["evol$eq$fB", "_"], "//", "Simplify"}], ")"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["fK1", "_"], ",", "t"}], "]"}], "\[Equal]", 
          RowBox[{"(", 
           RowBox[{
            UnderscriptBox["evol$eq$fK1", "_"], "//", "Simplify"}], ")"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"\[Rho]\[FivePointedStar]", "[", "t", "]"}], ",", "t"}], 
           "]"}], "\[Equal]", 
          RowBox[{"3", 
           RowBox[{"gK", "[", "t", "]"}], 
           RowBox[{"\[Rho]\[FivePointedStar]", "[", "t", "]"}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"a", "[", "t$0", "]"}], "\[Equal]", "id$a"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"gK", "[", "t$0", "]"}], "\[Equal]", "id$gK"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Y", "[", "t$0", "]"}], "\[Equal]", 
          RowBox[{"id$a", " ", "id$R"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fK", "[", "t$0", "]"}], "\[Equal]", 
          RowBox[{"id$gK", "/", "id$R"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"\[Rho]\[FivePointedStar]", "[", "t$0", "]"}], "\[Equal]", 
          "id$\[Rho]\[FivePointedStar]"}]}], "\[IndentingNewLine]", "}"}]}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"X", "[", "t_", "]"}], "=", "id$X"}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Instantiate", " ", "X"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"id$sol", "=", 
       RowBox[{"Quiet", "@", 
        RowBox[{"NDSolveValue", "[", "\[IndentingNewLine]", 
         RowBox[{"id$eom", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "a", ",", "gK", ",", "Y", ",", "fK", ",", 
            "\[Rho]\[FivePointedStar]"}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "t$min", ",", "t$max"}], "}"}]}], 
         "\[IndentingNewLine]", "]"}]}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "@", "id$sol"}], "===", "NDSolveValue"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<  *** No solution ***\>\"", ",", "16", ",", "Red"}], 
         "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "sol$a", ",", "sol$gK", ",", "sol$Y", ",", "sol$fK", ",", 
            "sol$\[Rho]\[FivePointedStar]"}], "}"}], "=", "id$sol"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Quiet", "@", 
          RowBox[{"Plot", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"sol$a", "[", "t", "]"}], ",", 
              RowBox[{"sol$gK", "[", "t", "]"}], ",", 
              RowBox[{"sol$Y", "[", "t", "]"}], ",", 
              RowBox[{"sol$fK", "[", "t", "]"}], ",", 
              RowBox[{"100", 
               RowBox[{"sol$\[Rho]\[FivePointedStar]", "[", "t", "]"}]}], ",",
               "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "sol$Y", "]"}], 
                "[", "t", "]"}], "/", 
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "sol$a", "]"}], 
                "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{"id$X", "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"a", "\[Rule]", "sol$a"}], ",", 
                 RowBox[{"gK", "\[Rule]", "sol$gK"}], ",", 
                 RowBox[{"Y", "\[Rule]", "sol$Y"}], ",", 
                 RowBox[{"fK", "\[Rule]", "sol$fK"}], ",", 
                 RowBox[{
                 "\[Rho]\[FivePointedStar]", "\[Rule]", 
                  "sol$\[Rho]\[FivePointedStar]"}]}], "}"}]}]}], 
             "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"sol$a", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], 
              ",", 
              RowBox[{
               RowBox[{"sol$a", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], 
               "-", "0.2"}]}], "}"}], ",", 
            RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{"Placed", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"a", ",", "K", ",", "Y", ",", 
                 OverscriptBox["K", "~"], ",", 
                 RowBox[{"100", 
                  SubscriptBox["\[Rho]", "\[FivePointedStar]"]}], ",", "X", 
                 ",", 
                 OverscriptBox["\[Alpha]", "~"]}], "}"}], ",", 
               RowBox[{"Scaled", "[", 
                RowBox[{"{", 
                 RowBox[{"0.9", ",", "0.75"}], "}"}], "]"}]}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Blue", ",", 
               RowBox[{"Darker", "@", "Blue"}], ",", "Red", ",", 
               RowBox[{"Darker", "@", "Red"}], ",", 
               RowBox[{"Darker", "@", "Green"}], ",", "LightGray", ",", 
               RowBox[{"{", 
                RowBox[{"Black", ",", "Dashed"}], "}"}]}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"FrameLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"Row", "@", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "\"\< \[LongRightArrow]\>\""}], "}"}]}], 
                ",", "Black", ",", "16"}], "]"}], "}"}]}]}], 
           "\[IndentingNewLine]", "]"}]}]}]}], "\[IndentingNewLine]", 
       "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Text", "@", "\"\<\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"Text", "@", 
    RowBox[{"Style", "[", 
     RowBox[{"\"\<Initial conditions:\>\"", ",", "14"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c$\[Rho]\[FivePointedStar]$0", ",", 
       RowBox[{"1", "/", "100"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(\[FivePointedStar]\)]\)\>\""}], 
      "}"}], ",", "0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c$a$0", ",", "1", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(0\)]\)\>\""}], 
      "}"}], ",", "0.001", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c$k", ",", 
       RowBox[{"-", "1"}], ",", "\"\<k\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"Text", "@", 
    RowBox[{"Style", "[", 
     RowBox[{"\"\<Integration range:\>\"", ",", "14"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t$min", ",", "0", ",", 
       "\"\<\!\(\*SubscriptBox[\(t\), \(min\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "50"}], ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t$max", ",", "20", ",", 
       "\"\<\!\(\*SubscriptBox[\(t\), \(max\)]\)\>\""}], "}"}], ",", "1", ",",
      "50"}], "}"}], ",", "\[IndentingNewLine]", "Delimiter", ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Text", "@", 
    RowBox[{"Style", "[", 
     RowBox[{"\"\<Parameters:\>\"", ",", "14"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b$0", ",", "0", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(0\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b$1", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "20"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b$2", ",", "0", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b$3", ",", "0", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b$4", ",", "0", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(4\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c$kg", ",", "1", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)\>\""}], "}"}], ",", 
     "0.0001", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c$kf", ",", "1", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)\>\""}], "}"}], ",", 
     "0.0001", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Paneled", "\[Rule]", "False"}], ",", 
   RowBox[{"AppearanceElements", "\[Rule]", "None"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Now do the diagnostics (check the eom, the constraints etc) and setup the \
initial data\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"echoNice", "/@", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"X", "[", "t", "]"}], "\[Equal]", 
       RowBox[{"id$X", "[", "t", "]"}]}], "}"}], ",", "id$eom"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sol$X1", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{"id$X", "[", "t", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Rule]", "sol$a"}], ",", 
      RowBox[{"gK", "\[Rule]", "sol$gK"}], ",", 
      RowBox[{"Y", "\[Rule]", "sol$Y"}], ",", 
      RowBox[{"fK", "\[Rule]", "sol$fK"}], ",", 
      RowBox[{
      "\[Rho]\[FivePointedStar]", "\[Rule]", 
       "sol$\[Rho]\[FivePointedStar]"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"sol$X2", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sol$Y", "[", "t", "]"}], ",", "t"}], "]"}], "/", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sol$a", "[", "t", "]"}], ",", "t"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sol$X1", "[", "t", "]"}], ",", 
     RowBox[{"sol$X2", "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"sol$X1", "[", "t", "]"}], "-", 
      RowBox[{"sol$X2", "[", "t", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"sol$a", "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{
      RowBox[{"sol$a", "\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
      "0.2"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "1"}], ",", 
   RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      OverscriptBox["\[Alpha]", "~"], ",", 
      RowBox[{"X", "\[Equal]", 
       RowBox[{
        OverscriptBox["Y", "."], "/", 
        OverscriptBox["a", "."]}]}], ",", 
      RowBox[{
       OverscriptBox["\[Alpha]", "~"], "-", "\[VeryThinSpace]", "X"}]}], 
     "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Darker", "@", "Yellow"}], ",", "Dashed", ",", "Red"}], 
     "}"}]}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"diagnostics", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Block", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
          "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "fA", ",", "fB", ",", 
           "fK1", ",", "fK2", ",", "pfD", ",", "pfS", ",", "pf\[Tau]", ",", 
           "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",", "g$JK2", ",",
            "f$\[Rho]", ",", "f$JK1", ",", "f$JK2", ",", 
           "\[IndentingNewLine]", "Lt", ",", "p", ",", "q", ",", "R", ",", 
           "P", ",", "\[Beta]", ",", "k$g", ",", "k$f", ",", "k", ",", 
           "\[IndentingNewLine]", "gAlp", ",", "fAlp", ",", "K2const"}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"k", "=", "id$k"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"k$g", ",", "k$f", ",", 
             RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
             RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
             RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
             RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
             RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}], "=", 
           "id$modelParams"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$gA", "[", "r_", "]"}], ":=", 
           RowBox[{"id$a", "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"id$k", " ", 
                RowBox[{"r", "^", "2"}]}]}], ")"}], 
             RowBox[{"1", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$gB", "[", "r_", "]"}], ":=", "id$a"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$gK1", "[", "r_", "]"}], ":=", "id$gK"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$gK2", "[", "r_", "]"}], ":=", "id$gK"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$fA", "[", "r_", "]"}], ":=", 
           RowBox[{"id$Y", "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"id$k", " ", 
                RowBox[{"r", "^", "2"}]}]}], ")"}], 
             RowBox[{"1", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$fB", "[", "r_", "]"}], ":=", "id$Y"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$fK1", "[", "r_", "]"}], ":=", 
           RowBox[{"id$gK", "/", "id$R"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$fK2", "[", "r_", "]"}], ":=", 
           RowBox[{"id$gK", "/", "id$R"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$p", "[", "r_", "]"}], ":=", "0"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$pfD", "[", "r_", "]"}], ":=", 
           RowBox[{"3", "id$\[Rho]\[FivePointedStar]", " ", 
            RowBox[{"id$gA", "[", "r", "]"}], 
            SuperscriptBox[
             RowBox[{"id$gB", "[", "r", "]"}], "2"]}]}], ";", "   ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"where", " ", 
             SubscriptBox["\[Rho]", "*"]}], " ", "=", " ", 
            RowBox[{"\[Rho]", "/", 
             RowBox[{"(", 
              RowBox[{"3", 
               SuperscriptBox[
                SubscriptBox["M", "g"], "2"], 
               SuperscriptBox["m", "2"]}], ")"}]}]}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$pfS", "[", "r_", "]"}], ":=", "0"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"id$pf\[Tau]", "[", "r_", "]"}], ":=", "0"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"P", "[", 
            RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
           RowBox[{"eq$esP", "[", 
            RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"g$\[Rho]", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"eq$gV$\[Rho]", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "+", 
            RowBox[{"gT$\[Rho]", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"g$JK1", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"eq$gV$JK1", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "+", 
            RowBox[{"gT$JK1", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"g$JK2", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"eq$gV$JK2", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "+", 
            RowBox[{"gT$JK2", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"f$\[Rho]", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"eq$fV$\[Rho]", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "+", 
            RowBox[{"fT$\[Rho]", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"f$JK1", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"eq$fV$JK1", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "+", 
            RowBox[{"fT$JK1", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"f$JK2", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"eq$fV$JK2", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "+", 
            RowBox[{"fT$JK2", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"gA", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$gA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"gB", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$gB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"gK1", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$gK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"gK2", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$gK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"fA", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$fA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"fB", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$fB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"fK1", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"fK2", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"pfD", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$pfD", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"pfS", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$pfS", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"pf\[Tau]", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"R", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"id$fB", "[", "r", "]"}], "/", 
            RowBox[{"id$gB", "[", "r", "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"p", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{"id$p", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Lt", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"p", "[", 
               RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
            RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"gAlp", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"fAlp", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"gAlp", "[", 
              RowBox[{"t", ",", "r"}], "]"}]}], 
            RowBox[{
             RowBox[{"eq$gW", "[", 
              RowBox[{"t", ",", "r"}], "]"}], "/", 
             RowBox[{"eq$fW", "[", 
              RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"c$1", ",", "c$2", ",", "c$3", ",", "c$4", ",", "c$p"}], 
            "}"}], "=", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                UnderscriptBox["eq$C1", "_"], ",", 
                UnderscriptBox["eq$C2", "_"], ",", 
                UnderscriptBox["eq$C3", "_"], ",", 
                UnderscriptBox["eq$C4", "_"], ",", 
                UnderscriptBox["eq$p$g", "_"]}], "}"}], "/.", 
              RowBox[{"{", 
               RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", 
             "Expand"}], "//", "Simplify"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"c$p$t", "=", 
           UnderscriptBox["evol$eq$p", "_"]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"Grid", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "\"\<Constraints:\>\"", ",", "SpanFromLeft", ",", 
                 "SpanFromLeft"}], "}"}], ",", 
               RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<    \!\(\*SubscriptBox[\(C\), \(1\)]\), ..., \
\!\(\*SubscriptBox[\(C\), \(4\)]\)\>\"", ",", "\"\<=\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{"c$1", ",", "c$2", ",", "c$3", ",", "c$4"}], 
                  "}"}]}], "}"}], ",", 
               RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<Behavior of p and \!\(\*SubscriptBox[\(\[PartialD]\), \
\(t\)]\)p at \!\(\*SubscriptBox[\(t\), \(0\)]\)\>\"", ",", "SpanFromLeft", 
                 ",", "SpanFromLeft"}], "}"}], ",", 
               RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<    p\>\"", ",", "\"\<=\>\"", ",", "c$p"}], 
                "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<    \!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)p\>\"", 
                 ",", "\"\<=\>\"", ",", "c$p$t"}], "}"}], ",", 
               RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<The bimetric lapse ratio:\>\"", ",", "SpanFromLeft", ",",
                  "SpanFromLeft"}], "}"}], ",", 
               RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<    \[Alpha]\>\"", ",", "\"\<=\>\"", ",", 
                 RowBox[{"gAlp", "[", 
                  RowBox[{"t", ",", "r"}], "]"}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<    \!\(\*SubscriptBox[\(W\), \(g\)]\)\>\"", ",", 
                 "\"\<=\>\"", ",", 
                 RowBox[{"eq$gW", "[", 
                  RowBox[{"t", ",", "r"}], "]"}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<    \!\(\*SubscriptBox[\(W\), \(f\)]\)\>\"", ",", 
                 "\"\<=\>\"", ",", 
                 RowBox[{"eq$fW", "[", 
                  RowBox[{"t", ",", "r"}], "]"}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<    \!\(\*OverscriptBox[\(\[Alpha]\), \(~\)]\)\
\[ThinSpace]=\[ThinSpace]-\!\(\*SubscriptBox[\(W\), \(g\)]\)\[ThinSpace]/\
\[ThinSpace]\!\(\*SubscriptBox[\(W\), \(f\)]\)\>\"", ",", "\"\<=\>\"", ",", 
                 RowBox[{"fAlp", "[", 
                  RowBox[{"t", ",", "r"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<Crosscheck with \
X\[ThinSpace]=\[ThinSpace]\!\(\*OverscriptBox[\(Y\), \
\(.\)]\)/\!\(\*OverscriptBox[\(a\), \(.\)]\) from the paper:\>\"", ",", 
                 "SpanFromLeft", ",", "SpanFromLeft"}], "}"}], ",", 
               RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<   \!\(\*OverscriptBox[\(Y\), \(.\)]\)\[ThinSpace]=\
\[ThinSpace]-X\[ThinSpace]Y\[ThinSpace]\!\(\*SubscriptBox[OverscriptBox[\(K\),\
 \(~\)], \(2\)]\)\>\"", ",", "\"\<=\>\"", ",", 
                 RowBox[{
                  RowBox[{"-", " ", 
                   RowBox[{"fAlp", "[", 
                    RowBox[{"t", ",", "r"}], "]"}]}], 
                  RowBox[{"fB", "[", 
                   RowBox[{"t", ",", "r"}], "]"}], 
                  RowBox[{"fK2", "[", 
                   RowBox[{"t", ",", "r"}], "]"}]}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<   \!\(\*OverscriptBox[\(a\), \(.\)]\)\[ThinSpace]=\
\[ThinSpace]-a\[ThinSpace]\!\(\*SubscriptBox[\(K\), \(2\)]\)\>\"", ",", 
                 "\"\<=\>\"", ",", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"gAlp", "[", 
                    RowBox[{"t", ",", "r"}], "]"}]}], 
                  RowBox[{"gB", "[", 
                   RowBox[{"t", ",", "r"}], "]"}], 
                  RowBox[{"gK2", "[", 
                   RowBox[{"t", ",", "r"}], "]"}]}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<   X\[ThinSpace]=\[ThinSpace]\!\(\*OverscriptBox[\(Y\), \
\(.\)]\)/\!\(\*OverscriptBox[\(a\), \(.\)]\)\>\"", ",", "\"\<=\>\"", ",", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"fAlp", "[", 
                    RowBox[{"t", ",", "r"}], "]"}]}], 
                   RowBox[{"fB", "[", 
                    RowBox[{"t", ",", "r"}], "]"}], 
                   RowBox[{"fK2", "[", 
                    RowBox[{"t", ",", "r"}], "]"}]}], 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"gAlp", "[", 
                    RowBox[{"t", ",", "r"}], "]"}]}], 
                   RowBox[{"gB", "[", 
                    RowBox[{"t", ",", "r"}], "]"}], 
                   RowBox[{"gK2", "[", 
                    RowBox[{"t", ",", "r"}], "]"}]}]]}], "}"}]}], 
              "\[IndentingNewLine]", "}"}], "//", "Simplify"}], ",", 
            RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}], "//", "Chop"}], "//", "Expand"}], "//", 
     "Simplify"}], "//", "N"}], "//", "Rationalize"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Row", "@", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "=", "sol$a"}], ",", 
      RowBox[{"gK", "=", "sol$gK"}], ",", 
      RowBox[{"Y", "=", "sol$Y"}], ",", 
      RowBox[{"fK", "=", "sol$fK"}], ",", 
      RowBox[{
      "\[Rho]\[FivePointedStar]", "=", "sol$\[Rho]\[FivePointedStar]"}], ",", 
      "gW", ",", "fAlp"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"gW", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], "=", 
      RowBox[{"id$gW", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fAlp", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], "=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"id$gW", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], "/", 
       RowBox[{"id$fW", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ContourPlot", "[", 
        RowBox[{
         RowBox[{"gW", "[", 
          RowBox[{"t", ",", "r"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{"sol$a", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{"sol$a", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], 
            "-", "0.2"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"Scaled", "[", "0.3", "]"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          SubscriptBox["W", "g"]}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"radius", ",", "time"}], "}"}]}]}], "\[IndentingNewLine]", 
        "]"}], ",", 
       RowBox[{"Spacer", "[", "25", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ContourPlot", "[", 
        RowBox[{
         RowBox[{"fAlp", "[", 
          RowBox[{"t", ",", "r"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{"sol$a", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{"sol$a", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], 
            "-", "0.2"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"Scaled", "[", "0.3", "]"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          OverscriptBox["\[Alpha]", "~"]}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"radius", ",", "time"}], "}"}]}]}], "\[IndentingNewLine]", 
        "]"}]}], "}"}]}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup the default integration parameters", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", "=", "20"}], ";", " ", 
  RowBox[{"\[CapitalDelta]t", "=", "0.005"}], ";", " ", 
  RowBox[{"mSkip", "=", "10"}], ";", " ", 
  RowBox[{"iMethod", "=", "\"\<RK3\>\""}], ";", " ", 
  RowBox[{"$dissipation", "=", "0.03"}], ";", 
  RowBox[{"slicingMethod", "=", "\"\<const\>\""}], ";", 
  RowBox[{"smoothingMethod", "=", "0"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r0", "=", "0"}], ";", " ", 
  RowBox[{"r1", "=", "10"}], ";", " ", 
  RowBox[{"nLen", "=", "1000"}], ";", 
  RowBox[{"nOut", "=", "1000"}], ";", 
  RowBox[{"nSkip", "=", "10"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Instantiate EoM and display the initial data", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"instantiateEoM", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Head", "@", "id$r$range"}], "===", "List"}], ",", 
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
         RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{
         RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
          RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], "-", 
         RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
          RowBox[{";;", 
           RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}]}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"Row", "@", 
       RowBox[{"{", 
        RowBox[{"\"\<Discretization of \!\(\*
StyleBox[\"r\",
FontSlant->\"Italic\"]\) : \>\"", ",", 
         RowBox[{"Length", "@", "id$r$range"}], ",", "\"\< points\>\""}], 
        "}"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"r", ",", "\"\<\[CapitalDelta]r\>\""}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "12", "]"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"12", ",", "Black"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"Scaled", "[", "0.6", "]"}]}]}], "\[IndentingNewLine]", "]"}]}],
   "]"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figIC", "=", 
   RowBox[{"displayInitialData", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{"$exportPDFs", ",", 
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"\"\<figures/fig-\>\"", "<>", 
       RowBox[{"ToString", "@", "id$setup"}], "<>", "\"\<-t0.pdf\>\""}], ",", 
      "figIC"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutHideCode", "[", 
  RowBox[{"figIC", ",", "\"\<derivativesPlot\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Head", "@", "id$r$range"}], "===", "List"}], ",", 
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"Quiet", "@", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{
        "id$EoM$pEqs", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r0", ",", "r1"}], "}"}], ",", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "550"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)p\>\"", ",", "r"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Bottom"}], "}"}]}], "]"}]}], "]"}]}], "Input"],

Cell[TextData[{
 "Observtion: Wg and Wf are very small (smaller than ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "6"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") at r < 0.1 and r > 4"
}], "Text"],

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"0.000047479609532020435`", " ", 
       SuperscriptBox["r", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["r", "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]], ",", 
     FractionBox[
      RowBox[{"0.0001418371624945754`", " ", 
       SuperscriptBox["r", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["r", "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "2"}]], ",", "10"}], "}"}]}], "]"}]], "Input"]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1334, 1053},
WindowMargins->{{238, Automatic}, {18, Automatic}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.1999999999999, 841.8},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 79, 2, 53, "Text"],
Cell[640, 24, 45, 0, 38, "Text"],
Cell[688, 26, 420, 12, 88, "Text"],
Cell[CellGroupData[{
Cell[1133, 42, 39, 0, 42, "Subsubsection"],
Cell[1175, 44, 273, 8, 83, "Input"],
Cell[1451, 54, 1572, 43, 88, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3060, 102, 30, 0, 42, "Subsubsection"],
Cell[3093, 104, 645, 23, 83, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3775, 132, 74, 0, 42, "Subsubsection"],
Cell[3852, 134, 5702, 153, 646, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9591, 292, 49, 0, 42, "Subsubsection"],
Cell[9643, 294, 392, 13, 42, "Text"],
Cell[10038, 309, 9235, 244, 1294, "Input"],
Cell[19276, 555, 1050, 42, 78, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20363, 602, 144, 3, 52, "Subsubsection"],
Cell[20510, 607, 366, 12, 47, "Text"],
Cell[20879, 621, 12618, 212, 88, "Text"],
Cell[33500, 835, 1354, 37, 340, "Input"],
Cell[34857, 874, 166, 6, 47, "Text"],
Cell[35026, 882, 948, 26, 161, "Input"],
Cell[35977, 910, 603, 23, 51, "Text"],
Cell[36583, 935, 62912, 1051, 262, "Text"],
Cell[99498, 1988, 604, 23, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100139, 2016, 54, 0, 52, "Subsubsection"],
Cell[100196, 2018, 649, 27, 47, "Text"],
Cell[100848, 2047, 1955, 58, 260, "Input"],
Cell[102806, 2107, 536, 23, 58, "Text"],
Cell[103345, 2132, 2305, 69, 357, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105687, 2206, 67, 0, 65, "Subsubsection"],
Cell[105757, 2208, 22691, 560, 4560, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128485, 2773, 121, 3, 65, "Subsubsection"],
Cell[128609, 2778, 269, 9, 56, "Input"],
Cell[128881, 2789, 2160, 63, 131, "Input"],
Cell[131044, 2854, 16668, 378, 1842, "Input"],
Cell[147715, 3234, 3086, 74, 313, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150838, 3313, 65, 0, 42, "Subsubsection"],
Cell[150906, 3315, 379, 8, 60, "Input"],
Cell[151288, 3325, 229, 6, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151554, 3336, 69, 0, 42, "Subsubsection"],
Cell[151626, 3338, 1645, 39, 175, "Input"],
Cell[153274, 3379, 1314, 36, 129, "Input"],
Cell[154591, 3417, 238, 8, 38, "Text"],
Cell[154832, 3427, 737, 24, 67, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
