(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     23285,        652]
NotebookOptionsPosition[     19124,        553]
NotebookOutlinePosition[     22730,        635]
CellTagsIndexPosition[     22687,        632]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Initial Data: GR collapse with conformally flat ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " and the Gaussian ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "PF"], TraditionalForm]]]
}], "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell[TextData[{
 "Note: \[OpenCurlyDoubleQuote]erf\[CloseCurlyDoubleQuote] is the integral of \
the Gaussian distribution, given by  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"erf", "(", "z", ")"}], "=", 
    RowBox[{
     FractionBox["2", 
      SqrtBox["\[Pi]"]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "z"], 
      RowBox[{
       SuperscriptBox["e", 
        RowBox[{"-", 
         SuperscriptBox["t", "2"]}]], "d", "\[InvisibleSpace]", "t"}]}]}]}], 
   TraditionalForm]], "InlineMath"],
 ". "
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"id$setup", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$debugMode", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"id$title", "=", "\"\<GR dust collapse\>\""}], ";"}]}], "Input"],

Cell["Setup the gauge,", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eq$q", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], ";", 
  RowBox[{"0.001", "r", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "r"}], "]"}]}], ")"}], "4"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$q", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", "0.01"}], "r"}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$q", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$gAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$fAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.001", "r"}], ",", 
     RowBox[{"0.001", "r", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "r"}], "]"}]}], ")"}], "4"]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]], "Input"],

Cell["A possible initial value for eq$gAlp,", "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"Erf", "[", 
           RowBox[{"r", "/", "\[Lambda]"}], "]"}], 
          RowBox[{"2", "r", " "}]]}], ")"}], 
       RowBox[{"-", "2"}]], ",", 
      RowBox[{"{", 
       RowBox[{"\[Lambda]", ",", "1", ",", "3", ",", "0.5"}], "}"}]}], 
     "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "6"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], ",", 
   RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1.4"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Thread", "[", 
     RowBox[{"\[Lambda]", "\[Equal]", 
      RowBox[{"Range", "[", 
       RowBox[{"1", ",", "3", ",", "0.5"}], "]"}]}], "]"}]}]}], 
  "]"}]], "Input"],

Cell["The constraints,", "Text"],

Cell[BoxData[
 RowBox[{"Block", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "\[IndentingNewLine]", "fA",
      ",", "fB", ",", "fK1", ",", "fK2", ",", "\[IndentingNewLine]", "gAlp", 
     ",", "fAlp", ",", "\[IndentingNewLine]", "pfD", ",", "pfS", ",", 
     "pf\[Tau]", ",", "\[IndentingNewLine]", "Lt", ",", "p", ",", "q", ",", 
     "R", ",", "\[IndentingNewLine]", "P", ",", "\[Beta]", ",", 
     "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",", "g$JK2", ",", 
     "f$\[Rho]", ",", "f$JK1", ",", "f$JK2"}], "\[IndentingNewLine]", "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "id$gA", ",", "id$gB", ",", "id$gK1", ",", "id$gK2", ",", "id$fA", ",", 
      "id$fB", ",", "id$fK1", ",", "id$fK2", ",", "id$p", ",", "id$q", ",", 
      "id$gAlp", ",", "id$fAlp", ",", "id$pfD", ",", "id$pfS", ",", 
      "id$pf\[Tau]", ",", "id$gKretschmann", ",", "id$fKretschmann", ",", 
      "id$gW", ",", "id$fW"}], "]"}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gA", "[", "r_", "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"\[Phi]GR", "[", 
       RowBox[{"r", ",", "3"}], "]"}], "2"]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gB", "[", "r_", "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"\[Phi]GR", "[", 
       RowBox[{"r", ",", "3"}], "]"}], "2"]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK1", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK2", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fA", "[", "r_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fB", "[", "r_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK1", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK2", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$p", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Phi]GR", "[", 
      RowBox[{"r_", ",", "\[Lambda]_"}], "]"}], ":=", 
     RowBox[{"1", "+", 
      RowBox[{
       RowBox[{"Erf", "[", 
        FractionBox["r", 
         RowBox[{
          SqrtBox["2"], " ", "\[Lambda]"}]], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", "r"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[DoubleStruckCapitalD]", "[", 
      RowBox[{"r_", ",", "\[Lambda]_"}], "]"}], ":=", " ", 
     RowBox[{"8", "\[Pi]", " ", 
      RowBox[{"\[Phi]GR", "[", 
       RowBox[{"r", ",", "\[Lambda]"}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["r", "2"], 
         RowBox[{"2", 
          SuperscriptBox["\[Lambda]", "2"]}]]}], "]"}], 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}], 
           RowBox[{"1", "/", "2"}]], "\[Lambda]"}], ")"}], "3"]]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Rho]ADM", "[", 
      RowBox[{"r_", ",", "\[Lambda]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"\[DoubleStruckCapitalD]", "[", 
       RowBox[{"r", ",", "\[Lambda]"}], "]"}], "/", 
      SuperscriptBox[
       RowBox[{"\[Phi]GR", "[", 
        RowBox[{"r", ",", "\[Lambda]"}], "]"}], "6"]}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfD", "[", "r_", "]"}], ":=", 
     RowBox[{"\[DoubleStruckCapitalD]", "[", 
      RowBox[{"r", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfS", "[", "r_", "]"}], ":=", "0"}], " ", ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pf\[Tau]", "[", "r_", "]"}], ":=", "0"}], " ", ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"P", "[", 
      RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
     RowBox[{"eq$esP", "[", 
      RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfD", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfD", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfS", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfS", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pf\[Tau]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"fB", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "/", 
      RowBox[{"gB", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$p", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Lt", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"p", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
      RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c$1", ",", "c$2", ",", "c$3", ",", "c$4", ",", "c$p"}], "}"}], 
     "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          UnderscriptBox["eq$C1", "_"], ",", 
          UnderscriptBox["eq$C2", "_"], ",", 
          UnderscriptBox["eq$C3", "_"], ",", 
          UnderscriptBox["eq$C4", "_"], ",", 
          UnderscriptBox["eq$p$g", "_"]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", "Expand"}],
       "//", "Simplify"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"id$modelParams", "=", 
     RowBox[{"modelParamNames", "/.", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"k$g", "\[Rule]", "1"}], ",", 
        RowBox[{"k$f", "\[Rule]", "1"}], ",", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "0", "]"}], "\[Rule]", "0"}], ",", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "4", "]"}], "\[Rule]", "0"}]}], "}"}]}]}], 
    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Echo", "/@", 
     RowBox[{"printNice", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Row", "@", 
           RowBox[{"{", 
            RowBox[{"\"\<c$p \[Equal] \>\"", ",", "c$p"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Row", "@", 
           RowBox[{"{", 
            RowBox[{"\"\<c$1 \[Equal] \>\"", ",", "c$1"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Row", "@", 
           RowBox[{"{", 
            RowBox[{"\"\<c$2 \[Equal] \>\"", ",", "c$2"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Row", "@", 
           RowBox[{"{", 
            RowBox[{"\"\<c$3 \[Equal] \>\"", ",", "c$3"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Row", "@", 
           RowBox[{"{", 
            RowBox[{"\"\<c$4 \[Equal] \>\"", ",", "c$4"}], "}"}]}]}], 
         "\[IndentingNewLine]", "}"}], "/.", 
        RowBox[{"Thread", "[", 
         RowBox[{"modelParamNames", "\[Rule]", "id$modelParams"}], "]"}]}], 
       ",", "$disabledESP$"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Setup the default integration parameters", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"r1", " ", "=", " ", "80"}], ";", 
   RowBox[{"slicingMethod", "=", "\"\<MS2\>\""}], ";", " ", 
   RowBox[{"nLen", "  ", "=", 
    RowBox[{"100", "r1"}]}], ";", 
   RowBox[{"nOut", "  ", "=", " ", 
    RowBox[{"nLen", "/", "8"}]}], ";", 
   RowBox[{"nSkip", " ", "=", "1"}], ";"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", "=", "65"}], ";", 
  RowBox[{"\[CapitalDelta]t", "=", "0.005"}], ";", 
  RowBox[{"mSkip", "=", "20"}], ";", " ", 
  RowBox[{"iMethod", "=", "\"\<RK3\>\""}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Instantiate EoM and display the initial data", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"instantiateEoM", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Head", "@", "id$r$range"}], "===", "List"}], ",", 
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
         RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{
         RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
          RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], "-", 
         RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
          RowBox[{";;", 
           RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}]}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"Row", "@", 
       RowBox[{"{", 
        RowBox[{"\"\<Discretization of \!\(\*
StyleBox[\"r\",
FontSlant->\"Italic\"]\) : \>\"", ",", 
         RowBox[{"Length", "@", "id$r$range"}], ",", "\"\< points\>\""}], 
        "}"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"r", ",", "\"\<\[CapitalDelta]r\>\""}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "12", "]"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"12", ",", "Black"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"Scaled", "[", "0.6", "]"}]}]}], "\[IndentingNewLine]", "]"}]}],
   "]"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figIC", "=", 
   RowBox[{"displayInitialData", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{"$exportPDFs", ",", 
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"\"\<figures/fig-\>\"", "<>", 
       RowBox[{"ToString", "@", "id$setup"}], "<>", "\"\<-t0.pdf\>\""}], ",", 
      "figIC"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutHideCode", "[", 
  RowBox[{"figIC", ",", "\"\<derivativesPlot\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Head", "@", "id$r$range"}], "===", "List"}], ",", 
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"Quiet", "@", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{
        "id$EoM$pEqs", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r0", ",", "r1"}], "}"}], ",", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "550"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)p\>\"", ",", "r"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Bottom"}], "}"}]}], "]"}]}], "]"}]}], "Input"]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1334, 1053},
WindowMargins->{{266, Automatic}, {Automatic, 11}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 267, 10, 53, "Text"],
Cell[828, 32, 540, 18, 52, "Text"],
Cell[1371, 52, 255, 6, 83, "Input"],
Cell[1629, 60, 32, 0, 38, "Text"],
Cell[1664, 62, 902, 32, 132, "Input"],
Cell[2569, 96, 542, 17, 41, "Input"],
Cell[3114, 115, 53, 0, 38, "Text"],
Cell[3170, 117, 987, 29, 89, "Input"],
Cell[4160, 148, 32, 0, 38, "Text"],
Cell[4195, 150, 11189, 294, 1762, "Input"],
Cell[CellGroupData[{
Cell[15409, 448, 65, 0, 42, "Subsubsection"],
Cell[15477, 450, 344, 9, 36, "Input"],
Cell[15824, 461, 213, 5, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16074, 471, 69, 0, 42, "Subsubsection"],
Cell[16146, 473, 1645, 39, 175, "Input"],
Cell[17794, 514, 1314, 36, 129, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
