(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    182137,       3769]
NotebookOptionsPosition[    176889,       3633]
NotebookOutlinePosition[    180630,       3721]
CellTagsIndexPosition[    180552,       3716]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Initial Data: Bimetric collapse with conformally flat ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ", and the Gaussian ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "PF"], TraditionalForm]]]
}], "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["Identification", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"id$setup", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "id$title", "=", 
   "\"\<Conformaly flat \!\(TraditionalForm\`g\) and \!\(TraditionalForm\`f\) \
at \!\(TraditionalForm\`t0\) with Guassian \!\(TraditionalForm\`PF\)\>\""}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gauge", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eq$q", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$gAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$fAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"gAlp", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"gW", "[", 
      RowBox[{"t", ",", "r"}], "]"}], "/", 
     RowBox[{"fW", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve the constraints", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "\[IndentingNewLine]", "fA",
      ",", "fB", ",", "fK1", ",", "fK2", ",", "\[IndentingNewLine]", "gAlp", 
     ",", "fAlp", ",", "\[IndentingNewLine]", "pfD", ",", "pfS", ",", 
     "pf\[Tau]", ",", "\[IndentingNewLine]", "Lt", ",", "p", ",", "q", ",", 
     "R", ",", "\[IndentingNewLine]", "P", ",", "\[Beta]", ",", 
     "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",", "g$JK2", ",", 
     "f$\[Rho]", ",", "f$JK1", ",", "f$JK2"}], "\[IndentingNewLine]", "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "id$gA", ",", "id$gB", ",", "id$gK1", ",", "id$gK2", ",", "id$fA", ",", 
      "id$fB", ",", "id$fK1", ",", "id$fK2", ",", "id$p", ",", "id$q", ",", 
      "id$gAlp", ",", "id$fAlp", ",", "id$pfD", ",", "id$pfS", ",", 
      "id$pf\[Tau]", ",", "id$gKretschmann", ",", "id$fKretschmann", ",", 
      "id$gW", ",", "id$fW"}], "]"}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK1", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK2", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK1", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK2", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$p", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Phi]GR", "[", 
      RowBox[{"r_", ",", "\[Lambda]_"}], "]"}], ":=", 
     RowBox[{"1", "+", 
      RowBox[{
       RowBox[{"Erf", "[", 
        FractionBox["r", 
         RowBox[{
          SqrtBox["2"], " ", "\[Lambda]"}]], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", "r"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[DoubleStruckCapitalD]", "[", 
      RowBox[{"r_", ",", "\[Lambda]_"}], "]"}], ":=", " ", 
     RowBox[{"8", "\[Pi]", " ", 
      RowBox[{"\[Phi]GR", "[", 
       RowBox[{"r", ",", "\[Lambda]"}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["r", "2"], 
         RowBox[{"2", 
          SuperscriptBox["\[Lambda]", "2"]}]]}], "]"}], 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}], 
           RowBox[{"1", "/", "2"}]], "\[Lambda]"}], ")"}], "3"]]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Rho]ADM", "[", 
      RowBox[{"r_", ",", "\[Lambda]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"\[DoubleStruckCapitalD]", "[", 
       RowBox[{"r", ",", "\[Lambda]"}], "]"}], "/", 
      SuperscriptBox[
       RowBox[{"\[Phi]GR", "[", 
        RowBox[{"r", ",", "\[Lambda]"}], "]"}], "6"]}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfD", "[", "r_", "]"}], ":=", 
     RowBox[{"\[DoubleStruckCapitalD]", "[", 
      RowBox[{"r", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfS", "[", "r_", "]"}], ":=", "0"}], " ", ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pf\[Tau]", "[", "r_", "]"}], ":=", "0"}], " ", ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"P", "[", 
      RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
     RowBox[{"eq$esP", "[", 
      RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"\[Phi]g", "[", "r", "]"}], "2"]}], ";", "    ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"conformal", " ", "factor"}], ",", " ", 
      RowBox[{"to", " ", "be", " ", "solved"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"\[Phi]g", "[", "r", "]"}], "2"]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"\[Phi]f", "[", "r", "]"}], "2"]}], ";", "    ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"conformal", " ", "factor"}], ",", " ", 
      RowBox[{"to", " ", "be", " ", "solved"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"\[Phi]f", "[", "r", "]"}], "2"]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfD", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfD", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfS", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfS", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pf\[Tau]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"fB", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "/", 
      RowBox[{"gB", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$p", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Lt", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"p", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
      RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c$1", ",", "c$2", ",", "c$3", ",", "c$4", ",", "c$p"}], "}"}], 
     "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          UnderscriptBox["eq$C1", "_"], ",", 
          UnderscriptBox["eq$C2", "_"], ",", 
          UnderscriptBox["eq$C3", "_"], ",", 
          UnderscriptBox["eq$C4", "_"], ",", 
          UnderscriptBox["eq$p$g", "_"]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", "Expand"}],
       "//", "Simplify"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{"False", ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"track", " ", 
        RowBox[{"dp", "/", "dt"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"q", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"eq$q", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gAlp", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"eq$gAlp", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fAlp", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"eq$fAlp", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"c$pdt", "=", 
        RowBox[{
         UnderscriptBox["evol$eq$p", "_"], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"gW", "\[Rule]", "eq$gW"}], ",", 
           RowBox[{"fW", "\[Rule]", "eq$fW"}]}], "}"}]}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Echo", "/@", 
     RowBox[{"printNice", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$p \[Equal] \>\"", ",", "c$p"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$1 \[Equal] \>\"", ",", "c$1"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$2 \[Equal] \>\"", ",", "c$2"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$3 \[Equal] \>\"", ",", "c$3"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$4 \[Equal] \>\"", ",", "c$4"}], "}"}]}]}], 
        "\[IndentingNewLine]", "}"}], ",", "$disabledESP$"}], "]"}]}], 
    ";"}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{"\"c$p \[Equal] \"","0"},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 TemplateBox[{"\"c$1 \[Equal] \"",RowBox[{"-", 
     FractionBox[
      RowBox[{
        RowBox[{"27", " ", "r", " ", 
          StyleBox[
           SubscriptBox["\[Kappa]", "g"], 
           RGBColor[0, 0, 1], StripOnInput -> False], " ", 
          SubscriptBox["\[Beta]", "3"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "f"], 
              RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}], 
           "6"]}], "+", 
        RowBox[{"81", " ", "r", " ", 
          StyleBox[
           SubscriptBox["\[Kappa]", "g"], 
           RGBColor[0, 0, 1], StripOnInput -> False], " ", 
          SubscriptBox["\[Beta]", "2"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "f"], 
              RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}], 
           "4"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "g"], 
              RGBColor[0, 0, 1], StripOnInput -> False], "[", "r", "]"}], 
           "2"]}], "+", 
        RowBox[{"81", " ", "r", " ", 
          StyleBox[
           SubscriptBox["\[Kappa]", "g"], 
           RGBColor[0, 0, 1], StripOnInput -> False], " ", 
          SubscriptBox["\[Beta]", "1"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "f"], 
              RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}], 
           "2"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "g"], 
              RGBColor[0, 0, 1], StripOnInput -> False], "[", "r", "]"}], 
           "4"]}], "+", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
             FractionBox[
              SuperscriptBox["r", "2"], "18"]}]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SqrtBox[
                 FractionBox["2", "\[Pi]"]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", "r"}], "+", 
                    RowBox[{"Erf", "[", 
                    FractionBox["r", 
                    RowBox[{"3", " ", 
                    SqrtBox["2"]}]], "]"}]}], ")"}], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "g"], 
                 RGBColor[0, 0, 1], StripOnInput -> False]}], "+", 
              RowBox[{"108", " ", 
                SuperscriptBox["\[ExponentialE]", 
                 FractionBox[
                  SuperscriptBox["r", "2"], "18"]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", 
                    RowBox[{"r"}]], 
                    StyleBox[
                    SubscriptBox["\[Phi]", "g"], 
                    RGBColor[0, 0, 1], StripOnInput -> False]}], HoldForm]}], 
                    "+", 
                    RowBox[{"r", " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", 
                    RowBox[{"rr"}]], 
                    StyleBox[
                    SubscriptBox["\[Phi]", "g"], 
                    RGBColor[0, 0, 1], StripOnInput -> False]}], 
                    HoldForm]}]}], ")"}], " ", 
                RowBox[{
                  StyleBox[
                   SubscriptBox["\[Phi]", "g"], 
                   RGBColor[0, 0, 1], StripOnInput -> False], "[", "r", 
                  "]"}]}], "+", 
              RowBox[{"27", " ", 
                SuperscriptBox["\[ExponentialE]", 
                 FractionBox[
                  SuperscriptBox["r", "2"], "18"]], " ", "r", " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "g"], 
                 RGBColor[0, 0, 1], StripOnInput -> False], " ", 
                SubscriptBox["\[Beta]", "0"], " ", 
                SuperscriptBox[
                 RowBox[{
                   StyleBox[
                    SubscriptBox["\[Phi]", "g"], 
                    RGBColor[0, 0, 1], StripOnInput -> False], "[", "r", 
                   "]"}], "6"]}]}], ")"}]}]}], 
      RowBox[{"27", " ", "r", " ", 
        SuperscriptBox[
         RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "g"], 
            RGBColor[0, 0, 1], StripOnInput -> False], "[", "r", "]"}], 
         "6"]}]]}]},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 TemplateBox[{"\"c$2 \[Equal] \"",RowBox[{"-", 
     FractionBox[
      RowBox[{
        RowBox[{"8", " ", 
          TagBox[
           RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"r"}]], 
             StyleBox[
              SubscriptBox["\[Phi]", "f"], 
              RGBColor[1, 0, 0], StripOnInput -> False]}], HoldForm], " ", 
          RowBox[{
            StyleBox[
             SubscriptBox["\[Phi]", "f"], 
             RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}]}], 
        "+", 
        RowBox[{"4", " ", "r", " ", 
          TagBox[
           RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"rr"}]], 
             StyleBox[
              SubscriptBox["\[Phi]", "f"], 
              RGBColor[1, 0, 0], StripOnInput -> False]}], HoldForm], " ", 
          RowBox[{
            StyleBox[
             SubscriptBox["\[Phi]", "f"], 
             RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}]}], 
        "+", 
        RowBox[{"r", " ", 
          StyleBox[
           SubscriptBox["\[Kappa]", "f"], 
           RGBColor[1, 0, 0], StripOnInput -> False], " ", 
          SubscriptBox["\[Beta]", "4"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "f"], 
              RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}], 
           "6"]}], "+", 
        RowBox[{"3", " ", "r", " ", 
          StyleBox[
           SubscriptBox["\[Kappa]", "f"], 
           RGBColor[1, 0, 0], StripOnInput -> False], " ", 
          SubscriptBox["\[Beta]", "3"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "f"], 
              RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}], 
           "4"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "g"], 
              RGBColor[0, 0, 1], StripOnInput -> False], "[", "r", "]"}], 
           "2"]}], "+", 
        RowBox[{"3", " ", "r", " ", 
          StyleBox[
           SubscriptBox["\[Kappa]", "f"], 
           RGBColor[1, 0, 0], StripOnInput -> False], " ", 
          SubscriptBox["\[Beta]", "2"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "f"], 
              RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}], 
           "2"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "g"], 
              RGBColor[0, 0, 1], StripOnInput -> False], "[", "r", "]"}], 
           "4"]}], "+", 
        RowBox[{"r", " ", 
          StyleBox[
           SubscriptBox["\[Kappa]", "f"], 
           RGBColor[1, 0, 0], StripOnInput -> False], " ", 
          SubscriptBox["\[Beta]", "1"], " ", 
          SuperscriptBox[
           RowBox[{
             StyleBox[
              SubscriptBox["\[Phi]", "g"], 
              RGBColor[0, 0, 1], StripOnInput -> False], "[", "r", "]"}], 
           "6"]}]}], 
      RowBox[{"r", " ", 
        SuperscriptBox[
         RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "f"], 
            RGBColor[1, 0, 0], StripOnInput -> False], "[", "r", "]"}], 
         "6"]}]]}]},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 TemplateBox[{"\"c$3 \[Equal] \"","0"},
  "RowDefault"]], "Echo"],

Cell[BoxData[
 TemplateBox[{"\"c$4 \[Equal] \"","0"},
  "RowDefault"]], "Echo"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"eq$\[Phi]g", ",", "eq$\[Phi]f"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Phi]g", "[", "r", "]"}], "5"], "c$1"}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Phi]f", "[", "r", "]"}], "5"], "c$2"}]}], "}"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{"k$g", ",", "k$f"}], "}"}], ",", "Expand"}], "]"}], "&"}]}], 
    "//", "echoNice"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"8", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["\[Phi]", "g"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}], "r"]}], "-", 
     RowBox[{"4", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "rr"], 
        StyleBox[
         SubscriptBox["\[Phi]", "g"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm]}], "+", 
     RowBox[{
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["r", "2"], "18"]}]], " ", 
           SqrtBox[
            FractionBox["2", "\[Pi]"]]}], 
          RowBox[{"27", " ", 
           RowBox[{
            StyleBox[
             SubscriptBox["\[Phi]", "g"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}]}]]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             SuperscriptBox["r", "2"], "18"]}]], " ", 
          SqrtBox[
           FractionBox["2", "\[Pi]"]], " ", 
          RowBox[{"Erf", "[", 
           FractionBox["r", 
            RowBox[{"3", " ", 
             SqrtBox["2"]}]], "]"}]}], 
         RowBox[{"27", " ", "r", " ", 
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}]}]], "-", 
        FractionBox[
         RowBox[{
          SubscriptBox["\[Beta]", "3"], " ", 
          SuperscriptBox[
           RowBox[{
            StyleBox[
             SubscriptBox["\[Phi]", "f"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "[", "r", "]"}], "6"]}], 
         RowBox[{
          StyleBox[
           SubscriptBox["\[Phi]", "g"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}]], "-", 
        RowBox[{"3", " ", 
         SubscriptBox["\[Beta]", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "f"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "[", "r", "]"}], "4"], " ", 
         RowBox[{
          StyleBox[
           SubscriptBox["\[Phi]", "g"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SubscriptBox["\[Beta]", "1"], " ", 
         SuperscriptBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "f"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "[", "r", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}], "3"]}], "-", 
        RowBox[{
         SubscriptBox["\[Beta]", "0"], " ", 
         SuperscriptBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}], "5"]}]}], 
       ")"}]}]}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"8", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["\[Phi]", "f"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "r"]}], "-", 
     RowBox[{"4", " ", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "rr"], 
        StyleBox[
         SubscriptBox["\[Phi]", "f"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm]}], "+", 
     RowBox[{
      StyleBox[
       SubscriptBox["\[Kappa]", "f"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["\[Beta]", "4"]}], " ", 
         SuperscriptBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "f"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "[", "r", "]"}], "5"]}], "-", 
        RowBox[{"3", " ", 
         SubscriptBox["\[Beta]", "3"], " ", 
         SuperscriptBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "f"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "[", "r", "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SubscriptBox["\[Beta]", "2"], " ", 
         RowBox[{
          StyleBox[
           SubscriptBox["\[Phi]", "f"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "[", "r", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           StyleBox[
            SubscriptBox["\[Phi]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}], "4"]}], "-", 
        FractionBox[
         RowBox[{
          SubscriptBox["\[Beta]", "1"], " ", 
          SuperscriptBox[
           RowBox[{
            StyleBox[
             SubscriptBox["\[Phi]", "g"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "[", "r", "]"}], "6"]}], 
         RowBox[{
          StyleBox[
           SubscriptBox["\[Phi]", "f"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "[", "r", "]"}]]}], ")"}]}]}]}], 
   "}"}]}]], "Echo"]
}, Open  ]],

Cell["The asymptotic condition,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"sol$\[Beta]0", ",", "sol$\[Beta]4"}], "}"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
        RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"eq$\[Phi]g", "\[Equal]", "0"}], ",", 
             RowBox[{"eq$\[Phi]f", "\[Equal]", "0"}]}], "}"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Derivative", "[", "n_", "]"}], "[", "f_", "]"}], "[",
                "r", "]"}], "\[RuleDelayed]", "0"}], ",", 
             RowBox[{
              RowBox[{"\[Phi]g", "[", "r", "]"}], "\[Rule]", "1"}], ",", 
             RowBox[{
              RowBox[{"\[Phi]f", "[", "r", "]"}], "\[Rule]", "1"}]}], "}"}]}],
           "/.", 
          RowBox[{"{", 
           RowBox[{"r", "\[Rule]", "1000."}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
           RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}]}], "]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "//", 
     "Chop"}], "//", "Rationalize"}], "//", "Simplify"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     RowBox[{"\[Beta]", "[", "1", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"\[Beta]", "[", "2", "]"}]}], "-", 
    RowBox[{"\[Beta]", "[", "3", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Beta]", "[", "1", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "2", "]"}], "+", 
       RowBox[{"\[Beta]", "[", "3", "]"}]}], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"TwoAxisPlot", "[", 
   RowBox[{"plotFunctions_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "x1_", ",", "x2_"}], "}"}], ",", "plotRanges_", ",", 
    "plotColors_", ",", "plotLegends_", ",", "plotOptions___"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"graphs", ",", "ranges", ",", "fticks", ",", "gticks"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"graphs", "=", 
      RowBox[{"MapIndexed", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{"#", ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"x", ",", "x1", ",", "x2"}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"plotRanges", "\[LeftDoubleBracket]", 
             RowBox[{
             "#2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             "\[RightDoubleBracket]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"plotColors", "\[LeftDoubleBracket]", 
             RowBox[{
             "#2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             "\[RightDoubleBracket]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"Placed", "[", 
             RowBox[{
              RowBox[{"LineLegend", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"plotLegends", "\[LeftDoubleBracket]", 
                  RowBox[{
                  "#2", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], 
                 "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"\<Row\>\""}], ",", 
                RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
                   "16"}], "}"}]}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.75", ",", "0.9"}], "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", "plotOptions"}], "\[IndentingNewLine]", 
          "]"}], "&"}], ",", "plotFunctions"}], "\[IndentingNewLine]", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ranges", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"PlotRange", "/.", 
           RowBox[{"AbsoluteOptions", "[", 
            RowBox[{"#", ",", "PlotRange"}], "]"}]}], ")"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", "graphs"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ranges", "\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], "=", 
      RowBox[{"Min", "[", 
       RowBox[{"ranges", "\[LeftDoubleBracket]", 
        RowBox[{
         RowBox[{"2", ";;"}], ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ranges", "\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "=", 
      RowBox[{"Max", "[", 
       RowBox[{"ranges", "\[LeftDoubleBracket]", 
        RowBox[{
         RowBox[{"2", ";;"}], ",", "2"}], "\[RightDoubleBracket]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"fticks", "=", 
      RowBox[{"N", "@", 
       RowBox[{"FindDivisions", "[", 
        RowBox[{
         RowBox[{
         "ranges", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         ",", "5"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"gticks", "=", 
      RowBox[{"Quiet", "@", 
       RowBox[{"Transpose", "@", 
        RowBox[{"{", 
         RowBox[{"fticks", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"ToString", "[", 
             RowBox[{
              RowBox[{"NumberForm", "[", 
               RowBox[{"#", ",", 
                RowBox[{"{", 
                 RowBox[{"10", ",", "3"}], "}"}]}], "]"}], ",", 
              "StandardForm"}], "]"}], "&"}], "/@", 
           RowBox[{"Rescale", "[", 
            RowBox[{"fticks", ",", 
             RowBox[{
             "ranges", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
              ",", 
             RowBox[{
             "ranges", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}]}], "]"}]}]}], "}"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{
       "graphs", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Sequence", "@@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"graphs", "\[LeftDoubleBracket]", 
           RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], "/.", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"graph_", ",", "s___"}], "]"}], "\[RuleDelayed]", 
           RowBox[{"Graphics", "[", 
            RowBox[{
             RowBox[{"GeometricTransformation", "[", 
              RowBox[{"graph", ",", 
               RowBox[{"RescalingTransform", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}], ",", 
                   RowBox[{
                   "ranges", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}], ",", 
                   RowBox[{
                   "ranges", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "}"}]}], "]"}]}], "]"}], ",",
              "s"}], "]"}]}]}], ")"}]}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"FrameStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
            "plotColors", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}], ",", 
            RowBox[{
            "plotColors", "\[LeftDoubleBracket]", "2", 
             "\[RightDoubleBracket]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"fticks", ",", "gticks"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rc", "=", 
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{"\[Beta]", ",", 
         RowBox[{"k$g", "=", 
          RowBox[{"Rationalize", "@", "c$kg"}]}], ",", 
         RowBox[{"k$f", "=", 
          RowBox[{"Rationalize", "@", "c$kf"}]}], ",", "P", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"r$0", "=", 
          SuperscriptBox["10", 
           RowBox[{"-", "10"}]]}], ",", "\[IndentingNewLine]", 
         "NDSolveParams", ",", "sol$\[Phi]g", ",", "sol$\[Phi]f"}], 
        "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Beta]", "[", "0", "]"}], "=", "sol$\[Beta]0"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "1", "]"}], ":=", 
         RowBox[{"Rationalize", "@", "b$1"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "2", "]"}], ":=", 
         RowBox[{"Rationalize", "@", "b$2"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "3", "]"}], ":=", 
         RowBox[{"Rationalize", "@", "b$3"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "4", "]"}], ":=", "sol$\[Beta]4"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"P", "[", 
          RowBox[{"n_", ",", "k_", ",", "1"}], "]"}], ":=", 
         RowBox[{"eq$esP", "[", 
          RowBox[{"n", ",", "k", ",", "1"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"id$modelParams", "=", 
         RowBox[{"{", 
          RowBox[{"k$g", ",", "k$f", ",", 
           RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
           RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
           RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
           RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
           RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"sol$\[Phi]g", ",", "sol$\[Phi]f"}], "}"}], "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Indeterminate", "&"}], ",", 
           RowBox[{"Indeterminate", "&"}]}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"id$DE", "=", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"eq$\[Phi]g", "\[Equal]", "0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"eq$\[Phi]f", "\[Equal]", "0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"\[Phi]g", "[", 
             RowBox[{"Rationalize", "@", "r$0"}], "]"}], "\[Equal]", 
            RowBox[{"Rationalize", "@", "c$\[Phi]g0"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Phi]g", "'"}], "[", 
             RowBox[{"Rationalize", "@", "r$0"}], "]"}], "\[Equal]", "0"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"\[Phi]f", "[", 
             RowBox[{"Rationalize", "@", "r$0"}], "]"}], "\[Equal]", 
            RowBox[{"Rationalize", "@", "c$\[Phi]f0"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Phi]f", "'"}], "[", 
             RowBox[{"Rationalize", "@", "r$0"}], "]"}], "\[Equal]", "0"}]}], 
          "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"id$intRange", "=", 
         RowBox[{"Rationalize", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"r$min", "*", 
             SuperscriptBox["10", 
              RowBox[{"-", "r$minf"}]]}], ",", 
            RowBox[{"r$max", "*", 
             SuperscriptBox["10", "r$maxf"]}]}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Quiet", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"sol$\[Phi]g", ",", "sol$\[Phi]f"}], "}"}], "=", 
          RowBox[{"NDSolveValue", "[", "\[IndentingNewLine]", 
           RowBox[{"id$DE", ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"\[Phi]g", ",", "\[Phi]f"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"r", ",", 
              RowBox[{"r$min", "*", 
               SuperscriptBox["10", 
                RowBox[{"-", "r$minf"}]]}], ",", 
              RowBox[{"r$max", "*", 
               SuperscriptBox["10", "r$maxf"]}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"WorkingPrecision", "\[Rule]", 
             RowBox[{"ControlActive", "[", 
              RowBox[{"MachinePrecision", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"r$max", "*", 
                   SuperscriptBox["10", "r$maxf"]}], ">", 
                  SuperscriptBox["10", "4"]}], ",", "20", ",", 
                 "MachinePrecision"}], "]"}]}], "]"}]}]}], 
           "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"ControlActive", "[", 
           RowBox[{"False", ",", "c$twoAxisPlot"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Quiet", "@", 
           RowBox[{"TwoAxisPlot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Rho]ADM", "[", 
                RowBox[{"r", ",", "3"}], "]"}], ",", 
               RowBox[{"\[Phi]GR", "[", 
                RowBox[{"r", ",", "3"}], "]"}], ",", 
               RowBox[{"sol$\[Phi]g", "[", "r", "]"}], ",", 
               RowBox[{"sol$\[Phi]f", "[", "r", "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{"sol$\[Phi]g", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], 
               ",", 
               RowBox[{"sol$\[Phi]g", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1", ",", "2"}], 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"Full", ",", "Full", ",", "Full", ",", " ", "Full"}], 
              "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Darker", "@", "Green"}], ",", "Magenta", ",", "Blue", 
               ",", "Red"}], "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["\[Rho]", "ADM"], ",", 
               SubscriptBox["\[Phi]", "GR"], ",", 
               SubscriptBox["\[Phi]", "g"], ",", 
               SubscriptBox["\[Phi]", "f"]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"FrameLabel", "\[Rule]", 
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"Row", "@", 
                 RowBox[{"{", 
                  RowBox[{"\"\<r \[Element] ( \>\"", ",", 
                   RowBox[{"N", "@", 
                    RowBox[{"sol$\[Phi]g", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1", ",", "1"}], 
                    "\[RightDoubleBracket]"}]}], ",", "\"\<, \>\"", ",", 
                   RowBox[{"N", "@", 
                    RowBox[{"sol$\[Phi]g", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1", ",", "2"}], 
                    "\[RightDoubleBracket]"}]}], ",", " ", "\"\< )\>\""}], 
                  "}"}]}], ",", "Blue", ",", "14"}], "]"}]}]}], 
            "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Quiet", "@", 
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Rho]ADM", "[", 
                RowBox[{"r", ",", "3"}], "]"}], ",", 
               RowBox[{
                RowBox[{"\[Phi]GR", "[", 
                 RowBox[{"r", ",", "3"}], "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{"sol$\[Phi]g", "[", "r", "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{"sol$\[Phi]f", "[", "r", "]"}], "-", "1"}]}], "}"}], 
             ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{"sol$\[Phi]g", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], 
               ",", 
               RowBox[{"sol$\[Phi]g", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1", ",", "2"}], 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "0.05"}], ",", "0.2"}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Darker", "@", "Green"}], ",", "Magenta", ",", "Blue",
                 ",", "Red"}], "}"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"Placed", "[", 
               RowBox[{
                RowBox[{"LineLegend", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    SubscriptBox["\[Rho]", "ADM"], ",", 
                    RowBox[{
                    SubscriptBox["\[Phi]", "GR"], "-", "1"}], ",", 
                    RowBox[{
                    SubscriptBox["\[Phi]", "g"], "-", "1"}], ",", 
                    RowBox[{
                    SubscriptBox["\[Phi]", "f"], "-", "1"}]}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"\<Row\>\""}], ",", 
                  RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",",
                     "16"}], "}"}]}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0.75", ",", "0.9"}], "}"}]}], "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"FrameLabel", "\[Rule]", 
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"Row", "@", 
                 RowBox[{"{", 
                  RowBox[{"\"\<r \[Element] ( \>\"", ",", 
                   RowBox[{"N", "@", 
                    RowBox[{"sol$\[Phi]g", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1", ",", "1"}], 
                    "\[RightDoubleBracket]"}]}], ",", "\"\<, \>\"", ",", 
                   RowBox[{"N", "@", 
                    RowBox[{"sol$\[Phi]g", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1", ",", "2"}], 
                    "\[RightDoubleBracket]"}]}], ",", " ", "\"\< )\>\""}], 
                  "}"}]}], ",", "Blue", ",", "14"}], "]"}]}]}], 
            "\[IndentingNewLine]", "]"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"c$twoAxisPlot", ",", "True", ",", "\"\<2-Axes?\>\""}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
     RowBox[{"Text", "@", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Initial conditions:\>\"", ",", "14"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "c$\[Phi]g0", ",", "1.157", ",", 
         "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(g\)]\)\>\""}], "}"}], ",", 
       "0.1", ",", "2"}], "}"}], ",", " ", 
     RowBox[{"(*", "1.075", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "c$\[Phi]f0", ",", "1.157", ",", 
         "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(f\)]\)\>\""}], "}"}], ",", 
       "0.1", ",", "2"}], "}"}], ",", " ", 
     RowBox[{"(*", "1.075", "*)"}], "\[IndentingNewLine]", "Delimiter", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Text", "@", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Integration range:\>\"", ",", "14"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "r$min", ",", "0.0001", ",", 
         "\"\<\!\(\*SubscriptBox[\(r\), \(min\)]\)\>\""}], "}"}], ",", 
       "0.0001", ",", "0.1"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "r$minf", ",", "6", ",", 
         "\"\<\!\(\*SubscriptBox[\(r\), \(min\)]\)\[Divide]\>\""}], "}"}], 
       ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "r$max", ",", "20", ",", 
         "\"\<\!\(\*SubscriptBox[\(r\), \(max\)]\)\>\""}], "}"}], ",", "1", 
       ",", "100"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "r$maxf", ",", "0", ",", 
         "\"\<\!\(\*SubscriptBox[\(r\), \(max\)]\)\[Times]\>\""}], "}"}], ",",
        "0", ",", "5"}], "}"}], ",", "\[IndentingNewLine]", "Delimiter", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Text", "@", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Parameters:\>\"", ",", "14"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "b$1", ",", "0", ",", 
         "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)\>\""}], "}"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"(*", "0", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "b$2", ",", "0.1", ",", 
         "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)\>\""}], "}"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"(*", 
      RowBox[{"-", "0.1"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"b$3", ",", 
         RowBox[{"-", "0.3"}], ",", 
         "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)\>\""}], "}"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", " ", 
     RowBox[{"(*", "0", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "c$kg", ",", "3", ",", 
         "\"\<\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)\>\""}], "}"}], ",", 
       "0.0001", ",", "10"}], "}"}], ",", 
     RowBox[{"(*", "1", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "c$kf", ",", "2", ",", 
         "\"\<\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)\>\""}], "}"}], ",", 
       "0.0001", ",", "10"}], "}"}], " ", 
     RowBox[{"(*", "1", "*)"}], " ", ",", "\[IndentingNewLine]", 
     RowBox[{"Paneled", "\[Rule]", "False"}], ",", 
     RowBox[{"AppearanceElements", "\[Rule]", "None"}], ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Right"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Initialization", "\[RuleDelayed]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"c$\[Phi]g0", "=", "1.06"}], ";", 
        RowBox[{"c$\[Phi]f0", "=", "1.08"}], ";", "\[IndentingNewLine]", 
        RowBox[{"b$1", "=", 
         RowBox[{"-", "1"}]}], ";", 
        RowBox[{"b$2", "=", "0"}], ";", 
        RowBox[{"b$3", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"c$kg", "=", 
         RowBox[{"c$kf", "=", "1"}]}], ";"}], "\[IndentingNewLine]", 
       "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutHideCode", "[", 
  RowBox[{"rc", ",", "\"\<case5explorer\>\""}], "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`b$1$$ = -1, $CellContext`b$2$$ = 
    0, $CellContext`b$3$$ = 0, $CellContext`c$kf$$ = 1, $CellContext`c$kg$$ = 
    1, $CellContext`c$twoAxisPlot$$ = True, $CellContext`c$\[Phi]f0$$ = 
    1.08, $CellContext`c$\[Phi]g0$$ = 1.06, $CellContext`r$max$$ = 
    20, $CellContext`r$maxf$$ = 0, $CellContext`r$min$$ = 
    0.0001, $CellContext`r$minf$$ = 6, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$twoAxisPlot$$], True, "2-Axes?"}, {True, False}}, {
      Hold[
       Text[
        Style["Initial conditions:", 14]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`c$\[Phi]g0$$], 1.157, 
       "\!\(\*SubscriptBox[\(\[Phi]\), \(g\)]\)"}, 0.1, 2}, {{
       Hold[$CellContext`c$\[Phi]f0$$], 1.157, 
       "\!\(\*SubscriptBox[\(\[Phi]\), \(f\)]\)"}, 0.1, 2}, {
      Hold[
       Text[
        Style["Integration range:", 14]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`r$min$$], 0.0001, 
       "\!\(\*SubscriptBox[\(r\), \(min\)]\)"}, 0.0001, 0.1}, {{
       Hold[$CellContext`r$minf$$], 6, 
       "\!\(\*SubscriptBox[\(r\), \(min\)]\)\[Divide]"}, 0, 10}, {{
       Hold[$CellContext`r$max$$], 20, 
       "\!\(\*SubscriptBox[\(r\), \(max\)]\)"}, 1, 100}, {{
       Hold[$CellContext`r$maxf$$], 0, 
       "\!\(\*SubscriptBox[\(r\), \(max\)]\)\[Times]"}, 0, 5}, {
      Hold[
       Text[
        Style["Parameters:", 14]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`b$1$$], 0, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$2$$], 0.1, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$3$$], -0.3, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)"}, -2, 2}, {{
       Hold[$CellContext`c$kg$$], 3, 
       "\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)"}, 0.0001, 10}, {{
       Hold[$CellContext`c$kf$$], 2, 
       "\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)"}, 0.0001, 10}}, 
    Typeset`size$$ = {750., {235., 243.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`c$twoAxisPlot$179949$$ = 
    False, $CellContext`c$\[Phi]g0$179950$$ = 
    0, $CellContext`c$\[Phi]f0$179951$$ = 0, $CellContext`r$min$179952$$ = 
    0, $CellContext`r$minf$179953$$ = 0, $CellContext`r$max$179954$$ = 
    0, $CellContext`r$maxf$179955$$ = 0, $CellContext`b$1$179956$$ = 
    0, $CellContext`b$2$179957$$ = 0, $CellContext`b$3$179958$$ = 
    0, $CellContext`c$kg$179959$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`b$1$$ = 0, $CellContext`b$2$$ = 
        0.1, $CellContext`b$3$$ = -0.3, $CellContext`c$kf$$ = 
        2, $CellContext`c$kg$$ = 3, $CellContext`c$twoAxisPlot$$ = 
        True, $CellContext`c$\[Phi]f0$$ = 1.157, $CellContext`c$\[Phi]g0$$ = 
        1.157, $CellContext`r$max$$ = 20, $CellContext`r$maxf$$ = 
        0, $CellContext`r$min$$ = 0.0001, $CellContext`r$minf$$ = 6}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$twoAxisPlot$$, \
$CellContext`c$twoAxisPlot$179949$$, False], 
        Hold[$CellContext`c$\[Phi]g0$$, $CellContext`c$\[Phi]g0$179950$$, 0], 
        Hold[$CellContext`c$\[Phi]f0$$, $CellContext`c$\[Phi]f0$179951$$, 0], 
        Hold[$CellContext`r$min$$, $CellContext`r$min$179952$$, 0], 
        Hold[$CellContext`r$minf$$, $CellContext`r$minf$179953$$, 0], 
        Hold[$CellContext`r$max$$, $CellContext`r$max$179954$$, 0], 
        Hold[$CellContext`r$maxf$$, $CellContext`r$maxf$179955$$, 0], 
        Hold[$CellContext`b$1$$, $CellContext`b$1$179956$$, 0], 
        Hold[$CellContext`b$2$$, $CellContext`b$2$179957$$, 0], 
        Hold[$CellContext`b$3$$, $CellContext`b$3$179958$$, 0], 
        Hold[$CellContext`c$kg$$, $CellContext`c$kg$179959$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Block[{$CellContext`\[Beta], $CellContext`k$g = 
         Rationalize[$CellContext`c$kg$$], $CellContext`k$f = 
         Rationalize[$CellContext`c$kf$$], $CellContext`P, $CellContext`r$0 = 
         10^(-10), $CellContext`NDSolveParams, $CellContext`sol$\[Phi]g, \
$CellContext`sol$\[Phi]f}, $CellContext`\[Beta][
          0] = $CellContext`sol$\[Beta]0; $CellContext`\[Beta][1] := 
         Rationalize[$CellContext`b$1$$]; $CellContext`\[Beta][2] := 
         Rationalize[$CellContext`b$2$$]; $CellContext`\[Beta][3] := 
         Rationalize[$CellContext`b$3$$]; $CellContext`\[Beta][
          4] := $CellContext`sol$\[Beta]4; $CellContext`P[
           Pattern[$CellContext`n, 
            Blank[]], 
           Pattern[$CellContext`k, 
            Blank[]], 
           1] := $CellContext`eq$esP[$CellContext`n, $CellContext`k, 
           1]; $CellContext`id$modelParams = {$CellContext`k$g, \
$CellContext`k$f, 
           $CellContext`\[Beta][0], 
           $CellContext`\[Beta][1], 
           $CellContext`\[Beta][2], 
           $CellContext`\[Beta][3], 
           $CellContext`\[Beta][
           4]}; {$CellContext`sol$\[Phi]g, $CellContext`sol$\[Phi]f} = {
          Indeterminate& , 
           Indeterminate& }; $CellContext`id$DE = {$CellContext`eq$\[Phi]g == 
           0, $CellContext`eq$\[Phi]f == 0, $CellContext`\[Phi]g[
             Rationalize[$CellContext`r$0]] == 
           Rationalize[$CellContext`c$\[Phi]g0$$], 
           Derivative[1][$CellContext`\[Phi]g][
             Rationalize[$CellContext`r$0]] == 0, $CellContext`\[Phi]f[
             Rationalize[$CellContext`r$0]] == 
           Rationalize[$CellContext`c$\[Phi]f0$$], 
           Derivative[1][$CellContext`\[Phi]f][
             Rationalize[$CellContext`r$0]] == 0}; $CellContext`id$intRange = 
         Rationalize[{$CellContext`r$min$$ 
            10^(-$CellContext`r$minf$$), $CellContext`r$max$$ 
            10^$CellContext`r$maxf$$}]; 
        Quiet[{$CellContext`sol$\[Phi]g, $CellContext`sol$\[Phi]f} = 
          NDSolveValue[$CellContext`id$DE, {$CellContext`\[Phi]g, \
$CellContext`\[Phi]f}, {$CellContext`r, $CellContext`r$min$$ 
             10^(-$CellContext`r$minf$$), $CellContext`r$max$$ 
             10^$CellContext`r$maxf$$}, WorkingPrecision -> 
            ControlActive[MachinePrecision, 
              
              If[$CellContext`r$max$$ 10^$CellContext`r$maxf$$ > 10^4, 20, 
               MachinePrecision]]]]; If[
          ControlActive[False, $CellContext`c$twoAxisPlot$$], 
          Quiet[
           $CellContext`TwoAxisPlot[{
             $CellContext`\[Rho]ADM[$CellContext`r, 3], 
             $CellContext`\[Phi]GR[$CellContext`r, 3], 
             $CellContext`sol$\[Phi]g[$CellContext`r], 
             $CellContext`sol$\[Phi]f[$CellContext`r]}, {$CellContext`r, 
             Part[$CellContext`sol$\[Phi]g, 1, 1, 1], 
             Part[$CellContext`sol$\[Phi]g, 1, 1, 2]}, {
            Full, Full, Full, Full}, {
             Darker[Green], Magenta, Blue, Red}, {
             Subscript[$CellContext`\[Rho], $CellContext`ADM], 
             Subscript[$CellContext`\[Phi], $CellContext`GR], 
             Subscript[$CellContext`\[Phi], $CellContext`g], 
             Subscript[$CellContext`\[Phi], $CellContext`f]}, PlotTheme -> 
            "Scientific", ImageSize -> 600, FrameLabel -> Style[
              Row[{"r \[Element] ( ", 
                N[
                 Part[$CellContext`sol$\[Phi]g, 1, 1, 1]], ", ", 
                N[
                 Part[$CellContext`sol$\[Phi]g, 1, 1, 2]], " )"}], Blue, 
              14]]], 
          Quiet[
           Plot[{
             $CellContext`\[Rho]ADM[$CellContext`r, 
              3], $CellContext`\[Phi]GR[$CellContext`r, 3] - 
             1, $CellContext`sol$\[Phi]g[$CellContext`r] - 
             1, $CellContext`sol$\[Phi]f[$CellContext`r] - 
             1}, {$CellContext`r, 
             Part[$CellContext`sol$\[Phi]g, 1, 1, 1], 
             Part[$CellContext`sol$\[Phi]g, 1, 1, 2]}, 
            PlotRange -> {-0.05, 0.2}, PlotTheme -> "Scientific", ImageSize -> 
            600, PlotStyle -> {
              Darker[Green], Magenta, Blue, Red}, PlotLegends -> Placed[
              LineLegend[{
                Subscript[$CellContext`\[Rho], $CellContext`ADM], 
                Subscript[$CellContext`\[Phi], $CellContext`GR] - 1, 
                Subscript[$CellContext`\[Phi], $CellContext`g] - 1, 
                Subscript[$CellContext`\[Phi], $CellContext`f] - 1}, 
               LegendLayout -> "Row", 
               LabelStyle -> {FontFamily -> "Courier", 16}], {0.75, 0.9}], 
            FrameLabel -> Style[
              Row[{"r \[Element] ( ", 
                N[
                 Part[$CellContext`sol$\[Phi]g, 1, 1, 1]], ", ", 
                N[
                 Part[$CellContext`sol$\[Phi]g, 1, 1, 2]], " )"}], Blue, 
              14]]]]], 
      "Specifications" :> {{{$CellContext`c$twoAxisPlot$$, True, "2-Axes?"}, {
         True, False}}, Delimiter, 
        Text[
         Style[
         "Initial conditions:", 14]], {{$CellContext`c$\[Phi]g0$$, 1.157, 
          "\!\(\*SubscriptBox[\(\[Phi]\), \(g\)]\)"}, 0.1, 
         2}, {{$CellContext`c$\[Phi]f0$$, 1.157, 
          "\!\(\*SubscriptBox[\(\[Phi]\), \(f\)]\)"}, 0.1, 2}, Delimiter, 
        Text[
         Style[
         "Integration range:", 14]], {{$CellContext`r$min$$, 0.0001, 
          "\!\(\*SubscriptBox[\(r\), \(min\)]\)"}, 0.0001, 
         0.1}, {{$CellContext`r$minf$$, 6, 
          "\!\(\*SubscriptBox[\(r\), \(min\)]\)\[Divide]"}, 0, 
         10}, {{$CellContext`r$max$$, 20, 
          "\!\(\*SubscriptBox[\(r\), \(max\)]\)"}, 1, 
         100}, {{$CellContext`r$maxf$$, 0, 
          "\!\(\*SubscriptBox[\(r\), \(max\)]\)\[Times]"}, 0, 5}, Delimiter, 
        Text[
         Style[
         "Parameters:", 14]], {{$CellContext`b$1$$, 0, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)"}, -2, 
         2}, {{$CellContext`b$2$$, 0.1, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)"}, -2, 
         2}, {{$CellContext`b$3$$, -0.3, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)"}, -2, 
         2}, {{$CellContext`c$kg$$, 3, 
          "\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)"}, 0.0001, 
         10}, {{$CellContext`c$kf$$, 2, 
          "\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)"}, 0.0001, 10}}, 
      "Options" :> {
       Paneled -> False, AppearanceElements -> None, ControlPlacement -> 
        Right}, "DefaultOptions" :> {}],
     ImageSizeCache->{1113., {249., 256.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`c$\[Phi]g0$$ = 
        1.06; $CellContext`c$\[Phi]f0$$ = 
        1.08; $CellContext`b$1$$ = -1; $CellContext`b$2$$ = 
        0; $CellContext`b$3$$ = 
        0; $CellContext`c$kg$$ = ($CellContext`c$kf$$ = 1); Null}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellFrame->0.1,
 CellMargins->{{40, 5}, {0, 0}},
 CellTags->"case5explorer"]
}, Open  ]],

Cell["Solve the constraint equations with higher precision:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"id$\[Phi]g", ",", "id$\[Phi]f"}], "}"}], "=", 
   RowBox[{"NDSolveValue", "[", "\[IndentingNewLine]", 
    RowBox[{"id$DE", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\[Phi]g", ",", "\[Phi]f"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"r", ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "15"}]], ",", 
       SuperscriptBox["10", "4"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"WorkingPrecision", "\[Rule]", "$workingPrecision"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"id$gA", "[", "r_", "]"}], ":=", 
   SuperscriptBox[
    RowBox[{"id$\[Phi]g", "[", "r", "]"}], "2"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"id$gB", "[", "r_", "]"}], ":=", 
   SuperscriptBox[
    RowBox[{"id$\[Phi]g", "[", "r", "]"}], "2"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"id$fA", "[", "r_", "]"}], ":=", 
   SuperscriptBox[
    RowBox[{"id$\[Phi]f", "[", "r", "]"}], "2"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"id$fB", "[", "r_", "]"}], ":=", 
   SuperscriptBox[
    RowBox[{"id$\[Phi]f", "[", "r", "]"}], "2"]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup the default integration parameters", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r1", "=", "80"}], ";", 
  RowBox[{"nLen", "=", "8000"}], ";", 
  RowBox[{"nOut", "=", "1000"}], ";", 
  RowBox[{"nSkip", "=", "10"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"t1", "=", "10"}], ";", 
   RowBox[{"\[CapitalDelta]t", "=", "0.005"}], ";", 
   RowBox[{"mSkip", "=", "1"}], ";", " ", 
   RowBox[{"iMethod", "=", "\"\<RK1\>\""}], ";", 
   RowBox[{"$dissipation", "=", "0.2"}], ";"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"slicingMethod", "=", "\"\<const\>\""}], ";", 
  RowBox[{"smoothingMethod", "=", "2"}], ";"}]], "Input"],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQl0XNWZ7yvue+ut1/e92+t1377dd9273usOQ8KQAIZgEqfT0J2BKRAS
BhtsCJkMDaRDBxww0JeEgO0ACSaQJh076Q4m2CBb8ihrlqx5LkmloVTzXKWS
VKp5LvH2cM6pM9Yg1SCpvv/6L+nMtc+pXbV/9e3pE9/54Td3/6eampqn/0/0
55vffvbvf/Sjb++9539HK/+w95nvf+d/w1svqql5DS3g5b6+vrNnz/7hD3/4
5S9/+dxzz1326et5vu6yq667FPnKLZdeseWSK6695PJrL/7UNRd/6uqLP5nD
n5BzzrOUrpPZgl9d6MuvQanCvuJanM4rSYKvwimnvpS7BeJL6I1gb2E3KpxC
zqJ3fQl+FfFLMxsl2/lpY5LHvBzvhQTPWWIuGVdm0sBckz6Tyz6jaNGzyvLo
pOYe+2Wil8jvIvzXYm+ce8KXCc1/U0ju2pLXm8J/E5n35dqMr8jqzJHcW3ON
YGOu58O7oy35vZWCm+XSzLyPWd7EfK3wseKllnmk/FzNy1rsk89Y9uFfJvfw
s+f8Ej6rS4UWPZA8Pxc58zB3sPhDcXXmsTMPWXiPoiec33eOIIdnsrcgbxfy
MMFgMHiD+cknn3zppZfefffdDz744AzR4cOHX3/9dbTris9c99t//2MksSLj
OHU6jBzL06m8jyzEcbEj2CR5gjR/HEkSK96L5HjW4cQKdpxxKJbOy1Gxg6zJ
ASuhOGf0EtghqeN844ODMWR8kQByJIUdTvnDSWWnsCOswxJLdvmoQ0nkZeRg
gtqLHGAdzGrusECcPTjppVcLI6eWIxKHqckB5EhvSHiKxN5wEpseGUwsKZhL
lfwBgbjYStslxpdlUpjyRZDTvmjaH11hHMs4wPhjuoA3ogMiaWTuaZNHncuh
HPbJmH1Dw2kfeUWatoDQmWRnLLiXgPAumFuIppm74G5Eai4B3KsLH07G7Muh
x+iLMGbea/IWe7n3xR9bRPYp25/DS/44tuKbmysD+CUmOYfJtDSLymRvJpOz
hwkzNrpZesuM2e3sZ0Fk0Vk0+5XdK1Xgcj9G2e8QoT8uugOldlzgYFEdym7Z
spV1eLWOFMvJ8jpBKCjJmgBPMrWy85YvpdaHUEqSqTSCT4SgCESffvrpN998
87333vuP//gPhKZ/9T//+vAfPlgIprSe5IQzMeFMTiK7yF9kR2LCEZ+wxyds
8QlrbBzZEiWOsY5OiB1BnrREGVtzmTvMFlXb8N/MdrKgtsbUtpjaHpexIz7l
SEw5ktOu5LQ7NTOfpp71rMx4Vqbn09ju1BS1CzmpdiKn1C7sSez0hCs96VpB
Hnelx51plTM9Zk+N2ZIjlsSwOTZkig4ZiQ3Yg3TZGENGy9iG6ACyHjmC3K/D
7iPuR6uG2IApPmhJDlpTQ9b0kA15ZchOnR7kbGNtTfdb0n3I5lSvKdFjiHfr
Yl1zkQuacOdMqH062D7FuA070KbGbkWeCmJPh9qmw63IU6EWZHWoWY3+Blum
gniBbpwONU+Hm6bCTZNB5MaJQMN44NyY78zo8plR75kR7+mhxZODnvr++Trk
PnddL+PjPciu493Izlq00OOq7XEjH++dP4729rpP9M+fGFg4MbBYN7RUP+I9
ObZ8atx/eiJwajJ4ajLA+eSE/+S4r34Mebl+dLkOecRbN4KX0Za6MV+dyof+
1qsY140tnxj1Hh/xHh9eqh1c+GjA82Gf+8NeN/7bN0/+4oWP+jP+sJ/bjn2s
14Xd4zra4zza7UA+1uM41utktzuP9qCN9qNd9g8uMH8/6ES2fXDBhhaOdTk+
Qjc4uFA3jG7Kd3rCf1YdOjcTOT8bbdTEmubiTdp4sy7Roku26JOt+lSrIdWq
T7cZ0ngZbZxLNM/Gm6ajjerI+YnQ+Ylgg8p/bsx/btR3lnqEepkxt32MHEat
4jvQoMLvWsN4kO9z6C+6PnqVqWjjTKxpNtY8h1OFk8E3SpIWp4q6mRgva5No
V6sOJx6nnxiv4uPRMfHm2VjTTLRxKnpeHT4/GUavxZi8NErV2bHAOVWwYTLM
JEATx1fWplp0qRY9drMu2aRNIDfOxZHPa2INs9Fz05GzU+HTKJNMBNDjrRte
OjG4UNvvQc/8w27nUfpetFv/iNxGbeEZb0d7P+iwYXfaxcZvKHpznejd/xC5
1y3vHjc64Bg6DJs9ktvY5Tzahf66qNH2j/o8xweXTuAc66sf959EKceZPIgX
kMf9aCPOvWM49yLX0/yMjsQHo8OCpydD1HT15Di6dz/+OIwsnxj2Mh5Cf9EH
BJ2LTkTXDyGfVoeRz0xH1uqZaP4+yzhWHcY3K/8opqMFPmdyKbJ8Fplc+RzK
87OxBpT5NfHzc9QJ5Eb0udCiD0iySce4WZdqRp8afbpF1obVu5V1m5KN8m7P
5Q5jupPaJPYFibuQzRl3U1sY93C2pnuF7qO2YffzPEBtxx7keYh42IE9wvMo
tTPjMcYryCpkV8bjQk9QuwWeVLaael7GU1md8xj1fJq3ms7YnVa7U9jzxGQZ
/cJ94Cs3e8ZV5tP1tjP19rPYzrP1buy6hbN1i2frvGfrls/W+bCPB84eD549
HlJwkLc3eLY2gH3ch40ucmLpzImFMyc8Z064sOscZ+psxNbTdaZTdfOqMZSS
pVBy1hX1BBIIRBGOUkClUdPD//FH63JyHFNogtKpBFCTakcC/cUH2OOcJ1k+
pJ6yI1DEnkZ2UidmCnaSOIHOnXYQo42uJPIszzOs8aobOTU7n9J40tgLK3PE
Gp5nPemMCb5ScEVv5TR6N9lsM0lyFwLUcUdKZU+NIkC1JrAtceRhZDMxolbi
IWQzchx50ERsjA9gx/qJ0cKAKTFozqDpIEJTm5BL7ewHitrKGAFqLwJUY7LH
kOjWY0a9oEWOds4x7tAQo4W5CLYm2o6MV2Ptc7E2TRR7NtrKGG+hC60a7BZN
rBl5Jto8HWmajjSoQw2TiG2C5yYCZ1X+M2OIVJdPjSydHF46ObRYjzy4UD+w
UNfvqevznOibP97vOTGAvFCHWBRh29AiggoEpYjfKJeeVPkYNJ0InCYFtwBQ
J0kxrfJx5li0ninZ/fW8jScQoDKMulQ7vFg7tIAwFf8dWsQLg9wq448GOXuw
B1j3s8hKCXaAGC/T7S5kBlkRu/Y4KZwgUKkdmD8xvIgoGt/XROAMolP00GYj
5zXRxjkMqM2I3xCg6llA1aco4LE0mGhGqIYYdSbWiDB1KoIZknoyLG9EgOwx
6Hiho4ynxW6iUIqxMI5elEFTSdEj5lWGWlMclPLNAirLqBr8EghTManS153i
7ginGSeDSUOiGZ1FLsvRqQygzvAAleQK9JxPDC+hnwO1A55a/ENjnmVIl7zF
tElO6cPvLP61Qt56Lp8cx14UuXZgAbufmC4PLBLTLR5idiM6BaHjCGVOPwZL
5idYxgymSs0cEGJQkzELqDTbI0zlrAqQ65NTCJdiTxWDTgk7YQOdytGpPKNO
rwJQI2I6nSF0igE1jgGVWo5OmxCd6pTpdA2A2ipx/oCaE1MzgJo/o/IwlaNT
KaP2KDBqv5RR7fKMOpwHo47xGFUEqPKM6s6XUbMAahb+zOMARTqlzjAqodP7
v3Sze2TEXPcRsrXuI1vdR/b6Y876Y+76Y576Ywsnjy2ePLZ88piPdSBv+/GJ
R+lZ3pNHF04e9dQfna876qo76qg7aqs7aj3xoeXEhyZi1/Dw/f+A6XTUEkY2
L8URjtII6hNPPHHFZ65bCKbGHXFklk4JoBI0Vbswo5IwIw05IkzF26eI1eSA
KXdymnhmPjnjpqyY1MwznptPMfYU31puYQE5jaxbXKHWsp7jzKNW9HeWmoZY
PStTxByj4iCqIz1uT40hRsWYmhqRcRJ5GNmKPYRsoUY4is1wqQUZo+kgi6ZK
XMp9rPpJ+LQf02m6z5TqQcaMmuw2JLr0jC/w3JlxknOHPtmuT7Rrsdt0yMl2
bRIvCxxv1cRbEEVo4ggnGmciyOenI+enwufUwbOTwTMIwxBhjvlOj/pOjyyf
RGyG4BMh6CDi1aV6AqL1JOZ5ctR7Ev0dw5x5inDpqQk/BdHT6iAqfLHVwVPq
ADZl1PEAPoyYiSmxZuh03MdYxURTeYyKMZX85YxWl06wPj68SF3L99Bihloz
KItZ9yMGaDGEfDQwz6LsPF4meHN8aBFdtg7do8qPeVsdQjTFhU8bafiU0GAm
gkrMAirDqCRWiR94xrOEWiXG2/mHzeVlEgLFUdAWJgoqg6aK5ohUspGkn9wC
i6nMjXD3MkuQdZZjY3RAko2a4kgsSgZHp82ETimg8sOniPkJoAZOkoA5eton
CKZiUkUeWuAIk/frY0H48wS/y8cZLzHGp3szAUkcqMexer7xC41kDiBePsFt
H/VmFrBxOLSO+SVF0ZFYHRQxKsZUYul2fLCao1M2iDpOGHWcoixG1lMTgpAp
RdPi0WkE6DQ7oyqETwsGVD7xUjo9x9Ipw6iVptMixlE7RIBaaBzVwliJUWUA
VYlRbQqAqsSocoCaF6NKAFWJUdWFB1FzHsOnUzWfTnmMygEqotP7/v5v3QMD
+mPvm469bz72vvXY+7aP3rd/9L7ro/fdtUeQF2qPLNYe8dYeWT5+xIf9XkDB
aJdfuIpO8R5/z4sv8p6n9j0XsfPDI7YPj1g/PGI5esR09Ijx6BHd0SOu/n6U
Eo5OkT2BBILSe+655/rrr//tv/9xzpOgdMoLnyYmCJeyaMp3mtSPp6bdyOkZ
Nw5FztKgJQLFBWzCiindImLFtJ56KW0ogfVL/CuvGFkbeNZLzOErRVaKqaQZ
ADZ+991MxF7lTKsc6TGaae0Cjwg9bENODSFbqZODjFPYpMoeh0xp3T1blS/i
Umr6QWMq9xGgEkZF7jGlCaamuoi7TakuE7OMfIHnTgN1ErmDdTuG1RQxXU62
Ebci6xJMTGyO0kX0PIKumUjDVLhhKnR2MnRmIog9HjiNjNhsDNmHfJL4lArj
5WlixBWnEblNsGFSNSZS7Cl2Qc2LoE4wxhX9QtdTU0zlAyqfUUUe9fJ9fJTh
VYmFvDqyVEuDsTyCxZAzzFArMg61DS9gRhr11quW2dhp8Ox06NxMGIdP+YAq
qt83pCjskbp+XogSo2OyhW+t0LxdrQWZHwvNn0vzo1Y28ZyTrYLEJ0RszEdT
SqeK4VMEqDMMoNK8wfxUQT9SSAsQBITM2zrqFf4qYT0qMDq4jjYaYYxzDmPa
bkTgZTnzd/nqeU1NyE8nYiYiShmSY878jZhTCKg0iJq5YEgUMuW7eICam1HP
ClxxbiwfoCo+k9XRqTB8ykZQuSp+BlAZRtUKALWk9fu5AXW1jLqaOKoCoOYZ
R5Wp6xcGUYfyC6KO5WLU8bUzan6AuoqWAIp0SmKn9/zd5+09Pdr3DuuRjxw2
HjlsPnLY+v5hO7Hr/cPu9w973j+8iH3I+/4hH+t3nn3hnvt3U6Nl2S1L7x9a
eP+3C0cOzR85hK7jfP+QDfnIIcuRQ6b3DhneO6RD/sOhuT8csnV3o5RgOrUy
dDrjiiIoRWh62aevX46uTDBoytKpgxc+xXTKASq6uzQiUlonTpp34tgjrjr3
pOcW0jRWqWMh0OBdMRKbvCvmZWwTsVloE89ZduV0nqcYl3GSOHBFqaWYSmr/
cRB1mry5OP8QQB13EjtWxhwroxKPUNtXhrFxbifNSgVm0ZRtVioXL+0n8dI+
npnPGoumDKAyzXJS/HqQC9Tkc8192NFCB+NUhzEl+K4wpNsNKc5t+hQHNi1s
88LGuRjCLQRdDYhRpyPnEKOqkYNnaUB1EiMo4lUCophFT+ONoTMkQEoKaFLm
8tF0igVU5hhauU+chU4neHRKTLlCwctSi5A1w67y4Mq4lsZdeVtOjC4R2kF0
6js57qdtFc5Ohc5Nh/Ejms00QCX1+0I6lfueZ8uClIBaZY2PYUqNLOVI7pKl
eIzKg1Upr2bMHpChU3QvYkBl6VQEqLQNKvvjJYCyAfltIverRNbsb5l6WUti
9ZmIPZPTBAfUZxxAOFovU1mPvXo6lTBqxuqQLJeWAFAhgloOOuUvCwE1ngFU
hlGxhYBa/AaoshHU1cVRZTG1Y7WMymBqgYyqFEcdENb1D/EBlWXU4fwZtUgV
/UWPoE4JIqi8IKqETr+x7QZbZ8fsoXc0xLpD7+gPv2M8/I758DvWw+/YiV2H
33Yffttz+O1F7F9RIwT9mBVa/tXTz4q2oGMWDr89f/hXrsO/ch7+le3Q27bD
71gOv2069Lbh0Nu6Q29rf/v2LPHMb9+2drR/4/M3IDods0YooI5ZwghKaS/+
SGJl3B5nzGGqnSNVtg2qMzmmW1QNzuLbJHTKhEyZ6nJSq06Qj+IoR6SW5RWr
r8i2KDhzwLKMxehLyBkhtH5RwKhMRT95cydJEHWc5ECUJ0f55tCU9TDDqKS7
Ex9HrdgD7KosmvZJ0BTbkjHzScwAKjbXSucCz52cBYyK3U6NvzRYNBXQEY6j
NutolSsOAyJGRdB1fpZ8i06HETZgq8OEVJExRTAmu8gC9mnGQYE5WCV0ejIr
nWYYVUinDKBm8zLfJ8a88h5dOp7FXCMBAqWUS+vGvLhvi2r55Ljv1IT/9CQJ
n2YANcpvgCoOn+bRiKvILjWpKiOrAF/lSr0s3aOQcXBpOoxzkZr3K4bmBy4P
5M4GPlG2ETrz80cp7ymYl28lXhWdYkClPq1kBS4tNqACncrTadb6/VU+bUEt
v7CKXwioyQrS6eriqFJG7VgDo2Y6TK2irj9Xh6khEaYWEkddRW8pWUYtqBnq
qrpTiQA1Ten0rs9eY2puHP/lgck3D6jfPDD95oGZg/s1B/drD+7XH9xvPLjf
/NZ+61v7kB1v7XO+tc/11qtu4rd++CMRjvKX3/rhP7sOvuI8uM9xcJ/14KvI
poP7jAf36Q/u0x7cp3lz3/Sb+6Z+uX/yl/snfrlf9Yv9xqbzd11/NUunERo+
DcfTmE6vug4tjFljKhv2OLHKjo0AVWUJD49bJk0hGlDtOtXc+9bLajdpaOpM
qC3BaXdyjqnET+kXcfW6cSlt8qYpmlIutflW7P4Vmx//5dsh3pLO0za+fWLb
JVtEtiIvpxHKYkal0V0uiLrEVPRP8wCVT6djLJfKoCmfTjNcmqLmOjpxnZ5k
ubQ3C5daZKC0i/sUS7i0Q5FL0+0kdtomNBvUEtIpEz5lfI52XSHtA7G5BVQ+
MlagUzWvWl9NW+Ktbzrl+cTYEj2F0Cmu2UdpODnBAuoUr35fgwA1hgFVVL+v
rwSglo1O83BBgIrDpxk6JT9keDmEyw856TRPRl0HdBpcI50WCVCBTnMwqkLr
08IY9ay4jQTbQ0rQAJVW8Utbn5abTosVR+2QsxKmCgCVFG35M2pBcVQlQFUK
osr0lnIWD1DzCKLm3ZcqzQRRPZJmqCydfm3LVfqGsyMHXh478PL4gZcnD7ys
fu0nU6/9RPPaT7Sv/0SP/MZPzMS2N35iJ3ayPviDp/hQyqEp2u5kD7aRc01v
vKR7/SXday/NvfbS7GsvqV97afLnL03s/6lq/09H9/90eP9PdefOfO3aq2Tp
9FJCp6PmyJgFOYptZawiy+d+f9Rw9N8nNUvogM6932j74SeHZ9xqZ6K37lTf
uZZZ0ulJ60npFtL6hbRhMW1cTJuW0mZv2rKMIRDjIgFRidMZE6S0+1Jr8rLE
XtbC7TZkCqjEmSAqYVQ+oOJOUohOhYAqz6UsnQ7ZmZDpACJSS7LfnCBOEqf6
LCna16nfKl+Vz3Epg6PcR082Xsr7COfmUlPmi4L9YhGiKUenWrbHCh3nRENq
nUhQC3+LzkT4PoMoQmQBnYb4XHqaK4szXUX4gJpf69PcobP86HRsKU9A5eiU
AVQVEz49Sfp8oZsigIq7R/Hr95to/30MqCmZKv6qp9NWuQaogvp9YfiUi6DW
iyKouTC12HTq51flKwJq4fX72ei0fOHT3Ixata1PizfAlAyjihugyveQKhWg
5smoa4mjytJpvqFUc8GMmmccVdQMtXBGLeaQU0UF1LRaSKdqCZ3ecfXlujOn
hn724vDPXhz92Yuqn7048erzk68+P/Pq85p9z2uR9z9vJLbsf95KbOf5zSd+
gHDUxwotv/n4D+z7nke27tuLbNm317hvr2HfXu2+vXOv7p19de/0K3snXtk7
/sresZdfGHn5haGXXxh8+QXt6ZO3X315hk6tYWSGTq/cghZGjKERE3J4FJsu
hMhCqKNLPf2Ply2++CXbS9vb7/tPv/7qRR/s+e7pPfcb9l411D0x60rMuRNa
T1I3n9R7EoaFpHEhaVpMmZdcxx+s4bT9vAtRqBM5sIJNl4kdvhRx0r7Ms1fO
WXbJOMGzYJdtKWnzppCtCKG9KQyoXkTUDKDS3lIaZqxUpgEqGWOKxE55DU1x
W1MRmrLxUsylpkSfMdFriPcaYvivkayakn2YUUmnJ9KmVICmEi7t5sVL5UOm
3AdZrh6/QwSlMvTCUBMTOMV9WJhuOE201ZO4TWCGTs/yzENTNoIqKFslZfGk
HKCuogFqfoC6xgiqhE4JoI4v0/ApC6ihDKBqMg1QRXRKW5BWYQRViU5lAVVE
pwJAxW0+8/+dUiI6zQGoJ0tBp7kAtXh0mu8gqECnxezCP8vV7/PodP0B6qrj
qFnoNC9GFbZeKxajDvA7KRdY0T9auiBqLv7MA1DToi78nDk6/cJf/N9DB9+o
u+2m+ttvOnX7TWduv+n87V9s+doX2772xc6vfaHrzi/03fWFobu+MHLXF8bu
+sLEXV+YzHgb8oF77kFE6maFlvffc8/Enduox+/cNnrntpE7tw3eua33zm1d
X9vWece2tjv+tvmOv2247W9P3/Z3J2/7Yt1tXzxx6xcH33wdpYTSKWeGTq/Y
Eo6lhnSBYZ2fmC4EBjXLvQO6IfV8f69mds8Ngw/UXLi/5vdfrfnn62te3HbR
0IM1Cz+9V20KzthjGmdszhXTuuI6d1w/Hzd44iZP3LzgQHR631knDlcOH76o
puYXI5ROidGCL+UkUOpYxs6Q5FLGtqW4PWP+rrjUNtadv7qo5i21bTFuW4jZ
FuJ4QWgr9VLCupS0LKXM3hSh07SR7SelpR35CaCit5KO1Y/H5yc5c4RpR70i
8pB9ZZCNl/YZMZT2aKNdc+EuTbh7LtKtjfboYz2GRA9m1FQf2x8fd3qySmrw
WS7lRifmoLRLWOuR+QgblevxFb4uWkW9yBlU4GghKaVTBhskPpOp2SfmGqMy
DeoUSuT86FSpir+g+n1FQM2HThlAXeIDKlu/j+hU3AD1PNcAldbv61lA1VeC
TtcHoMoXc/kCKq8B6gTXANWfJ53WZafTkjRALVHr03JFUIFOFeg0F6Ouik7F
4/PHMyOgMuPzFzI4/xoYNX86XUvX/nwZVYSpZjGg5sWo+XXqV2LUQkedKgqg
5hlEVQLUrN2pCKCS1qeITrf92Z8MvHGg9kufO/7lz9V9+XMnv/y5s1++sfGr
N7Z8dWv7Vz/bectne2797MCtnx269bMjt35Wdetnx3ne/427EY7ahMKA+o27
6QEqctYQuUL3rZ/tuOX6tq9e3/yVG85/ZeuZL22t/9KNJ750Y+2XbvzoH27s
f33/5//sT2Tp9JLLrw1FUwOzXoFnvP3T3pb3Tw89e7vh+eujP7/Us/+Kkec+
cX73f+t96n/MvXjF7Pf/ZO7JK6brTs90T8z0qmdnHRpHZM4R0TkjBmfU6I6a
5m21DyA6dSACtC0763fh8CmCUhex00/RNIXR1EtocxE5ZqNe4By1eYjRwkIs
q6P0YKsn2vnWRTUHJ9CCdZ6YbKS7qC3I81GzJ2ZeiJsXE2YEqEsp41KKjkml
X0xrF9OaRdzha9pNJpNyJsftSZU9OUrHNbUkh6wpMnhUmp3viaApyuRMyDTe
q4t2z4UvzAQ7p/zY04HOmdAFTaQL8ao+3mNM4g74si1LWfPnzpCpx+dZ8OnO
g0tbOevTHJTyTQGVT6fk53yMfHkyzqApaYYqS6e0SF0/dCrPqPm3PhUFUWn4
dJwLn4oBVRg+5feQKjudrg9AVWBUEaAmlQCVmV9M0AA13+5RefaQqjSdSrrw
F06nxQFUoNOsjFpMOhWSqrj1KVu/XzCdrgpQC6XTVTBq9mao2UKpbNO11TCq
chxVDKhZGTUPQE1nAdTi9uXPQqdCiBV34afGdPrn/3nwlweOf/kLJ766rf6r
207dsu3sLZ9vvPXzLbd+rv2WGztvu7Hn9hsHbr9x+I4bR+64UXXHjeN3bB2/
HXv/N76BQNTISrSM9qJjVLdvHbl969DtWwdu39pz29aOW7e23bK1+ZYbz9/y
uTNf/dypr36+/iufP/GVz9d+advAG/s//+f/WZZOL/7UNaFosk+92Kde6FN7
kHsnPb0T8z3j890qd+Or/+vMQzXGvX8a+s3fh3+zLfzO1eG3r7e9cvmhO/+v
s9+s0X27xvP852bqz0zP2GcsQY01qLWFdPaw3hE2OC0f7qi577TNirDT66zf
iejU6fTPvHkRV9v/225vwuFV/+Kimjd+9W9o8/1nrBgsWb3eG7G6w53ohDff
fZ1u3tGi8liOP0CW3xy3zkeQeae820GPZ7SrVh2yqJvvZ9fvO2W2uMJjJx+q
2f7uazvw8W1ua+0DzN6fDyBApXS6olvEo2NpPOkZV0rtTE3YEuO2xKgVzxWF
54QiA+wP0WlJ2Y75Q6RCn0RNYz26aJcmdGE60DHhax1bRG4b97ZN+tung52z
4QsUUE0p3Pue9sFX5lJuqKhOpXgpz6Juktm4NBO8SrdI6VQIqHSWPRGgclzK
mU+npJTk06kCoCq2Ps23AWr+rU+zRVALoNNMm9U6HqCeVKrfp+FTfgNUfuV+
ORm10lyaJ53SCCqu0CSAyrQhkTZAnSi4C39J6DQnoK4hgiqPqWULn+YxgRS0
Pi1WF35e+FTQ+pQHqEl+5/2mkoVPS82o2fvy54ijmtfGqHlMMiVi1Lwq+gsM
osoyarZZpXKBaHZAVaTTaHrbX/yX4bd/cfyuv6+/6+aTd9189us3N9x9c+Pd
N7fefXPH3Td33X1zz903D3zz5qFv3jxyz02qe24av+fvqBGCallhHL3vPtEW
dAw6Hp2FzkVXQNe5cPdN7Xff1PL1m85//aZzX7/pzF031d95U92dN9XeedPQ
r17//F/8F3k6/eTVwUgSsWjPuLtn3NUz5uoec3WNOLqGHReG7K3nhg59/S8t
P/l/Qn+8P1z3UOgPXw3/+pqp//XJn/79n5y/p0b/w8tUZ1vUet+UwT9t9M8Y
/RqTf84S0FqDepvxw+0ICK0WT8w217G95lv1OhwvdTF1+jO/vKhm+zm7fXHy
Fxgnf9OJUTOMcJQ41IF3N486g+1k92vdQcskw5n3nTSR5V21k6GxeoSazWOu
kMVJTvnFmNlBTnlj1GQPmOyjr11U89qFINponmy6D50yERxFp9TU3FtnNDlC
rRh9J02euNGTMC4mMZ2S6QO0CE3n0zPu1JQzOWlPqCyxUXN0xBgdMkYGDMjR
AQOenHTAwhtp35oesKT6jQkcNSVo2j6+3DKy0DjgbhxwNQ15mkeXWsd97VPB
DgyosS5jknZ0onSahUsv8Nre5OZS3Bk/Ly4VfCNJGBV99ZHvwGSjjg+omFFJ
09OoCE2pJQUln06zAWo+XfgVW58WCKhKPaQKoVNmma3fx1X84v77mQmk5EdA
ZXpIAZ3K0ak0fJoBVLW0ir9SdJozghpYSwR11V34i0SnEejCvyo6XVMXfunw
p7T/fiMHqJIu/OuETvPE1JyD9ueOoxaVUUWd+rmRHvOv6OcDqlJvKSmgyg7a
Xyig5oygqrPS6d/+5Z+N/ObXJ3fceXrH187u+FrDjq817rijZccd7Q/e3rnz
1u5dt/btunVg160jD2OrHr51nPX+Bx/gxt5Hy7JbVA8zJw6Q63TtuqVj5y1t
D97WvOP289tvP7f9jjPb7zi1/Y767XcMv/v2F/7yz7LQKSbSUWQH4tILw/bO
IVvngLWjbbr3xUcnnvmvkSP3hM4+Fjr9/VDtI6HffNHz88vfveevPritZvK1
p1SaxYk576TWq9Z5p/XLM4ZljdE3Z/JrLQZEp5zeGEw6fEnEpd3vZKKj95+1
2Rcn3riICZNaEGR2v8vb3ThiD7Sh3fefH7UHzHZDLcLdOiNGTccYxs4uYy3v
JZhTbH58yuvDRqvP1Ml7MRog7QwMn9hVc9/5IWvAYA8YCaDee8pm9MQNnqRh
MYXpdCE950lp5lPTrqTaER+3RMeM4WF9aEgXGtSG+uaCfeivPtJniPWbcGd8
BKUDZMAotNyrj9EK/faJ5ZbRhaYB17lu+7kue0Ofq3HI0zTmbZnwt0+HOudi
XYZktymNrTRyqRBHO/LkUslv1RxcKqHTZtZNGFDx12AjE0HFjNpAvjllAfWM
Ap0KI6iKjCou2Qvtwp93Ff+a6JRrgErplAeowvCpYAKpJt4EUq2i/vtlo9MN
BKjZ+u/LjoDqX9fDn5adTis0/Gn1MGrO1qerolMeporplN9/X26Aqcr2kFpF
HHVNjGoqGaMKAbUojKrKyqh5AmpRgqiiHlKITm/673859v6/Nzz2UMP3dpz/
3o6W3TtaH93R8eiOzse29zy2ve+x7QOPbx954n7k8SfvRVY/ee+UgtWSVXoK
PR1dB12t+7HtHY/d3/7o9pbd25u/v73hu9vPIT+6c/S936GULIVl6PQTl10d
DCd48VJb5yBG0/Yz/aPPfWfxub+KvHNzuP77oeMPhd7/Zuj97eFDt4bf2jr1
wpX19/256wf/c+xUEwZUzdKEZlE9tzilXZrRe2cNy3Mm/dH7a+6tM5vdUetC
zI4r8ZOTDY/U1Bzq9iUdXkf9g5hObQuETnvCVleIhDcRcwZM9sAIYsj7zw9b
fa2vIwwlqGkzfLS95t4TepPdT4OiP79AttQZSJjUb7T50WFG63ILPmXIYFk2
tCM6fbvFsky2Mx46jul00OLTWwN6W9DgMB/Dtfw1B3oThoWUfhGP3YrQdJYM
6DppjY2ZwiO64NCcv1/j753x90z5umcC3ZpQrzbab4hTQO03p3Dg1JTAdfqz
oU61v0211DQ0f77XcabDcrrDfBYBar+7cXihWbXcqg62a6IX9Ak8/agpxfR1
kqvK56NpR55cyvsGyItLeXTaLDRHp020ih/RqSZOhpZi6PQcr9HUmVx0mgNQ
pXSaE1ALaIaaTwR1ta1PWUDlxucX1u9H+ePz0x5SguFPy0mn65tRmd9HchNI
nWOakciPgJo/nebqIVWa4U8rQaflHP60KiOosSIOMMXNHkWWI9LB+XMNf1r5
LvyrwFQlQC2MUdfYHlXCqP1W4YCoQkZdVUW/eMipnIyqBKiTys1Q8wDUtHAO
KUynX//UxSMnTnS8uKf16ceQO595FLnnmUf7frx76LndI8/tHntu9/jz30Oe
euF7Uy9+b+bF780qeEayio5HZ9HTx8jV0DV7f7y7+5ndHU9jt/zoUeT2F54e
rq1FKcF0aotgC+j0MyydOnHglKPT8yO9H7UOnBsYOXRY/cL/G3r70tCRHaEj
O8OvX23+l4vNz/215cfXOV/8onHfI6qm3rGp+fHZxcnZBQSo09qlWf2yxqT7
ANOpyeSO4Mr9JdwfvwvT4hTuoY/r+mvuP221zmM6fa0HV82bu/71oppft9kD
Rpvhw/trcITT4mt5jaKmz2jRo433HtdjCrWN/BzRaacfB0Jrdn44jtHUYPWh
wxCUklMGDeZlvWkYHcaQqoXu9Q3V7qy5t2HAvKyz+HQIUO1hnTPajKv4p/QL
Kd0CHrtVM59EdDrliE9YomOG8JAmMDC93Du13D3l65pcvqBe7poJ9MyF+/Sx
PmOijwKqJdVH6PTCbKhD7WsZW2wacJ/rtp9uM59qM52+YDvb62wY9DSOelsn
g+2zkU594gKhU25O4Sxc2iH85GbjUn7Rnw+XEtNf382ygKpN0bmeKZ3yAZX/
pVogoObRAFWZTk+WhE4LGf5UFlDpAFOTkvH5mfr9OG2AyvaQqtD4/OuYTjlA
5YdPpd2jBBNIZbpHFdJDquh0WpLhT4Pro/Up1O+XnE6lcdRM/b6GX7/PG11K
y7Y+XR8DTK2CUWnhtXpGFY06pRxK5TOq/FyoksaoUkZdXRCVD6hjxWqJusoI
qgyd/uyhnb/f/4r66Pv9r/2s52d7e37yzMBPnhl++ZmRnz0z/gry0+pXnp7a
//TM/h9pDiA/pS/EGuwfoXPRFdB1xrGfGf7ZM0MvP93/0tPdyC8/2/fzn05+
8N7v973y8q4HvZhOo2I6zdTsYzrtGrFjQB2wdfRb2/vMHX2WCw0jM3v+W9N3
ayK/+VLonS+d/dafHrqtpm1HzYU3Xh2anB9qn+hvGxtRWcZnFiZmPWrNAg6f
Grwao56hUxfuHW9djBNAddTtzNSz33fagugUs2R3yOQImezBkbpdvN0NQ2aC
mj/HqGkw6wid6kgIlNBph99oJRzL6t5and7s1Y803IvXHjw6sqxv41fuv91s
Xh74CNNpv2lZa/Y1v8Hu3N424I7rPEmGTt2IThOITsfN0VFDaEDj65vy9qi9
XerlznHvhYnlC9N+HD5l6bTPlOwjdNqti3YiOp30t44uNRI6PdVmPonotNN2
psdF6bRlMtA2E+nQYTrF5gZzy8WlXEen3FzKm9k8G5SKzAdU9nsPfwcSQG0k
Y5tQQEVfm/T7Wek7VlxW5qRTWUAtGp3KAGoRJ5DKDNHPq98XT28qHp+/coBa
aS7NQqdy4/NnGwFVnCXyGskhey3/+hn+dP20Ps2rCz/QqVwD1NWgKb97lHSA
KWH3qPUy/OkqGLVd5EIxld/arUBG7VLo1M/H1H6WUbNX9A8X0KM/RxC1hF2l
3Fxz0wydGrxprXX+zs9c8e6/7B05d8bc2mRuPI1sazxtR24+7Wo56W7F9rSe
XGg9uVi4F8i59CLoauia6OLWxlMm6pbzw2dOvfviXpSGObNL64mrJHTKtDtV
ubtVrq4xXtPTQVvHII6jtv/+jz0v72z49b9a39hle+ZPe568duqNf46+8Je9
P39hcGJ+WO0ZmV5QTXtUmE4XJzWLUzovbX2qtQT09pDRFcF0uhCjQ4zaiK0L
cTyy03zE4g6bXWGzM2R0BI32ADaOgvoNFmSf3rzMN9nI2soexi7oyfE6ZJOX
eBmbnKhjrsAcoEVoasLJ09qCOntY64hoXTEdplO2Wn8+OUMbnZojI/rg4Ky/
b3q5R73cPbl8AXliuWs60D0XZugUmVTu95qS3brYBU24Y8rfqvI2Dnkaep2n
O62nOiynu+xn+9wNg4uNY8vNk4HWWUynnYZUpzHVKemJn4VLKV1k41IWTbN/
NYm5lE+nOrEZOiWA2oBM6JQHqPJfwqvrIZVn+LS+GF341zqB1Gi2+n0cPhUM
fxoT1O/rKjrAVKXRVJFO+eFTyQRS4u5Ror5RxaLT1feQygKoG3p604IGmKoe
Rs01/GnBdMpdUDD8KQeoMuPza/MD1Mr1kCoto/LG915jHFU68FRfIRX9ikFU
R44gqkoKqK411fIr0inveK6HlGY+ZlsM/eo7O79//RV3fvL/Q77rU39z9+Wf
+MYVF3/zqkvuueqSez992X2f+eT9V39qxzXIlyM/SH0t8TXs32suf+AawSo9
ePs1n0Lnoiug66CroWuiK6Pro1ehL4de961vP2jxBKbtIYSmDJ3aJH328RBS
bsqoTBx11HlhxHlh1NneNHKhR989Pj915DfGJ/+PkRMNvePusXM9k7//1/4+
HaXT0ZkF1ewCrtyfW5rSLc8YfLOk877OFjI4IyZ31OyJI0a1LOBh8NFfiydm
no+a3RGzK2JyhU2YTkMGOwLUoMEWMNj8eiuyj/AkawvdqGwMqH6d2Uet5Zms
+onJFhNZteKxBeZshE6dMe18QutJzXlSs57UjJt2icK99UcMkUFtsH/W3zPj
757G7pryd80Ge7TRXkOcxE6TdHR9TKf6+IW5SMdMqG3C1zy6dH5g/ky34wxC
0153w4Dn/PBSo8rfrA61zUY79EmGTnmtaLjPmhKXtsl9wEXx0uxfSvJcSq1L
S9GU0in9wY58nqHTOPfTvpiAKqXTVXThL6R+f81D9EsnkBJNb8rW72vE3aNg
+FN5RuWNz9+kXL8vHJ+/iHS6xgiqXwFQK0an5Rz+tCqDqEWmUyaIKh6fP8Y2
PeXG5xcP0Z97jKl1A6h8TBXTaaGMasrNqPLtUXM1RuXPMF5oRX9xg6jFAdR5
DlAFEVSjF1fxY0cKs5dndjXlDRNHWIezOMlZ54mPETTN0KmNN95pJNk7uYCH
OZ309Ex4yOhS8914gCk3Xibb+9QLvWfbx958oW/U0Tfh6Zv0DI5YBsecQ9OL
IzOLY7NLyONz3knd8pTeh0eXMvk1lqDWFtY7IgYXHZ8fEWkMj4HviSFepTa6
ItjOsNERNjhCemR7SG8L6m0BbGtAjxAX2YpAN8Bt1PFtI8aoiY/UWvysA9jm
ALPA8xw1QlNreM4e0Tiic87YnDuhmaf9oRCapqZcqUl7UmWNj5hjg/pIvy7U
NxfqnQv1zAa7NQhNI736WC9B0z6EpuYUHlTfnOo2JLq0sU5NpH062DLhaxpZ
ahicb+ifbxhabBxZahzzNU0EWqfDbZpYuy6J0LTDkKHTbCFTudI8B5dKvpey
cSltd6qTAVT0pdeIzALq+blkgyZBf8ufY6r45RugKtFptiH6ZVufFm2I/kLo
NN8BpmQmkBKMz48BVTj8Ka97lBhQy8molebSnIAqCp/K1u+Lu0fxR5dadxNI
laD1aTnDp3kMf1q1dCrPqKuq3BfTafb++zKdpDYMnVLL02n+jCqZubuwOGpW
Ru1dNaMq95ZSGhN11UHUAmr53VwVf6YxasZuzim+J1mrXYwnXUnqCWon9qST
LiQmHMRowRmfcGCPc7YjxzirsKPYGEoZc4zKzhV1TSia6p9ZQu6bpl7sm1og
RguL/dNol7d/Zrl7yDRwYXIAHTm9NIg84x2e9Y5ovCNzvlHtskrrm9D5J/V+
tRE5MGMOzlpCGoJ/WjyHVFTvInZKHSHGY/jjPkrYIeavLaS1YuMFZHsYmy7b
gsQhznPWEAHOoJZ4zsLaKjJKFbEtMotsj846YrPOxKwribh0Bs9CS9+CFHra
KlsCj8Bvig7qo/36aJ8u0ktN6vR7aXNTc7qPTvxkTncbk12G+AVdrEMTaZtC
gOpvGvM2jnqbMJf6myeDzVPh1tlo21y8Q59EaEp7IEq5VBovFVeA5smlFDuz
Q6nILKA2CU0YFdMpDZ+WhE7VBQx/Wjid5t89apVd+PmAepLOcMrrvy/TPUo4
Amp10ql89haOLiWt3+d3jxJljwK6R22oLvyrnkCqSHQaATrNzqglaX0q339/
89BptghqPpgqR6cFM6pyXb9oTNTsjVGLG0RdXS3/JHE2OsX8KUenAkaVB9RJ
t4BOM4zKAuokD1DHHQydTijQaQZQeXQ6JqLTK8hMpnM+npcHNJx9yINaZP+Q
1j845xvU+IbmltHCMLLWP6L1j+r9Kn1AZQhMGIKTxqDaHJoyh6YtoRlrmOBf
BAHqnAMz6pydtSOqdUZ1zhhnrQM5ijyHHWGMDw6z5k4Py1qDbCO2EtvCs1ae
MYuGOc8QLp1xxKYd8RlnfNqZnHalpt3YOGrqSk+40uPOFJm9NDFMpogaNMX7
jfE+I/pL+ulTNLWkOeP8bEp1GZMX9IlOLQLUaNt0uFUdbJ4MtKhDrdPhFmSE
ppp4my7ZoU8pTfPERwhZLsXOOY0dHzjz5FLWTTpqOTrNACq/AWrBgJq9fl8M
qAVOIFWM4U+9dHTTgvvvqwQznEr775/nAFVcv1+lw5/KAqps69Ms3aP4bVAr
T6c5G6CuJoiqTKdlBdTcjFp9w58ygKrcQ6rw2Kni+PwxUfi0sAao66aHVDEZ
VRlQ82TULANPMVONSxlVGkTNg1FHFRg1RxC1kL78k3kBqijiWgCdTsrSqSCC
mqFTDKhOEZ0KGJWjUzZkypmh00uv3BKOpYb0AWUHhw3IIeLgMFrVB0aQDcih
UWNozBRSmcIT5vC4OTxpjqitkSlrZNoWmbZHp23RGXt0lv61Y1JFWIiXHVGN
I6ZxxqnnWGvEjgnNbJlFdrB2snbgy8448GsxtvGW8fYYNibS2LQ9No2g1IG4
NDHtZKry8XtBuBSjqYvkHEdqxJ4atiaHLclBS3LAksTD75M+UP0WZDbHWtjY
qSndbUx1GVIEUOMdmljbbKR1JtI2G21FsIpW5zCatiOTwGmH8HNXKJcqjcMs
Bs78uLRJZCGgUjpl6ve1a4mghvMcnz/PCKps69OydeFXGv6U3wCV138/Mz6/
dPaoctPpemJU2fApH1AbecOfSur3AzxArTid5hdBLS6dwgRSlXcx6VQEqNIu
/MzwpwyjYpcaUEtKp63Cb4P1w6hMBFUCqHlW9BfUW2rtQVS1O48I6rw0grpS
IJ0qMKqocp8XQZXQaVxcuS+OoHJ0eh1aGDGFZGwMDRvRQnjEFMF/zWGyzHjU
GB4zh8csEeRxSxR5whqdsEUnbTG1PTbliE/ZkQkHItswqU5hXo3gZUyJOGg5
40zMuBKzyG7y15XMbSdyYsaRmGaNL0I87RDajj1FTLfgZQexM6l2pNTO5BQB
fhyvdpKQqRvnBJUzrWJzzqg9PWJLD7HG+RBPWsoG+UlGxVmX0GkPHlqfjLFv
THXqkx36RIc23j4Xb9cm2nUJyqVteoymoo9bznp8aby0WY5OFeFTVwiXKtGp
oAFqItMANUOn+QFqPgNMqddUv59H75iiDTAlrtwfk4RPpQNMsQ1QM+FTGP5U
GVCl4VNZQBXNHpUno+ag01V24S86neZqgLpOJ5CqODSWj06z1u+vlU6lQ/QL
AbXk4dNS02mr5DuhsFCqifEaGVW2PWpORs1d0Z8bUAsLomav5S8ggiqt5c/V
AFUWUHl0SgBVFEEVtz4VNUCV0mmUodOrMJ2OWqKj5gjfI9QW/BdvsUTwMdRm
YrKssiLHVLbYuC0+YWc8aU+onXG1I6F2xNWYUeNqG7M8acd/1QQRSdyS2JUU
OsXYLXISmz1sim8nY7WcJ1mrxQv0IacnnNjjLjrvGI2aYo/S7EQyGKXTQRZQ
OTSldMo0paYTP+ERovBYpp0G3O+pw5Bsx6SKa/MJl6bapVxaYLy0WUin2Wrq
dTznA6UKdNok7CElS6dKjLq56VR5+FMfHp9fsX4/xq/fr/LhTxUZNUf//Yiw
exQvS4xXtgt/Keg0uD4GmAI6zcGoRWmAKkOntIeUzARSCdnpTTccnUoBtYBQ
qknsghg1e2PUHp7zrejPo7fUaoKoec8qNZkXo6YVm6HmG0FNydFpJog6zuPS
CR6dkqipEFDl6PQyTKcrY9ZoBj6prVLHxvi2IcdVnDGXkvRgcmYh0JGcdCQY
2xPcMgZXHLFEYJli7OY7nbErLVhljxE8OpfA/Ec3wdnJOT3uJNX3lEgJlI7T
zOBMqxwkXupMjziZLIRzFKVTNr/RHChAUyuDpt2kcr+LG8LUSOkUG0OpUfyx
yhIyzYdL+ZCZg0uFdJqDSzN0Ktv6lNc9ao4PqLF86bSwyv3c4/Mrji6Vdxd+
RTrNf/hTKZ1mukcFxP33Z6Xj86cEVfzlZNRKQ2k+dCod/jRH/f6EcBTcXJha
gvr9UkwglZVOyxc+zYtRq7P1aXEnkJIPn4pGQBX3kNqorU+V6HTVjFpoHFUp
iKoEqHkyaqWCqDkANRedThZCp6IGqBOSBqiS2KkAULnwqUpEp5++HtOpLTZK
TJgz5vQl5wPJeX/S7cd/sQOyTlF7grJOLwTT5G9mFS1zfxdDIq/kbXz8QnYz
L4cTIPV8cEVitDHtVrArkLGT2p928GwX2ubL2Eq9zLNwoyWXzYXaq+A1X8rE
OMXZiLyUzHgxacBOGBaElm5ZiFPr83IsY4+8dVLP53Q0L7sj2lzWzUdkTvRE
meQtxOjNGhcT2EsJ01IS2exFTlmQJW+6IJ+U2svrwtk+At4UZ5MXPzqS2fDD
5GWkTA4pODPInsKzUq7L7QUl55nzxTbktvSzxvsYFs3JfGysPud6JoU9ZMHF
lwTG3yG8r2LeZyTzbZ+zcFlXXtMXSOHfe/xi2uaXN79Yd2S1kzogsEtiJcag
nmdMmCSUsSerF5QcVjY+gMISuxpOZ5yTrzJO8e0JyaJgMuNAxhQj0YLTnxQ1
QBXSaXyMh6a/+6DuoSefX72fyHgX58eR9zLmbWeOXMvLrSpJD0ld6jQU7xbW
5MomsrxPSf69rvhbCQaDwWAw+Mnnf/9BXQZQpTX7LJqi7W5/EpXgPhAIBAKB
QCAQqGRCgDofkKHTTK8o1ohOdz0OdAoCgUAgEAgEKqFEdKri6PTKLWREKTxs
1DAZNsrtS+x8fG+l0wsCgUAgEAgE2swS0CkxO1fUllAsNaTDo+5jG0Lu5fjO
x56rdHpBIBAIBAKBQJtZLJ1mxudn6PRyMpMpnbSUzGTq9MYe2P3jSqcXBAKB
QCAQCLSZhejUk6HTGEenF3/qmmAk2ate6J1a7Jta6ptecixGdnz36UqnFwQC
gUAgEAi0mSVDpwlMp5/45NXBcKJ7zNWtcner5rvH5x2e8P3feqrS6QWBQCAQ
CAQCbWYp0ulln0F0emHI0TnM2OYO3rvrnyqdXhAIBAKBQCDQZhalU24CKeRw
YgXR6d9c+ulAKN7eb+Vsdfq/+cCTlU4vCAQCgUAgEGgzi6NTDlAZOr2E0qml
rc/c1ottcfi/sf3xSqcXBAKBQCAQCLSZhfvsB5PjDgmd0thpnwWjaY+ptdto
sfvuvv8fK51eEAgEAoFAINBmFqVTlRKd9lvb+sytHJ3e91il0wsCgUAgEAgE
2szi6FRlZ0zp9BOXfiYQTnQM2GjlPgJURKffgNgpCAQCgUCgTaGDBw8+++yz
T1WH0J2i+630I89XUjqNUDqlffZHHB1D9o4Ba3ufxQrtTkEgEAgEAm0K7T9w
4K233nK73anqELpTdL/oriv94PMS7hVF6ZSajZ1e/Kmrg5Fkt2q+a8zVOezo
GLRZnYFvPvBEpdMLAoFAIBAItFbt2bPH4/EkEolAdQjdKbpfdNeVfvB5idIp
7hUlpFM6k2nf9GLPpKdb5e4adZHxTn9Q6fSCQCAQCAQCrVVPPfVUKpWqNDOW
Veh+0V1X+sHnJUU6veLaUCw1qPH1z3j7pxZ7Jz0wVxQIBAKBQKDNIcRpyWTS
X01C97vR6fTSK7eEY+khfXBI66eM6lyM7PjO05VOL6jkqj1xpkpc6ScNKocq
ns0gP5dPtY/UED1SW+mUlExj+7eSW9y6f2zN16qCx5VdlE4rnYqyasPR6YQj
To0YlfaKuvSq68Lx9IgpPGIIYUbV+Z3e2APf3xjNFUBrESrmPq4CQWleJYL8
vDnFklWNiNXI9gxuiVazXm3DQBpObTHo1LfRbrzYAjpdz8rQqZ0BVEqnlxE6
HbNGR82REXN4xBhy++IPPvpspdMLKrmgNAdtJkF+3oQS4BmJJnJrm49O8f0J
WbSIdEoe3jq98dKL0ulyNWmj0WmKi51m6PTT14fjK2O2+Kg1NooY1RJ1+xM7
//G5SqcXVHJBaQ7aTIL8vOkkISq0QYlON4GkLAp0WiQhTkskEkvVJHS/G4xO
nQliIZ0mMJ0SY0B1+5O7Ht9b6fSCSi4ozUGbSZCfN52EwVKR+HQq365S0CYA
X0Z0GG+VbeSZ9RLitgU5LqJ0TcFV2V2SFyI7WDrl9koeBv88yc5MCtDOrUCn
Qnz78FvosXzrQxHUjbx6Q03NDa+OZA4h4h2HN7IHrGNtMDoNcXSKAZWjU7SA
pze1xajn1xed8j9gVfvZKomgNC+7IDOXUJCfN5+YD4zsZ0UUOxXFBgVgywtB
yh3GgZ2IhiXXUPjQylxE8ZqKCZOscS/Kva7spUR8q/AExHuFp25+UTpdFOjY
wzU3IL0yJNqIRDYOvXJDzcPH6OahV17hlh6+4YYa0VnrURuZThOydDpmXVd0
yv+AVdvnqeRSKM11B7dxBLW7odxlb/FVmdJc2oQMMnOJBfl5UyoTHBR9XLLS
qWKVuBydKqyK9injaTYwzpEwwUUV6DTbPQoSRDbIg6/46Gr7AqJ0uiAQptOH
EWq+MijY9vDDaDvedoz5Lzrphldekdux7rSx6HQhlJp0JbCd2FI6HUNeV+1O
s32SQWuVXGlOivJtB3Xc8sYv0CtTmudsQgaZudiC/Lx5JYpHEmUjt8JIUgEs
10SneSYsSyRVZks2eBZdXZJaaHcqR6evDGIePcZsGXzlBrqFwieOowoxFB2A
DpbF1nLrcjnxD9hwdKp2JdQsoPLplKnWt0bGLJF5RKdl7rPP/DzmNbDhGt1I
fxtW7Qes2JIpzRt2c2U5u7rhi/Pyl+ayTcggM5dakJ83uSiiKvWKKj6dSmOR
2Wr2C6BTsVZHpzIJAjpVEuK0SCRiEOh3D9Rc9y/t+N8DvyMb2v/lOmYD/sdu
wu8QcwBzKP+ASkqEpqK96H43B52O2xGdRhGajpkjbl/iwd0/Lnf6yMdw61b8
8cGL+FMkbRIv+LYArVHS0lxSem+G4nx9xE4hM5dckJ83vbI1BC0BnfqENKmI
dmuInQoEdFoyUTrVCXR4R82WF1p1utYXtpD/aH3HYd52TuiAGrSLPU56QOXE
oal01waj02BqypWYIoCqztDpdZROx6xRhKajxrB7OV6B0fhlPmrSAj1rF05Q
gZKU5vxqUCpSmgu2bDytVzqFzFxkQX7edEKfIuXPTDY6Vf5wFUKn/PGrsqnQ
tqzZRiHIn06zA6g8ZwOd8sRBJsHOwyx7ysEn5tMdO3YIIt7rCFBlt28wOiWx
0yl3Qk3MjcaPFibscZUF0Wl41BhyL8d2fO+ZcqdPphU7FOilVR6luXTLxhPQ
aZUI8vOmk6h+QQhY2Ufjl3QCYi6T/SxJu9O8PqDZLiJZFd0T3iuDrrWPkP/Z
ryzshy/3suIWBdXcKwrRmlagw9sRYbawizX8FbJ4+AVmg7YFwSm7V3jiOtZG
pFPqKSGdjtviKhw7DY8Yg25vbMd3ny53+oBOyy4ozUv5cIFOyy3Iz5tQonaa
QjTNbOMN1SYCMCrBUBmKZ4mHB+BfQXghnrJfUy5hWcYo5fZwTdUzB8leSpDE
rMOqskfyb62q6DQcDmsE+i2CzOeb6HLT81u2/1a8/bfbuefH7RSfuH6F7ndj
0SmCUmxSvy+KnY5boypzeNQQxLHTdUGn0JGktILSvJQPV5yfITOXWpCfQUUV
2wGCE/yg3LCSo9NNro1Fp4uh1LQ7OYXMo9NLhXQ6ZiR0+p11Qafi33fV3a67
6IJeJKV8uOL8DJm51IL8DCqi5D6gRZxYFFRWUTqdqSZtODqdcSenWUd5dDpp
j03YouOW9UWnwjY68MO1yJKW5uIRIcn6Bi/MKzgav7AJGWTmEgvyM6iYkgyq
AR/ajSvEaaFQaKqahO53I9FpODUzn5ymFtGpA9OpyhJWmUIVoFOZaYfl9sEX
Q1ElN3o5v1PzZqgG/bhypbmgCZl4G2Tm4gvyM6jIEo9OCnUdG1VAp+tZHJ1y
jvLanRI6jYwTOp2vSLtTUNmlMPMjKdCpNn5R/jGU5lUjyM8gEEhWlE4nq0kb
jU7TM/OpWdbRZIZO1Y7YpD06aY2Mm8PzvngFRpQClV0KpflmE5TmVSLIzyAQ
SFaI04LB4EQ1Cd3vBqLTpXB61pNC1hDz6XTKFVcjOrVFJ6wRj78So/GDyi4o
zUGbSZCfQSCQrPbs2WO1WhcXF1XVIXSn6H7RXVf6weclPp3O8un009dFEyvT
rviUI6a2I0cX/JWYyRRUdkFpDtpMgvwMAoFkdeDAgTfffNNutwerQ+hO0f2i
u670g89LlE41nrRGFDv99PWUTrGdsSl7bCGQ2PnYs5VOL6jkgtIctJkE+RkE
Ailp3759e/bseao6hO4U3W+lH3m+QnTqDafnFpBT1Hw6nXEnZtwEUB2xxWBy
5z/urXR6QSUXKuaqxJV+0qByqOLZDPIzCAQCFSpKp9qFDKBm6DS5MutOIM+4
4siLoeSux4FOQSAQCAQCgUAlFKbTSFq3wBhhaoxHp5r5BPXsfGIplNr1xPOV
Ti8IBAKBQCAQaDOLodPFjGXpFHkpDHQKAoFAIBAIBCqtGDpdSuuR+XR61XUs
nSbniL3h1ENApyAQCAQCgUCgUgrR6XKEoOlS2rCIAZVPp3PzCcYeTKcQOwWB
QCAQCAQClVSYTqNpg5d4KW1cQnT6MaLTS6/C453OueNz88gJ7XwC0yn0igKB
QCAQCAQClVKITn2RtNGbMUOnV14XS6xo3XHseWxvOLkT6BQEAoFAIBAIVEph
Oo2mTXw6TVE63RJNpOdcMS2yO6adj3lDyZ2PPVfp9IJAIBAIBAKBNrMonZq9
GFBNy9hxQqeXXLEllkhrXRGtK0qM6fTBR2EmUxAIBAKBQCBQCYXo1I/odJnY
i83Q6eXXRhGdOsJzzojWiRnVG0w88L09lU4vqOSq+JQ3MLcOqIiqeDaD/AwC
gUCFitKpZTljSqcXf+qaWCI9Zw8hQNU68F9vML7jO09XOr2gkqsW5iUHbSJB
fgaBQKANJ0ynsbTFRyyi03haaw8Sh3T2kDcQv/+Rf650ekElF5TmoM0kyM8g
EAi04UTp1OrLmKHTT16N6dQW5Oz1x+57+IeVTi+o5ILSHLSZBPkZBAKBNpwQ
nQZiaZuf2IdN6fQTlyE6TWmtfq01oEMmdHrvrn+qdHpBJReU5qDNJMjPIBAI
tOFE6HTF4U/bidFCgqHTzyA61WMuxUYLmE53/qDS6RVqbP/Wmq37xyqdjM0l
KM0rI8jMpVE++Vl3cPdBXRkyXQm17vIzCAQCrUGIToOITgMrzkCaOkOniZTB
FjDYGS8H1hWd1j5SQwUFepGVvTTXHdxWU7NNUpSTzYx2N8ietMq9pVJlSnN5
BIXMXELJ5Gd+jmMkzdIbTECnIBBoMwnRaSi+4goQB5HTiXSGTo32ALYDOegL
rJuafVyYP1JLi3oo0IutbHTKFOuiopxPrPQIPmSuZW8JVZnSHGddYY6FzFxi
KdFp+X4IlUVApyAQaDOJodMgMWZUlk4/eXU8kTY7gybWvmC83L2imJASLrKZ
RVyMZwQFeimkTKe4UN+9e7eYThuEW/Aqr+hfy95SqvylORchZSXIzZCZSySg
UxAIBNpwInSadgXTbuRA2sXW7F/8qWsQnVrdYcbzYX84UYERpUisaetWXJCz
QaaMoEAvhZToFJEj5sgGMZ1KiFKwYS17S6r1EjtlBZm5RAI6BYFAoA0nSqfu
YMY0dnrJ5dckkmmbJ2JfoI4Gwskd3y37aPwk3iRk0oygQC+F5OmUYVNJtFOm
ISohTH5l/Sr3llZAp1UioFMQCKSkgwcPPvvss09Vh9Cdovut9CPPV4hOw/H0
fIg4iJ2kdHrFtYnUitMb4xyMJh/Y/eNyp0+5NPdBgV4aydEpx6b50KmkKekq
95ZWQKdVIiU63baN6xq14btEfQx0CgIVrv0HDrz11ltutztVHUJ3iu4X3XWl
H3xeonS6EGLsCTF0eumVWxCdun0JzqFYaudjz5Y7fUCnZZekNMdleab8ZukU
bSXRJ6DTgh4u0Gm5Jfdri5+laV+8DQ+oQKcgUKHas2ePx+NJJBKB6hC6U3S/
6K4r/eDzEqHTFYymYcYMnV51XTK1Mu9Pcg4jOn18b7nTB3RadolLc1LZLiug
08IfLtBpuZV7vNPyZboSCugUBCpUTz31VCqVqjQzllXoftFdV/rB5yVEp5HE
ymI4zZnS6WWITtMrC8EkdgD/RXS6C+i0CpSjNIdeUWt6uECn5VYeo/GXcaiI
kgnoFAQqVIjTksmkv5qE7ndj0elSOM2ZodNPYzpdDKcWQ4wj8fSuJ54vd/qA
TsuuQulUPEqpsMvJWvaWVJUbjZ/JsrWPCLIuZOYSSZqfea2oM7kOYqegtYh8
fmFCjQ0mSqeVTkVZtbHoNJpY8UYyTjF0ej2i06VQijOiU3RwWRPHGyBSZiip
bINHglavwueKKlYn/bJSQqVKcy5TsxkWMnNpJUunvHxW1jkgSqeqo1Ph8MHr
AgqzxlKyjz+Tv4TfF+vivjeugE7XsyidLkewvZE0soBOwynOkUTZ6RRUCWWj
00wbVDlAVewAvZa9pVLVlebVKoUxKHja6GFTourKzwIOrFC1g3RW4jLQKblX
9iIU0OGn7OpF6XS5mrRB6ZQ4Q6ep9Io3nOIcBTqtDuXRTm8zqLpK8yoW5OdN
JwGiMRvKT6fysxKXNR3QHGiNQpyWSCSWqknofjcQncaSK75oxnw6XY6kkL0R
oNMqEpTmoM0kyM+bTspQxlb3I3TN1IATjhWtypwjX1Euv1d+VmKWTrm90hOY
F1dOp+wLK6WuSI0FqldydDry6g3M8/7Wh5UByJJqA9JpmlieTqmBTqtEUJqD
NpMgP28+MUQny2XC7kkc+/FWeZBHdyvVlGffKx87zRwj+1riiyskTLCqxKCS
EDKoUFE6XeTr2CuvDNGFh2tqHj62uNm00eg07Y9Sr/hjAjr1AZ1Wn6A0B20m
QX7elMqEFkV8JgeBIuzj9kq4j2xQpELBXiU6Fb30qlZF+2TxFG8ENF2jKJ0u
yAvh6Q2vDCrs3LDa2HS6wtHpx3Q7jayiw4BOq0GomKsSV/pJg8qhimczyM8l
kygymtm2KgjE4oFg9r15tDstnE7Zk3PTKdoE7U3Xrmx0OvjKDRsQTi+XE/+A
jUanK4FYxjw6xb2ioM8+CAQCgdapKKIKe/Dnx4Ty1Mduyr63pHSaI4YLcFos
IU6LRCIGGbX/y3U1D/xObs+6lwhNRXvR/W4gOo2SXlHL0fRyJL3Ma3eKts/O
J6ln3MnFcAroFAQCgUDrStnijhuTTn38pgtQg18yUTrVSXR4R03NjsPS7RtF
HJpKd20sOvVGVnRLK3rWsSRDp6H4yoAljtxvjveZ4w5/EugUBAKBQBWVOHK4
WjqVAmh2eJWeXCo6rcgQWVUoWTptfWHLhkZTKlk01W00OnUH06NO7DHicCJD
p5hLTdi9prjDB3QKAoFAoMpK2DtJRJFyXZMUOsOL++GL45fZ90pnJc7+0qK9
2Q6WDvSf9QGAVitKp1q+Dm+v2fJCi3bTasPR6YiD8ahDQKccmgKdgkAgEGhd
SDQYKAd5vGk+8bbsq5JTZKrQs+4VzEqcSRLBxsJSIh6BQGZ6Y0mtP9Dp2oU4
LRwOa3h6fovgqW//rWaTCd3vxqLTYZZOR5xiOu0FOgWBQCAQqEySjBYFk0KV
RlI63fTaiHQ6LEenHJr2GIFOQSAQCAQqreRG2S/7JKnVIUqnM9WkjUWnLpZO
KaBydBpk6bSH0Kkd6BQEAoFAoJJKUnEPodMSCXFaKBSaqiah+91IdBpIDzky
gCqiU4qmQKcgEAgEApVDooa1MKZUaQR0up7F0Kk9A6h8OuXQtBvotGpU8Slv
YG4dEAgEApValE4nq0kbkk5ZQBXQKYum3caYfRnotCpUC/OSg0AgEGizC3Fa
MBicqCah+91YdDpozwBqhk5jKwRNY8hdBqDTahHQKQgEAoE2vfbs2WO1WhcX
F1XVIXSn6H7RXVf6weclBJxOQqfUCFBDPDqlUVOEpkCn1SOgUxAIBAJteh04
cODNN9+02+3B6hC6U3S/6K4r/eDzEqXTAUU6ZdD0giFm22R0yjY7Z5qbi1ar
WECnm0GQvUEgECiX9u3bt2fPnqeqQ+hO0f1W+pHnKxGdDgrplEPTTUinvlxT
y1WrgE43iSB7K2hs/yMwOA8IBAKtZzF0assAqohOKZp26oFOq0XZ6FR3cFvN
toM6+R2sdjcUtnftV8jn+mIBnVaLcswKKTpC+oSy7wWBQCBQ8UXptN+WAVQZ
OtXHOnUxmzf50BNAp5tfCnTasJspoKV0SuCQ2UxBkY+I2feu/Qr5XB/otIqz
t9zUO+LdDK5SEOUfm30vCAQCgUqiTOyUBVSGTq+6DtFppyHaqYt2aLGt3uSu
MtMpr7FcJn6RrXAQDGHMi4/wtvNPz1F8i2Iu1VIqydApJlOMfHwQFO7lbSQY
mwHE7HvXfoV8rr9O6FQ5P0P2LqGy06loikiZh6a8FwQCgUClET92Sv9SOr30
qusCsTRC03ZtpH0u0jYXsS4ldj2+t9zpY4tQWkJkm9BNsI9XqCht92UvvgVF
WlUVSllq9mXpVMKDgg3Z9679Cvlcf73QqU82P0P2LrGy0qnk3gUbsu8FgUAg
UImE6dSfoVPkUJzQ6ZXXBaLpDk2kXRNunQ21zoQsi/Gdjz1X7vSJShblgkYU
5FDanq3sybGvWsqkAulUuo3wIb+qXXHv2q+Qz/XXHZ2K8nMme0L2LoWy0an0
BwF/jvPse0EgEAhUKiE6dSA6tWYAldLpJVdsCURTrVOBFmS1v2nSZ/bEHnz0
x+VOX/bSPCOlmIZsdSY/1KRY9cnGtTZvqa2gNdOppCFoDhZdyxXyudp6p9M8
fnxB9l6D6EPZyrVj4H9/SL9QJA1NFfeCQCAQqFSidNpnzQAqQ6eXX+sPp5pU
3kbksaWGkSWjO7Lje8+UO31FoVOx8iq+uZerlkKcFdBpCVUKOoXsnUP4PtmH
Qu+Z+woBOgWBQKD1KI5OOUCldHrxJ6/2hZLn+ufP9rvP9LtO97v0jtD2b/+o
3Okrduw0207FY6urOg/otIQqcew0207I3lSC7xCgUxAIBFqP4tNpH49OP3HZ
Z5YD8ZOdVmJb3QWbzua/7+Gnyp2+fOlUaUfW0iRL8Y3Py6e56yYU9IoqoVZJ
p5C9i6gC+j1BrygQCASqiCid9loz4VNKp39zyae9/lhto762yVDbbDzeYtJa
fPfu+qdyp09UGmQpjSXN6pjDRJEhfrmco/jOnKXUJ2VTqlA6FY8xSta51ex7
136FfK6/jug0e36G7F0CobvLEv4Uj2EqJPXse0EgEAhUIjF0askAKqXTv774
Sq8veuzM7LGzcx82aD88r58zLd+z8wdlTRxvREZSImRa2ckWEPwBHKUdbcU7
RINEiseMFLXoq6ISqVA6XVsX+7VfIZ/rrw86FeXn7KvZzobsXYCE/C4dUT//
TvpQrQ8CgUBlEqXTHkKnvXw6/cSVS8vRD+qnPzg1e/Ts3LFzWo3Re8+DT1Y6
vaCSS45O+VOFshIEKLmZpJThU3Hv2q+Qz/XXAZ2CKiMhisvgJe+AgveCQCAQ
qPjK0CkLqDw6jSA6PXpKQ+hUpyl/7BRUCWWJnW4mAZ2CQCAQCLQ+xdEpB6hB
XuyUQdPz+g+bDHPmSrQ7BZVdQKcgEAgEAoEqKESndpZOKaAGmV5RV3l90Q/P
6z7CvaJMtW0WrbUSffZBZRfQKQgEAoFAoAqK0mm3JQOolE4/celnvIH4iTbz
iQ5b3QV7fbdTV5HxTkFlF9ApCAQCgUCgCoqj024hnV78yauXg4lTva5Tfe5T
A57TgwsGV7gCc0WByi6EbVXiSj9pEAgEAoFAMmLo1JwB1CA7k6kvnDw34j07
snRudPmcymecjz346I8rnV4QCAQCgUAg0GYWpdMuMwOoHJ1eesUWfyR1fsJ/
fjLQMBk4rw6aFuI7H3uu0ukFgUAgEAgEWpN++eab+bjSyaxecXTKASpDp1dd
54+mm6bDjcgzEWTTYmLX43srnV4QCAQCVbF481JkBqDNjEpb1EFp+XNglGm8
28xLykySwd0mf644sUSTm8FwvfJC5BmSUywWi8fjkUgELQOdVlBiOjUL6LRZ
E23RRJtmo02aqHkpueuJ5yudXhAIBAJVt6RTfvmKPyOv6EUY0ivHvGosc4pf
i4NNyWRnsqkUTLxLr7mZZ4UrVJRO68408T04Mv67o53P7qvVm+zhcBjotIJC
dGpj6bSLR6eXffo6f2ylRRtrnou1zMWaNTGzN/kQ0CkIBAKBKivZSWWLS6dy
L1EuwkOv/ch+6evjJD3yiPguhXSqQO4+mIhXIo5Oh1XT1CPjM0te//bHf/fl
B3/V1DEeiUSATisoSqcXzBlAZen0+gChUwyo2ljTHKHTJ4FOQSAQCFRR5UWn
wmptabxRsfpc8RUE5MdcAx+jXBkv90K8yKjCiZhOayUpQOehVQmDi+lUuiHr
5uqViE5HJ2bMVmd9o+orD/7q+8/+0eVyQ81+ZYXp1Ifp9IICnVI0bdICnYJA
IBBoHSg3nUprtdkVwblK8ValACS5EncCy5n8RqCZq2V5IZZK6RbJ3aANeFWS
bLyck06zcDWwKV8cnU7PGUxWx7RGHwiGHv7nP9yy653W7hmdXg90WlkxdGrK
ACpHp36WTqmBTkEgEAhUeeWmUxGzoVVmRUR3ChHFrNXj8tQrTla2FxKxohgd
GTrln8PCaS46lU84PgbQVCRKp72Do4Mqw5G6gSWvt/nC9G0P/+v3fvzHWCw2
PT0DdFpZiej0AtApCAQCgdaz8qjZZ8OTMl2nckca82y8ma1SPesLydEpLxEs
nWZ20Fp92fRKuu1LUs2dDOKL0qnRbPmnlz66Zdc7qinro88dveORd893TEci
Eb3BCHRaWVE67TRlAJVPpxyaNs/FTECnIBBoo6niU5LB3GfFV569omSadcoO
wZQ/ncrU7PMP4qUr6wvlS6fMnkce2coerUCn2QKjAKfyonQ6qpowWuZvfejX
t33rXxGafvvp92PxBNpusVqBTisrjk45QBXQqS7erI0jNG1EdLoEdAoCgTaY
ELZ9XAUCOlXus89Hynz7BonakMq/biGxU+l18qFTjnJlW83KJwKUnyid9g0M
eRZ9r/9by+3fevdr3/7NyaYJOtip0+kEOq2sxHRqEtbs8+kUYqcgEGijCeh0
M0oGyQTExzXTFO/Ke1wludGjxCdnq73P+kIF0KlcgwWg02KI0unQ8IhWqzNZ
59/4t+aDv2sLBCOLS0sLC4vz8x6g08qKT6edUjrFaBrHffaBTkEg0AYU0Omm
lLjqXURt0vahwmCk8Eh5tqN8KoqUyjT5zNITS+mFREfKUG9WrpXGa7Pwdq79
VSv+XFHhcDgej8diMbTAnzcK6LSCEtFpp4ROm1g6hV5RIBBowwnodLMqy3im
kmafyjuzcluOmUBzdkiSfSHeRble+LxVbrdSa1j+Tt4LKN0I0KmCEHnm40on
s3olpdOAoFcUrtlvIq507HRs/yPwASub+N/K2SuN8joSpimRCPJzmQR0CiqV
oFIdBCqZEHBac9EpcmPF6RS+B8onSeup7I37cx7JACzQKU9K+Rk/K3hQxZQC
neoObuN+Ve1uyMZ9eRyJD9l2UFcEyFy1gE4rICiVQKCSidJphyKdJpCbKk+n
CmPXgUqh/IarzvtI+cmhq1vK+bm4c4WD5OmUACeDkxQ+lQA155ENuxlwBTqt
PgGdgkAlE0enHeuZTsm0wzLNZ3gzHYvG3QCtWvlO25zfkUz7foAuvhTyc+5h
tUGFS4ZOMVHyYJIApjyeZj8Sr+I1PsJWSkCn5Za4+SgIBCqmctJpE6HTyrY7
rX0kM62b3NQfW7eSzpAwW1sxpDBiiQxa5nEk1/cU6JSnnPkZHlQRJaVTCY0q
4mmeRwKdgkAgUHHF0KkxA6h8Om3i0Wnl+uwzhbl8y0aoWymypMyp1KUp55G8
cVEAujLKmZ/hQRVTEjqVsiRhThm6zPdIoFMQCAQqrkR02iFPp4mmuUSl6JQ/
MDEtziXhOijNi6hi0amwew/7NpE67ZKmf70L8nOZlQedKtFlvkcCnYJAIFBx
laFTY046TVWCTkU4I1d3DKV5MVUkOpWdZRraaEF+LruATkEgEGjDSUCnRjGd
NusYNK0YnaLCWm4cZeF8HFCaF1PF7RXF2wNvE+TnCgjoFAQCgTacxHRqlNDp
XCXpVFKYy04eB6V5MSU7RaAscuZ/JLxNVJCfyy/oFQUCgUAbTjnoVJuhU1P5
6ZTfRE+wlVecQ2lefPGrm6UdnZRWs80HBXNFYeWTnwWNI6r+iRVDUjoVj1tK
1mVHlMrzSKBTEAgEKq5k6DQmQ6eNFaBT0SzKEqGim9e4sbpbMxZdStM3Zx2k
M+tEz1mPqAblkZ/JcdzTgixdFMmNxs/vei9CS1Gv/CxHZgR0CgKBQMUVpdN2
WTqNrjTPJagrEzsFgUCgtUlhJlNujqecY0YpHfmxcJJTVtmnRS2ZgE5BINBm
Uj50mqnZfwLoFAQCbSQp0OlmE9ApCATaTOLotF1Ep1ddh+i0SRNvJD6viZuW
kruATkEg0IYS0CkIBAJtOPHptJ1Hp5cSOj0/HT0/Qx0zIjp9fG+l0wsCgUAF
COgUBAKBNpxEdNrOp9NI+txkCFsdRjYuJHYCnYJAoA0loFMQCATacFKk0yu3
+MKpM2P+M6oA9njQ4IntfOzZSqf3/2/vzJ7jOO483//FPuzD2hJlSyJlCVCQ
D3rejfF492F8iaQoUZj1DC1LHi9tDUybDHlfaJHhXZvUxIy9lsnwIUsCTfEm
cRAgZUm2TFK8CYAAGjcvEGfjajS6AXKzjq7OzMrMqm50d9bx/cRPYnedmYWs
yk9nZWUBAEAREG2LSeg+0gAAUDZkdvroE89MzeeOXhg/emHi6IXJYxcme0cW
Nm75oe70AgAAAACAKCO108efnprNHfpk5INPRg79ZeTQJ/eTd+Y3fOt13ekF
AAAAAABRRmanj3zhS5Mziwfahg60DTeY0T08882Xt+pOLwAAAAAAiDIyO/38
Y09NTGfePdVrRCOJvpv9U9/Y9C+60wsAAAAAAKKM1E5XrZlIZf5wtOsPR4z4
/ZGujuTE1za8pju9AAAAQCTIv7cYry2uPr/Ys8dP6E5mfJHZ6eceXTM+tfD7
Qx2/+6DjtwfbSbR3j/3DN7+jO70AAADiTF7pGMLjd2byC8nlvhbF5V3r6GOw
btflsqXSvflyb103xDznRGQymcXFxXQ6TT7DTjWittPfES/9043fHri+v+Fa
e9foP3zj27rTCwAAIOawSmdbVEgEtUx2amWaPQZlFUhzi/ntW78IQnKE/WHZ
6eETLXScv3h1//t/3vbmwd6B2/Pz87BTjXi0nX7Q/jvDTm/sb7gOOwUAABAA
eKXjVC1MlGanAhklG6pg82b57Vc3jp1+dqXDiotXOycmp9e/uv+/vvBvLR9e
TafTsFONSO101ZqJqcwfjtz8/eFO6+Z+R/fYV3FnHwAAgGZcSidwPKoDAC9/
TN8ASrno6YLJZDOFm93mNrmv1MLG6vK56rZTRcrpJXy5IlnSU319LhNS/ZfB
2emla52Dw3ePNF/5by/82z9ve/fevRHc2deL+pn99071/vFE8p3jPe8c6+ns
ncRTUXFA+ytv8G4dUEa0FzOU5wogbDulbI35bixcmCebxTa/8ney86JpLexo
J/VVYLP2JE4lmTvmrqwoUl6giIbM8tgpl+ZI4NhpR3ffwPCdjq7emdm5zd//
/d+9+O9tn3Qme3thp3rxGO+0dbihdbDh9OD7LQNdA6lvvPg93ekFFecg3ksO
IgTKcxQR9DulZY2zOnppmfCJW2OdJTk94/aoFk5uaeXCipTzia2enRq7i5ia
pvJ2+tfzl85f6Xvn8LmJycnTH3X8/eZf/tMP381kMh0dnbBTvUjt9IvGu6IO
f3L/0Cf3Dn1874OP7vXcmn2+7vu60wsqDmpzECVQnqMI+9g+72kKO5TdoBY0
DjKLiuxU+lXd70C1sFebML1Otey0sv1Z9WHZaf/g0Pf+95/+7sV/v9I+/O0f
vf/f637V9GFHOp3u7euHnepF+ibTJ55JzS8d/2zyGIkLJCZ676U3/NO/6k5v
cbB3Y4AvUJuHBRRvP6A8RxG+NVQggzxqO5X1/iyPnTKS6Wmn4pTTqO/sc+NM
MTD58VjGSVI0rzCWnV66cq1/6P6XX/qPv3/5l0RN//H1P2YWs2T60PAw7FQv
Mjtd9WRNKr186trcqWuzJE5emem/n3nh2z/Und6iUZ3G0evnXQ5Qm4cIFG9P
UJ6jiPt2uM9BmvTYacltpzKq/1RU9LDs9NNzF0bHU//n161feflX/+Mf/9/R
lmvWYKd3796FnepFaqera6cXHjR3LpiRbupID4xnN33nR7rTWzSovosFtXmI
QPH2BOU5iogeJeJ6dopPC+kscXsn27W1VDv13+/U9+NOAj0VN3LCTmVYdnrh
s4s9PcmB4fv/99en9+4/MzObHp+YGBsbv39/FHaqF5mdPmbaaUt3tqV70Yiu
xYGJ3Iuv/lh3eosmeqO0VRpVbZ7c+1ziub3JKla6FSMatTmKtycoz1HEJWec
nwoekxc3T5I59JP1Uk1UPVnv+mptik2M1F1FX8UpZ+AyLG1NXamdFtHFNWTQ
74qan59fXFzMZDLkA/3eKNipRqR2uubZ6cyD0z05JwYnl158bXtVEycfZU4E
15HGXo6+bDCjyHHjzqkHqYsTktq8cYt9UFCbl3xkpeUZxbtyoDxHDqqky4dx
ko1dmmLPJWYOc5K5xvp3pqq/crvmtsUtLBzZVJ5y+YGQntGwUxnEPP2E7mTG
F4WdzmQetCaXTidzRmix05RwlDnhieJ+6Zqg+hYOfOe+JogHqYsNgtrcqMm3
NFpNTajNV0JRoyZyq6F4lwTKM6g26FQDwIpR39lv7cmSMO/vZwcnddzZV3fv
KeC+OyKovvmbJEV1FooNijuhqM1XSlGjJhZA8S4dlGdQbWCnAKwY9VNRLZ2Z
lpuLzZ0ZEgPjuU3BsFN565LgkuCsIei/U9SDlrEBtXkFKerZCn49FO9SQHkG
1SYmpxYAlUQxotR0ernpxrwZc43X5/rHspte2Vbt9Pm2U2euvJuP63pR1CB1
sQG1eQUp1U6duSjexYLyDKqKuxsqAKB41KPxn7iUOnFp2or++5mNW6o+3mlR
dmrD9KgrrOFeF41LIlCbV5CV2KkNindxoDwDAEDokNrp409PzeWO/G2MxFES
58Z676Y3fOv1aqfPp52y9zXplfiOefTa6JgnArV5BSnNTlG8VwDKMwAAhA6Z
nT7yhS9NzmQPfnj74J/vkDj00b2e27PP132/2ulTjzKXEk+nH10WjIMsey+H
epC62IDavJIHV1meUbwrAMozAACEDpmdfv6xpyanFxuaB95vHmhoGTzQOtQ9
NP2Nl75X1cTxHXgKo7u5alVu4De6ZYmeUlhsXV1dEYPUxQnU5pWi2FETqb8J
infJoDwDAEDokNnp51atmUhl/ni8590TyXdP9r53qrerf+rrm76rO72VJDat
SWpQm0eTuBZvlGcAAAgdUjt9dPXE1MIfDt9850jXO8e6/ni8+2bf5Nc2vKY7
vZUkrtU3h6g2N6txDmM48xATu9o8rsUb5RkAAEKH1E4fse30D0eMeOdoV2fv
xNc2vKo7vZUkrtU3h+q95BEidrV5XIs3yjMAAIQOtZ2+Y7Wdkoi8nWKQujyo
zSNIjIs3yjMAAIQO9Z39Px7refd4j9n7tMe8sx9dOwV5UJuDKIHyDAAAoUNu
p8ZTUe+d6nuvse/9pv73G/u7+lNffyHST0UBE9TmIEqgPAMAQOiQjii1yhhR
6kDr0IG24T+RODPcPTz9zSqPKAV0QKq5mITuIw2qgfZihvIMAADFohiNf2o2
e+jje4c/Hjn8yb3DfxlJ3pnTMBo/AAAAAACIE1I7/aLxJtNj58aPn584fmHi
2GeTvfcWNLzJFAAAAAAAxAmZnT76xDOp+aVTV2ZOXp05dXWWRP/o4gtbfqg7
vQAAAAAAIMrI7HTVkzXT6eWm9nRT+0JzhxED47lNr/xId3oBAAAAAECUkdrp
6trphQctXYskTpPoXhyczL346o91pxcAAAAAAEQZmZ0+Ruw086C1J9vak2tN
GjE0ufTia9t1pxcAAAAAAEQZqZ2uedaw096ltnwMTS2/BDsFAAAAAACVRGGn
5ENb33Jb35IVhp1+F3YKAAAgThysi+dbgKPNL/bs8RO6kxlfYKcAAADCx+Vd
6xIF1u26XMF9mYJasFPua5BZWVKreYyrDDHPOS9gpxrxsNPeZeO2Puw0Zuzd
u3fbtm1bIwfJFMma7qMLqk1Uy7MWAnISWdbkSJctUf4lzFihGNcydxACO3Xn
ayVJZXJttSAHMdOlYdnp4RMtXBw5efpky5nWsx/BTvWieCpqJvOgjet3CjuN
Abt2737rrbdGRkaWIgfJFMkayaDuYwyqR4TLsxYCcRKZ1sTJZXHyZCy9AjsN
LMXmqxhERz3EOHb62ZUOJ67e6Oro6k32DXz0yV9hp3rxsNPkkh14Kio21NfX
j46OZrPZmchBMkWyRjKo+xiD6hHh8qyFIJxEYk2im1PtnqL5ZfL3p5mZBSTW
Sd/VXreuYKfCbqj0RtntuXZnpovaSGE/fELoVbn8srfczTUF+RL3mGUW5I+R
/JgEtsG4NDg7vXSt83pHT1eyv29gaPjW7U//dg52qhf1eKfGiFLJXFvPkjGi
FOw0HmzdunVpaUl3HVgpSNZIBnUfY1A9ol2etaD7JOLu6juY9uRIHNeKKOg4
qmwGZA2Yb5hlmlLdX7guB/nNcGnI+6A1m1dudkNsAtx33OkvbL64Vl9XgszP
8g3KthN+HDu9dO3m1fbu9pvJpCmmd+7eHRkZuXjpEuxUL6p3RS08aLlpDMXf
2p093YPxTuMCqXdyudx0RCFZg53GimiXZy3oPolkdur2OV72/NspP18klmJV
Y/RP2V1V5I3OV5ci0u7tVm2/dirJt3yD1AJRUtNU3k6PN7V1dPX29A4MDt0i
Ujo+Pj5h0t7RCTvVi8xOH33CepPpQnNnxhLUQdhpPLBqc92pqBS6K1ZQbaJd
nrWg+yRS2qms7bQ4O3W5odIk3euWbKeSFfmV2a4Kkp0L9iK9OS/dYH616PQ3
zWPZaXPrh30DQ7fv3BkdHZ2amnJuEPT29cNO9WLZ6RmBnT6TInZ6ba7pRtoQ
1O5Fo+0UbzItjVANlxft2lx3xQqqTbTLsxZ0n0Ql3dmvtJ1Khl5i0qRugFV1
AhBNEnZXLdVOpRu014qenNp22vbhx7du37l///7ExASRUjJlfn6e/H9oeBh2
qhfHTq0o2Onjz6Tml05dmTEEtX2h5ebioEY75fpr2ycKN5WbL5wrOi3ZruSV
OgnD06Hcqs2nIoruirUisP3XVkaofkn5IdrlWQvaTyJWQ/NwHTerZ6fqHcuf
l1qhnQoPxkrsVLjB6GLZ6cd/+dRSUzKFfE3nuXv3LuxUL5ydnsnb6SNffDo1
t3TyUqrx6mzTjbRGO1V1Mnc/u+k+wQtz7TqcOe2Yc7mSA2aEp0s5qXey2exE
RCFZ01exyp/NTVF1WGklsIwjyYTnl5Qfol2etaD1JDIRjR7FX75X9FSUqy5Q
NHuKNJiuVKS7Udmp0o+NjxJT9rBTSR2n2GB0sez0wmcX29s7ksnewaGhu/fu
jY6NjY2Pk//u3x+FnepFaae5ExenjObT6/PNnZnByZwGOxWcTPRdBvVs8dwE
d6pyFwDYqaw2P/ByIrH2pxerXheWFd0Vq6xp0hFXf2VEPOZ2mcpueMqqH0Tl
2SjKDi8fcCY6xfviT9cWZgjWZWbRK/og/OeR7pPIwDqR2AZL9gRg2jXs806o
ggfrBCeO6Il5SQdSd39R9qv0tBQZL5cjsVYqOti686V8y5Vd4yl77Ea1MRXv
igo4AbdTr9NC3dopmstcdIpqLJUMPUcNrMdfwmTD5bk3yD6oKd5atbBq83Ge
Czs3r12bWLvzgmtOqNBdsZIyUbfLXezMtos6/4LpdlHYqQRReW7Y7JRk8jGx
uYGdSM12Y8wkZ4K1Dr81b6JwHuk+iWw8X7JJLVB30PXYj3P9lRV15gJNr85s
l9tRYSRTapwoFtcMcyOFvbmHnHIlkxvZVDzwqjCp3FaZ+4ySDUbYTv2E7mTG
F7939ju13Nn3tMfi7ZQ90+zz1LMmVg09Z4vBOvPWSGHcDR/D5bkGnZNvrYpY
tfkYR8PmtTt3GrXweX5OuNBdsRp2elB029Cu1YTFla0xBGNupwqFSN5BQDGy
t+cvqRAjKs8NVEl2Ptsfzu801FNegszFGnauLZwKDUWcF5E4j3SfRCHCdQmv
ZPcxAKKEzE6D8VSU5282dRcf4YWAf95T9JNVmA7Z0HPifnrq4fJUXaJ09/oT
1eakxiYVdjG1sCYeF0EvoLtitcso80fOd/riy4zXTxhBnxXxbyOvn1fqX1Ih
x8NOCx/NT97maK8g3IQX4TiPAn8ShQbRXYgy3uQAIMpI7TQQI0r5s1Oa4u2U
3Y5wZx5Dz4muN+pHPoVDg4g1pPqQeiedTvfR7N+Y2Ljf/Kf2jbN9AYerVbm5
JGtBsFO6CDhPJAh+s6h+wgjsVPZgg/rnlfqXVNgRlGejJOcxCjYzsTBBjHMW
uD/w2xbsISTnUbBPovDgqsHQdAqAT2R2usocjb+5faHFGo2/J6vjXVFF3tn3
1XYqN15LUQWzvAb3KM1OeYJlp0mKHTU1O9rIv/s2JKwPQcepVd2zdFesThl1
CqfzGJ/ooQj/P2FU4+eof155DZ4TctzluVCS23bUJDbsoyfuI1PUhZw6C8hH
Y22f50VbuM6jAJ9EoYK/2EfmxAKgskjt1HmTabehpq3J3NDUcvXfFVWhp6Jk
a0hmVsZOVX3xg2WnG5irawgq1qRZtwqn665YC7+grMJWV+cM5SJ8ZNf3TxiV
naoLcIztlFLGwkTyb0FZ3dBuadkta5v7NnB/s/y29oXuPArqSQQAiD5SO11d
S+zU8tK25FJb7xKx05eq/yZTgZ56jChFIRtRiu5h593YmvKsvwU+qR4uT5ns
YNhpj4B960mV2iqaEx50V6x0+z43KoNH2ykD7NQ3ovJMl2Tnc2Fiq9mAKinp
7FlgLGqqZis1n2X9PuUWQojukwgAEH1kdvrY6tqZzAPLS0mc6Vse1mKnrtvt
rF4KO5E68GrretyDW0DuA4qh51Jin/QzXF5hHXow5ADY6fz8fJeAt0mtur1F
NCc8kKwFxk65PzVXrIr8CaOyU7WAqn9JhR5ReWZKcsv2GvMbM5F8sb/xpZ7/
bqxe3HkR+vNI90kEAIg+HnbaZ3ipFYadfrf6dmog6bkjGratgGCcOUGVqxzm
Tb493nCFa0uHy3Pvmm9O80hLRZHbaRTQXbHyzfUUrp9aip8wnmNu+x/Z2/OX
VMhZYXkmKrn+7TIWwCig+yQCAEQfqZ2ueZZ8sNXUnE4W02WnoJpYtXlnRNFa
sSqGhmDH83Ymy8coZcbcLixmLiQagls+sje3H9EvqTCzsvL86+cTz/+6nAUw
CsBOAQCVxsNOqemw05hA6p25ubn2iEKyhoo1VkS7PGsBJxEAoNLATgFHtGtz
VKxxI9rlWQs4iQAAlQZ2Cjis2vx6REHFGjeiXZ61gJMIAFBpYKeAg9Q7s7Oz
1yIKyRoq1lgR7fKsBZxEAIBKAzsFHPX19cPDw+Pj41ciB8kUyRrJoO5jDKpH
hMuzFnASAQCqAOwUcOzevXvPnj23b9+ejRwkUyRrJIO6jzGoHhEuz1rASQQA
qAKwU+DmzTffrK+v3xo5SKZI1nQfXVBtolqetYCTCABQBWCnAAAAAAAgOMBO
AQAAAABAcICdAgAAAACA4AA7BQAAAAAAwQF2CgAAAAAAggPsFAAAAAAABAfY
KQAAABAQLu9alzBYt+tyQDdYCgfrzDQk6g7qSwPLL/bs8RO6kxlf1HZ6tn/5
LOwUAABAUMjblm7hqhxmDsuZt7JvsBRMQXXslPor6vlDEvOc8wJ2qhHYKQAA
gFBhqY3vdjhjcR1uVvJ+DZGLnJ2aibD/ZvRnu1212q2qlp0ePtHCxZGTp0+2
nGk9+xHsVC+wU+Bm796927Zt0/1SmvJDMkWypvvoAgBWSJG2VW7Z80vJ+428
nQrmVDt5jp1+dqXDias3ujq6epN9Ax998lfYqV5gp4Bj1+7db7311sjIyFLk
IJkiWduFV4QDEG5YnaH6NBbuF7MNcxSOH1FzWGdyrWLuy55q7NX+KNrSSvbL
poDakXtJ0R6FybcOEn28qNnr1q3jN8IcWfXR5DMkOjL0/Xtzb8Ics/f8qwRn
p5eudV7v6OlK9vcNDA3fuv3p387BTvXix06tgJ3GhPr6+tHR0Ww2OxM5SKZI
1kgGdR9jUD0OHjoRk9B9pKuJq7GNffKHn+1uimSWYGa75lDaZC5IHItMMT4a
M5gGQb7DQTH7ZeCeITK/Msoo26Nk+26bZ7ZWSIR9HJks2HO9c8oeGfFvCIGD
yttUK4pjp5eu3bza3t1+M5k0xfTO3bsjIyMXL12CneoFdgo4tm7durS0pFsk
KwXJGsmg7mMMqgfRtocxAHa6ziVpCkvkJlASKliTayRUeRSXriL2y8KvKL/1
LfdO2VLGZ2qf/AbW1dWxFir2Z0FORe279Mri3BZktspYdnq8qa2jq7end2Bw
6BaR0vHx8QmT9o5O2KleYKeAg8hbLpebjigka7DTWAE7jSK+7FRuibwnUYt7
2qm6eyS7RBH7VW1GsKZ4UelSzo44NXXmOY20ZCHqWS6pnHrlVJQYURtpoWm2
6lh22tz6Yd/A0O07d0ZHR6emppx2jN6+ftipXmCngMOyU92pqBRa7ZQdQ4Xv
vJVnhX2wKteFS0vnsBUDO40i5bBTHrpbpurOvqxpkt9Qkftl8LRT8R7Vdiq7
5BSOnSmn1N7dcuo3p6LECOxUo5zadtr24ce3bt+5f//+xMQEkVIyZX5+nvx/
aHgYdqqXUNtpIAYZ9oOoE1FgK3rYaSVhqj6nCPtsJfG/hzIULfdgOLDTAAM7
XUnbKYf0kSOBgyn3VOR+FTvi+x6I9+Hddipsrs0fPFtOnbvtZLq8obc8baca
sez04798aqkpmUK+pvPcvXsXdqqXkNgp95OTKuC6hgopFsFv8ACdpzSWnU5F
FN12Kqgb9Az250lYziwvYKdRZIV2qhrBSHEzW3BScFNWsF/ljqgVVXuUbp/v
dyrMxa46Z6qpp7sYOS0up6L9BKzWs+z0wmcX29s7ksnewaGhu/fujY6NjY2P
k//u3x+Fneol+HZqtS5xva+VJ0VZdlnubYbKTrPZ7EREIVkLmp0yj78K2tW5
/gCSd63k78yJWunz/c2ETfY+B8MRN/jTC/IPeyQkI/xUGYmdJvc+56R8S6NC
+xq3UMfhub3JCtnlSomjnfLNFHI7ZeTOuXnNLVBomSzCTkUDMJW0X/eOJA/I
q/fIHgfHtNnj4X6XgbU/xaP7fvbLHzZ2N/xYU840vf1O8a6owOJhp33LTgxP
Lb/0WtXtVPRKEKarSiXstFLbDLOdHng5kVj704vO94s/XWvV1y8fqKpdrpQg
2il3jXYP3MJc3wVPFjOlSfRUR2Hz/oemkVTEnABIX/eiHuGniojs1FRT2zQt
TRULqmmmjpFaSwZUUONkp9TvMqp4Ub+BCj+a3GOMuk8NVrNEvcMLjZaujfCp
oX4QFrlfBrJM4RdhcXtkRhgVHh4qBUw6FW3R6v1Kjgx/zPLrc4dCo536CS1p
AymFna6unck8ONO7ZIcmO/Wu1PInlXMWuJZWXAsErU+CViP5jkXblZyoHnYq
ax/TgGWn4xQ7iYhu3rw5sXbnBXvKBTJpcwP9ISwE0k5Zz5OLp11pqaZ7PHPs
f2gaTzt1/cBSOLbOLmcCOzWkk5JM00GFekrm0DKqElndxMlOK4rd5bKAxl9W
AMQYw06nBHa6anXt9MKD1u5sW0+2LZk7k1wii71YbTsVtZxysDcc+QuJqnlH
LgGebafMbqilZdP5Hahau7S3qlp2OsbTYNjpeevzedNJ+Y+hIGx2mnK3N6in
e9mpooB5PeYgb9QVbFndD7CKuO3UZaNyPfVYMUDATsuCZNAj2CkA1UZqp0/W
TC8st3RkTt9cbO1aJI46NLlUdTv10e4v6m7kr3lH3vrkdTWSzeemu4xX5gzy
lOjAh53KPuvncRH0AoG0U2WrY4puWWcLhnC6l52Kf8G57wJ42KlAckNip/Rt
fQv2Br4Y91rBAnZaHlx1DppOAdCCzE4ffaImlV5uujbX3J5u6VggjmrY6as/
rm7qxFcKpj4WPUjos3lH2vrkYaeyxiflPVTlnX1pSnRA5C2dTvfx7N+YqH3j
rPN5437B9EDAqSk3l2QtcHYqeoJD+qSEoGAq5VbVdlrkEDGRtVO1eVKPRcFO
4wDfuysQl2UA4oZtp30uO338mdT80smLU6euzDRdnyeCOjiR21RtOxXd2Vf3
jiuqAk1JWp9WYqc8vuxUmhIdWHaa5Nm3IVGzo039OSg4auqeFUA75aWTLsPs
I72FObLp/BflbybRubOCfqeCHgmRsFNmKdzZBwCAKlCw0z7GTh/54tNTc7lj
fxs/8dmkIag35gfHc5u+U2U7FbUWlddOhfspU9upaqZ0Wa0PMZr4sNO2HTX5
z+RjYsO+SqpmaQjVNKnfTvm/L/+oe4otG2xpLxRM2fSUuKSJ55Y0GA6/ZUaK
Zf1aImGnD/11AdAE7BQAECWkdvqFL03NZo/85f7xcxMnLqYar80NEDt95UfV
Tp9b1oqwU2XzjqL1ycNOZRWtsgJW2KkiJTqw7LSHZ996Yqet9pdW4qTr99Ef
woJWOxWMVSPvSmrN4Brk2aLtni7u+iLdXxGD4bi3zGdIPAQFl4vql+wyPhUV
5M6nsFMAQJTwsNOPR8zm06nGq7MDY1kNduoaFdj6Ln0WXuCukuYdReuTu9WI
w9VrVDSYJKudHnbqu+G28hB5m5+f76LYXkPJTc32FmNaiz3R/hoaSNa0tp1W
He1jQOjGbaf8wFDmd5GcGjPcj08F89Y+7BQAECUYO+0LXtupCTdiKWeDhfae
opp3pK1SzDxZte4e8VicVtdEY4P8kKiqlFQft51GCdhp3BCNxk/foefaQ12z
CjYa4JZT2CkAIFrwdtrH9Ds9fs5oONXY7xRUH8tOOyMK7DRuSN5kKnsSn+ta
yrzHNLBq+hB2CgCIFjI7tZ7ZP6H5mX2gASJvc3Nz7RGFZC1Gdiq8mxAzJHYa
NWCnAIAoIbVTZrzTjKbxToEGYKcgSsBOAQAgdMjsNBjvigIasOz0ekSBncYN
2CkAAIQOqZ2urp1eeNDanSVe2pbMnUkukcVgp3GAyNvs7Oy1iEKyBjuNFbBT
AAAIHTI7fWx17UzmwZneJTv6lsliL8FOY0B9ff3w8PD4+PiVyEEyRbJGMqj7
GIPqQbQtJqH7SAMAQNmQ2umaZ8mHs33LTsBOY8Lu3bv37Nlz+/bt2chBMkWy
RjKo+xgDAAAAQIqHnfYvOzGcWiYL604vqAZvvvlmfX391shBMkWypvvoAgAA
AEAF2k4BAAAAAEBwUNupOcXueoqnogAAAAAAQKXxfirKeGDfCIx3CgAAAAAA
Ko1iRClip23d2dbuRSO6Focm8CZTAAAAAABQWdTjnZ7uzLR0kFgw3mQ6ntv0
yjbd6QUAAAAAAFFG9a6o9HLT9Tk7rs0NjC2+sOWHutMLAAAAAACijMxOH33i
mdT80smLU070j2Q2/NO/6k4vAAAA4Iu9e/du27ZN91B2RUBSS9Ich5xuXUFm
QRyQ2unjT6fmcsf+NmbG+PFz43130+v/5+u60wsAAAB4s2v37rfeemtkZGQp
PJDUkjTvKvKNIWHM6VKpmQUxQWanj3zhS1Oz2UN/vnP4o7tGfHwveXvu+brv
604vAAAA4E19ff3o6Gg2m50JDyS1JM3Fvm05jDmdKTWzICbI7PTzjz01ObP4
p9ahP7UNHTwzfPDsrZ7hmW9u/l+60wsqjvbXheO95ACAlbN169alpSXdClY0
JM0k5XHI6UxJmQUxQWqnq56anF58v7Gvoam/oXnwQMtQ99D0N178nu70gopD
tO1hDICdAhBtiPbkcrnpsEHSXIKdhjGn0yVlFsQEmZ1+btWaiVTmvRPJ9072
vn+q7/2m/q6B6a9v+hfd6QUVB3YKAIgAIXU22CkAKU87Pd7jCGpXf+rrL8BO
ow/sFAAQASxn052KoinZTiuTnMoCOwUyvOw0+d6J3vdO9r1/qh92GhNgpwCA
CBBSZ4OdApBS9TtdMzmdMe7pN/Y3NA00NA90D0b3zv7lXesS63Zd1p2MYLBy
O03u3bI3WRaFrCAhtVOjqBrUHaSnHqxLFBCW5Px6/Jrs6vaqhYUZBGsCEFws
Z5sKGyXbqe6ElwLsFMggdjqkfmbfemy/bbhneCayT0UZtTPs1EZsp41bKE15
jpHP5N7neI9hF2CW2NJYWev0S/js1HJGlyKaaumUXmshYWHOOyi/BcdF6Rns
Vp2FIKggPBDtyWazE2GDpLkEOw1jTidKyiyICTI7tcY7Pfxnc7DTj+6RMMY7
fXlrVRNHVafKph/XClwLkj05P4VtfmKanVABi+zUNFNHOC1PpSTTdE+5dJqz
7bUtTQ2EoIbMTs1CK5NOerrEYa05dbvcmzFWqKvjf5+598f7KgABp2rONvty
4uHLB8q1tYjZ6YGXEwn5wYGdAhkyO7XeFXX83Hg+JvS8KypvklatKK+i+VrZ
cs5CHc21jpqzpXPjjdBO6cZQXjHVdmrILLW26bZB0NNQ2alZuP39bOKKNruR
uoOuU8iSW9cZILHTuP90A2HCcrZxCVM71z5MJKhYm74gW9aDmc2Jh5sbSlzZ
Rcl26rXhhs1MO0z5Uuy5V/muYKdAhtROn3gmNb906vK0HVem++9nNv5z1d/p
wFXL8lraVXeyTT1c7cttB3ZK4d3vlDNMpZ26bDQoehosOyUlUCF+fsVQ9evN
nGvMYzZmNpweFJwB/KbgpiB0eNvp2p1T5RCw4NvphZ1rOR+9sHPzzlJtvChg
p6A0LDtt6zOCttNVT9ZMLyw3t6edGBjLvvDtbdVOn8hORdWvQFuZ+hR26htP
O+X9UmWn9G19au3n9D81FSw7LXiiALsk088q8aWV6p/iZaf0ieHsVGyn6PAC
wozlbGMSJk07nZTNLgbLTsuxJYOS7VS6RUMQ1+48X64EFodlp7K5sFMgg7bT
NtpOV9dOLzxo7Vp0Ymgit+k7P652+vzaqaBpB3ZaGh526vZNa8pzzoNPrl4A
gqVhpwKMYiiQQLZ3S0rVtVT58FLeTgtnkdNl1X1eCdtOoaggTJRgp27PNKbk
F5ukOwNQizlr+V597bzcFcttp+d3rlW66XmzXdW53Z+fTKySrFWYyW2C7iaQ
n0VtqbA07BSUhsxOH1tdO5N50JbMOTE0ufTiq7DT6KO0U2E7qTEx75tWp1TH
PmGnNJKRmjiEz9SzxVN1n1369JJjp/YW6+qc1lpvO8VTUSB0EO1Jp9N9Em69
Ufuw9o1b3NT9Gx8mNo5Q3+cSibn9xqeRjQlq1tnJ2sTDjfutL8Ys67N6dWd3
/GIMJM0l2Kk0p2ffqE3UvnFWdhjI/I3O3P0bE4l8pozPCWdN81t+lrHJwjbt
DRhLONOoDdHbLEtmQUyQ2umaZ4mdnuldcmJ4avnF17ZXO31+7dRdX7Nr4qko
38jt1OPhfHopRlZhp/5QtZ26n7NXPh6otlOnJwDd/dTLThUttgAEEcvZkhKG
dtQwT0XV7BgyJrdN1CQWd7TZC+3bYE9v27GYSMzuo9Y3ptRMmAve25B4uMGa
p1jdXthZjNkaRcl2Kt5c246aRM2ONvFMnn0bEgk7J9RHbjPcHOFejO/WMqKl
V5RZEBM4O21j7PTh2f5lJ4ZTy2ThaqeP00hFrczeeuQXZKpWrmpmlj5YF3dN
ldkp9/C9HKZfKp6K8ol3v1PxFNebJKTtqrSdcj/I0HYKIoi3ndpGKp1OtHMx
b2QPExvusSY3m/dVyk4Vqye4WJQoY/Xt1FikQMFOmdUcyxTqpjGRx1oddgpK
w8NO+5aN0GWn1I1Q59EN8c1P1/KKMcfpB0yYtlXFluOE0E7pm/cGjVvo8U8V
jaPFDT9VRYJlp+pn9rlmS8YTuXnq328yuXS3i/Iuap0gkFMQIixn65EwaGrk
oHtGq9nO2Wp9WH/Pmrhv/UPns82+mURiZp/x6d76xMP1+4pcXUrJdirZ3r71
hii2KuYWZhvf7JyQj8xazixqGcFc4Q7Ec0rMLIgJUjs1+53at/VNRx2eWn6p
+nf2QdUR2CnvpoyRsg/hu8fbp+cH5bb+w6DZqSdsl1XFe0wlBums755NbVr5
JlP8cAPhokQ7NW1zcUersQDjnLaLUlNMC+Xs1Ofqcsptp2TnNVJBZN2RXlJq
p8LNyfcBOwWlIbPTVdZTUT3G81BOv1PYaRyQvCuKhx9hXzRDsEAw1PRh6OwU
AFAkRHvm5+e7JAxsJ3a6fUA47+31D2vWz9TUjLcUpt0hCppYf8f+1jJeQ4z0
7cKs/Ge/q6+X7Lqri6S5BDtV5JTsbrtx675mews9ab3x1Zxjp91aKv/t7fXs
Cm+vp2c5n50tCSey65UnsyAmSO30SWNEqdM3F1u7F4mjnklqeioKVB3v0fgj
AewUgGjjbadsR9CZgkOZ8ulyV3qVDGVuvJ1KVjcFVbD6yoXNy05NTH0skFdP
20mtKayCyuyUWYuyXnoPzETYKSgemZ0++kTNdHq5uSPd0plp7SKCmh2ehJ3G
AtgpACACWM7WGTZKtlPdCS8F2CmQIbXTx803mV6dbbox39KxYIzGr2W8U1B1
YKcAgAhAtGdubq49bJA0l2CnYcxpe0mZBTFBZqePfPHp1Fzu+IXJU5enm64T
Qc0MTeRgp3EAdgoAiAAhdTbYKQApuZ1+/gtfmprNHf10zBDUKzPN7elBLW8y
BVWHaFtMQveRBgBUEMvZroeNku1Ud8JLAXYKZEjt9LGnJmeyhz8ZOXZu4uSl
VNP1+cFx2CkAAIBwEFJng50CkFLY6Spip4uH/nz36KdjJz6barw2N2DY6Y90
pxcAAADwhmjP7OzstbBB0lyCnYYxp9dKyiyICWo7/YDY6V9HjZv7V2cHxnKb
XoGdAgAACAH19fXDw8Pj4+NXwgNJLUkzSXnkc3ql1MyCmKC8s2+3nR7/bLLR
sNMs7BQAAEAo2L179549e27fvj0bHkhqSZpJyiOf09lSMwtigsJOp2ayR4x+
p+MnLubv7MNOAQAAhIQ333yzvr5+a3ggqSVpjkNOt64gsyAOSEeUMp/ZP2Y+
s3/SHFRqEP1OAQAAAABAhVGMdzpljndK1LTx2pwxohSe2QcAAAAAABXG411R
V2aarhtqeroTo/EDAAAAAICKI7PTVU/UTKeXm2+kWzoWTt9cxJtMAQAAAABA
FZDa6ZO10wsPLC9t68629eSGiZ2+tl13egEAAAAAQJSR2unq2unMg9aebGsy
10aid2l4ahl2CgAAAAAAKorMTh9bXTuTeUCk1IozfcvETl+CnQIAAAAAgEoi
tdM1z5IPREqdGE4tk4V1pxcAAAAAAEQZDzvtX3YCdgoAAAAAACoN7BQAAAAA
AAQH2CkAAAAAAAgOsFMAAAAAABAcYKcAAAAAACA4wE4BAAAAAEBwgJ0CAAAA
AIDgADsFAAAAAADBAXYKAAAAAACCA+wUAAAAAAAEB9gpAAAAAAAIDrBTAAAA
AAAQHGCnAAAAAAAgOMBOAQAAAABAcICdAgAAAACA4ODfTvsmH/zynaNkeQQC
gUAgEAgEokLxH+8c7Z14ILTTadZOL999QAR1OLUci5haHiouloYmlwb9xQAf
OSMmmOhnP/ezn5kYLzaysujzjDEz/C/pEYtc9FJhTinsjkkqfUyso8cf5OXB
ov+ChRhWRFXKnhXuhA1yMWnEQNVj0H+406wO0UbMndoni6zkexU/cRmTRKYQ
o9JIuuO+Ohb8RbpnxFckSbhWt5M3lrEya50vA/kzZdAI40plBLlk0QW+ipfW
QIXgLOMv19S117pO2gVJXiQ8SoIZwiLEhqL4iWNMEX5KvjjcF2oqlFd4PzWF
r8j5ieKrwoiE/JgUd5wFG2dlw7kO87XtyipcWRA1vXSXsdNp004Jb//u3fO3
l2lB9RlnAxAlJJsJ+2gsiaN3qTUf+c+51mTuNBPZQvRkW6ho7nbHohVNJLoy
dDRacTP/wfqcj1M3F051+oqTTKRPdojjhCrmT7Sb4bGYEcfb573jxhwXx/Jh
T2mfM3dn7NFOIUm5laObCyT7TV2LRhiHzjq21pFfOt1rRP5vtGxHH3OPQBFn
1FFqoSqurLJJIom3cnE6Hy1WJI1o1hEtfqK3yLBXXKKjmURProlEN4lsYxeJ
xVNG4c84RdpHCeTL2LEbs3xct+Po9Rk7rjkxzcURK65akXLi8BVFTNFx6PKk
OC5NkPjAK4zFLk84ax2+QmLqyNWpo1dTx65NH78+c/zG7Mn2uVOd84030003
F8jFpLk709KzSK5I5GJFLlnk2mVd0FZSqku7ugYnuHPfumg4l/H8Fdu4LDca
15wF4yJplKXZ40aBmbHCKiF2AfAoA/mgyowojNLlLnXKyJfV68IoFG9ByVcF
f5VmghwK5UXeT2XhOxZOdKqCreMysQn5MekQXBjVwR5Do549ddPRD6u2zTaT
M6InR4JUuC3kHDGv0vlqd7lVGH2lh3Nunru1TKSUqOm3vvWtJ56qvZWCnSrs
NMfYqRWedipQ04KjmnZqRV5Nb6qiVDtVCarcUStup+5LH2OnjpqK7LTZtFNy
snBqmlc782tZ7LTUqry4EstWna15QT3NCSqlgkEU1GLttJAp3k6dcATVclSZ
nYrLIf87SFIj04J6XWynBUdl7dRLUItw1OLs1BTUI4agpkjCjl03BPUEEdSO
+cbOtCWozV2Zlu5Fcjk6rddOg+So7tPfvlZQgmo3HZiCesq4cs5bgurYqSmo
2u0076hiOzWi/HZqX6irI6gedso6qnZpDICdluSoLkHN5AXVuOQaimLpSsFO
bUetkKA6J+ZwaplI6Ve+8pXXX3/9sTXP7vvdu51jD8IoqOW6eMrstC3fcEq3
o9LXNEXbqbwRVWCnfAvqTa4F1fp1U4KjlmCnpqDa4aOc+xHUdvHlrtCCav42
ZwXVCFtQuwSCeto6TZKOo1pnRxF2WrkW1GLtVC2obHtjIO209BZU1k4NQV1S
2qn4ChxhO+UE9bAtqIXm02NO86ktqAtNXQtG86kpqIXm0968oFbfUXWrqdBO
uRZUuvlUJqhmITHLw9UiHNXDTq/a7fO67XSWv6VVpJ2WT1Bhp2I7ta+B5bfT
NCOo5iWXF1T/dlqqoFqnZOfoA6KjREo3bNjw85///NVXX/1P//m/kCm3UssX
ir/Fr11Qy+Wo0hbUvKYyjiqxUydKs9Mm6v6+qFnVr6Cu2E5t7fTZglqaoFLm
QAmq6xb/qY4F6oBQ9/fp/hXcb4cy2mmptXkRZdVVe6qbT4Nrp8UKquvmfgsl
qEI7lTlqtO3UdlS+BdVqPrXv759onz3Zobq/3xp7QRU7qiOohcs13Xyaztvp
7LHrTPEoCKqfFlRPRw2Enc6u0E7LJKiwUw9HLaOd2p87nK50BTstCGqxdlqS
oJ6/ZbSaEhElOvrVr3719ddf/81vfrNr1y4iqERWn3iq9u3fvjuTeRjXeCCL
6XzQn4uOBV+RUsVycCNddExRwcxacH01wjgChQMlPc4PndBdnEqP6XiF6nzx
ewr4KGPKWCo95lcYORKTPsJc0lklv3o+GSkjCgdk2gj+TKGuafoLeWBCUfb4
0rWikrCSMlZK+C/84ijhkk6XwOqGut6MUlT7SCor3HJWBEQ+iYISESVqunXr
1p/85CcNDQ2/+tWviKC+8sorGzdutJ7iV8Xq2kJ4Luwz6G3Kolz7CnUIDkuQ
jkwl/mqxKwPB+ePWUqH9sCAQCAQiyvHlL3/5+eef/8EPfkDU9Gc/+9n/B+iR
euY=
    "], {{0, 338}, {906, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{640.0999999999996, Automatic},
  ImageSizeRaw->{906, 338},
  PlotRange->{{0, 906}, {0, 338}}]], "Input"]], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1", "=", "4000"}], ";", 
  RowBox[{"nLen", "=", "100000"}], ";", 
  RowBox[{"nOut", "=", "250"}], ";", 
  RowBox[{"nSkip", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"t1", "=", "10"}], ";", 
   RowBox[{"\[CapitalDelta]t", "=", "0.01"}], ";", 
   RowBox[{"mSkip", "=", "1"}], ";", " ", 
   RowBox[{"iMethod", "=", "\"\<RK4\>\""}], ";", 
   RowBox[{"$dissipation", "=", "0.3"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"slicingMethod", "=", "\"\<MS4\>\""}], ";", 
  RowBox[{"smoothingMethod", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"maximalSlice_", "4", " ", 
    RowBox[{"(", 
     RowBox[{"m", ",", 
      RowBox[{"nLen", "/", "100"}], ",", "1"}], ")"}]}], "*)"}]}]}], "Input"],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQmUW/Wd51uZ9847b+Yt82amT6bPvDOvO+xbWExwA91JOp1AICSEQPAO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    "], {{0, 338}, {906, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{639.2999999999989, Automatic},
  ImageSizeRaw->{906, 338},
  PlotRange->{{0, 906}, {0, 338}}]], "Input"]], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1", "=", "10000"}], ";", 
  RowBox[{"nLen", "=", "250000"}], ";", 
  RowBox[{"nOut", "=", "250"}], ";", 
  RowBox[{"nSkip", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"t1", "=", "10"}], ";", 
   RowBox[{"\[CapitalDelta]t", "=", "0.01"}], ";", 
   RowBox[{"mSkip", "=", "1"}], ";", " ", 
   RowBox[{"iMethod", "=", "\"\<RK4\>\""}], ";", 
   RowBox[{"$dissipation", "=", "0.3"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"slicingMethod", "=", "\"\<MS4\>\""}], ";", 
  RowBox[{"smoothingMethod", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"maximalSlice_", "4", " ", 
    RowBox[{"(", 
     RowBox[{"m", ",", 
      RowBox[{"nLen", "/", "200"}], ",", "1"}], ")"}]}], "*)"}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1", "=", "2000"}], ";", 
  RowBox[{"nLen", "=", "50000"}], ";", 
  RowBox[{"nOut", "=", "1000"}], ";", 
  RowBox[{"nSkip", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"t1", "=", "10"}], ";", 
   RowBox[{"\[CapitalDelta]t", "=", "0.01"}], ";", 
   RowBox[{"mSkip", "=", "1"}], ";", " ", 
   RowBox[{"iMethod", "=", "\"\<RK4\>\""}], ";", 
   RowBox[{"$dissipation", "=", "0.3"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"slicingMethod", "=", "\"\<MS4\>\""}], ";", 
  RowBox[{"smoothingMethod", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"maximalSlice_", "4", " ", 
    RowBox[{"(", 
     RowBox[{"m", ",", 
      RowBox[{"nLen", "/", "25"}], ",", "1"}], ")"}]}], "*)"}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1", "=", "100"}], ";", 
  RowBox[{"nLen", "=", "2500"}], ";", 
  RowBox[{"nOut", "=", "2500"}], ";", 
  RowBox[{"nSkip", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"t1", "=", "10"}], ";", 
   RowBox[{"\[CapitalDelta]t", "=", "0.01"}], ";", 
   RowBox[{"mSkip", "=", "1"}], ";", " ", 
   RowBox[{"iMethod", "=", "\"\<RK1\>\""}], ";", 
   RowBox[{"$dissipation", "=", "0.3"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"slicingMethod", "=", "\"\<MS4\>\""}], ";", 
  RowBox[{"smoothingMethod", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"maximalSlice_", "4", " ", 
    RowBox[{"(", 
     RowBox[{"m", ",", 
      RowBox[{"nLen", "/", "25"}], ",", "1"}], ")"}]}], "*)"}]}]}], "Input"]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1334, 1053},
WindowMargins->{{266, Automatic}, {Automatic, 11}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "case5explorer"->{
  Cell[57744, 1554, 11588, 227, 527, "Output",
   CellTags->"case5explorer"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"case5explorer", 180450, 3710}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 334, 13, 53, "Text"],
Cell[CellGroupData[{
Cell[917, 37, 39, 0, 42, "Subsubsection"],
Cell[959, 39, 308, 8, 60, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1304, 52, 30, 0, 42, "Subsubsection"],
Cell[1337, 54, 645, 23, 83, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2019, 82, 46, 0, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[2090, 86, 11343, 301, 1770, "Input"],
Cell[CellGroupData[{
Cell[13458, 391, 79, 2, 29, "Echo"],
Cell[13540, 395, 4596, 119, 120, "Echo"],
Cell[18139, 516, 3340, 93, 51, "Echo"],
Cell[21482, 611, 79, 2, 29, "Echo"],
Cell[21564, 615, 79, 2, 29, "Echo"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21692, 623, 607, 20, 41, "Input"],
Cell[22302, 645, 10119, 283, 167, "Echo"]
}, Open  ]],
Cell[32436, 931, 41, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[32502, 935, 1429, 40, 83, "Input"],
Cell[33934, 977, 525, 17, 36, "Output"]
}, Open  ]],
Cell[34474, 997, 6837, 167, 635, "Input"],
Cell[CellGroupData[{
Cell[41336, 1168, 16405, 384, 1879, "Input"],
Cell[57744, 1554, 11588, 227, 527, "Output",
 CellTags->"case5explorer"]
}, Open  ]],
Cell[69347, 1784, 69, 0, 38, "Text"],
Cell[69419, 1786, 1298, 38, 257, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70754, 1829, 65, 0, 42, "Subsubsection"],
Cell[70822, 1831, 185, 5, 36, "Input"],
Cell[71010, 1838, 281, 7, 36, "Input"],
Cell[71294, 1847, 138, 3, 36, "Input"],
Cell[71435, 1852, 50977, 840, 316, "Text"],
Cell[122415, 2694, 806, 21, 106, "Input"],
Cell[123224, 2717, 51225, 844, 315, "Text"],
Cell[174452, 3563, 807, 21, 106, "Input"],
Cell[175262, 3586, 805, 21, 106, "Input"],
Cell[176070, 3609, 803, 21, 106, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
