(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1112738,      18334]
NotebookOptionsPosition[   1106656,      18183]
NotebookOutlinePosition[   1110262,      18265]
CellTagsIndexPosition[   1110219,      18262]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Initial Data: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["K", "2"], "=", "const"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"B", "=", 
    RowBox[{
     OverscriptBox["B", "~"], "=", "1"}]}], TraditionalForm]]],
 " where either (1) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], "p"}], "=", "0"}], TraditionalForm]]],
 " or (2) ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "0"], TraditionalForm]]],
 " is arbitrary"
}], "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell["The prescription for the ID is obtained from Marcus.", "Text"],

Cell[TextData[{
 "Note the convention ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Gamma]", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "2"], 
      StyleBox["d",
       FontSlant->"Plain"], "\[VeryThinSpace]", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["B", "2"], 
      SuperscriptBox["r", "2"], 
      StyleBox["d",
       FontSlant->"Plain"], "\[VeryThinSpace]", 
      SuperscriptBox["\[CapitalOmega]", "2"]}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "Changelog:\n2018-08-24  Created\n2018-08-27  Comparison with the numerical \
values obtained from Marcus\n2018-08-28  Plugged in into the bim-solver (to \
get the behavior of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], "p"}], TraditionalForm]]],
 ")\n2018-08-29  Solved for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "0"], TraditionalForm]]],
 " after imposing ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], "p"}], "=", "0"}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell["Assumptions", "Subsubsection"],

Cell["The assumptions,", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["K", "1"], "=", 
    RowBox[{
     SubscriptBox["K", "2"], "=", "const"}]}], TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ", and"
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"A", "[", "r", "]"}], ",", " ", 
    RowBox[{
     OverscriptBox["A", "~"], "[", "r", "]"}], ",", " ", 
    RowBox[{
     SubscriptBox["K", "1"], "[", "r", "]"}], ",", " ", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["K", "~"], "1"], "[", "r", "]"}], ",", " ", 
    RowBox[{"and", " ", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["K", "~"], "2"], "[", "r", "]"}]}]}], TraditionalForm]]],
 "  are unknown functions (needed to be solved at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ")."
}], "Text"],

Cell[TextData[{
 "We also assume ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "=", "0"}], TraditionalForm]]],
 " and either:"
}], "Text"],

Cell[TextData[{
 "\t(1)\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], "p"}], "=", "0"}], TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ", or"
}], "Text"],

Cell[TextData[{
 "\t(2)\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is arbitrary given."
}], "Text"],

Cell["\<\
The above two options are configurable by the following flag:\
\>", "Text"],

Cell[BoxData[
 FrameBox[
  RowBox[{
   RowBox[{"$impose$dtpzero", "=", "False"}], ";"}]]], "Input"],

Cell[TextData[{
 "The bimetric model (",
 Cell[BoxData[
  FormBox[
   RowBox[{"k$g", "=", 
    SubscriptBox["\[Kappa]", "g"]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k$f", "=", 
    SubscriptBox["\[Kappa]", "f"]}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Beta]", "[", "n", "]"}], "=", 
    SubscriptBox["\[Beta]", "n"]}], TraditionalForm]]],
 ") is assumed to be generic.  \n(Later on, the initial values for the \
manipulator will be ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k$g", "=", "1"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k$f", "=", "1"}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Beta]", "[", "1", "]"}], "=", 
    RowBox[{"-", "1"}]}], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Beta]", "[", "0", "]"}], "..."}], 
     RowBox[{"\[Beta]", "[", "4", "]"}]}], "=", "0"}], TraditionalForm]]],
 ".)"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Identification", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"id$setup", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$debugMode", "=", "True"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "id$title", "=", 
   "\"\<Conformaly flat \!\(TraditionalForm\`g\) and \!\(TraditionalForm\`f\) \
at \!\(TraditionalForm\`t0\) with Guassian \!\(TraditionalForm\`PF\)\>\""}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gauge", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eq$q", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$gAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$fAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"gAlp", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"gW", "[", 
      RowBox[{"t", ",", "r"}], "]"}], "/", 
     RowBox[{"fW", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup the constraint equations", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Block", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "fA", ",", "fB", ",", "fK1",
      ",", "fK2", ",", "pfD", ",", "pfS", ",", "pf\[Tau]", ",", 
     "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",", "g$JK2", ",", 
     "f$\[Rho]", ",", "f$JK1", ",", "f$JK2", ",", "\[IndentingNewLine]", "Lt",
      ",", "p", ",", "q", ",", "R", ",", "P", ",", "\[Beta]", ",", "k$g", ",",
      "k$f", ",", "\[IndentingNewLine]", "gAlp", ",", "fAlp", ",", 
     "K2const"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "id$gA", ",", "id$gB", ",", "id$gK1", ",", "id$gK2", ",", "id$fA", ",", 
      "id$fB", ",", "id$fK1", ",", "id$fK2", ",", "id$p", ",", "id$q", ",", 
      "id$gAlp", ",", "id$fAlp", ",", "id$pfD", ",", "id$pfS", ",", 
      "id$pf\[Tau]", ",", "id$gKretschmann", ",", "id$fKretschmann", ",", 
      "id$gW", ",", "id$fW", ",", "id$\[Rho]0"}], "]"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gB", "[", "r_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK1", "[", "r_", "]"}], ":=", "K2const"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK2", "[", "r_", "]"}], ":=", "K2const"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fB", "[", "r_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK1", "[", "r_", "]"}], ":=", 
     RowBox[{"fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK2", "[", "r_", "]"}], ":=", 
     RowBox[{"fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfD", "[", "r_", "]"}], ":=", 
     RowBox[{
      RowBox[{"\[Rho]0", "[", "r", "]"}], 
      RowBox[{"gA", "[", 
       RowBox[{"t", ",", "r"}], "]"}], 
      SuperscriptBox[
       RowBox[{"gB", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "2"]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfS", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pf\[Tau]", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$p", "[", "r_", "]"}], ":=", "0"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"P", "[", 
      RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
     RowBox[{"eq$esP", "[", 
      RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$gV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"gT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$\[Rho]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f$JK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"eq$fV$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"fT$JK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"gA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$gK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fA", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"fA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fB", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fK2", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfD", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfD", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pfS", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pfS", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pf\[Tau]", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"fB", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "/", 
      RowBox[{"gB", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"id$p", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Lt", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"p", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
      RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gAlp", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fAlp", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"gAlp", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}], 
      RowBox[{
       RowBox[{"eq$gW", "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "/", 
       RowBox[{"eq$fW", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c$1", ",", "c$2", ",", "c$3", ",", "c$4", ",", "c$p"}], "}"}], 
     "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          UnderscriptBox["eq$C1", "_"], ",", 
          UnderscriptBox["eq$C2", "_"], ",", 
          UnderscriptBox["eq$C3", "_"], ",", 
          UnderscriptBox["eq$C4", "_"], ",", 
          UnderscriptBox["eq$p$g", "_"]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", "Expand"}],
       "//", "Simplify"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"c$p$t", "=", 
     UnderscriptBox["evol$eq$p", "_"]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Echo", "/@", 
     RowBox[{"printNice", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$p \[Equal] \>\"", ",", "c$p"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$1 \[Equal] \>\"", ",", "c$1"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$2 \[Equal] \>\"", ",", "c$2"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$3 \[Equal] \>\"", ",", "c$3"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<c$4 \[Equal] \>\"", ",", "c$4"}], "}"}]}]}], 
        "\[IndentingNewLine]", "}"}], ",", "$disabledESP$"}], "]"}]}], 
    ";"}]}], "\[IndentingNewLine]", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve the constraint equations", "Subsubsection"],

Cell[TextData[{
 "Then solve  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    OverscriptBox["K", "~"], "2", "\[Prime]"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["K", "~"], "1"], TraditionalForm]]],
 " from ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "3"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "4"], TraditionalForm]]],
 ","
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqs1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"c$3", "\[Equal]", "0"}], ",", 
          RowBox[{"c$4", "\[Equal]", "0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"fK2", "[", "r", "]"}], ",", "r"}], "]"}], ",", 
          RowBox[{"fK1", "[", "r", "]"}]}], "}"}]}], "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "//", 
     "Simplify"}], "//", "echoNice"}]}], ";"}]], "Input"],

Cell[TextData[{
 "We have the algebraic expression for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["K", "~"], "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ","
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sol$fK1", "[", "r_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fK1", "[", "r", "]"}], "/.", 
      RowBox[{
      "eqs1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "//", 
     "Simplify"}], "//", "echoNice"}]}], ";"}]], "Input"],

Cell[TextData[{
 "Solve for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "\[Prime]"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["A", "~"], "\[Prime]"], TraditionalForm]]],
 ","
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqs2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"c$1", "\[Equal]", "0"}], ",", 
           RowBox[{"c$2", "\[Equal]", "0"}]}], "}"}], "/.", 
         RowBox[{"{", 
          RowBox[{"fK1", "\[Rule]", "sol$fK1"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"gA", "[", "r", "]"}], ",", "r"}], "]"}], ",", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"fA", "[", "r", "]"}], ",", "r"}], "]"}]}], "}"}]}], 
       "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "//", 
     "Simplify"}], "//", "echoNice"}]}], ";"}]], "Input"],

Cell[TextData[{
 "What we have is an ODE system in a normal form for ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    OverscriptBox["K", "~"], "2", "\[Prime]"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "\[Prime]"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["A", "~"], "\[Prime]"], TraditionalForm]]],
 ","
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"odeSys", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"fK2", "[", "r", "]"}], ",", "r"}], "]"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"fK2", "[", "r", "]"}], ",", "r"}], "]"}], "/.", 
          RowBox[{
          "eqs1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "//",
          "Simplify"}], ")"}]}], "//", "echoNice"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"gA", "[", "r", "]"}], ",", "r"}], "]"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"gA", "[", "r", "]"}], ",", "r"}], "]"}], "/.", 
          RowBox[{
          "eqs2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "//",
          "Simplify"}], ")"}]}], "//", "echoNice"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"fA", "[", "r", "]"}], ",", "r"}], "]"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"fA", "[", "r", "]"}], ",", "r"}], "]"}], "/.", 
          RowBox[{
          "eqs2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "//",
          "Simplify"}], ")"}]}], "//", "echoNice"}]}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input"],

Cell[TextData[{
 "What about the extra condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], "p"}], "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "? As we shall see, this requires that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is fixed (assuming that ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["B", "~"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " are freely chosen),"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c$p$t", "//", "Variables"}], "//", "echoNice"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fK1r$rule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"fK1", "[", "r", "]"}], ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fK1", "[", "r", "]"}], "/.", 
           RowBox[{
           "eqs1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          ",", "r"}], "]"}]}], "/.", "eqs1"}], "/.", "eqs2"}], "/.", 
     RowBox[{"(", 
      RowBox[{"odeSys", "/.", 
       RowBox[{"Equal", "\[Rule]", "Rule"}]}], ")"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "Removing all the other spatial derivatives, we are left with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "r"], 
    SubscriptBox["\[Rho]", "0"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ","
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"c$p$t", "/.", "eqs1"}], "/.", "eqs2"}], "/.", 
    RowBox[{"(", 
     RowBox[{"odeSys", "/.", 
      RowBox[{"Equal", "\[Rule]", "Rule"}]}], ")"}]}], "/.", "fK1r$rule"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "//", "Variables"}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol$\[Rho]0$r", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"\[Rho]0", "[", "r", "]"}], ",", "r"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"%%", "\[Equal]", "0"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[Rho]0", "[", "r", "]"}], ",", "r"}], "]"}]}], "]"}], 
     "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}], ";"}]}], "Input"],

Cell["Beware not to print sol$\[Rho]0$r since:", "Text"],

Cell[BoxData[
 RowBox[{"sol$\[Rho]0$r", "//", "LeafCount"}]], "Input"],

Cell["So the odeSys get enlarged to,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"odeSys2", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"odeSys", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[Rho]0", "[", "r", "]"}], ",", "r"}], "]"}], "\[Equal]", 
       "sol$\[Rho]0$r"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell["The initial data is a solution to ODE ...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "\[Rho]0", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Not", "@", "$impose$dtpzero"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Rho]0", "[", "r_", "]"}], ":=", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"-", "r"}], "]"}], "*", "0"}]}]}], "\[IndentingNewLine]", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ode$sol", "=", 
       RowBox[{"Quiet", "@", 
        RowBox[{"NDSolveValue", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Join", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{"$impose$dtpzero", ",", "odeSys2", ",", "odeSys"}], 
              "]"}], "/.", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"K2const", "\[Rule]", "gK2$0"}], ",", 
               RowBox[{"k$g", "\[Rule]", "ck$g"}], ",", 
               RowBox[{"k$f", "\[Rule]", "ck$f"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"\[Beta]", "[", "0", "]"}], "\[Rule]", "b$0"}], ",", 
               RowBox[{
                RowBox[{"\[Beta]", "[", "1", "]"}], "\[Rule]", "b$1"}], ",", 
               RowBox[{
                RowBox[{"\[Beta]", "[", "2", "]"}], "\[Rule]", "b$2"}], ",", 
               RowBox[{
                RowBox[{"\[Beta]", "[", "3", "]"}], "\[Rule]", "b$3"}], ",", 
               RowBox[{
                RowBox[{"\[Beta]", "[", "4", "]"}], "\[Rule]", "b$4"}]}], 
              "\[IndentingNewLine]", "}"}]}], ",", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"fK2", "[", "r$0", "]"}], "\[Equal]", "fK2$0"}], ",", 
              RowBox[{
               RowBox[{"gA", "[", "r$0", "]"}], "\[Equal]", "gA$0"}], ",", 
              RowBox[{
               RowBox[{"fA", "[", "r$0", "]"}], "\[Equal]", "fA$0"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"If", "[", 
                RowBox[{"$impose$dtpzero", ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Rho]0", "[", "r$0", "]"}], "\[Equal]", 
                   "\[Rho]0$0"}], "}"}], ",", 
                 RowBox[{"{", "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
             "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"gA", ",", "fA", ",", "fK2", ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"If", "[", 
              RowBox[{"$impose$dtpzero", ",", 
               RowBox[{"{", "\[Rho]0", "}"}], ",", 
               RowBox[{"{", "}"}]}], "]"}]}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"r", ",", "0", ",", "r$max"}], "}"}]}], 
         "\[IndentingNewLine]", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Plot", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Evaluate", "@", 
         RowBox[{"Join", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", "r", "]"}], "&"}], "/@", "ode$sol"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"$impose$dtpzero", ",", 
             RowBox[{"{", "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Rho]0", "[", "r", "]"}], "}"}]}], "]"}]}], 
          "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r", ",", "1", ",", "1.1"}], "}"}], ","}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"Evaluate", "@", 
         RowBox[{"{", 
          RowBox[{"r", ",", 
           RowBox[{"Sequence", "@@", 
            RowBox[{
             RowBox[{
              RowBox[{
              "ode$sol", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}]}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "500"}], ",", "\[IndentingNewLine]", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Black", ",", "16"}], "]"}], "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
            "\"\<A\>\"", ",", "\"\<\!\(\*OverscriptBox[\(A\), \(~\)]\)\>\"", 
             ",", "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\
\)\>\"", ",", "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)\>\""}], "}"}]}], 
          ")"}]}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Style", "[", 
           RowBox[{"r", ",", "Black", ",", "16"}], "]"}], "}"}]}]}], 
       "\[IndentingNewLine]", "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "r$0", ",", "1", ",", "\"\<\!\(\*SubscriptBox[\(r\), \(0\)]\)\>\""}], 
      "}"}], ",", "0.001", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "r$max", ",", "3", ",", 
       "\"\<\!\(\*SubscriptBox[\(r\), \(max\)]\)\>\""}], "}"}], ",", "2", ",",
      "100"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Rho]0$0", ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", "1"}], "]"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)\>\""}], "}"}], ",", "0", 
     ",", "100"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "gK2$0", ",", "0.01", ",", 
       "\"\<\!\(\*SubscriptBox[\(K\), \(2\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "fK2$0", ",", "0.01", ",", 
       "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)\>\""}], 
      "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"gA$0", ",", 
       FractionBox["1", 
        SqrtBox[
         RowBox[{"1", "-", "0.16"}]]], ",", "\"\<A\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "fA$0", ",", "0.1", ",", 
       "\"\<\!\(\*OverscriptBox[\(A\), \(~\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b$0", ",", "0", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(0\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b$1", ",", 
       RowBox[{"-", "1"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b$2", ",", "0.5", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b$3", ",", "2", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b$4", ",", 
       RowBox[{"-", "5"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Beta]\), \(4\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ck$g", ",", "1", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)\>\""}], "}"}], ",", 
     "0.001", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ck$f", ",", "1", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)\>\""}], "}"}], ",", 
     "0.001", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AppearanceElements", "\[Rule]", "None"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`b$0$$ = 
    0, $CellContext`b$1$$ = -1, $CellContext`b$2$$ = 0.5, $CellContext`b$3$$ =
     2, $CellContext`b$4$$ = -5, $CellContext`ck$f$$ = 
    1, $CellContext`ck$g$$ = 1, $CellContext`fA$0$$ = 
    0.1, $CellContext`fK2$0$$ = 0.01, $CellContext`gA$0$$ = 
    1.0910894511799618`, $CellContext`gK2$0$$ = 0.01, $CellContext`r$0$$ = 
    1, $CellContext`r$max$$ = 3, $CellContext`\[Rho]0$0$$ = E^(-1), 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`r$0$$], 1, "\!\(\*SubscriptBox[\(r\), \(0\)]\)"}, 
      0.001, 2}, {{
       Hold[$CellContext`r$max$$], 3, "\!\(\*SubscriptBox[\(r\), \(max\)]\)"},
       2, 100}, {{
       Hold[$CellContext`\[Rho]0$0$$], E^(-1), 
       "\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)"}, 0, 100}, {{
       Hold[$CellContext`gK2$0$$], 0.01, 
       "\!\(\*SubscriptBox[\(K\), \(2\)]\)"}, -2, 2}, {{
       Hold[$CellContext`fK2$0$$], 0.01, 
       "\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)"}, -2, 2}, {{
       Hold[$CellContext`gA$0$$], 1.0910894511799618`, "A"}, -2, 2}, {{
       Hold[$CellContext`fA$0$$], 0.1, 
       "\!\(\*OverscriptBox[\(A\), \(~\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$0$$], 0, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(0\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$1$$], -1, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$2$$], 0.5, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$3$$], 2, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$4$$], -5, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(4\)]\)"}, -2, 2}, {{
       Hold[$CellContext`ck$g$$], 1, 
       "\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)"}, 0.001, 10}, {{
       Hold[$CellContext`ck$f$$], 1, 
       "\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)"}, 0.001, 10}}, 
    Typeset`size$$ = {705., {208., 215.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`r$0$543552$$ = 0, $CellContext`r$max$543553$$ = 
    0, $CellContext`\[Rho]0$0$543554$$ = 0, $CellContext`gK2$0$543555$$ = 
    0, $CellContext`fK2$0$543556$$ = 0, $CellContext`gA$0$543557$$ = 
    0, $CellContext`fA$0$543558$$ = 0, $CellContext`b$0$543559$$ = 
    0, $CellContext`b$1$543560$$ = 0, $CellContext`b$2$543561$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`b$0$$ = 
        0, $CellContext`b$1$$ = -1, $CellContext`b$2$$ = 
        0.5, $CellContext`b$3$$ = 
        2, $CellContext`b$4$$ = -5, $CellContext`ck$f$$ = 
        1, $CellContext`ck$g$$ = 1, $CellContext`fA$0$$ = 
        0.1, $CellContext`fK2$0$$ = 0.01, $CellContext`gA$0$$ = 
        1.0910894511799618`, $CellContext`gK2$0$$ = 0.01, $CellContext`r$0$$ = 
        1, $CellContext`r$max$$ = 3, $CellContext`\[Rho]0$0$$ = E^(-1)}, 
      "ControllerVariables" :> {
        Hold[$CellContext`r$0$$, $CellContext`r$0$543552$$, 0], 
        Hold[$CellContext`r$max$$, $CellContext`r$max$543553$$, 0], 
        Hold[$CellContext`\[Rho]0$0$$, $CellContext`\[Rho]0$0$543554$$, 0], 
        Hold[$CellContext`gK2$0$$, $CellContext`gK2$0$543555$$, 0], 
        Hold[$CellContext`fK2$0$$, $CellContext`fK2$0$543556$$, 0], 
        Hold[$CellContext`gA$0$$, $CellContext`gA$0$543557$$, 0], 
        Hold[$CellContext`fA$0$$, $CellContext`fA$0$543558$$, 0], 
        Hold[$CellContext`b$0$$, $CellContext`b$0$543559$$, 0], 
        Hold[$CellContext`b$1$$, $CellContext`b$1$543560$$, 0], 
        Hold[$CellContext`b$2$$, $CellContext`b$2$543561$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Block[{$CellContext`\[Rho]0}, If[
          Not[$CellContext`$impose$dtpzero], $CellContext`\[Rho]0[
            Pattern[$CellContext`r, 
             Blank[]]] := Exp[-$CellContext`r] 0]; $CellContext`ode$sol = 
         Quiet[
           NDSolveValue[
            Join[
             ReplaceAll[
              
              If[$CellContext`$impose$dtpzero, $CellContext`odeSys2, \
$CellContext`odeSys], {$CellContext`K2const -> $CellContext`gK2$0$$, \
$CellContext`k$g -> $CellContext`ck$g$$, $CellContext`k$f -> \
$CellContext`ck$f$$, $CellContext`\[Beta][
                0] -> $CellContext`b$0$$, $CellContext`\[Beta][
                1] -> $CellContext`b$1$$, $CellContext`\[Beta][
                2] -> $CellContext`b$2$$, $CellContext`\[Beta][
                3] -> $CellContext`b$3$$, $CellContext`\[Beta][
                4] -> $CellContext`b$4$$}], \
{$CellContext`fK2[$CellContext`r$0$$] == $CellContext`fK2$0$$, \
$CellContext`gA[$CellContext`r$0$$] == $CellContext`gA$0$$, \
$CellContext`fA[$CellContext`r$0$$] == $CellContext`fA$0$$, 
              Apply[Sequence, 
               
               If[$CellContext`$impose$dtpzero, \
{$CellContext`\[Rho]0[$CellContext`r$0$$] == $CellContext`\[Rho]0$0$$}, \
{}]]}], {$CellContext`gA, $CellContext`fA, $CellContext`fK2, 
             Apply[Sequence, 
              
              If[$CellContext`$impose$dtpzero, {$CellContext`\[Rho]0}, {}]]}, \
{$CellContext`r, 0, $CellContext`r$max$$}]]; Plot[
          Evaluate[
           Join[
            Map[#[$CellContext`r]& , $CellContext`ode$sol], 
            If[$CellContext`$impose$dtpzero, {}, {
              $CellContext`\[Rho]0[$CellContext`r]}]]], 
          Evaluate[{$CellContext`r, 
            Apply[Sequence, 
             Part[
              Part[
               Part[$CellContext`ode$sol, 1], 1], 1]]}], PlotTheme -> 
          "Scientific", ImageSize -> 500, PlotLegends -> 
          Map[Style[#, Black, 16]& , {
            "A", "\!\(\*OverscriptBox[\(A\), \(~\)]\)", 
             "\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)", 
             "\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)"}], FrameLabel -> {
            Style[$CellContext`r, Black, 16]}]], 
      "Specifications" :> {{{$CellContext`r$0$$, 1, 
          "\!\(\*SubscriptBox[\(r\), \(0\)]\)"}, 0.001, 
         2}, {{$CellContext`r$max$$, 3, 
          "\!\(\*SubscriptBox[\(r\), \(max\)]\)"}, 2, 
         100}, {{$CellContext`\[Rho]0$0$$, E^(-1), 
          "\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)"}, 0, 
         100}, {{$CellContext`gK2$0$$, 0.01, 
          "\!\(\*SubscriptBox[\(K\), \(2\)]\)"}, -2, 
         2}, {{$CellContext`fK2$0$$, 0.01, 
          "\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)"}, -2, 
         2}, {{$CellContext`gA$0$$, 1.0910894511799618`, "A"}, -2, 
         2}, {{$CellContext`fA$0$$, 0.1, 
          "\!\(\*OverscriptBox[\(A\), \(~\)]\)"}, -2, 
         2}, {{$CellContext`b$0$$, 0, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(0\)]\)"}, -2, 
         2}, {{$CellContext`b$1$$, -1, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)"}, -2, 
         2}, {{$CellContext`b$2$$, 0.5, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)"}, -2, 
         2}, {{$CellContext`b$3$$, 2, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)"}, -2, 
         2}, {{$CellContext`b$4$$, -5, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(4\)]\)"}, -2, 
         2}, {{$CellContext`ck$g$$, 1, 
          "\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)"}, 0.001, 
         10}, {{$CellContext`ck$f$$, 1, 
          "\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)"}, 0.001, 10}}, 
      "Options" :> {AppearanceElements -> None}, "DefaultOptions" :> {}],
     ImageSizeCache->{1073., {236., 243.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`$impose$dtpzero = 
       False, $CellContext`ode$sol = {
         InterpolatingFunction[{{0.5437043713710581, 3.}}, {
          5, 7, 1, {733}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
           False}, CompressedData["
1:eJwt1wc4lV0cAHBEUXxIpWiSXRnRl4ZzI8rKDC0rsmdWFCUZoUFKRlG2aBlF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          "], {Developer`PackedArrayForm, CompressedData["
1:eJwl1Q1HKIAVBuDWWpIkSZKkJUmSJEmSJEmSJEmSJEnSkiRJkiRJkiRJkiRJ
kiRJkiRJkutKciVJkuRKkmRP2+FxfsB7Pv7d+J/K9n8EBAT8CQz4X/20IIIJ
IZQwwokgkiiiiSGWOOJJIJEkkkkhlTTSySCTLLLJIZc88imgkCKKKaGUMsqp
oJIqqqmhljrqaaCRJpppoZU22umgky666aGXPvoZYJAhhhlhlDHGmWCSKaaZ
YZY55llgkSWWWWGVNdbZYJMtttlhlz32OeCQI4454ZQzzrngkl/85oprbn7y
45Y77nngkSeeeeGVv7zxzgeffPFNgEEIJIhgQggljHAiiCSKaGKIJY54Ekgk
iWRSSCWNdDLIJItscsglj3wKKKSIYkoopYxyKqikimpqqKWOehpopIlmWmil
jZ8h76CTLrrpoZc++hlgkCGGGWGUMcaZYJIppplhljnmWWCRJZZZYZU11tlg
ky222WGXPfY54JAjjjnhlDPOueCSX/zmimtu+MMtd9zzwCNPPPPCK395450P
Pvnim5/lDySIYEIIJYxwIogkimhiiCWOeBJIJIlkUkgljXQyyCSLbHLIJY98
CiikiGJKKKWMciqopIpqaqiljnoaaKSJZlpopY12Ouiki2566KWPfgYYZIhh
RhhljHEmmGSKaWaYZY55FlhkiWVWWGWNdTbYZIttdthlj30OOOSIY0445Yxz
LrjkF7+54pqbwP/f71vuuOeBR5545oVX/vLGOx988sU3Af+UP0EEE0IoYYQT
QSRRRBNDLHHEk0AiSSSTQipppJNBJllkk0MueeRTQCFFFFNCKWWUU0ElVVRT
Qy111NNAI00000IrbbTTQSdddNNDL330M8AgQwwzwihjjDPBJFNMM8Msc8yz
wCJLLLPCKmuss8EmW2yzwy577HPAIUccc8IpZ5xzwSW/+M0V19zwh1vuuOeB
R5545oVX/vLGOx988sU3P48/kCCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU0
0skgkyyyySGXPPIpoJAiiimhlDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMu
uumhlz76GWCQIYYZYZQxxplgkimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZc9
9jngkCOOOeGUM8654JJf/OaKa274wy133PPAI08888Irf3njnQ8++eKbgH/J
nyCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU00skgkyyyySGXPPIpoJAiiimh
lDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMuuumhlz76GWCQIYYZYZQxxplg
kimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZf/AmDhaR8=
           "], CompressedData["
1:eJwNlHc0138Dxe1N9s6WmQgh4/v+mBnJjkRkZM8QFdmizMgIKUJ+Ziik72fY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           "]}, {Automatic}], 
         InterpolatingFunction[{{0.5437043713710581, 3.}}, {
          5, 7, 1, {733}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
           False}, CompressedData["
1:eJwt1wc4lV0cAHBEUXxIpWiSXRnRl4ZzI8rKDC0rsmdWFCUZoUFKRlG2aBlF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          "], {Developer`PackedArrayForm, CompressedData["
1:eJwl1Q1HKIAVBuDWWpIkSZKkJUmSJEmSJEmSJEmSJEnSkiRJkiRJkiRJkiRJ
kiRJkiRJkutKciVJkuRKkmRP2+FxfsB7Pv7d+J/K9n8EBAT8CQz4X/20IIIJ
IZQwwokgkiiiiSGWOOJJIJEkkkkhlTTSySCTLLLJIZc88imgkCKKKaGUMsqp
oJIqqqmhljrqaaCRJpppoZU22umgky666aGXPvoZYJAhhhlhlDHGmWCSKaaZ
YZY55llgkSWWWWGVNdbZYJMtttlhlz32OeCQI4454ZQzzrngkl/85oprbn7y
45Y77nngkSeeeeGVv7zxzgeffPFNgEEIJIhgQggljHAiiCSKaGKIJY54Ekgk
iWRSSCWNdDLIJItscsglj3wKKKSIYkoopYxyKqikimpqqKWOehpopIlmWmil
jZ8h76CTLrrpoZc++hlgkCGGGWGUMcaZYJIppplhljnmWWCRJZZZYZU11tlg
ky222WGXPfY54JAjjjnhlDPOueCSX/zmimtu+MMtd9zzwCNPPPPCK395450P
Pvnim5/lDySIYEIIJYxwIogkimhiiCWOeBJIJIlkUkgljXQyyCSLbHLIJY98
CiikiGJKKKWMciqopIpqaqiljnoaaKSJZlpopY12Ouiki2566KWPfgYYZIhh
RhhljHEmmGSKaWaYZY55FlhkiWVWWGWNdTbYZIttdthlj30OOOSIY0445Yxz
LrjkF7+54pqbwP/f71vuuOeBR5545oVX/vLGOx988sU3Af+UP0EEE0IoYYQT
QSRRRBNDLHHEk0AiSSSTQipppJNBJllkk0MueeRTQCFFFFNCKWWUU0ElVVRT
Qy111NNAI00000IrbbTTQSdddNNDL330M8AgQwwzwihjjDPBJFNMM8Msc8yz
wCJLLLPCKmuss8EmW2yzwy577HPAIUccc8IpZ5xzwSW/+M0V19zwh1vuuOeB
R5545oVX/vLGOx988sU3P48/kCCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU0
0skgkyyyySGXPPIpoJAiiimhlDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMu
uumhlz76GWCQIYYZYZQxxplgkimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZc9
9jngkCOOOeGUM8654JJf/OaKa274wy133PPAI08888Irf3njnQ8++eKbgH/J
nyCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU00skgkyyyySGXPPIpoJAiiimh
lDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMuuumhlz76GWCQIYYZYZQxxplg
kimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZf/AmDhaR8=
           "], CompressedData["
1:eJwd13c8lV8cB3BbMjKSZFQIZYQoI74nyQhJkp29KiOSSCSEkIyspIziRxn3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           "]}, {Automatic}], 
         InterpolatingFunction[{{0.5437043713710581, 3.}}, {
          5, 7, 1, {733}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
           False}, CompressedData["
1:eJwt1wc4lV0cAHBEUXxIpWiSXRnRl4ZzI8rKDC0rsmdWFCUZoUFKRlG2aBlF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          "], {Developer`PackedArrayForm, CompressedData["
1:eJwl1Q1HKIAVBuDWWpIkSZKkJUmSJEmSJEmSJEmSJEnSkiRJkiRJkiRJkiRJ
kiRJkiRJkutKciVJkuRKkmRP2+FxfsB7Pv7d+J/K9n8EBAT8CQz4X/20IIIJ
IZQwwokgkiiiiSGWOOJJIJEkkkkhlTTSySCTLLLJIZc88imgkCKKKaGUMsqp
oJIqqqmhljrqaaCRJpppoZU22umgky666aGXPvoZYJAhhhlhlDHGmWCSKaaZ
YZY55llgkSWWWWGVNdbZYJMtttlhlz32OeCQI4454ZQzzrngkl/85oprbn7y
45Y77nngkSeeeeGVv7zxzgeffPFNgEEIJIhgQggljHAiiCSKaGKIJY54Ekgk
iWRSSCWNdDLIJItscsglj3wKKKSIYkoopYxyKqikimpqqKWOehpopIlmWmil
jZ8h76CTLrrpoZc++hlgkCGGGWGUMcaZYJIppplhljnmWWCRJZZZYZU11tlg
ky222WGXPfY54JAjjjnhlDPOueCSX/zmimtu+MMtd9zzwCNPPPPCK395450P
Pvnim5/lDySIYEIIJYxwIogkimhiiCWOeBJIJIlkUkgljXQyyCSLbHLIJY98
CiikiGJKKKWMciqopIpqaqiljnoaaKSJZlpopY12Ouiki2566KWPfgYYZIhh
RhhljHEmmGSKaWaYZY55FlhkiWVWWGWNdTbYZIttdthlj30OOOSIY0445Yxz
LrjkF7+54pqbwP/f71vuuOeBR5545oVX/vLGOx988sU3Af+UP0EEE0IoYYQT
QSRRRBNDLHHEk0AiSSSTQipppJNBJllkk0MueeRTQCFFFFNCKWWUU0ElVVRT
Qy111NNAI00000IrbbTTQSdddNNDL330M8AgQwwzwihjjDPBJFNMM8Msc8yz
wCJLLLPCKmuss8EmW2yzwy577HPAIUccc8IpZ5xzwSW/+M0V19zwh1vuuOeB
R5545oVX/vLGOx988sU3P48/kCCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU0
0skgkyyyySGXPPIpoJAiiimhlDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMu
uumhlz76GWCQIYYZYZQxxplgkimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZc9
9jngkCOOOeGUM8654JJf/OaKa274wy133PPAI08888Irf3njnQ8++eKbgH/J
nyCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU00skgkyyyySGXPPIpoJAiiimh
lDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMuuumhlz76GWCQIYYZYZQxxplg
kimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZf/AmDhaR8=
           "], CompressedData["
1:eJwd13c8V98bAHCUPUJGZkgoIiMzXSNKocy+lYxKZVRERmT7fOwtJJEZ2Xuf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           "]}, {Automatic}]}, $CellContext`odeSys2 = {
        Derivative[
          1][$CellContext`fK2][$CellContext`r] == \
($CellContext`gA[$CellContext`r] ((-2) $CellContext`fK2[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
               3 $CellContext`\[Beta][1] + 
               4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
               3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
               1] + 4 $CellContext`\[Beta][2] + 
              3 $CellContext`\[Beta][
                3])))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
           2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])), 
         Derivative[
          1][$CellContext`gA][$CellContext`r] == \
($CellContext`gA[$CellContext`r] (
            1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
              2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
               3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
              3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
              2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                
                2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(2 $CellContext`r), 
         Derivative[
          1][$CellContext`fA][$CellContext`r] == ($CellContext`r \
$CellContext`fA[$CellContext`r]^3 (
            1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]))/$CellContext`fA[$CellContext`r] - (
             1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
             2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
              3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                   2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
              4])/$CellContext`r^2))/2, 
         Derivative[
          1][$CellContext`\[Rho]0][$CellContext`r] == (((-2) \
(-$CellContext`fA[$CellContext`r] + $CellContext`gA[$CellContext`r]) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
              2]))/($CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + (
             3 $CellContext`k$g $CellContext`r^3 \
$CellContext`fA[$CellContext`r]^4 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3])^2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) (
              2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                   3])) + $CellContext`r^2 (
                2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                    2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                    2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                    2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (6 $CellContext`gA[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                    2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                    2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                    2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))))/(
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`r^3 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
               2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
             2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) - $CellContext`fA[$CellContext`r] ($CellContext`K2const^2 + 
              2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                 2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
             2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                  3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
               2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] - (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))) (
             1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]))/$CellContext`fA[$CellContext`r] - (
              1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
              2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
               3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                 
                 2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3])) - $CellContext`k$f $CellContext`r^2 \
$CellContext`\[Beta][4])/$CellContext`r^2) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`k$f $CellContext`r^3 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]))/$CellContext`fA[$CellContext`r] - (
              1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
              2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
               3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                 2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3])) - $CellContext`k$f $CellContext`r^2 \
$CellContext`\[Beta][
               4])/$CellContext`r^2) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                 4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`\[Beta][3]) + 
               2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][2] - 
                 2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
             2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                4]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                 4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][2] + 
                2 $CellContext`\[Beta][3] + $CellContext`\[Beta][4]))) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))))/(
           2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2) - (
            2 $CellContext`r $CellContext`gA[$CellContext`r]^2 \
($CellContext`fA[$CellContext`r] $CellContext`fK2[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
             2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) - $CellContext`fA[$CellContext`r] ($CellContext`K2const^2 + 
              2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                 2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
             2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                  3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
               2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] - (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) (
             1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
               3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
               2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`k$f $CellContext`r $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
             3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                 4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`\[Beta][3]) + 
               2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][2] - 
                 2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
             2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                4]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                 4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][2] + 
                2 $CellContext`\[Beta][3] + $CellContext`\[Beta][4]))) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) (
             1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
               3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
               2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`k$g $CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2))))) ((-4) (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
             2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`\[Beta][0] + 
               2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                2] + $CellContext`\[Rho]0[$CellContext`r])) (
             1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
               3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
               2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
           2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2) - \
($CellContext`k$g $CellContext`r^3 $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]))/$CellContext`fA[$CellContext`r] - (
              1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
              2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
               3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                 2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3])) - $CellContext`k$f $CellContext`r^2 \
$CellContext`\[Beta][4])/$CellContext`r^2) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2))))) ((-6) $CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
               2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][0] + 
                 2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                  2] + $CellContext`\[Rho]0[$CellContext`r]))))/(
            
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`k$g $CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) (
             1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
               3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
               2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])) ((-6) $CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
               2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][0] + 
                 2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                  2] + $CellContext`\[Rho]0[$CellContext`r]))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - (
            2 (2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) ((
               3 $CellContext`r $CellContext`fA[$CellContext`r]^5 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                 1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                 2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                  3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
              2 + $CellContext`r $CellContext`fA[$CellContext`r]^4 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][3]) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r + (
               3 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][3]) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
              2 $CellContext`r)))/($CellContext`fA[$CellContext`r] (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2) - \
($CellContext`k$f $CellContext`r^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
             3]) (2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2))))) (($CellContext`r $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                  4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) (
                1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                 1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                 2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                  3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/2 - 
             2 $CellContext`r $CellContext`fA[$CellContext`r]^4 \
((-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][2] - 
                2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                4]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                 4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][2] + 
                2 $CellContext`\[Beta][3] + $CellContext`\[Beta][4])) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                  4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(2 $CellContext`r)))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - (
            2 $CellContext`r (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) (
             2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
               2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                   1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                   2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
               2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                    3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                   4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
               2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                  4]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][2] + 
                  2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                   4]))) + $CellContext`k$g $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][0] + 
                   2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))/($\
CellContext`fA[$CellContext`r] (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2) + \
($CellContext`k$g $CellContext`r^3 $CellContext`fA[$CellContext`r]^4 \
$CellContext`gA[$CellContext`r]^2 ((-4) (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
              2 (-$CellContext`\[Beta][0] - 
               2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
               2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3])) (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
            2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + (
             2 $CellContext`r^3 $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                  4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                   3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                   2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$f $CellContext`r^3 $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) (
              6 $CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][4]))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + (
             2 (-$CellContext`fA[$CellContext`r] + \
$CellContext`gA[$CellContext`r]) (-$CellContext`\[Beta][
                2] - $CellContext`\[Beta][3]) (
              2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                   3])) + $CellContext`r^2 (
                2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                    2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                    2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                    2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (6 $CellContext`gA[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                    2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                    2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                    2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2))))))/($CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + (
             2 $CellContext`r (
              2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                  2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                  2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                  2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (6 $CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                  2 (-$CellContext`\[Beta][0] - 
                   2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2)))))/($CellContext`fA[$CellContext`r] (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + \
($CellContext`k$g $CellContext`r^3 $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                2 (-$CellContext`\[Beta][0] - 
                 2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
              2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) ($CellContext`\[Beta][0] + 
                  2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                   2] + $CellContext`\[Rho]0[$CellContext`r]/2))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$g $CellContext`r $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 ((-4) (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
              2 (-$CellContext`\[Beta][0] - 
               2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
               2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3])) (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + \
($CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                  4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                   3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                   2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))) (
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$f $CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              6 $CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][4]))) (
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$g $CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                2 (-$CellContext`\[Beta][0] - 
                 2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
              2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) ($CellContext`\[Beta][0] + 
                  2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                   2] + $CellContext`\[Rho]0[$CellContext`r]/2))) (
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + (
             2 $CellContext`k$g $CellContext`r \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^3 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) ((-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
              2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) ($CellContext`\[Beta][0] + 
                2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                 2] + $CellContext`\[Rho]0[$CellContext`r]/2)) (
              
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$f $CellContext`r^2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) (($CellContext`r $CellContext`fA[$CellContext`r]^3 \
((-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][4])) (
                 1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                  1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                  2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                   3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
               2 + (3 $CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                   1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + (
             2 ($CellContext`r $CellContext`fA[$CellContext`r]^4 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] - 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                 1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                 2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                  3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + (
                3 $CellContext`r $CellContext`fA[$CellContext`r]^5 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][3]) (
                 1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                  1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                  2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                   3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
               2 + (3 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
               2 $CellContext`r) + ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][3]) (
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r))/($CellContext`fA[$\
CellContext`r] (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) - (
            2 $CellContext`r^2 $CellContext`gA[$CellContext`r]^2 (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) ((
               2 $CellContext`fK2[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + (
               2 $CellContext`fK2[$CellContext`r] \
$CellContext`gA[$CellContext`r] $CellContext`\[Beta][
                2] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + (
               2 (-$CellContext`K2const + $CellContext`fK2[$CellContext`r]) \
$CellContext`gA[$CellContext`r] $CellContext`\[Beta][
                2] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + (
               2 $CellContext`K2const $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) + ($CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))) ((-3) $CellContext`fK2[$CellContext`r] + (
                  2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) + ($CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))) ($CellContext`fK2[$CellContext`r] ((-2) \
$CellContext`\[Beta][2] - 
                  3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                2 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] - (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) + ($CellContext`r $CellContext`fA[$CellContext`r]^3 \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                 1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                 2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                  3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
              2 + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) - ($CellContext`r \
$CellContext`fA[$CellContext`r]^3 ($CellContext`K2const^2 + 
               2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
             2 + $CellContext`r $CellContext`fA[$CellContext`r]^4 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                 2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + 
             2 $CellContext`K2const $CellContext`r \
$CellContext`fA[$CellContext`r]^4 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                  3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + $CellContext`r \
$CellContext`fA[$CellContext`r]^4 $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
               2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] - (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
              2 $CellContext`r) + ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r - \
($CellContext`fA[$CellContext`r] ($CellContext`K2const^2 + 
               2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
               1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                 3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                 2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                   1] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Beta][
                   2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
             2 $CellContext`r) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((((-2) $CellContext`\[Beta][2] - 
                  3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3])) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + 
               2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3])))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + ($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                  2 ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                   2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                   2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (((-3) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + 
               2 (-($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                  2 ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                    2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                    2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) + 
             2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-(($CellContext`\[Beta][
                   3] ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                  2 ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                    2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                    2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 + (
             2 $CellContext`r^2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 ((
                  2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                 2 $CellContext`K2const (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))) + ($CellContext`r $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) (
                 1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                  1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                  2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                   3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
               2 + ($CellContext`gA[$CellContext`r]^2 (
                 2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                 2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                   4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])) (
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r + \
($CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
(-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) (
                 
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
               2 $CellContext`r) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   
                   3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3])))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + 
                  2 (-($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                    2 ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                    2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                    2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) + 
                2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-(((-$CellContext`\[Beta][2] - 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                    2 ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                    2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                    2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))))/((
            2 $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^3 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
             3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - (
           2 $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^3 \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
            2]) (-$CellContext`\[Beta][1] - 
            2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]))/(
          2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
               1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
               3])) + $CellContext`r^2 (
            2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
              2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) - $CellContext`fA[$CellContext`r] ($CellContext`K2const^2 + 
               2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                  2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
              2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                   3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                2 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] - (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                  4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
              2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                   1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                 2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                 4]) + (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                  4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][2] + 
                 2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                  4]))) + $CellContext`k$g $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) ((-6) $CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][0] + 
                  2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                   2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$g $CellContext`r^2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2)/(
           2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                3])) + $CellContext`r^2 (
             2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
               2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                   1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                   2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
               2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                    3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                   4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
               2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                  4]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][2] + 
                  2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                   4]))) + $CellContext`k$g $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][0] + 
                   2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))))}, 
       Attributes[Derivative] = {
        NHoldAll, ReadProtected}, $CellContext`odeSys = {
        Derivative[
          1][$CellContext`fK2][$CellContext`r] == \
($CellContext`gA[$CellContext`r] ((-2) $CellContext`fK2[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
               3 $CellContext`\[Beta][1] + 
               4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                
                3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
               3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
               1] + 4 $CellContext`\[Beta][2] + 
              3 $CellContext`\[Beta][
                3])))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
           2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])), 
         Derivative[
          1][$CellContext`gA][$CellContext`r] == \
($CellContext`gA[$CellContext`r] (
            1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
              2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
               3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
              3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
              2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(2 $CellContext`r), 
         Derivative[
          1][$CellContext`fA][$CellContext`r] == ($CellContext`r \
$CellContext`fA[$CellContext`r]^3 (
            1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]))/$CellContext`fA[$CellContext`r] - (
             1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
             2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
              3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                   2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
              4])/$CellContext`r^2))/2}}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`b$0$$ = 
    0, $CellContext`b$1$$ = -1, $CellContext`b$2$$ = 0.5, $CellContext`b$3$$ =
     2, $CellContext`b$4$$ = -5, $CellContext`ck$f$$ = 
    1, $CellContext`ck$g$$ = 1, $CellContext`fA$0$$ = 
    0.1, $CellContext`fK2$0$$ = 0.01, $CellContext`gA$0$$ = 
    1.0910894511799618`, $CellContext`gK2$0$$ = 0.01, $CellContext`r$0$$ = 
    1, $CellContext`r$max$$ = 3, $CellContext`\[Rho]0$0$$ = E^(-1), 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`r$0$$], 1, "\!\(\*SubscriptBox[\(r\), \(0\)]\)"}, 
      0.001, 2}, {{
       Hold[$CellContext`r$max$$], 3, "\!\(\*SubscriptBox[\(r\), \(max\)]\)"},
       2, 100}, {{
       Hold[$CellContext`\[Rho]0$0$$], E^(-1), 
       "\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)"}, 0, 100}, {{
       Hold[$CellContext`gK2$0$$], 0.01, 
       "\!\(\*SubscriptBox[\(K\), \(2\)]\)"}, -2, 2}, {{
       Hold[$CellContext`fK2$0$$], 0.01, 
       "\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)"}, -2, 2}, {{
       Hold[$CellContext`gA$0$$], 1.0910894511799618`, "A"}, -2, 2}, {{
       Hold[$CellContext`fA$0$$], 0.1, 
       "\!\(\*OverscriptBox[\(A\), \(~\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$0$$], 0, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(0\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$1$$], -1, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$2$$], 0.5, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$3$$], 2, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)"}, -2, 2}, {{
       Hold[$CellContext`b$4$$], -5, 
       "\!\(\*SubscriptBox[\(\[Beta]\), \(4\)]\)"}, -2, 2}, {{
       Hold[$CellContext`ck$g$$], 1, 
       "\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)"}, 0.001, 10}, {{
       Hold[$CellContext`ck$f$$], 1, 
       "\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)"}, 0.001, 10}}, 
    Typeset`size$$ = {705., {208., 215.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`r$0$132709$$ = 0, $CellContext`r$max$132710$$ = 
    0, $CellContext`\[Rho]0$0$132711$$ = 0, $CellContext`gK2$0$132712$$ = 
    0, $CellContext`fK2$0$132713$$ = 0, $CellContext`gA$0$132714$$ = 
    0, $CellContext`fA$0$132715$$ = 0, $CellContext`b$0$132716$$ = 
    0, $CellContext`b$1$132717$$ = 0, $CellContext`b$2$132718$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`b$0$$ = 
        0, $CellContext`b$1$$ = -1, $CellContext`b$2$$ = 
        0.5, $CellContext`b$3$$ = 
        2, $CellContext`b$4$$ = -5, $CellContext`ck$f$$ = 
        1, $CellContext`ck$g$$ = 1, $CellContext`fA$0$$ = 
        0.1, $CellContext`fK2$0$$ = 0.01, $CellContext`gA$0$$ = 
        1.0910894511799618`, $CellContext`gK2$0$$ = 0.01, $CellContext`r$0$$ = 
        1, $CellContext`r$max$$ = 3, $CellContext`\[Rho]0$0$$ = E^(-1)}, 
      "ControllerVariables" :> {
        Hold[$CellContext`r$0$$, $CellContext`r$0$132709$$, 0], 
        Hold[$CellContext`r$max$$, $CellContext`r$max$132710$$, 0], 
        Hold[$CellContext`\[Rho]0$0$$, $CellContext`\[Rho]0$0$132711$$, 0], 
        Hold[$CellContext`gK2$0$$, $CellContext`gK2$0$132712$$, 0], 
        Hold[$CellContext`fK2$0$$, $CellContext`fK2$0$132713$$, 0], 
        Hold[$CellContext`gA$0$$, $CellContext`gA$0$132714$$, 0], 
        Hold[$CellContext`fA$0$$, $CellContext`fA$0$132715$$, 0], 
        Hold[$CellContext`b$0$$, $CellContext`b$0$132716$$, 0], 
        Hold[$CellContext`b$1$$, $CellContext`b$1$132717$$, 0], 
        Hold[$CellContext`b$2$$, $CellContext`b$2$132718$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Block[{$CellContext`\[Rho]0}, If[
          Not[$CellContext`$impose$dtpzero], $CellContext`\[Rho]0[
            Pattern[$CellContext`r, 
             Blank[]]] := Exp[-$CellContext`r] 0]; $CellContext`ode$sol = 
         Quiet[
           NDSolveValue[
            Join[
             ReplaceAll[
              
              If[$CellContext`$impose$dtpzero, $CellContext`odeSys2, \
$CellContext`odeSys], {$CellContext`K2const -> $CellContext`gK2$0$$, \
$CellContext`k$g -> $CellContext`ck$g$$, $CellContext`k$f -> \
$CellContext`ck$f$$, $CellContext`\[Beta][
                0] -> $CellContext`b$0$$, $CellContext`\[Beta][
                1] -> $CellContext`b$1$$, $CellContext`\[Beta][
                2] -> $CellContext`b$2$$, $CellContext`\[Beta][
                3] -> $CellContext`b$3$$, $CellContext`\[Beta][
                4] -> $CellContext`b$4$$}], \
{$CellContext`fK2[$CellContext`r$0$$] == $CellContext`fK2$0$$, \
$CellContext`gA[$CellContext`r$0$$] == $CellContext`gA$0$$, \
$CellContext`fA[$CellContext`r$0$$] == $CellContext`fA$0$$, 
              Apply[Sequence, 
               
               If[$CellContext`$impose$dtpzero, \
{$CellContext`\[Rho]0[$CellContext`r$0$$] == $CellContext`\[Rho]0$0$$}, \
{}]]}], {$CellContext`gA, $CellContext`fA, $CellContext`fK2, 
             Apply[Sequence, 
              
              If[$CellContext`$impose$dtpzero, {$CellContext`\[Rho]0}, {}]]}, \
{$CellContext`r, 0, $CellContext`r$max$$}]]; Plot[
          Evaluate[
           Join[
            Map[#[$CellContext`r]& , $CellContext`ode$sol], 
            If[$CellContext`$impose$dtpzero, {}, {
              $CellContext`\[Rho]0[$CellContext`r]}]]], 
          Evaluate[{$CellContext`r, 
            Apply[Sequence, 
             Part[
              Part[
               Part[$CellContext`ode$sol, 1], 1], 1]]}], PlotTheme -> 
          "Scientific", ImageSize -> 500, PlotLegends -> 
          Map[Style[#, Black, 16]& , {
            "A", "\!\(\*OverscriptBox[\(A\), \(~\)]\)", 
             "\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)", 
             "\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)"}], FrameLabel -> {
            Style[$CellContext`r, Black, 16]}]], 
      "Specifications" :> {{{$CellContext`r$0$$, 1, 
          "\!\(\*SubscriptBox[\(r\), \(0\)]\)"}, 0.001, 
         2}, {{$CellContext`r$max$$, 3, 
          "\!\(\*SubscriptBox[\(r\), \(max\)]\)"}, 2, 
         100}, {{$CellContext`\[Rho]0$0$$, E^(-1), 
          "\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)"}, 0, 
         100}, {{$CellContext`gK2$0$$, 0.01, 
          "\!\(\*SubscriptBox[\(K\), \(2\)]\)"}, -2, 
         2}, {{$CellContext`fK2$0$$, 0.01, 
          "\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)"}, -2, 
         2}, {{$CellContext`gA$0$$, 1.0910894511799618`, "A"}, -2, 
         2}, {{$CellContext`fA$0$$, 0.1, 
          "\!\(\*OverscriptBox[\(A\), \(~\)]\)"}, -2, 
         2}, {{$CellContext`b$0$$, 0, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(0\)]\)"}, -2, 
         2}, {{$CellContext`b$1$$, -1, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(1\)]\)"}, -2, 
         2}, {{$CellContext`b$2$$, 0.5, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(2\)]\)"}, -2, 
         2}, {{$CellContext`b$3$$, 2, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(3\)]\)"}, -2, 
         2}, {{$CellContext`b$4$$, -5, 
          "\!\(\*SubscriptBox[\(\[Beta]\), \(4\)]\)"}, -2, 
         2}, {{$CellContext`ck$g$$, 1, 
          "\!\(\*SubscriptBox[\(\[Kappa]\), \(g\)]\)"}, 0.001, 
         10}, {{$CellContext`ck$f$$, 1, 
          "\!\(\*SubscriptBox[\(\[Kappa]\), \(f\)]\)"}, 0.001, 10}}, 
      "Options" :> {AppearanceElements -> None}, "DefaultOptions" :> {}],
     ImageSizeCache->{1073., {236., 243.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`$impose$dtpzero = 
       False, $CellContext`ode$sol = {
         InterpolatingFunction[{{0.5437043713710581, 3.}}, {
          5, 7, 1, {733}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
           False}, CompressedData["
1:eJwt1wc4lV0cAHBEUXxIpWiSXRnRl4ZzI8rKDC0rsmdWFCUZoUFKRlG2aBlF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          "], {Developer`PackedArrayForm, CompressedData["
1:eJwl1Q1HKIAVBuDWWpIkSZKkJUmSJEmSJEmSJEmSJEnSkiRJkiRJkiRJkiRJ
kiRJkiRJkutKciVJkuRKkmRP2+FxfsB7Pv7d+J/K9n8EBAT8CQz4X/20IIIJ
IZQwwokgkiiiiSGWOOJJIJEkkkkhlTTSySCTLLLJIZc88imgkCKKKaGUMsqp
oJIqqqmhljrqaaCRJpppoZU22umgky666aGXPvoZYJAhhhlhlDHGmWCSKaaZ
YZY55llgkSWWWWGVNdbZYJMtttlhlz32OeCQI4454ZQzzrngkl/85oprbn7y
45Y77nngkSeeeeGVv7zxzgeffPFNgEEIJIhgQggljHAiiCSKaGKIJY54Ekgk
iWRSSCWNdDLIJItscsglj3wKKKSIYkoopYxyKqikimpqqKWOehpopIlmWmil
jZ8h76CTLrrpoZc++hlgkCGGGWGUMcaZYJIppplhljnmWWCRJZZZYZU11tlg
ky222WGXPfY54JAjjjnhlDPOueCSX/zmimtu+MMtd9zzwCNPPPPCK395450P
Pvnim5/lDySIYEIIJYxwIogkimhiiCWOeBJIJIlkUkgljXQyyCSLbHLIJY98
CiikiGJKKKWMciqopIpqaqiljnoaaKSJZlpopY12Ouiki2566KWPfgYYZIhh
RhhljHEmmGSKaWaYZY55FlhkiWVWWGWNdTbYZIttdthlj30OOOSIY0445Yxz
LrjkF7+54pqbwP/f71vuuOeBR5545oVX/vLGOx988sU3Af+UP0EEE0IoYYQT
QSRRRBNDLHHEk0AiSSSTQipppJNBJllkk0MueeRTQCFFFFNCKWWUU0ElVVRT
Qy111NNAI00000IrbbTTQSdddNNDL330M8AgQwwzwihjjDPBJFNMM8Msc8yz
wCJLLLPCKmuss8EmW2yzwy577HPAIUccc8IpZ5xzwSW/+M0V19zwh1vuuOeB
R5545oVX/vLGOx988sU3P48/kCCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU0
0skgkyyyySGXPPIpoJAiiimhlDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMu
uumhlz76GWCQIYYZYZQxxplgkimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZc9
9jngkCOOOeGUM8654JJf/OaKa274wy133PPAI08888Irf3njnQ8++eKbgH/J
nyCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU00skgkyyyySGXPPIpoJAiiimh
lDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMuuumhlz76GWCQIYYZYZQxxplg
kimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZf/AmDhaR8=
           "], CompressedData["
1:eJwNlHc0138Dxe1N9s6WmQgh4/v+mBnJjkRkZM8QFdmizMgIKUJ+Ziik72fY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           "]}, {Automatic}], 
         InterpolatingFunction[{{0.5437043713710581, 3.}}, {
          5, 7, 1, {733}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
           False}, CompressedData["
1:eJwt1wc4lV0cAHBEUXxIpWiSXRnRl4ZzI8rKDC0rsmdWFCUZoUFKRlG2aBlF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          "], {Developer`PackedArrayForm, CompressedData["
1:eJwl1Q1HKIAVBuDWWpIkSZKkJUmSJEmSJEmSJEmSJEnSkiRJkiRJkiRJkiRJ
kiRJkiRJkutKciVJkuRKkmRP2+FxfsB7Pv7d+J/K9n8EBAT8CQz4X/20IIIJ
IZQwwokgkiiiiSGWOOJJIJEkkkkhlTTSySCTLLLJIZc88imgkCKKKaGUMsqp
oJIqqqmhljrqaaCRJpppoZU22umgky666aGXPvoZYJAhhhlhlDHGmWCSKaaZ
YZY55llgkSWWWWGVNdbZYJMtttlhlz32OeCQI4454ZQzzrngkl/85oprbn7y
45Y77nngkSeeeeGVv7zxzgeffPFNgEEIJIhgQggljHAiiCSKaGKIJY54Ekgk
iWRSSCWNdDLIJItscsglj3wKKKSIYkoopYxyKqikimpqqKWOehpopIlmWmil
jZ8h76CTLrrpoZc++hlgkCGGGWGUMcaZYJIppplhljnmWWCRJZZZYZU11tlg
ky222WGXPfY54JAjjjnhlDPOueCSX/zmimtu+MMtd9zzwCNPPPPCK395450P
Pvnim5/lDySIYEIIJYxwIogkimhiiCWOeBJIJIlkUkgljXQyyCSLbHLIJY98
CiikiGJKKKWMciqopIpqaqiljnoaaKSJZlpopY12Ouiki2566KWPfgYYZIhh
RhhljHEmmGSKaWaYZY55FlhkiWVWWGWNdTbYZIttdthlj30OOOSIY0445Yxz
LrjkF7+54pqbwP/f71vuuOeBR5545oVX/vLGOx988sU3Af+UP0EEE0IoYYQT
QSRRRBNDLHHEk0AiSSSTQipppJNBJllkk0MueeRTQCFFFFNCKWWUU0ElVVRT
Qy111NNAI00000IrbbTTQSdddNNDL330M8AgQwwzwihjjDPBJFNMM8Msc8yz
wCJLLLPCKmuss8EmW2yzwy577HPAIUccc8IpZ5xzwSW/+M0V19zwh1vuuOeB
R5545oVX/vLGOx988sU3P48/kCCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU0
0skgkyyyySGXPPIpoJAiiimhlDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMu
uumhlz76GWCQIYYZYZQxxplgkimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZc9
9jngkCOOOeGUM8654JJf/OaKa274wy133PPAI08888Irf3njnQ8++eKbgH/J
nyCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU00skgkyyyySGXPPIpoJAiiimh
lDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMuuumhlz76GWCQIYYZYZQxxplg
kimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZf/AmDhaR8=
           "], CompressedData["
1:eJwd13c8lV8cB3BbMjKSZFQIZYQoI74nyQhJkp29KiOSSCSEkIyspIziRxn3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           "]}, {Automatic}], 
         InterpolatingFunction[{{0.5437043713710581, 3.}}, {
          5, 7, 1, {733}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
           False}, CompressedData["
1:eJwt1wc4lV0cAHBEUXxIpWiSXRnRl4ZzI8rKDC0rsmdWFCUZoUFKRlG2aBlF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          "], {Developer`PackedArrayForm, CompressedData["
1:eJwl1Q1HKIAVBuDWWpIkSZKkJUmSJEmSJEmSJEmSJEnSkiRJkiRJkiRJkiRJ
kiRJkiRJkutKciVJkuRKkmRP2+FxfsB7Pv7d+J/K9n8EBAT8CQz4X/20IIIJ
IZQwwokgkiiiiSGWOOJJIJEkkkkhlTTSySCTLLLJIZc88imgkCKKKaGUMsqp
oJIqqqmhljrqaaCRJpppoZU22umgky666aGXPvoZYJAhhhlhlDHGmWCSKaaZ
YZY55llgkSWWWWGVNdbZYJMtttlhlz32OeCQI4454ZQzzrngkl/85oprbn7y
45Y77nngkSeeeeGVv7zxzgeffPFNgEEIJIhgQggljHAiiCSKaGKIJY54Ekgk
iWRSSCWNdDLIJItscsglj3wKKKSIYkoopYxyKqikimpqqKWOehpopIlmWmil
jZ8h76CTLrrpoZc++hlgkCGGGWGUMcaZYJIppplhljnmWWCRJZZZYZU11tlg
ky222WGXPfY54JAjjjnhlDPOueCSX/zmimtu+MMtd9zzwCNPPPPCK395450P
Pvnim5/lDySIYEIIJYxwIogkimhiiCWOeBJIJIlkUkgljXQyyCSLbHLIJY98
CiikiGJKKKWMciqopIpqaqiljnoaaKSJZlpopY12Ouiki2566KWPfgYYZIhh
RhhljHEmmGSKaWaYZY55FlhkiWVWWGWNdTbYZIttdthlj30OOOSIY0445Yxz
LrjkF7+54pqbwP/f71vuuOeBR5545oVX/vLGOx988sU3Af+UP0EEE0IoYYQT
QSRRRBNDLHHEk0AiSSSTQipppJNBJllkk0MueeRTQCFFFFNCKWWUU0ElVVRT
Qy111NNAI00000IrbbTTQSdddNNDL330M8AgQwwzwihjjDPBJFNMM8Msc8yz
wCJLLLPCKmuss8EmW2yzwy577HPAIUccc8IpZ5xzwSW/+M0V19zwh1vuuOeB
R5545oVX/vLGOx988sU3P48/kCCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU0
0skgkyyyySGXPPIpoJAiiimhlDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMu
uumhlz76GWCQIYYZYZQxxplgkimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZc9
9jngkCOOOeGUM8654JJf/OaKa274wy133PPAI08888Irf3njnQ8++eKbgH/J
nyCCCSGUMMKJIJIoookhljjiSSCRJJJJIZU00skgkyyyySGXPPIpoJAiiimh
lDLKqaCSKqqpoZY66mmgkSaaaaGVNtrpoJMuuumhlz76GWCQIYYZYZQxxplg
kimmmWGWOeZZYJEllllhlTXW2WCTLbbZYZf/AmDhaR8=
           "], CompressedData["
1:eJwd13c8V98bAHCUPUJGZkgoIiMzXSNKocy+lYxKZVRERmT7fOwtJJEZ2Xuf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           "]}, {Automatic}]}, $CellContext`odeSys2 = {
        Derivative[
          1][$CellContext`fK2][$CellContext`r] == \
($CellContext`gA[$CellContext`r] ((-2) $CellContext`fK2[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
               3 $CellContext`\[Beta][1] + 
               4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
               3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
               1] + 4 $CellContext`\[Beta][2] + 
              3 $CellContext`\[Beta][
                3])))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
           2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])), 
         Derivative[
          1][$CellContext`gA][$CellContext`r] == \
($CellContext`gA[$CellContext`r] (
            1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
              2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
               3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
              3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
              2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                
                2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(2 $CellContext`r), 
         Derivative[
          1][$CellContext`fA][$CellContext`r] == ($CellContext`r \
$CellContext`fA[$CellContext`r]^3 (
            1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]))/$CellContext`fA[$CellContext`r] - (
             1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
             2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
              3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                   2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
              4])/$CellContext`r^2))/2, 
         Derivative[
          1][$CellContext`\[Rho]0][$CellContext`r] == (((-2) \
(-$CellContext`fA[$CellContext`r] + $CellContext`gA[$CellContext`r]) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
              2]))/($CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + (
             3 $CellContext`k$g $CellContext`r^3 \
$CellContext`fA[$CellContext`r]^4 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3])^2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) (
              2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                   3])) + $CellContext`r^2 (
                2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                    2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                    2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                    2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (6 $CellContext`gA[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                    2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                    2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                    2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))))/(
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`r^3 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
               2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
             2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) - $CellContext`fA[$CellContext`r] ($CellContext`K2const^2 + 
              2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                 2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
             2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                  3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
               2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] - (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))) (
             1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]))/$CellContext`fA[$CellContext`r] - (
              1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
              2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
               3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                 
                 2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3])) - $CellContext`k$f $CellContext`r^2 \
$CellContext`\[Beta][4])/$CellContext`r^2) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`k$f $CellContext`r^3 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]))/$CellContext`fA[$CellContext`r] - (
              1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
              2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
               3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                 2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3])) - $CellContext`k$f $CellContext`r^2 \
$CellContext`\[Beta][
               4])/$CellContext`r^2) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                 4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`\[Beta][3]) + 
               2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][2] - 
                 2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
             2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                4]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                 4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][2] + 
                2 $CellContext`\[Beta][3] + $CellContext`\[Beta][4]))) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))))/(
           2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2) - (
            2 $CellContext`r $CellContext`gA[$CellContext`r]^2 \
($CellContext`fA[$CellContext`r] $CellContext`fK2[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
             2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) - $CellContext`fA[$CellContext`r] ($CellContext`K2const^2 + 
              2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                 2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
             2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                  3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
               2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] - (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) (
             1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
               3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
               2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`k$f $CellContext`r $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
             3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                 4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`\[Beta][3]) + 
               2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][2] - 
                 2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
             2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                4]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                 4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][2] + 
                2 $CellContext`\[Beta][3] + $CellContext`\[Beta][4]))) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) (
             1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
               3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
               2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`k$g $CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2))))) ((-4) (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
             2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`\[Beta][0] + 
               2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                2] + $CellContext`\[Rho]0[$CellContext`r])) (
             1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
               3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
               2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
           2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2) - \
($CellContext`k$g $CellContext`r^3 $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]))/$CellContext`fA[$CellContext`r] - (
              1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
              2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
               3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                 2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3])) - $CellContext`k$f $CellContext`r^2 \
$CellContext`\[Beta][4])/$CellContext`r^2) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2))))) ((-6) $CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
               2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][0] + 
                 2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                  2] + $CellContext`\[Rho]0[$CellContext`r]))))/(
            
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - \
($CellContext`k$g $CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) (
             1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
               3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
               2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                 2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])) ((-6) $CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
               2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][0] + 
                 2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                  2] + $CellContext`\[Rho]0[$CellContext`r]))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - (
            2 (2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) ((
               3 $CellContext`r $CellContext`fA[$CellContext`r]^5 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                 1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                 2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                  3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
              2 + $CellContext`r $CellContext`fA[$CellContext`r]^4 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][3]) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r + (
               3 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][3]) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
              2 $CellContext`r)))/($CellContext`fA[$CellContext`r] (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2) - \
($CellContext`k$f $CellContext`r^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
             3]) (2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2))))) (($CellContext`r $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                  4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) (
                1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                 1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                 2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                  3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/2 - 
             2 $CellContext`r $CellContext`fA[$CellContext`r]^4 \
((-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][2] - 
                2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                4]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                 4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`\[Beta][2] + 
                2 $CellContext`\[Beta][3] + $CellContext`\[Beta][4])) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                  4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(2 $CellContext`r)))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - (
            2 $CellContext`r (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) (
             2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
               2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                   1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                   2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
               2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                    3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                   4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
               2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                  4]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][2] + 
                  2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                   4]))) + $CellContext`k$g $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][0] + 
                   2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))/($\
CellContext`fA[$CellContext`r] (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2) + \
($CellContext`k$g $CellContext`r^3 $CellContext`fA[$CellContext`r]^4 \
$CellContext`gA[$CellContext`r]^2 ((-4) (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
              2 (-$CellContext`\[Beta][0] - 
               2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
               2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3])) (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
            2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + (
             2 $CellContext`r^3 $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                  4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                   3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                   2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$f $CellContext`r^3 $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) (
              6 $CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][4]))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + (
             2 (-$CellContext`fA[$CellContext`r] + \
$CellContext`gA[$CellContext`r]) (-$CellContext`\[Beta][
                2] - $CellContext`\[Beta][3]) (
              2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                   3])) + $CellContext`r^2 (
                2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                    2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                    2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                    2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (6 $CellContext`gA[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                    2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                    2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                    2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2))))))/($CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][1] - 
             2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + (
             2 $CellContext`r (
              2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                  2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                  2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                  2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (6 $CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                  2 (-$CellContext`\[Beta][0] - 
                   2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/
                    2)))))/($CellContext`fA[$CellContext`r] (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + \
($CellContext`k$g $CellContext`r^3 $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))/$CellContext`fA[$CellContext`r] - (
               1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
               2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                2 (-$CellContext`\[Beta][0] - 
                 2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
              2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) ($CellContext`\[Beta][0] + 
                  2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                   2] + $CellContext`\[Rho]0[$CellContext`r]/2))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$g $CellContext`r $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 ((-4) (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
              2 (-$CellContext`\[Beta][0] - 
               2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
               2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3])) (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + \
($CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                  4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                   3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                   2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))) (
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$f $CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
              6 $CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][4]))) (
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$g $CellContext`r $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                2 (-$CellContext`\[Beta][0] - 
                 2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
              2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) ($CellContext`\[Beta][0] + 
                  2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                   2] + $CellContext`\[Rho]0[$CellContext`r]/2))) (
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 (2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) + (
             2 $CellContext`k$g $CellContext`r \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^3 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) ((-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
              2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) ($CellContext`\[Beta][0] + 
                2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                 2] + $CellContext`\[Rho]0[$CellContext`r]/2)) (
              
              1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                  2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$f $CellContext`r^2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) (($CellContext`r $CellContext`fA[$CellContext`r]^3 \
((-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][4])) (
                 1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                  1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                  2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                   3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
               2 + (3 $CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                   1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))) + (
             2 ($CellContext`r $CellContext`fA[$CellContext`r]^4 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] - 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                 1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                 2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                  3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + (
                3 $CellContext`r $CellContext`fA[$CellContext`r]^5 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][3]) (
                 1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                  1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                  2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                   3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
               2 + (3 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
               2 $CellContext`r) + ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][3]) (
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r))/($CellContext`fA[$\
CellContext`r] (
             2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                  1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                 
                 2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                  2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\
\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                   2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                 2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][2] + 
                    2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-4) \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                   2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))) - (
            2 $CellContext`r^2 $CellContext`gA[$CellContext`r]^2 (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))) ((
               2 $CellContext`fK2[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + (
               2 $CellContext`fK2[$CellContext`r] \
$CellContext`gA[$CellContext`r] $CellContext`\[Beta][
                2] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + (
               2 (-$CellContext`K2const + $CellContext`fK2[$CellContext`r]) \
$CellContext`gA[$CellContext`r] $CellContext`\[Beta][
                2] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + (
               2 $CellContext`K2const $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) + ($CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))) ((-3) $CellContext`fK2[$CellContext`r] + (
                  2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) + ($CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                   3 $CellContext`\[Beta][
                    3]))) ($CellContext`fK2[$CellContext`r] ((-2) \
$CellContext`\[Beta][2] - 
                  3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                2 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] - (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))))/($CellContext`r ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) + ($CellContext`r $CellContext`fA[$CellContext`r]^3 \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                 1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                 2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                  3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
              2 + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) - ($CellContext`r \
$CellContext`fA[$CellContext`r]^3 ($CellContext`K2const^2 + 
               2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
             2 + $CellContext`r $CellContext`fA[$CellContext`r]^4 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                 2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + 
             2 $CellContext`K2const $CellContext`r \
$CellContext`fA[$CellContext`r]^4 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                  3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + $CellContext`r \
$CellContext`fA[$CellContext`r]^4 $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
               2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] - (
                  2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) (
               1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))/$CellContext`fA[$CellContext`r] - (
                1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                 3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
              2 $CellContext`r) + ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
                1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                  3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                  2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r - \
($CellContext`fA[$CellContext`r] ($CellContext`K2const^2 + 
               2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
               1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                 3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
                 2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                   1] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Beta][
                   2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
             2 $CellContext`r) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((((-2) $CellContext`\[Beta][2] - 
                  3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3])) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + 
               2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3])))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + ($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                  2 ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                   2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                   2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3])))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                 1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (((-3) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + 
               2 (-($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                  2 ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                    2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                    2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) + 
             2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-(($CellContext`\[Beta][
                   3] ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                  2 ($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                    2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                    2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 + (
             2 $CellContext`r^2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 ((
                  2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                 2 $CellContext`K2const (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                  3]))) + ($CellContext`r $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) (
                 1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                  1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                  2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                   3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/
               2 + ($CellContext`gA[$CellContext`r]^2 (
                 2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                 2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                   4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])) (
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/$CellContext`r + \
($CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
(-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                 2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) (
                 
                 1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                   2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                   3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                   2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
               2 $CellContext`r) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                  2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   
                   3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3])))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) + 
                  2 (-($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                    2 ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                    2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                    2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])))) + 
                2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-(((-$CellContext`\[Beta][2] - 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`r $CellContext`fA[$CellContext`r] (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2))/(
                    2 ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) + (((-2) $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) - (
                    2 ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\
\[Beta][1] + 4 $CellContext`\[Beta][2] + 
                    3 $CellContext`\[Beta][
                    3]))))/($CellContext`r ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3])) + $CellContext`r $CellContext`fA[$CellContext`r]^3 \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][3]) (
                    1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))/$CellContext`fA[$CellContext`r] - (
                    1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
                    2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
                    3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] \
(2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\
\[Beta][4])/$CellContext`r^2) + ($CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])) (
                    1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
                    3 $CellContext`K2const^2 $CellContext`r^2 + \
$CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][0] + 
                    2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                    1] + $CellContext`k$g $CellContext`r^2 $CellContext`\
\[Beta][2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(
                    2 $CellContext`r))/($CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
                    2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))))/((
            2 $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^3 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
             3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) (
             2 ($CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] - 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][2]) - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                  3])) + $CellContext`r^2 (
               2 $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r] ($CellContext`gA[$CellContext`r]^2 (
                   2 $CellContext`K2const ($CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) - 
                   2 $CellContext`K2const $CellContext`fK2[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`K2const^2 (-$CellContext`\[Beta][1] - 
                    4 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] (-($CellContext`K2const^2 (
                    3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3]) - 
                    2 $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3])) + $CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                   2 $CellContext`K2const (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-($CellContext`fK2[$CellContext`r] (-$CellContext`\
\[Beta][2] - 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]))) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (6 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   
                   3]) + $CellContext`fA[$CellContext`r] ((-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] + 
                    2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) - $CellContext`\[Beta][3]) - 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] + $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 - 
                   2 (-$CellContext`\[Beta][0] - 
                    2 $CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 $CellContext`gA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2] - $CellContext`\[Rho]0[$CellContext`r]/2) + 
                   2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]/2))))))/(
            2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                 1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                 3])) + $CellContext`r^2 (
              
              2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
                2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                 2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                    2 (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
                2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-($CellContext`fK2[$CellContext`r] \
$CellContext`\[Beta][3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                  2 (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                    4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                  2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                    2]) (-$CellContext`\[Beta][2] - 
                    2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
                2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][2] + 
                   2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                    4]))) + $CellContext`k$g \
$CellContext`fA[$CellContext`r]^2 $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + (-$CellContext`\[Beta][1] - 
                    2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                  2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) ($CellContext`\[Beta][0] + 
                    2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r])))))^2 - (
           2 $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^3 \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
            2]) (-$CellContext`\[Beta][1] - 
            2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]))/(
          2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
               1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
               3])) + $CellContext`r^2 (
            2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
              2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) - $CellContext`fA[$CellContext`r] ($CellContext`K2const^2 + 
               2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                  1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                  2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
              2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                   3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                   3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                2 (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`fK2[$CellContext`r] - (
                   2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                  4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                  2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
              2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                   1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                 2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                 4]) + (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                  4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`\[Beta][2] + 
                 2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                  4]))) + $CellContext`k$g $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
              3]) ((-6) $CellContext`fA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][0] + 
                  2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                   2] + $CellContext`\[Rho]0[$CellContext`r]))))) + \
($CellContext`k$g $CellContext`r^2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
              2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2)/(
           2 ($CellContext`fA[$CellContext`r]^3 \
$CellContext`gA[$CellContext`r]^2 ($CellContext`\[Beta][
                1] - $CellContext`\[Beta][3]) (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^3 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) (-$CellContext`\[Beta][1] + $CellContext`\[Beta][
                3])) + $CellContext`r^2 (
             2 $CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r]^2 ($CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r]^2 $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                 2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3]) + 
               2 $CellContext`fA[$CellContext`r] \
$CellContext`fK2[$CellContext`r] (-$CellContext`K2const + \
$CellContext`fK2[$CellContext`r]) $CellContext`gA[$CellContext`r] \
$CellContext`\[Beta][2] (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) - $CellContext`fA[$CellContext`r] \
($CellContext`K2const^2 + 
                2 $CellContext`K2const ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r])) $CellContext`gA[$CellContext`r] \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                3]) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][
                   1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ((-3) $CellContext`fK2[$CellContext`r] + (
                   2 (2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3]))) + 
               2 $CellContext`K2const $CellContext`fA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-($CellContext`fK2[$CellContext`r] $CellContext`\[Beta][
                    3]) + ((-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) (2 $CellContext`fA[$CellContext`r] \
($CellContext`K2const - $CellContext`fK2[$CellContext`r]) ($CellContext`\
\[Beta][2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))) + $CellContext`fA[$CellContext`r]^2 \
$CellContext`fK2[$CellContext`r] (-$CellContext`\[Beta][1] - 
                 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) ($CellContext`fK2[$CellContext`r] ((-2) $CellContext`\
\[Beta][2] - 3 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][3])) + 
                 2 (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`fK2[$CellContext`r] - (
                    2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                    2] + $CellContext`\[Beta][
                    3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3])))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))) + $CellContext`k$f \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r]^2 \
(-$CellContext`\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ($CellContext`fA[$CellContext`r] \
$CellContext`gA[$CellContext`r] ((-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][1] + 2 $CellContext`\[Beta][2] + 
                   4 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                    3]) + $CellContext`\[Beta][3]) + 
                 2 (-$CellContext`\[Beta][1] - $CellContext`\[Beta][
                   2]) (-$CellContext`\[Beta][2] - 
                   2 $CellContext`\[Beta][3] - $CellContext`\[Beta][4])) - 
               2 $CellContext`fA[$CellContext`r]^2 ((-$CellContext`\[Beta][
                    1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][2] - 
                  2 $CellContext`\[Beta][3] - $CellContext`\[Beta][
                  4]) + (-$CellContext`\[Beta][1] - 
                  2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][3] + $CellContext`\[Beta][
                   4]) + (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                  3]) ($CellContext`\[Beta][2] + 
                  2 $CellContext`\[Beta][3] + $CellContext`\[Beta][
                   4]))) + $CellContext`k$g $CellContext`fA[$CellContext`r]^2 \
$CellContext`gA[$CellContext`r]^2 (-$CellContext`\[Beta][1] - 
               2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
               3]) ((-6) $CellContext`fA[$CellContext`r] (-$CellContext`\
\[Beta][1] - 2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                 3]) + $CellContext`gA[$CellContext`r] ((-4) (-$CellContext`\
\[Beta][1] - $CellContext`\[Beta][2]) (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) + (-$CellContext`\[Beta][1] - 
                   2 $CellContext`\[Beta][2] - $CellContext`\[Beta][3])^2 + 
                 2 (-$CellContext`\[Beta][2] - $CellContext`\[Beta][
                   3]) ($CellContext`\[Beta][0] + 
                   2 $CellContext`\[Beta][1] + $CellContext`\[Beta][
                    2] + $CellContext`\[Rho]0[$CellContext`r]))))))}, 
       Attributes[Derivative] = {
        NHoldAll, ReadProtected}, $CellContext`odeSys = {
        Derivative[
          1][$CellContext`fK2][$CellContext`r] == \
($CellContext`gA[$CellContext`r] ((-2) $CellContext`fK2[$CellContext`r] \
($CellContext`\[Beta][1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
               3 $CellContext`\[Beta][1] + 
               4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                
                3])) - $CellContext`fA[$CellContext`r] ((-2) \
$CellContext`K2const ($CellContext`\[Beta][2] + $CellContext`\[Beta][
               3]) + $CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
               1] + 4 $CellContext`\[Beta][2] + 
              3 $CellContext`\[Beta][
                3])))/($CellContext`r $CellContext`fA[$CellContext`r] \
($CellContext`\[Beta][1] + 
           2 $CellContext`\[Beta][2] + $CellContext`\[Beta][3])), 
         Derivative[
          1][$CellContext`gA][$CellContext`r] == \
($CellContext`gA[$CellContext`r] (
            1 + $CellContext`k$g $CellContext`r^2 \
$CellContext`fA[$CellContext`r] $CellContext`gA[$CellContext`r] \
($CellContext`\[Beta][1] + 
              2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
               3]) + $CellContext`gA[$CellContext`r]^2 (-1 - 
              3 $CellContext`K2const^2 $CellContext`r^2 + $CellContext`k$g \
$CellContext`r^2 $CellContext`\[Beta][0] + 
              2 $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                1] + $CellContext`k$g $CellContext`r^2 $CellContext`\[Beta][
                2] + $CellContext`k$g $CellContext`r^2 \
$CellContext`\[Rho]0[$CellContext`r])))/(2 $CellContext`r), 
         Derivative[
          1][$CellContext`fA][$CellContext`r] == ($CellContext`r \
$CellContext`fA[$CellContext`r]^3 (
            1/($CellContext`r^2 $CellContext`fA[$CellContext`r]^2) + \
($CellContext`k$f $CellContext`gA[$CellContext`r] ($CellContext`\[Beta][1] + 
               2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3]))/$CellContext`fA[$CellContext`r] - (
             1 + $CellContext`r^2 $CellContext`fK2[$CellContext`r]^2 - \
$CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][2] - 
             2 $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
              3] + (2 $CellContext`r^2 $CellContext`fK2[$CellContext`r] (
                2 $CellContext`fA[$CellContext`r] ($CellContext`K2const - \
$CellContext`fK2[$CellContext`r]) ($CellContext`\[Beta][
                   2] + $CellContext`\[Beta][
                   3]) + $CellContext`gA[$CellContext`r] ((-2) \
$CellContext`fK2[$CellContext`r] ($CellContext`\[Beta][
                    1] + $CellContext`\[Beta][2]) + $CellContext`K2const (
                    3 $CellContext`\[Beta][1] + 
                    4 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                    3]))))/($CellContext`fA[$CellContext`r] ($CellContext`\
\[Beta][1] + 2 $CellContext`\[Beta][2] + $CellContext`\[Beta][
                3])) - $CellContext`k$f $CellContext`r^2 $CellContext`\[Beta][
              4])/$CellContext`r^2))/2}}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r$0", "=", "1"}], ",", 
     RowBox[{"r$max", "=", "3"}], ",", "\[IndentingNewLine]", "k$g", ",", 
     "k$f", ",", "\[Beta]", ",", "\[IndentingNewLine]", "\[Rho]0", ",", 
     "K2const", ",", "fK2$0", ",", "\[Rho]0$0", ",", "gA$0", ",", "fA$0", ",",
      "gK2$0"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"Not", "@", "$impose$dtpzero"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Rho]0", "[", "r_", "]"}], ":=", 
        RowBox[{"id$\[Rho]0", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"id$\[Rho]0", "[", "r_", "]"}], ":=", 
        RowBox[{"Exp", "[", 
         RowBox[{"-", "r"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"k$g", "=", "1"}], ";", 
    RowBox[{"k$f", "=", "1"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Beta]", "[", "0", "]"}], "=", "0"}], ";", 
    RowBox[{
     RowBox[{"\[Beta]", "[", "1", "]"}], "=", 
     RowBox[{"-", "1"}]}], ";", 
    RowBox[{
     RowBox[{"\[Beta]", "[", "2", "]"}], "=", "0.5"}], ";", 
    RowBox[{
     RowBox[{"\[Beta]", "[", "3", "]"}], "=", "2"}], ";", 
    RowBox[{
     RowBox[{"\[Beta]", "[", "4", "]"}], "=", 
     RowBox[{"-", "5"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"id$modelParams", "=", 
     RowBox[{"{", 
      RowBox[{"k$g", ",", "k$f", ",", 
       RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
       RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
       RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"K2const", "=", "0.01"}], ";", "\[IndentingNewLine]", 
    RowBox[{"gK2$0", "=", "0.01"}], ";", "\[IndentingNewLine]", 
    RowBox[{"fK2$0", "=", "0.01"}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Rho]0$0", "=", 
     RowBox[{"Exp", "[", 
      RowBox[{"-", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"gA$0", "=", 
     FractionBox["1", 
      SqrtBox[
       RowBox[{"1", "-", "0.16"}]]]}], ";", "\[IndentingNewLine]", 
    RowBox[{"fA$0", "=", "0.1"}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"id$ode", "=", 
     RowBox[{"Quiet", "@", 
      RowBox[{"NDSolveValue", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{"$impose$dtpzero", ",", "odeSys2", ",", "odeSys"}], "]"}], 
          ",", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"fK2", "[", "r$0", "]"}], "\[Equal]", "fK2$0"}], ",", 
            RowBox[{
             RowBox[{"gA", "[", "r$0", "]"}], "\[Equal]", "gA$0"}], ",", 
            RowBox[{
             RowBox[{"fA", "[", "r$0", "]"}], "\[Equal]", "fA$0"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"If", "[", 
              RowBox[{"$impose$dtpzero", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Rho]0", "[", "r$0", "]"}], "\[Equal]", 
                 "\[Rho]0$0"}], "}"}], ",", 
               RowBox[{"{", "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
           "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"gA", ",", "fA", ",", "fK2", ",", 
          RowBox[{"Sequence", "@@", 
           RowBox[{"If", "[", 
            RowBox[{"$impose$dtpzero", ",", 
             RowBox[{"{", "\[Rho]0", "}"}], ",", 
             RowBox[{"{", "}"}]}], "]"}]}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"r", ",", "0", ",", "r$max"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"WorkingPrecision", "\[Rule]", "$workingPrecision"}]}], 
       "\[IndentingNewLine]", "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{"$impose$dtpzero", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"id$\[Rho]0", "[", "r_", "]"}], "=", 
        RowBox[{
         RowBox[{
         "id$ode", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
         "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"id$pfD", "[", "r_", "]"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{
          "id$ode", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
          "[", "r", "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"id$gA", "[", "r", "]"}], 
           SuperscriptBox[
            RowBox[{"id$gB", "[", "r", "]"}], "2"]}], ")"}]}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", "Else", " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"id$pfD", "[", "r_", "]"}], "=", 
        RowBox[{
         RowBox[{"id$\[Rho]0", "[", "r", "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"id$gA", "[", "r", "]"}], 
           SuperscriptBox[
            RowBox[{"id$gB", "[", "r", "]"}], "2"]}], ")"}]}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pfS", "[", "r_", "]"}], "=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$pf\[Tau]", "[", "r_", "]"}], "=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK1", "[", "r_", "]"}], "=", "K2const"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$gK2", "[", "r_", "]"}], "=", "K2const"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"id$gA", "=", 
     RowBox[{
     "id$ode", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"id$fA", "=", 
     RowBox[{
     "id$ode", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"id$fK2", "=", 
     RowBox[{
     "id$ode", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$fK1", "[", "r_", "]"}], "=", 
     RowBox[{
      RowBox[{"sol$fK1", "[", "r", "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"gA", "\[Rule]", "id$gA"}], ",", 
        RowBox[{"fA", "\[Rule]", "id$fA"}], ",", 
        RowBox[{"fK2", "\[Rule]", 
         RowBox[{
         "id$ode", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}]}],
        "}"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"r0", "=", 
     RowBox[{
      RowBox[{"id$gA", "\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
      "0.01"}]}], ";", 
    RowBox[{"r1", "=", 
     RowBox[{
      RowBox[{"id$gA", "\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
      "0.01"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", "r", "]"}], "&"}], "/@", "id$ode"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "r0", ",", "r1"}], "}"}], ",", 
      RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"#", ",", "Black", ",", "16"}], "]"}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{
          "\"\<A\>\"", ",", "\"\<\!\(\*OverscriptBox[\(A\), \(~\)]\)\>\"", 
           ",", "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)\
\>\"", ",", "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(0\)]\)\>\""}], "}"}]}], 
        ")"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"Row", "@", 
           RowBox[{"{", 
            RowBox[{"r", ",", "\"\< \[Element] \>\"", ",", 
             RowBox[{"{", 
              RowBox[{"r0", ",", "r1"}], "}"}]}], "}"}]}], ",", "Black", ",", 
          "14"}], "]"}], "}"}]}]}], "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Wratio", "[", 
    RowBox[{"t_", ",", "r_", ",", "\[Rho]0factor_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"eq$gW", "[", 
      RowBox[{"t", ",", "r"}], "]"}], "/", 
     RowBox[{"eq$fW", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       UnderscriptBox["pfD", "_"], "+", 
       UnderscriptBox["pf\[Tau]", "_"]}], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"\[Rho]0factor", 
        RowBox[{"(", 
         RowBox[{
          UnderscriptBox["pfD", "_"], "+", 
          UnderscriptBox["pf\[Tau]", "_"]}], ")"}]}], ")"}]}], "}"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"diagnostics", "=", 
   RowBox[{
    RowBox[{"Block", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
       "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "fA", ",", "fB", ",", 
        "fK1", ",", "fK2", ",", "pfD", ",", "pfS", ",", "pf\[Tau]", ",", 
        "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",", "g$JK2", ",", 
        "f$\[Rho]", ",", "f$JK1", ",", "f$JK2", ",", "\[IndentingNewLine]", 
        "Lt", ",", "p", ",", "q", ",", "R", ",", "P", ",", "\[Beta]", ",", 
        "k$g", ",", "k$f", ",", "\[IndentingNewLine]", "gAlp", ",", "fAlp", 
        ",", "K2const"}], "\[IndentingNewLine]", "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"P", "[", 
         RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
        RowBox[{"eq$esP", "[", 
         RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g$\[Rho]", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"eq$gV$\[Rho]", "[", 
          RowBox[{"t", ",", "r"}], "]"}], "+", 
         RowBox[{"gT$\[Rho]", "[", 
          RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g$JK1", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"eq$gV$JK1", "[", 
          RowBox[{"t", ",", "r"}], "]"}], "+", 
         RowBox[{"gT$JK1", "[", 
          RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g$JK2", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"eq$gV$JK2", "[", 
          RowBox[{"t", ",", "r"}], "]"}], "+", 
         RowBox[{"gT$JK2", "[", 
          RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f$\[Rho]", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"eq$fV$\[Rho]", "[", 
          RowBox[{"t", ",", "r"}], "]"}], "+", 
         RowBox[{"fT$\[Rho]", "[", 
          RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f$JK1", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"eq$fV$JK1", "[", 
          RowBox[{"t", ",", "r"}], "]"}], "+", 
         RowBox[{"fT$JK1", "[", 
          RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f$JK2", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"eq$fV$JK2", "[", 
          RowBox[{"t", ",", "r"}], "]"}], "+", 
         RowBox[{"fT$JK2", "[", 
          RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gA", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$gA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gB", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$gB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gK1", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$gK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gK2", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$gK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fA", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$fA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fB", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$fB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fK1", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fK2", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pfD", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$pfD", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pfS", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$pfS", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pf\[Tau]", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"id$fB", "[", "r", "]"}], "/", 
         RowBox[{"id$gB", "[", "r", "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"p", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{"id$p", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Lt", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"p", "[", 
            RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
         RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gAlp", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fAlp", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"gAlp", "[", 
           RowBox[{"t", ",", "r"}], "]"}]}], 
         RowBox[{"Wratio", "[", 
          RowBox[{"t", ",", "r", ",", "\[Rho]0factor"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"c$1", ",", "c$2", ",", "c$3", ",", "c$4", ",", "c$p"}], 
         "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             UnderscriptBox["eq$C1", "_"], ",", 
             UnderscriptBox["eq$C2", "_"], ",", 
             UnderscriptBox["eq$C3", "_"], ",", 
             UnderscriptBox["eq$C4", "_"], ",", 
             UnderscriptBox["eq$p$g", "_"]}], "}"}], "/.", 
           RowBox[{"{", 
            RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", 
          "Expand"}], "//", "Simplify"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"c$p$t", "=", 
        UnderscriptBox["evol$eq$p", "_"]}], ";", "\[IndentingNewLine]", 
       RowBox[{"c$fAlp", "=", 
        UnderscriptBox["fAlp", "_"]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "c$1", ",", "c$2", ",", "c$3", ",", "c$4", ",", "c$p", ",", "c$fAlp", 
         ",", "c$p$t"}], "}"}]}]}], "\[IndentingNewLine]", "]"}], "/.", 
    RowBox[{"Thread", "[", 
     RowBox[{"modelParamNames", "\[Rule]", "id$modelParams"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"diagnostics", "\[LeftDoubleBracket]", 
     RowBox[{"1", ";;", 
      RowBox[{"-", "3"}]}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "r0", ",", "r1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    SuperscriptBox["10", 
     RowBox[{"-", "4"}]]}], ",", 
   RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"#", ",", "Black", ",", "16"}], "]"}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["C", "1"], ",", 
        SubscriptBox["C", "2"], ",", 
        SubscriptBox["C", "3"], ",", 
        SubscriptBox["C", "4"], ",", 
        SubscriptBox["C", "p"]}], "}"}]}], ")"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Style", "[", 
      RowBox[{
       RowBox[{"Row", "@", 
        RowBox[{"{", 
         RowBox[{"r", ",", "\"\< \[Element]\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"r0", ",", "r1"}], "}"}]}], "}"}]}], ",", "Black", ",", 
       "14"}], "]"}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"c$fAlp", "/.", 
      RowBox[{"Thread", "[", 
       RowBox[{"modelParamNames", "\[Rule]", "id$modelParams"}], "]"}]}], "/.", 
     RowBox[{"\[Rho]0factor", "\[Rule]", "1"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "r0", ",", "r1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r0", "=", "1"}], ",", 
       RowBox[{"r1", "=", "1.1"}]}], "}"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"diagnostics", "\[LeftDoubleBracket]", 
         RowBox[{"-", "2"}], "\[RightDoubleBracket]"}], "/.", 
        RowBox[{"\[Rho]0factor", "\[Rule]", "fact"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "r0", ",", "r1"}], "}"}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"#", ",", "Black", ",", "16"}], "]"}], "&"}], "/@", 
          RowBox[{
          "{", "\"\<\!\(\*OverscriptBox[\(\[Alpha]\), \(~\)]\)\>\"", "}"}]}], 
         ")"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"Row", "@", 
            RowBox[{"{", 
             RowBox[{"r", ",", "\"\< \[Element] \>\"", ",", 
              RowBox[{"{", 
               RowBox[{"r0", ",", "r1"}], "}"}]}], "}"}]}], ",", "Black", ",",
            "14"}], "]"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fact", ",", "1"}], "}"}], ",", 
     RowBox[{"-", "10"}], ",", "10", ",", "0.01"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r0", "=", "1"}], ",", 
       RowBox[{"r1", "=", "1.1"}]}], "}"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"diagnostics", "\[LeftDoubleBracket]", 
         RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], "/.", 
        RowBox[{"\[Rho]0factor", "\[Rule]", "fact"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "r0", ",", "r1"}], "}"}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"#", ",", "Black", ",", "16"}], "]"}], "&"}], "/@", 
          RowBox[{
          "{", "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)p\>\"", 
           "}"}]}], ")"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"Row", "@", 
            RowBox[{"{", 
             RowBox[{"r", ",", "\"\< \[Element] \>\"", ",", 
              RowBox[{"{", 
               RowBox[{"r0", ",", "r1"}], "}"}]}], "}"}]}], ",", "Black", ",",
            "14"}], "]"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fact", ",", "1"}], "}"}], ",", 
     RowBox[{"-", "10"}], ",", "10", ",", "0.01"}], "}"}]}], "]"}]], "Input"],

Cell["The integration parameters for this case,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", "=", "0.02"}], ";", 
  RowBox[{"\[CapitalDelta]t", "=", "0.005"}], ";", 
  RowBox[{"mSkip", "=", "1"}], ";", " ", 
  RowBox[{"iMethod", "=", "\"\<RK3\>\""}], ";", 
  RowBox[{"$dissipation", "=", "0.03"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r0", "=", 
   RowBox[{
    RowBox[{"id$gA", "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
    "0.01"}]}], ";", 
  RowBox[{"r1", "=", 
   RowBox[{
    RowBox[{"id$gA", "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
    "0.01"}]}], ";", 
  RowBox[{"nLen", "=", "1000"}], ";"}]], "Input"],

Cell["The integration parameters for only a few steps,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"slicingMethod", "=", "\"\<const\>\""}], ";", 
  RowBox[{"smoothingMethod", "=", "1"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", "=", 
   RowBox[{"5", " ", 
    SuperscriptBox["10.", 
     RowBox[{"-", "5"}]]}]}], ";", 
  RowBox[{"\[CapitalDelta]t", "=", 
   SuperscriptBox["10.", 
    RowBox[{"-", "5"}]]}], ";", 
  RowBox[{"mSkip", "=", "1"}], ";", " ", 
  RowBox[{"iMethod", "=", "\"\<Euler\>\""}], ";", 
  RowBox[{"$dissipation", "=", "0.03"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r0", "=", "0.9"}], ";", 
  RowBox[{"r1", "=", "1.2"}], ";", 
  RowBox[{"nLen", "=", "3000"}], ";", 
  RowBox[{"nOut", "=", "3000"}], ";", 
  RowBox[{"nSkip", "=", "10"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Instantiate EoM and display the initial data", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"instantiateEoM", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Head", "@", "id$r$range"}], "===", "List"}], ",", 
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
         RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{
         RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
          RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], "-", 
         RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
          RowBox[{";;", 
           RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}]}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"Row", "@", 
       RowBox[{"{", 
        RowBox[{"\"\<Discretization of \!\(\*
StyleBox[\"r\",
FontSlant->\"Italic\"]\) : \>\"", ",", 
         RowBox[{"Length", "@", "id$r$range"}], ",", "\"\< points\>\""}], 
        "}"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"r", ",", "\"\<\[CapitalDelta]r\>\""}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "12", "]"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"12", ",", "Black"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"Scaled", "[", "0.6", "]"}]}]}], "\[IndentingNewLine]", "]"}]}],
   "]"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figIC", "=", 
   RowBox[{"displayInitialData", "[", 
    RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}], "\[RightDoubleBracket]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{"$exportPDFs", ",", 
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"\"\<figures/fig-\>\"", "<>", 
       RowBox[{"ToString", "@", "id$setup"}], "<>", "\"\<-t0.pdf\>\""}], ",", 
      "figIC"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutHideCode", "[", 
  RowBox[{"figIC", ",", "\"\<derivativesPlot\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Head", "@", "id$r$range"}], "===", "List"}], ",", 
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"Quiet", "@", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{
        "id$EoM$pEqs", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r0", ",", "r1"}], "}"}], ",", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "550"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)p\>\"", ",", "r"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Bottom"}], "}"}]}], "]"}]}], "]"}]}], "Input"]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1334, 1053},
WindowMargins->{{203, Automatic}, {24, Automatic}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 576, 25, 55, "Text"],
Cell[1137, 47, 68, 0, 38, "Text"],
Cell[1208, 49, 502, 18, 38, "Text"],
Cell[1713, 69, 568, 18, 137, "Text"],
Cell[CellGroupData[{
Cell[2306, 91, 36, 0, 42, "Subsubsection"],
Cell[2345, 93, 32, 0, 38, "Text"],
Cell[2380, 95, 277, 13, 38, "Text"],
Cell[2660, 110, 625, 22, 38, "Text"],
Cell[3288, 134, 137, 6, 38, "Text"],
Cell[3428, 142, 258, 12, 38, "Text"],
Cell[3689, 156, 174, 7, 38, "Text"],
Cell[3866, 165, 85, 2, 38, "Text"],
Cell[3954, 169, 99, 3, 50, "Input"],
Cell[4056, 174, 1029, 41, 66, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5122, 220, 39, 0, 42, "Subsubsection"],
Cell[5164, 222, 388, 10, 83, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5589, 237, 30, 0, 42, "Subsubsection"],
Cell[5622, 239, 645, 23, 83, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6304, 267, 55, 0, 42, "Subsubsection"],
Cell[6362, 269, 9376, 246, 1565, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15775, 520, 55, 0, 42, "Subsubsection"],
Cell[15833, 522, 439, 20, 40, "Text"],
Cell[16275, 544, 626, 19, 36, "Input"],
Cell[16904, 565, 205, 8, 38, "Text"],
Cell[17112, 575, 316, 10, 36, "Input"],
Cell[17431, 587, 246, 11, 38, "Text"],
Cell[17680, 600, 804, 24, 36, "Input"],
Cell[18487, 626, 409, 16, 40, "Text"],
Cell[18899, 644, 1646, 49, 129, "Input"],
Cell[20548, 695, 748, 28, 38, "Text"],
Cell[21299, 725, 112, 3, 36, "Input"],
Cell[21414, 730, 662, 21, 36, "Input"],
Cell[22079, 753, 263, 9, 38, "Text"],
Cell[22345, 764, 879, 28, 83, "Input"],
Cell[23227, 794, 56, 0, 38, "Text"],
Cell[23286, 796, 70, 1, 36, "Input"],
Cell[23359, 799, 46, 0, 38, "Text"],
Cell[23408, 801, 318, 10, 36, "Input"],
Cell[23729, 813, 57, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[23811, 817, 8851, 224, 1059, "Input"],
Cell[32665, 1043, 523900, 8217, 499, "Output"],
Cell[556568, 9262, 523900, 8217, 499, "Output"]
}, Open  ]],
Cell[1080483, 17482, 8414, 210, 1222, "Input"],
Cell[1088900, 17694, 673, 22, 39, "Input"],
Cell[1089576, 17718, 8660, 219, 1132, "Input"],
Cell[1098239, 17939, 377, 10, 36, "Input"],
Cell[1098619, 17951, 1609, 43, 129, "Input"],
Cell[1100231, 17996, 1614, 43, 129, "Input"],
Cell[1101848, 18041, 57, 0, 38, "Text"],
Cell[1101908, 18043, 261, 6, 36, "Input"],
Cell[1102172, 18051, 423, 12, 36, "Input"],
Cell[1102598, 18065, 64, 0, 38, "Text"],
Cell[1102665, 18067, 138, 3, 36, "Input"],
Cell[1102806, 18072, 376, 11, 39, "Input"],
Cell[1103185, 18085, 222, 6, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1103444, 18096, 69, 0, 42, "Subsubsection"],
Cell[1103516, 18098, 1645, 39, 175, "Input"],
Cell[1105164, 18139, 1476, 41, 129, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
