(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    546132,      13704]
NotebookOptionsPosition[    540463,      13553]
NotebookOutlinePosition[    544238,      13642]
CellTagsIndexPosition[    544154,      13637]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Bimetric equations in standard 3+1 form \nreduced to spherical symmetry ",
 StyleBox["(\[OpenCurlyDoubleQuote]lapse optimizer\[CloseCurlyDoubleQuote])",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell["Mikica Kocic", "Text"],

Cell["Created 2018-02-08, Last modified 2018-08-21", "Text"],

Cell["\<\
This notebook optimizes the lapse function ratio by introducing compound \
constants that replace beta parameters.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Requirements",
  FontWeight->"Bold"],
 ":"
}], "Text"],

Cell["\<\
Evaluate first the main notebook: \[OpenCurlyDoubleQuote]bimetric-ss-in-3+1 \
(cpp solver)\[CloseCurlyDoubleQuote] and then \
\[OpenCurlyDoubleQuote](packager)\[CloseCurlyDoubleQuote]\
\>", "Text"],

Cell[TextData[{
 StyleBox["Changelog",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.720329745571742*^9, 3.7203297456965427`*^9}, {
  3.7203297847600107`*^9, 3.7203297956508303`*^9}, {3.7205583336652308`*^9, 
  3.7205583361144347`*^9}, {3.7207192650993385`*^9, 3.7207192738041534`*^9}, {
  3.720804920912696*^9, 3.7208050456419153`*^9}, {3.7208050794959755`*^9, 
  3.720805104705619*^9}, {3.720805135145273*^9, 3.720805252292879*^9}}],

Cell["2018-08-21  Lapse optimizer", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "Optimize ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "g"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "f"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Section",
 PageBreakAbove->True,
 CellTags->"evolutionEquations"],

Cell["\<\
This functions recursively scans an expression for those subexpressions that \
only contain the beta parameters and R,\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scanForBetas", "[", "e_", "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"noRs", "=", 
       RowBox[{"Length", "@", 
        RowBox[{"Complement", "[", 
         RowBox[{
          RowBox[{"Variables", "@", "e"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
            RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
            RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
            RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
            RowBox[{"\[Beta]", "[", "4", "]"}], ",", 
            RowBox[{"R", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}], "}"}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"withRs", "=", 
       RowBox[{"Length", "@", 
        RowBox[{"Intersection", "[", 
         RowBox[{
          RowBox[{"Variables", "@", "e"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
            RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
            RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
            RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
            RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}]}], "]"}]}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"noRs", "\[Equal]", "0"}], "&&", 
       RowBox[{"withRs", ">", "0"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Sow", "@", 
        RowBox[{"CoefficientList", "[", 
         RowBox[{"e", ",", 
          UnderscriptBox["R", "_"]}], "]"}]}], ";", 
       RowBox[{"Framed", "[", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lookupList", "===", 
           RowBox[{"{", "}"}]}], ",", "e", ",", 
          RowBox[{"FullSimplify", "[", 
           RowBox[{"e", "/.", "lookupList"}], "]"}]}], "]"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"scanForBetas", "/@", "e"}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell["\<\
Create a lookup table of reoccuring coefficients of R that contain betas,\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lookupList", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"expanded$gW", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       UnderscriptBox["eq$gW", "_"], "/.", 
       RowBox[{"P", "\[Rule]", "eq$esP"}]}], "//", "introduce$KTrace"}], "//",
      "Expand"}], "//", "introduceDs"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lookup$gW", "=", 
   RowBox[{
    RowBox[{"Reap", "[", 
     RowBox[{"scanForBetas", "/@", "expanded$gW"}], "]"}], 
    "\[LeftDoubleBracket]", 
    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"expanded$fW", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       UnderscriptBox["eq$fW", "_"], "/.", 
       RowBox[{"P", "\[Rule]", "eq$esP"}]}], "//", "introduce$KTrace"}], "//",
      "Expand"}], "//", "introduceDs"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lookup$fW", "=", 
   RowBox[{
    RowBox[{"Reap", "[", 
     RowBox[{"scanForBetas", "/@", "expanded$fW"}], "]"}], 
    "\[LeftDoubleBracket]", 
    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ";"}]}], "Input"],

Cell["This is the list:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"lookupList", "=", 
   RowBox[{"Complement", "[", 
    RowBox[{
     RowBox[{"Union", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Union", "[", 
        RowBox[{"lookup$gW", ",", "lookup$fW"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
       RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
       RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lookupList", "=", 
   RowBox[{
    RowBox[{"Reverse", "@", 
     RowBox[{"Thread", "[", 
      RowBox[{"lookupList", "\[Rule]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Symbol", "[", 
          RowBox[{"\"\<bc$\>\"", "<>", 
           RowBox[{"ToString", "@", "i"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "@", "lookupList"}]}], "}"}]}], "]"}]}], "]"}]}],
     "//", "echoNice"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SubsuperscriptBox["\[Beta]", "3", "2"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Beta]", "2"], " ", 
       SubscriptBox["\[Beta]", "4"]}]}], "\[Rule]", "bc$56"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", 
         SubscriptBox["\[Beta]", "2"], " ", 
         SubscriptBox["\[Beta]", "3"]}], "+", 
        RowBox[{
         SubscriptBox["\[Beta]", "1"], " ", 
         SubscriptBox["\[Beta]", "4"]}]}], ")"}]}], "\[Rule]", "bc$55"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Beta]", "4"]}], "\[Rule]", "bc$54"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SubsuperscriptBox["\[Beta]", "2", "2"]}], "+", 
      RowBox[{"5", " ", 
       SubscriptBox["\[Beta]", "1"], " ", 
       SubscriptBox["\[Beta]", "3"]}]}], "\[Rule]", "bc$53"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"4", " ", 
       SubsuperscriptBox["\[Beta]", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Beta]", "1"], " ", 
       SubscriptBox["\[Beta]", "3"]}]}], "\[Rule]", "bc$52"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["\[Beta]", "2", "2"], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Beta]", "1"], " ", 
         SubscriptBox["\[Beta]", "3"]}]}], ")"}]}], "\[Rule]", "bc$51"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SubsuperscriptBox["\[Beta]", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Beta]", "1"], " ", 
       SubscriptBox["\[Beta]", "3"]}]}], "\[Rule]", "bc$50"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"6", " ", 
       SubsuperscriptBox["\[Beta]", "2", "2"]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", "1"], " ", 
       SubscriptBox["\[Beta]", "3"]}]}], "\[Rule]", "bc$49"}], ",", 
    RowBox[{
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["\[Beta]", "2", "2"], "+", 
        RowBox[{
         SubscriptBox["\[Beta]", "1"], " ", 
         SubscriptBox["\[Beta]", "3"]}]}], ")"}]}], "\[Rule]", "bc$48"}], ",", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["\[Beta]", "2", "2"], "+", 
        RowBox[{
         SubscriptBox["\[Beta]", "1"], " ", 
         SubscriptBox["\[Beta]", "3"]}]}], ")"}]}], "\[Rule]", "bc$47"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["\[Beta]", "2", "2"], "+", 
        RowBox[{
         SubscriptBox["\[Beta]", "1"], " ", 
         SubscriptBox["\[Beta]", "3"]}]}], ")"}]}], "\[Rule]", "bc$46"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SubsuperscriptBox["\[Beta]", "2", "2"]}], "-", 
      RowBox[{
       SubscriptBox["\[Beta]", "1"], " ", 
       SubscriptBox["\[Beta]", "3"]}]}], "\[Rule]", "bc$45"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SubsuperscriptBox["\[Beta]", "2", "2"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Beta]", "1"], " ", 
       SubscriptBox["\[Beta]", "3"]}]}], "\[Rule]", "bc$44"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", 
         SubscriptBox["\[Beta]", "1"], " ", 
         SubscriptBox["\[Beta]", "2"]}], "+", 
        RowBox[{
         SubscriptBox["\[Beta]", "0"], " ", 
         SubscriptBox["\[Beta]", "3"]}]}], ")"}]}], "\[Rule]", "bc$43"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      SubsuperscriptBox["\[Beta]", "3", "2"]}], "\[Rule]", "bc$42"}], ",", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "3", "2"], "\[Rule]", "bc$41"}], ",", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["\[Beta]", "3", "2"]}], "\[Rule]", "bc$40"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SubsuperscriptBox["\[Beta]", "3", "2"]}], "\[Rule]", "bc$39"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SubsuperscriptBox["\[Beta]", "3", "2"]}], "\[Rule]", "bc$38"}], ",", 
    RowBox[{
     RowBox[{"7", " ", 
      SubscriptBox["\[Beta]", "2"], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$37"}], ",", 
    RowBox[{
     RowBox[{"5", " ", 
      SubscriptBox["\[Beta]", "2"], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$36"}], ",", 
    RowBox[{
     RowBox[{"4", " ", 
      SubscriptBox["\[Beta]", "2"], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$35"}], ",", 
    RowBox[{
     RowBox[{"3", " ", 
      SubscriptBox["\[Beta]", "2"], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$34"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Beta]", "2"], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$33"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["\[Beta]", "2"], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$32"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      SubscriptBox["\[Beta]", "2"], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$31"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SubscriptBox["\[Beta]", "2"], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$30"}], ",", 
    RowBox[{
     RowBox[{"3", " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$29"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$28"}], ",", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$27"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$26"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$25"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "5"}], " ", 
      SubscriptBox["\[Beta]", "3"]}], "\[Rule]", "bc$24"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SubsuperscriptBox["\[Beta]", "1", "2"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Beta]", "0"], " ", 
       SubscriptBox["\[Beta]", "2"]}]}], "\[Rule]", "bc$23"}], ",", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "2", "2"], "\[Rule]", "bc$22"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SubsuperscriptBox["\[Beta]", "2", "2"]}], "\[Rule]", "bc$21"}], ",", 
    RowBox[{
     RowBox[{"8", " ", 
      SubscriptBox["\[Beta]", "1"], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$20"}], ",", 
    RowBox[{
     RowBox[{"5", " ", 
      SubscriptBox["\[Beta]", "1"], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$19"}], ",", 
    RowBox[{
     RowBox[{"4", " ", 
      SubscriptBox["\[Beta]", "1"], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$18"}], ",", 
    RowBox[{
     RowBox[{"3", " ", 
      SubscriptBox["\[Beta]", "1"], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$17"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Beta]", "1"], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$16"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["\[Beta]", "1"], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$15"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      SubscriptBox["\[Beta]", "1"], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$14"}], ",", 
    RowBox[{
     RowBox[{"6", " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$13"}], ",", 
    RowBox[{
     RowBox[{"4", " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$12"}], ",", 
    RowBox[{
     RowBox[{"3", " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$11"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$10"}], ",", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$9"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$8"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SubscriptBox["\[Beta]", "2"]}], "\[Rule]", "bc$7"}], ",", 
    RowBox[{
     RowBox[{"3", " ", 
      SubsuperscriptBox["\[Beta]", "1", "2"]}], "\[Rule]", "bc$6"}], ",", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "1", "2"], "\[Rule]", "bc$5"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SubsuperscriptBox["\[Beta]", "1", "2"]}], "\[Rule]", "bc$4"}], ",", 
    RowBox[{
     RowBox[{"3", " ", 
      SubscriptBox["\[Beta]", "1"]}], "\[Rule]", "bc$3"}], ",", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Beta]", "1"]}], "\[Rule]", "bc$2"}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Beta]", "0"]}], "\[Rule]", "bc$1"}]}], "}"}]}]], "Echo"]
}, Open  ]],

Cell["\<\
Now optimize gW and fW by replacing the coefficients for the polynomials in R \
using the lookup table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optimized$eq$gW", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"scanForBetas", "@", "expanded$gW"}], "//", "Simplify"}], "//",
       "echoNice"}], ")"}], "/.", 
    RowBox[{"Framed", "\[Rule]", "Identity"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox["1", "9"], " ", 
   StyleBox["\[Lambda]",
    StripOnInput->False,
    LineColor->RGBColor[0, 
      Rational[2, 3], 0],
    FrontFaceColor->RGBColor[0, 
      Rational[2, 3], 0],
    BackFaceColor->RGBColor[0, 
      Rational[2, 3], 0],
    GraphicsColor->RGBColor[0, 
      Rational[2, 3], 0],
    FontColor->RGBColor[0, 
      Rational[2, 3], 0]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "36"}], " ", 
      FrameBox[
       RowBox[{
        RowBox[{"bc$28", " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]]}], "+", 
        SubscriptBox["\[Beta]", "2"]}],
       StripOnInput->False], " ", 
      FrameBox[
       RowBox[{
        SubscriptBox["\[Beta]", "1"], "+", 
        RowBox[{
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{"bc$10", "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
       StripOnInput->False], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "3"], " ", 
      SuperscriptBox[
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
     RowBox[{"18", " ", 
      FrameBox[
       RowBox[{
        SubscriptBox["\[Beta]", "2"], "+", 
        RowBox[{
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         SubscriptBox["\[Beta]", "3"]}]}],
       StripOnInput->False], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        FrameBox["bc$2",
         StripOnInput->False], "+", 
        FrameBox[
         RowBox[{"bc$8", " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}],
         StripOnInput->False], "+", 
        FrameBox[
         RowBox[{"bc$27", " ", 
          SuperscriptBox[
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "2"]}],
         StripOnInput->False], "+", 
        RowBox[{"4", " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            SubscriptBox["\[Beta]", "2"]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "3"], " ", 
      SuperscriptBox[
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
     RowBox[{"18", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"], " ", 
      StyleBox[
       SubscriptBox["D", "B"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FrameBox[
          RowBox[{"bc$4", "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$14", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$50", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$33", "+", 
                    RowBox[{"bc$41", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}],
          StripOnInput->False], " ", 
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"2", " ", 
         FrameBox[
          RowBox[{"bc$17", "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$51", "+", 
              RowBox[{"bc$34", " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FrameBox[
          RowBox[{
           RowBox[{"bc$27", " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "2"]}], "+", 
           SubscriptBox["\[Beta]", "1"]}],
          StripOnInput->False], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
        RowBox[{"2", " ", 
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           FrameBox[
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["\[Beta]", "1"], "+", 
               RowBox[{
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], " ", 
                SubscriptBox["\[Beta]", "2"]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["\[Beta]", "2"], "+", 
               RowBox[{
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], " ", 
                SubscriptBox["\[Beta]", "3"]}]}], ")"}]}],
            StripOnInput->False], "+", 
           RowBox[{
            FrameBox[
             RowBox[{"bc$6", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$20", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$49", "+", 
                    RowBox[{"bc$33", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{
         FrameBox[
          RowBox[{"bc$5", "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$19", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$53", "+", 
                 RowBox[{"bc$34", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "3"], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FrameBox[
          RowBox[{"bc$2", "+", 
           RowBox[{
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "2"], " ", 
            SubscriptBox["\[Beta]", "3"]}]}],
          StripOnInput->False], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
        RowBox[{"4", " ", 
         FrameBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", "1"], "+", 
             RowBox[{
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              SubscriptBox["\[Beta]", "2"]}]}], ")"}], "2"],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "24"}], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "2"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            SubscriptBox["\[Beta]", "3"]}]}],
          StripOnInput->False], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         RowBox[{"(", 
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["K", "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], ")"}], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "+", 
        RowBox[{"9", " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "2"]}]}],
             StripOnInput->False], " ", 
            FrameBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Beta]", "1"], "+", 
                RowBox[{
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 RowBox[{"(", 
                  RowBox[{"bc$10", "+", 
                   RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}], ")"}], "2"],
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}], "+", 
           RowBox[{
            FrameBox[
             RowBox[{"bc$5", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$15", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$46", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{"bc$55", "-", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "bc$41"}], "+", 
                    RowBox[{"bc$54", " ", 
                    SubscriptBox["\[Beta]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
                   ")"}]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$10", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
         StyleBox[
          SubscriptBox["\[Kappa]", "f"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "+", 
        RowBox[{"9", " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          SubscriptBox["\[Kappa]", "g"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            FrameBox[
             RowBox[{"bc$1", "+", 
              RowBox[{"bc$3", " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}], "+", 
              RowBox[{"bc$27", " ", 
               SuperscriptBox[
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "3"]}]}],
             StripOnInput->False], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "2"]}]}],
             StripOnInput->False], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}], "+", 
           RowBox[{"2", " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}], ")"}], " ", 
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
              StyleBox[
               OverscriptBox["\[Tau]", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]], "+", 
              RowBox[{
               SuperscriptBox[
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["\[Tau]", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], "-", 
                 RowBox[{
                  StyleBox[
                   SuperscriptBox["v", "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["S", "^"], "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], ")"}]}], 
           "+", 
           RowBox[{
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{"bc$23", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"6", " ", 
                    SubscriptBox["\[Beta]", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Beta]", "1"]}], "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "2"]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["\[Beta]", "0"], "+", 
                    RowBox[{"3", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "1"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                    SubscriptBox["\[Beta]", "2"]}]}], ")"}], " ", 
                    SubscriptBox["\[Beta]", "3"]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "3"], " ", 
                    SubsuperscriptBox["\[Beta]", "3", "2"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               SuperscriptBox[
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"], " ", 
               StyleBox[
                OverscriptBox["A", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              RowBox[{
               FrameBox[
                RowBox[{
                 RowBox[{"bc$27", " ", 
                  SuperscriptBox[
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"]}], "+", 
                 SubscriptBox["\[Beta]", "1"]}],
                StripOnInput->False], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["D", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], "+", 
                 StyleBox[
                  OverscriptBox["\[Tau]", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], "-", 
                 RowBox[{
                  StyleBox[
                   SuperscriptBox["v", "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["S", "^"], "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FrameBox[
             RowBox[{"bc$3", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$13", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            SuperscriptBox[
             StyleBox["K",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"]}], "+", 
           RowBox[{
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{"bc$3", "+", 
                 RowBox[{"bc$24", " ", 
                  SuperscriptBox[
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"]}]}],
                StripOnInput->False], " ", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              RowBox[{"2", " ", 
               FrameBox[
                RowBox[{"bc$3", "+", 
                 RowBox[{"bc$12", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "-", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{"bc$3", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$11", "+", 
                    RowBox[{"bc$26", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              RowBox[{
               FrameBox[
                SubscriptBox["\[Beta]", "2"],
                StripOnInput->False], " ", 
               SuperscriptBox[
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "2"], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["K", "~"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]], "-", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            FrameBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Beta]", "1"], "+", 
                RowBox[{
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 RowBox[{"(", 
                  RowBox[{"bc$10", "+", 
                   RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}], ")"}], "2"],
             StripOnInput->False], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            SuperscriptBox[
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"], " ", 
            StyleBox[
             SubscriptBox["\[Kappa]", "g"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           RowBox[{
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{"bc$3", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$12", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox["A",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], " ", 
               SuperscriptBox[
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  StyleBox["K",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], "-", 
                  StyleBox[
                   SubscriptBox["K", "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}], ")"}], "2"]}], "+", 
              RowBox[{"9", " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "1"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$10", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["D", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], "+", 
                 StyleBox[
                  OverscriptBox["\[Tau]", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}], " ", 
               StyleBox[
                SubscriptBox["\[Kappa]", "g"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
           RowBox[{
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "2"]}]}],
             StripOnInput->False], " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{"bc$3", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$12", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              RowBox[{"2", " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "2"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "1"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "2"]}]}],
                StripOnInput->False], " ", 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              RowBox[{
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "2"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}],
                StripOnInput->False], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "-", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "-", 
              RowBox[{
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "1"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "2"]}]}],
                StripOnInput->False], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
           RowBox[{
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "1"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "2"]}]}],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SuperscriptBox[
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
              RowBox[{"2", " ", 
               FrameBox[
                RowBox[{"bc$10", "+", 
                 RowBox[{"bc$29", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "-", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 FrameBox["bc$11",
                  StripOnInput->False], "+", 
                 RowBox[{
                  FrameBox[
                   SubscriptBox["\[Beta]", "3"],
                   StripOnInput->False], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  StyleBox["K",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], "-", 
                  StyleBox[
                   SubscriptBox["K", "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}], ")"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               FrameBox[
                SubscriptBox["\[Beta]", "2"],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "-", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "-", 
              RowBox[{"3", " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "1"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "2"]}]}],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SuperscriptBox[
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "\[CapitalDelta]"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "r", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FrameBox[
             RowBox[{"bc$6", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$20", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$49", "+", 
                    RowBox[{"bc$33", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            FrameBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Beta]", "1"], "+", 
                RowBox[{
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 SubscriptBox["\[Beta]", "2"]}]}], ")"}], "2"],
             StripOnInput->False], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            FrameBox[
             RowBox[{"bc$17", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$47", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$37", "+", 
                    RowBox[{"bc$42", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}], "-", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{"bc$10", "+", 
                 RowBox[{"bc$29", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}],
                StripOnInput->False], " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "1"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$10", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "-", 
              RowBox[{"2", " ", 
               FrameBox[
                RowBox[{"bc$45", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Beta]", "2"]}], "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              RowBox[{
               FrameBox[
                SubscriptBox["\[Beta]", "2"],
                StripOnInput->False], " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "1"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$10", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FrameBox[
             RowBox[{"bc$17", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$51", "+", 
                 RowBox[{"bc$34", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "+", 
           RowBox[{
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "2"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}],
                StripOnInput->False], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", 
                  FrameBox[
                   RowBox[{
                    SubscriptBox["\[Beta]", "1"], "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{"bc$10", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                   StripOnInput->False], " ", 
                  TagBox[
                   RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["p",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]]}],
                   HoldForm]}], "+", 
                 RowBox[{
                  FrameBox[
                   RowBox[{"bc$3", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{"bc$12", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                   StripOnInput->False], " ", 
                  StyleBox["A",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], " ", 
                  StyleBox["K",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                FrameBox[
                 RowBox[{
                  SubscriptBox["\[Beta]", "2"], "+", 
                  RowBox[{
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                   SubscriptBox["\[Beta]", "3"]}]}],
                 StripOnInput->False], "2"], " ", 
               StyleBox["A",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}], "+", 
              RowBox[{
               FrameBox[
                RowBox[{"bc$6", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$20", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{"bc$49", "+", 
                    RowBox[{"bc$33", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox["A",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], " ", 
               SuperscriptBox[
                StyleBox["\[Lambda]",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  StyleBox[
                   OverscriptBox["K", "~"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}], "+", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}]}], ")"}]}]}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optimized$eq$fW", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"scanForBetas", "@", "expanded$fW"}], "//", "Simplify"}], "//",
       "echoNice"}], ")"}], "/.", 
    RowBox[{"Framed", "\[Rule]", "Identity"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox["1", "9"], " ", 
   StyleBox["\[Lambda]",
    StripOnInput->False,
    LineColor->RGBColor[0, 
      Rational[2, 3], 0],
    FrontFaceColor->RGBColor[0, 
      Rational[2, 3], 0],
    BackFaceColor->RGBColor[0, 
      Rational[2, 3], 0],
    GraphicsColor->RGBColor[0, 
      Rational[2, 3], 0],
    FontColor->RGBColor[0, 
      Rational[2, 3], 0]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "72"}], " ", 
      FrameBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", "2"], "+", 
          RowBox[{
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           SubscriptBox["\[Beta]", "3"]}]}], ")"}], "2"],
       StripOnInput->False], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "3"], " ", 
      SuperscriptBox[
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
     RowBox[{"36", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "B"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         FrameBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", "2"], "+", 
             RowBox[{
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              SubscriptBox["\[Beta]", "3"]}]}], ")"}], "2"],
          StripOnInput->False], " ", 
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "+", 
        RowBox[{
         FrameBox[
          SubscriptBox["\[Beta]", "2"],
          StripOnInput->False], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
     RowBox[{"18", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      SuperscriptBox[
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"], " ", 
      StyleBox[
       SubscriptBox["D", "B"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FrameBox[
          RowBox[{"bc$17", "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$53", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$36", "+", 
                 RowBox[{"bc$41", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           FrameBox[
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Beta]", "2"], "+", 
                RowBox[{
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 SubscriptBox["\[Beta]", "3"]}]}], ")"}], "2"]}],
            StripOnInput->False], "+", 
           RowBox[{
            FrameBox[
             SubscriptBox["\[Beta]", "3"],
             StripOnInput->False], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$10", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"]}]}], ")"}], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FrameBox[
          RowBox[{
           RowBox[{"bc$27", " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "2"]}], "+", 
           SubscriptBox["\[Beta]", "1"]}],
          StripOnInput->False], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
        RowBox[{"2", " ", 
         FrameBox[
          RowBox[{"bc$17", "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$51", "+", 
              RowBox[{"bc$34", " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        RowBox[{
         FrameBox[
          RowBox[{"bc$5", "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$16", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$50", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$31", "+", 
                    RowBox[{"bc$39", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "3"], " ", 
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], " ", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FrameBox[
          RowBox[{
           RowBox[{"bc$27", " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "2"]}], "+", 
           SubscriptBox["\[Beta]", "1"]}],
          StripOnInput->False], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
        RowBox[{
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            SubscriptBox["\[Beta]", "2"]}]}],
          StripOnInput->False], " ", 
         RowBox[{"(", 
          RowBox[{
           FrameBox[
            SubscriptBox["\[Beta]", "1"],
            StripOnInput->False], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                SubscriptBox["\[Beta]", "3"],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               FrameBox[
                SubscriptBox["\[Beta]", "2"],
                StripOnInput->False], " ", 
               RowBox[{"(", 
                RowBox[{"2", "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "r", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            FrameBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Beta]", "2"], "+", 
                RowBox[{
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 SubscriptBox["\[Beta]", "3"]}]}], ")"}], "2"],
             StripOnInput->False], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
           RowBox[{
            FrameBox[
             RowBox[{"bc$45", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubscriptBox["\[Beta]", "2"]}], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$10", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm]}], "+", 
           RowBox[{
            FrameBox[
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$10", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["K",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}], "+", 
           RowBox[{"2", " ", 
            FrameBox[
             SubscriptBox["\[Beta]", "2"],
             StripOnInput->False], " ", 
            FrameBox[
             SubscriptBox["\[Beta]", "3"],
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "3"], " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "+", 
           RowBox[{"2", " ", 
            FrameBox["bc$22",
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           RowBox[{"5", " ", 
            FrameBox[
             SubscriptBox["\[Beta]", "2"],
             StripOnInput->False], " ", 
            FrameBox[
             SubscriptBox["\[Beta]", "3"],
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "2"], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           RowBox[{"2", " ", 
            FrameBox["bc$41",
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "3"], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             SubscriptBox["K", "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           RowBox[{
            FrameBox[
             SubscriptBox["\[Beta]", "1"],
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              FrameBox[
               SubscriptBox["\[Beta]", "2"],
               StripOnInput->False], "+", 
              RowBox[{"2", " ", 
               FrameBox[
                SubscriptBox["\[Beta]", "3"],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            FrameBox[
             RowBox[{"bc$6", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$20", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$49", "+", 
                    RowBox[{"bc$33", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "\[CapitalDelta]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "-", 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FrameBox[
             RowBox[{"bc$17", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$51", "+", 
                 RowBox[{"bc$34", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
           RowBox[{
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$12", "+", 
                    RowBox[{"bc$29", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
                 SubscriptBox["\[Beta]", "1"]}],
                StripOnInput->False], " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "2"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}],
                StripOnInput->False], " ", 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              RowBox[{
               FrameBox[
                RowBox[{"bc$45", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Beta]", "2"]}], "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox["K",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "-", 
                 StyleBox[
                  SubscriptBox["K", "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "1"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "2"]}]}],
                StripOnInput->False], " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "2"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}],
                StripOnInput->False], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "24"}], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            SubscriptBox["\[Beta]", "2"]}]}],
          StripOnInput->False], " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         RowBox[{"(", 
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["K", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "\[CapitalDelta]"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], ")"}], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "3"], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"]}], "+", 
        RowBox[{"9", " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FrameBox[
             RowBox[{"bc$5", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$15", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$46", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{"bc$55", "-", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "bc$41"}], "+", 
                    RowBox[{"bc$54", " ", 
                    SubscriptBox["\[Beta]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
                   ")"}]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           RowBox[{"2", " ", 
            FrameBox[
             RowBox[{"bc$2", "+", 
              RowBox[{
               SuperscriptBox[
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "2"], " ", 
               RowBox[{"(", 
                RowBox[{"bc$29", "+", 
                 RowBox[{"bc$54", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
         StyleBox[
          SubscriptBox["\[Kappa]", "f"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "+", 
        RowBox[{"9", " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$10", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
             StripOnInput->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{"bc$23", "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"6", " ", 
                    SubscriptBox["\[Beta]", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Beta]", "1"]}], "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "2"]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["\[Beta]", "0"], "+", 
                    RowBox[{"3", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "1"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                    SubscriptBox["\[Beta]", "2"]}]}], ")"}], " ", 
                    SubscriptBox["\[Beta]", "3"]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "3"], " ", 
                    SubsuperscriptBox["\[Beta]", "3", "2"]}]}], ")"}]}]}],
                StripOnInput->False], " ", 
               StyleBox["A",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], " ", 
               SuperscriptBox[
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"]}], "+", 
              RowBox[{"2", " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "2"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}],
                StripOnInput->False], " ", 
               RowBox[{"(", 
                RowBox[{
                 StyleBox[
                  OverscriptBox["D", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]], "+", 
                 StyleBox[
                  OverscriptBox["\[Tau]", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]]}], ")"}]}]}], ")"}]}], 
           "+", 
           RowBox[{"6", " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            FrameBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Beta]", "1"], "+", 
                RowBox[{
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], " ", 
                 RowBox[{"(", 
                  RowBox[{"bc$10", "+", 
                   RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}], ")"}], "2"],
             StripOnInput->False], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox["\[Lambda]",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
         StyleBox[
          SubscriptBox["\[Kappa]", "g"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{"2", " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               StyleBox["K",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], "-", 
              SuperscriptBox[
               StyleBox[
                SubscriptBox["K", "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], "-", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["K", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "-", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 FrameBox[
                  SubscriptBox["\[Beta]", "1"],
                  StripOnInput->False], "+", 
                 RowBox[{
                  FrameBox[
                   SubscriptBox["\[Beta]", "2"],
                   StripOnInput->False], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}], " ", 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              RowBox[{"2", " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FrameBox[
                   RowBox[{"bc$10", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}],
                   StripOnInput->False], " ", 
                  StyleBox["K",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}], "+", 
                 RowBox[{
                  FrameBox[
                   RowBox[{
                    RowBox[{"bc$28", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}], "+", 
                    SubscriptBox["\[Beta]", "2"]}],
                   StripOnInput->False], " ", 
                  StyleBox[
                   SubscriptBox["K", "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 FrameBox[
                  SubscriptBox["\[Beta]", "1"],
                  StripOnInput->False], "+", 
                 RowBox[{
                  FrameBox[
                   SubscriptBox["\[Beta]", "2"],
                   StripOnInput->False], " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox["\[Lambda]",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                    FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], "2"]}]}], ")"}]}]}], ")"}], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         FrameBox[
          RowBox[{
           SubscriptBox["\[Beta]", "1"], "+", 
           RowBox[{
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{"bc$10", "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}],
          StripOnInput->False], " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["p",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]]}],
             HoldForm], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  StyleBox[
                   OverscriptBox["K", "~"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}], "+", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "\[CapitalDelta]"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], "2"], " ", 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FrameBox[
                RowBox[{
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  RowBox[{"(", 
                   RowBox[{"bc$10", "+", 
                    RowBox[{"bc$29", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
                 SubscriptBox["\[Beta]", "1"]}],
                StripOnInput->False], " ", 
               SuperscriptBox[
                StyleBox[
                 OverscriptBox["K", "~"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
              RowBox[{"2", " ", 
               StyleBox[
                OverscriptBox["K", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FrameBox[
                   RowBox[{
                    RowBox[{"bc$28", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}], "+", 
                    SubscriptBox["\[Beta]", "2"]}],
                   StripOnInput->False], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                 RowBox[{
                  FrameBox[
                   RowBox[{
                    RowBox[{"bc$9", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}], "+", 
                    SubscriptBox["\[Beta]", "1"]}],
                   StripOnInput->False], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
              RowBox[{
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "\[CapitalDelta]"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  FrameBox[
                   RowBox[{"bc$10", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}],
                   StripOnInput->False], " ", 
                  StyleBox["\[Lambda]",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                   FontColor->RGBColor[0, 
                    Rational[2, 3], 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], "+", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
                 RowBox[{
                  FrameBox[
                   RowBox[{
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{"bc$7", "+", 
                    RowBox[{"bc$25", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
                    SubscriptBox["\[Beta]", "1"]}],
                   StripOnInput->False], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "2"], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FrameBox[
             RowBox[{
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"bc$12", "+", 
                 RowBox[{"bc$29", " ", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
              SubscriptBox["\[Beta]", "1"]}],
             StripOnInput->False], " ", 
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "2"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "3"]}]}],
             StripOnInput->False], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            SuperscriptBox[
             StyleBox[
              OverscriptBox["A", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "2"], " ", 
            StyleBox[
             OverscriptBox["K", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox["K",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "-", 
              StyleBox[
               SubscriptBox["K", "\[CapitalDelta]"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "-", 
           RowBox[{
            FrameBox[
             RowBox[{
              SubscriptBox["\[Beta]", "1"], "+", 
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               SubscriptBox["\[Beta]", "2"]}]}],
             StripOnInput->False], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", 
               FrameBox[
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["\[Beta]", "1"], "+", 
                   RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{"bc$10", "+", 
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "3"]}]}], ")"}]}]}], ")"}], "2"],
                StripOnInput->False], " ", 
               SuperscriptBox[
                StyleBox["A",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"], " ", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]], " ", 
               StyleBox[
                SubscriptBox["\[Kappa]", "f"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              RowBox[{"2", " ", 
               FrameBox[
                RowBox[{
                 SubscriptBox["\[Beta]", "2"], "+", 
                 RowBox[{
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "3"]}]}],
                StripOnInput->False], " ", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               StyleBox[
                OverscriptBox["A", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  StyleBox["A",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], " ", 
                  SuperscriptBox[
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    OverscriptBox["K", "~"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], ")"}], "2"]}], "+", 
                 RowBox[{
                  StyleBox[
                   OverscriptBox["A", "~"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    StyleBox["K",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], "+", 
                    StyleBox[
                    SubscriptBox["K", "\[CapitalDelta]"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "\[CapitalDelta]"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}]}], ")"}]}]}]], "Echo"]
}, Open  ]],

Cell["\<\
We also need a dictionary to be used in C++. The following two lines should \
be put by hand into the constructor of \[OpenCurlyDoubleQuote]BimetricModel\
\[CloseCurlyDoubleQuote].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{
   RowBox[{"InsertLinebreaks", "[", 
    RowBox[{
     RowBox[{"\"\<    Real \>\"", "<>", 
      RowBox[{"StringReplace", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"StringRiffle", "[", 
          RowBox[{
           RowBox[{"ToString", "/@", 
            RowBox[{"Reverse", "@", 
             RowBox[{"lookupList", "\[LeftDoubleBracket]", 
              RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}]}], ",", 
           "\"\<, \>\""}], "]"}], "<>", "\"\<;\>\""}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<==\>\"", "\[Rule]", "\"\<=\>\""}], ",", 
          RowBox[{"\"\<$\>\"", "\[Rule]", "\"\<_\>\""}]}], "}"}]}], "]"}]}], 
     ",", "80"}], "]"}], ",", 
   RowBox[{"\"\<\\n\>\"", "\[Rule]", "\"\<\\n         \>\""}]}], 
  "]"}]], "Input"],

Cell[BoxData["\<\"    Real bc_1, bc_2, bc_3, bc_4, bc_5, bc_6, bc_7, bc_8, \
bc_9, bc_10, bc_11,\\n         bc_12, bc_13, bc_14, bc_15, bc_16, bc_17, \
bc_18, bc_19, bc_20, bc_21, bc_22,\\n         bc_23, bc_24, bc_25, bc_26, \
bc_27, bc_28, bc_29, bc_30, bc_31, bc_32, bc_33,\\n         bc_34, bc_35, \
bc_36, bc_37, bc_38, bc_39, bc_40, bc_41, bc_42, bc_43, bc_44,\\n         \
bc_45, bc_46, bc_47, bc_48, bc_49, bc_50, bc_51, bc_52, bc_53, bc_54, \
bc_55,\\n         bc_56;\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Reverse", "@", 
     RowBox[{"lookupList", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "\[RightDoubleBracket]"}]}], "/.", 
    RowBox[{"Rule", "\[Rule]", "Equal"}]}], "/.", 
   RowBox[{
    RowBox[{"\[Beta]", "[", "n_", "]"}], "\[RuleDelayed]", 
    RowBox[{"Symbol", "[", 
     RowBox[{"\"\<b$\>\"", "<>", 
      RowBox[{"ToString", "@", "n"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"StringReplace", "[", 
  RowBox[{
   RowBox[{"\"\<        \>\"", "<>", 
    RowBox[{"StringRiffle", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"StringReplace", "[", 
         RowBox[{
          RowBox[{"ToString", "@", 
           RowBox[{"CForm", "@", 
            RowBox[{"powerCppRules", "@", "#"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\<==\>\"", "\[Rule]", "\"\<=\>\""}], ",", 
            RowBox[{"\"\<$\>\"", "\[Rule]", "\"\<_\>\""}]}], "}"}]}], "]"}], 
        "&"}], "/@", "%"}], ",", "\"\<;\\n        \>\""}], "]"}], "<>", 
    "\"\<;\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"\"\<*\>\"", "\[Rule]", "\"\< * \>\""}]}], "]"}]}], "Input"],

Cell[BoxData["\<\"        bc_1 = 2 * b_0;\\n        bc_2 = -b_1;\\n        \
bc_3 = 3 * b_1;\\n        bc_4 = -3 * pow2(b_1);\\n        bc_5 = \
pow2(b_1);\\n        bc_6 = 3 * pow2(b_1);\\n        bc_7 = -4 * b_2;\\n      \
  bc_8 = -2 * b_2;\\n        bc_9 = -b_2;\\n        bc_10 = 2 * b_2;\\n       \
 bc_11 = 3 * b_2;\\n        bc_12 = 4 * b_2;\\n        bc_13 = 6 * b_2;\\n    \
    bc_14 = -6 * b_1 * b_2;\\n        bc_15 = -2 * b_1 * b_2;\\n        bc_16 \
= 2 * b_1 * b_2;\\n        bc_17 = 3 * b_1 * b_2;\\n        bc_18 = 4 * b_1 * \
b_2;\\n        bc_19 = 5 * b_1 * b_2;\\n        bc_20 = 8 * b_1 * b_2;\\n     \
   bc_21 = -4 * pow2(b_2);\\n        bc_22 = pow2(b_2);\\n        bc_23 = 2 * \
b_0 * b_2 + 3 * pow2(b_1);\\n        bc_24 = -5 * b_3;\\n        bc_25 = -3 * \
b_3;\\n        bc_26 = -2 * b_3;\\n        bc_27 = -b_3;\\n        bc_28 = 2 \
* b_3;\\n        bc_29 = 3 * b_3;\\n        bc_30 = -8 * b_2 * b_3;\\n        \
bc_31 = -6 * b_2 * b_3;\\n        bc_32 = -2 * b_2 * b_3;\\n        bc_33 = 2 \
* b_2 * b_3;\\n        bc_34 = 3 * b_2 * b_3;\\n        bc_35 = 4 * b_2 * \
b_3;\\n        bc_36 = 5 * b_2 * b_3;\\n        bc_37 = 7 * b_2 * b_3;\\n     \
   bc_38 = -4 * pow2(b_3);\\n        bc_39 = -3 * pow2(b_3);\\n        bc_40 \
= -pow2(b_3);\\n        bc_41 = pow2(b_3);\\n        bc_42 = 2 * \
pow2(b_3);\\n        bc_43 = 2 * (6 * b_1 * b_2 + b_0 * b_3);\\n        bc_44 \
= -2 * b_1 * b_3 - 2 * pow2(b_2);\\n        bc_45 = -(b_1 * b_3) + 2 * \
pow2(b_2);\\n        bc_46 = -6 * (b_1 * b_3 + pow2(b_2));\\n        bc_47 = \
4 * (b_1 * b_3 + pow2(b_2));\\n        bc_48 = 6 * (b_1 * b_3 + \
pow2(b_2));\\n        bc_49 = b_1 * b_3 + 6 * pow2(b_2);\\n        bc_50 = 2 \
* b_1 * b_3 - 4 * pow2(b_2);\\n        bc_51 = 2 * (2 * b_1 * b_3 + \
pow2(b_2));\\n        bc_52 = 2 * b_1 * b_3 + 4 * pow2(b_2);\\n        bc_53 \
= 5 * b_1 * b_3 + 2 * pow2(b_2);\\n        bc_54 = 2 * b_4;\\n        bc_55 = \
-2 * (6 * b_2 * b_3 + b_1 * b_4);\\n        bc_56 = -2 * b_2 * b_4 - 3 * \
pow2(b_3);\"\>"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Conditions for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", " ", "\[Equal]", " ", "0"}], TraditionalForm]]],
 " (we also assume ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", "\[Equal]", "1"}], TraditionalForm]]],
 ")"
}], "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["eq$p$g", "_"], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         UnderscriptBox["p", "_"], "\[Rule]", "0"}], ",", 
        RowBox[{
         UnderscriptBox["Lt", "_"], "\[Rule]", "1"}], ",", 
        RowBox[{
         UnderscriptBox["q", "_"], "\[Rule]", "0"}], ",", 
        RowBox[{"P", "\[Rule]", "eq$esP"}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Beta]", "[", 
        RowBox[{"n_", "?", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "\[NotEqual]", "1"}], "&"}], ")"}]}], "]"}], 
       "\[RuleDelayed]", "0"}], "}"}]}], "//", "Simplify"}], "//", 
   "echoNice"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox["B",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            StyleBox[
             SubscriptBox["K", "1"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           StyleBox[
            SubscriptBox["K", "2"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
        RowBox[{
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               SubscriptBox["K", "2"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm]}], "-", 
           StyleBox[
            SubscriptBox["K", "1"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "+", 
           StyleBox[
            SubscriptBox["K", "2"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"r", " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}]}], 
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SubscriptBox["\[Beta]", "1"]}]]}]}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["evol$eq$p", "_"], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         UnderscriptBox["p", "_"], "\[Rule]", "0"}], ",", 
        RowBox[{
         UnderscriptBox["Lt", "_"], "\[Rule]", "1"}], ",", 
        RowBox[{
         UnderscriptBox["q", "_"], "\[Rule]", "0"}], ",", 
        RowBox[{"P", "\[Rule]", "eq$esP"}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Beta]", "[", 
        RowBox[{"n_", "?", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "\[NotEqual]", "1"}], "&"}], ")"}]}], "]"}], 
       "\[RuleDelayed]", "0"}], "}"}]}], "//", "Simplify"}], "//", 
   "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"%", "\[Equal]", "0"}], ",", 
         RowBox[{"D", "[", 
          RowBox[{
           UnderscriptBox["fAlp", "_"], ",", "r"}], "]"}]}], "]"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         UnderscriptBox["gAlp", "_"], "\[Rule]", "1"}], ",", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           UnderscriptBox["gAlp", "_"], ",", "r"}], "]"}], "\[Rule]", "0"}]}],
        "}"}]}], "//", "Expand"}], "//", "Simplify"}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["eq$gW", "_"], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        UnderscriptBox["p", "_"], "\[Rule]", "0"}], ",", 
       RowBox[{
        UnderscriptBox["Lt", "_"], "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["p", "_"], ",", "r"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        UnderscriptBox["q", "_"], "\[Rule]", "0"}], ",", 
       RowBox[{"P", "\[Rule]", "eq$esP"}]}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Beta]", "[", 
       RowBox[{"n_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"#", "\[NotEqual]", "1"}], "&"}], ")"}]}], "]"}], 
      "\[RuleDelayed]", "0"}], "}"}]}], "//", "Simplify"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["eq$fW", "_"], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        UnderscriptBox["p", "_"], "\[Rule]", "0"}], ",", 
       RowBox[{
        UnderscriptBox["Lt", "_"], "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["p", "_"], ",", "r"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        UnderscriptBox["q", "_"], "\[Rule]", "0"}], ",", 
       RowBox[{"P", "\[Rule]", "eq$esP"}]}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Beta]", "[", 
       RowBox[{"n_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"#", "\[NotEqual]", "1"}], "&"}], ")"}]}], "]"}], 
      "\[RuleDelayed]", "0"}], "}"}]}], "//", "Simplify"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["fAlp", "_"], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       UnderscriptBox["gAlp", "_"]}], 
      RowBox[{"%", "/", "%%"}]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       UnderscriptBox["gAlp", "_"], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         UnderscriptBox["gAlp", "_"], ",", "r"}], "]"}], "\[Rule]", "0"}]}], 
     "}"}]}], "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       UnderscriptBox["fAlp", "_"], ",", "r"}], "]"}], "\[Rule]", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        UnderscriptBox["fAlp", "_"], "/.", "%"}], ",", "r"}], "]"}]}], "//", 
    "Simplify"}], "//", "echoNice"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  FractionBox[
   RowBox[{
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], " ", 
        StyleBox["B",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"r", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    RowBox[{"2", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]}], 
   RowBox[{"r", " ", 
    StyleBox["A",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    StyleBox["B",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    StyleBox[
     OverscriptBox["A", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}]]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}],
    HoldForm], "\[Rule]", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r"}], " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"r", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "-", 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   StyleBox[
    OverscriptBox["\[Alpha]", "~"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                OverscriptBox["B", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm], ")"}], "2"], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                OverscriptBox["B", "~"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm], ")"}], "2"], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              SuperscriptBox[
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "2"], " ", 
              SuperscriptBox[
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "2"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], "+", 
          RowBox[{
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SuperscriptBox[
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              SuperscriptBox[
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "3"], " ", 
              SuperscriptBox[
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "2"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              StyleBox[
               SubscriptBox["\[Kappa]", "f"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], " ", 
              SubscriptBox["\[Beta]", "1"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              SuperscriptBox[
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "2"], " ", 
              StyleBox[
               SubscriptBox["\[Kappa]", "g"],
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], " ", 
              SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}], ")"}], 
      "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["B", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], ")"}], "2"], " ", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"], " ", 
         SuperscriptBox[
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "2"]}], "-", 
        RowBox[{"2", " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            OverscriptBox["B", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm], " ", 
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              OverscriptBox["B", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm], "+", 
           RowBox[{"6", " ", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}],
             HoldForm], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "+", 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "3"], " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["K", "~"], "2"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "1"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], "+", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            StyleBox[
             SubscriptBox["\[Kappa]", "f"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]], " ", 
            SubscriptBox["\[Beta]", "1"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "2"], " ", 
            StyleBox[
             SubscriptBox["\[Kappa]", "g"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
        RowBox[{
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              TagBox[
               RowBox[{
                SubscriptBox["\[PartialD]", "r"], 
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}],
               HoldForm], ")"}], "2"], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], " ", 
            StyleBox[
             SubscriptBox["\[Kappa]", "g"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            RowBox[{"(", 
             RowBox[{
              StyleBox[
               OverscriptBox["D", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]], "+", 
              StyleBox[
               OverscriptBox["\[Tau]", "^"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]], "-", 
              RowBox[{
               StyleBox[
                SuperscriptBox["v", "r"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], " ", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["S", "^"], "r"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  SuperscriptBox[
                   StyleBox["B",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                  SuperscriptBox[
                   StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox[
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"], " ", 
               StyleBox[
                SubscriptBox["\[Kappa]", "f"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], " ", 
               SubscriptBox["\[Beta]", "1"]}], "+", 
              RowBox[{
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox[
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], "2"], " ", 
               SuperscriptBox[
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}], "-", 
                 RowBox[{"3", " ", 
                  StyleBox[
                   SubscriptBox["\[Kappa]", "g"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], " ", 
                  SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}],
    HoldForm], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"], " ", 
          SuperscriptBox[
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "2"]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{"6", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "1"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "2"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
         RowBox[{
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}],
                HoldForm], ")"}], "2"], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "+", 
               StyleBox[
                OverscriptBox["\[Tau]", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "-", 
               RowBox[{
                StyleBox[
                 SuperscriptBox["v", "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["S", "^"], "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              StyleBox["A",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    StyleBox["B",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                   SuperscriptBox[
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "f"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], " ", 
                SubscriptBox["\[Beta]", "1"]}], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                SuperscriptBox[
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "-", 
                  RowBox[{"3", " ", 
                   StyleBox[
                    SubscriptBox["\[Kappa]", "g"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}],
           HoldForm], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}], "-", 
         RowBox[{"4", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "rr"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}], "+", 
         RowBox[{"4", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "rr"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"4", " ", "r", " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "3"], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "2"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "2"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm], " ", 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", " ", 
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox["B",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}],
                 HoldForm], " ", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]]}], "+", 
               RowBox[{
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"r", " ", 
                   TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}],
                    HoldForm]}], "+", 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}], ")"}]}]}], ")"}], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "-", 
         RowBox[{"6", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}],
             HoldForm], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "2"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}],
              HoldForm], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "+", 
            RowBox[{"r", " ", 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "r", " ", 
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox["B",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}],
                 HoldForm], " ", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]]}], "+", 
               RowBox[{
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "r", " ", 
                   TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}],
                    HoldForm]}], "+", 
                  RowBox[{"2", " ", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                SubscriptBox["\[Kappa]", "f"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "g"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"r", " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                SubscriptBox["\[Kappa]", "f"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]], "+", 
               RowBox[{"3", " ", "r", " ", 
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox["R",
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 1],
                   FrontFaceColor->RGBColor[1, 0, 1],
                   BackFaceColor->RGBColor[1, 0, 1],
                   GraphicsColor->RGBColor[1, 0, 1],
                   FontColor->RGBColor[1, 0, 1]]}],
                 HoldForm], " ", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "g"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "g"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"], " ", 
          SuperscriptBox[
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "2"]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{"6", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "1"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "2"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
         RowBox[{
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}],
                HoldForm], ")"}], "2"], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "+", 
               StyleBox[
                OverscriptBox["\[Tau]", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "-", 
               RowBox[{
                StyleBox[
                 SuperscriptBox["v", "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["S", "^"], "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              StyleBox["A",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    StyleBox["B",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                   SuperscriptBox[
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "f"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], " ", 
                SubscriptBox["\[Beta]", "1"]}], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                SuperscriptBox[
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "-", 
                  RowBox[{"3", " ", 
                   StyleBox[
                    SubscriptBox["\[Kappa]", "g"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}],
           HoldForm], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]]}], "+", 
         RowBox[{"16", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], ")"}], "2"], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "2"]}], "+", 
         RowBox[{"16", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "rr"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          SuperscriptBox[
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"], " ", 
          SuperscriptBox[
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "2"]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{"6", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}],
           HoldForm], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{"6", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{"6", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "rr"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{"6", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "-", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}],
              HoldForm]}], "+", 
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "rr"], 
              StyleBox[
               OverscriptBox["B", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}],
             HoldForm], "+", 
            RowBox[{"6", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "rr"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{"2", " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            TagBox[
             RowBox[{
              SubscriptBox["\[PartialD]", "r"], 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]]}],
             HoldForm], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "1"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}],
                HoldForm], "+", 
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "2"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}],
                HoldForm]}], ")"}], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], "+", 
            RowBox[{"r", " ", 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "r", " ", 
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox["B",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}],
                 HoldForm], " ", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]]}], "+", 
               RowBox[{
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "r", " ", 
                   TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}],
                    HoldForm]}], "+", 
                  RowBox[{"2", " ", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "2"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], "2"]}], "+", 
            RowBox[{"2", " ", "r", " ", 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", " ", 
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]]}],
                 HoldForm], " ", 
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], " ", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "r", " ", 
                   TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["B",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}],
                    HoldForm], " ", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}], "+", 
                  RowBox[{
                   StyleBox["B",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "r", " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}],
                    HoldForm]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}]}], ")"}], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "2"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"r", " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}],
              HoldForm], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", "r", " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "1"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "2"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "3"], " ", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "1"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               StyleBox[
                SubscriptBox[
                 OverscriptBox["K", "~"], "2"],
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 0],
                FrontFaceColor->RGBColor[1, 0, 0],
                BackFaceColor->RGBColor[1, 0, 0],
                GraphicsColor->RGBColor[1, 0, 0],
                FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "f"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], " ", 
             SubscriptBox["\[Beta]", "1"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              StyleBox["B",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             SuperscriptBox[
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "2"], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["A", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}],
                HoldForm], ")"}], "2"], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "+", 
               StyleBox[
                OverscriptBox["\[Tau]", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "-", 
               RowBox[{
                StyleBox[
                 SuperscriptBox["v", "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["S", "^"], "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              StyleBox["A",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    StyleBox["B",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                   SuperscriptBox[
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "f"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], " ", 
                SubscriptBox["\[Beta]", "1"]}], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                SuperscriptBox[
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "-", 
                  RowBox[{"3", " ", 
                   StyleBox[
                    SubscriptBox["\[Kappa]", "g"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]]}],
           HoldForm], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}],
                HoldForm], ")"}], "2"], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "+", 
               StyleBox[
                OverscriptBox["\[Tau]", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "-", 
               RowBox[{
                StyleBox[
                 SuperscriptBox["v", "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["S", "^"], "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              StyleBox["A",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    StyleBox["B",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                   SuperscriptBox[
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "f"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], " ", 
                SubscriptBox["\[Beta]", "1"]}], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                SuperscriptBox[
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "-", 
                  RowBox[{"3", " ", 
                   StyleBox[
                    SubscriptBox["\[Kappa]", "g"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          SuperscriptBox[
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]]}],
                HoldForm], ")"}], "2"], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}],
              HoldForm]}], "+", 
            RowBox[{"12", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "rr"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox[
                  OverscriptBox["D", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]]}],
                HoldForm], "+", 
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox[
                  OverscriptBox["\[Tau]", "^"],
                  StripOnInput->False,
                  LineColor->RGBColor[0.5, 0, 0.5],
                  FrontFaceColor->RGBColor[0.5, 0, 0.5],
                  BackFaceColor->RGBColor[0.5, 0, 0.5],
                  GraphicsColor->RGBColor[0.5, 0, 0.5],
                  FontColor->RGBColor[0.5, 0, 0.5]]}],
                HoldForm], "-", 
               RowBox[{
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["S", "^"], "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]]}],
                 HoldForm], " ", 
                StyleBox[
                 SuperscriptBox["v", "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}], "-", 
               RowBox[{
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox[
                   SuperscriptBox["v", "r"],
                   StripOnInput->False,
                   LineColor->RGBColor[0.5, 0, 0.5],
                   FrontFaceColor->RGBColor[0.5, 0, 0.5],
                   BackFaceColor->RGBColor[0.5, 0, 0.5],
                   GraphicsColor->RGBColor[0.5, 0, 0.5],
                   FontColor->RGBColor[0.5, 0, 0.5]]}],
                 HoldForm], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["S", "^"], "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "+", 
               StyleBox[
                OverscriptBox["\[Tau]", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "-", 
               RowBox[{
                StyleBox[
                 SuperscriptBox["v", "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["S", "^"], "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["A",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "+", 
               StyleBox[
                OverscriptBox["\[Tau]", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "-", 
               RowBox[{
                StyleBox[
                 SuperscriptBox["v", "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["S", "^"], "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", "r", " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], " ", 
             StyleBox[
              SubscriptBox["\[Kappa]", "g"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               StyleBox[
                OverscriptBox["D", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "+", 
               StyleBox[
                OverscriptBox["\[Tau]", "^"],
                StripOnInput->False,
                LineColor->RGBColor[0.5, 0, 0.5],
                FrontFaceColor->RGBColor[0.5, 0, 0.5],
                BackFaceColor->RGBColor[0.5, 0, 0.5],
                GraphicsColor->RGBColor[0.5, 0, 0.5],
                FontColor->RGBColor[0.5, 0, 0.5]], "-", 
               RowBox[{
                StyleBox[
                 SuperscriptBox["v", "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["S", "^"], "r"],
                 StripOnInput->False,
                 LineColor->RGBColor[0.5, 0, 0.5],
                 FrontFaceColor->RGBColor[0.5, 0, 0.5],
                 BackFaceColor->RGBColor[0.5, 0, 0.5],
                 GraphicsColor->RGBColor[0.5, 0, 0.5],
                 FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "-", 
            RowBox[{"4", " ", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["A",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], " ", 
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    StyleBox["B",
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                   SuperscriptBox[
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                StyleBox[
                 SubscriptBox["\[Kappa]", "f"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]], " ", 
                SubscriptBox["\[Beta]", "1"]}], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                SuperscriptBox[
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "-", 
                  RowBox[{"3", " ", 
                   StyleBox[
                    SubscriptBox["\[Kappa]", "g"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              StyleBox["A",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               TagBox[
                RowBox[{
                 SubscriptBox["\[PartialD]", "r"], 
                 StyleBox["R",
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 1],
                  FrontFaceColor->RGBColor[1, 0, 1],
                  BackFaceColor->RGBColor[1, 0, 1],
                  GraphicsColor->RGBColor[1, 0, 1],
                  FontColor->RGBColor[1, 0, 1]]}],
                HoldForm], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["r", "2"], " ", 
                TagBox[
                 RowBox[{
                  SubscriptBox["\[PartialD]", "r"], 
                  StyleBox["B",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]]}],
                 HoldForm], " ", 
                StyleBox["B",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                   SuperscriptBox[
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                   StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                   StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    SubscriptBox["\[Kappa]", "f"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], "-", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                    StyleBox[
                    SubscriptBox["\[Kappa]", "g"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
                   SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
               RowBox[{"r", " ", 
                SuperscriptBox[
                 StyleBox["B",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"r", " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}],
                    HoldForm]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
                   SuperscriptBox[
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
                  RowBox[{"2", " ", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                   StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"r", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}],
                    HoldForm]}], "+", 
                    RowBox[{
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"r", " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}],
                    HoldForm]}], "+", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}], ")"}], " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"r", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}],
                    HoldForm], "-", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}],
                    HoldForm]}], ")"}], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"r", " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}],
                    HoldForm]}], "+", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}], ")"}], " ", 
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}], "+", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    SubscriptBox["\[Kappa]", "f"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]], " ", 
                    SubscriptBox["\[Beta]", "1"]}], "-", 
                    RowBox[{"3", " ", "r", " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]]}],
                    HoldForm], " ", 
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], " ", 
                    StyleBox[
                    SubscriptBox["\[Kappa]", "g"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "1"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"r", " ", 
                    TagBox[
                    RowBox[{
                    SubscriptBox["\[PartialD]", "r"], 
                    StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}],
                    HoldForm], " ", 
                    StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], "-", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    SubscriptBox["\[Kappa]", "g"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], " ", 
                    SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], ")"}], "2"], " ", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], " ", 
        SuperscriptBox[
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "2"]}], "-", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], " ", 
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             OverscriptBox["B", "~"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "+", 
          RowBox[{"6", " ", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["B",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}]}], ")"}], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           SuperscriptBox[
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "3"], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "2"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["K", "~"], "1"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}], "+", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           StyleBox[
            SubscriptBox["\[Kappa]", "f"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           SubscriptBox["\[Beta]", "1"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            StyleBox["B",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           SuperscriptBox[
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "2"], " ", 
           StyleBox[
            SubscriptBox["\[Kappa]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           SubscriptBox["\[Beta]", "1"]}]}], ")"}]}], "+", 
       RowBox[{
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             TagBox[
              RowBox[{
               SubscriptBox["\[PartialD]", "r"], 
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]]}],
              HoldForm], ")"}], "2"], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]]}], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           StyleBox["A",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["\[Kappa]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              OverscriptBox["D", "^"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]], "+", 
             StyleBox[
              OverscriptBox["\[Tau]", "^"],
              StripOnInput->False,
              LineColor->RGBColor[0.5, 0, 0.5],
              FrontFaceColor->RGBColor[0.5, 0, 0.5],
              BackFaceColor->RGBColor[0.5, 0, 0.5],
              GraphicsColor->RGBColor[0.5, 0, 0.5],
              FontColor->RGBColor[0.5, 0, 0.5]], "-", 
             RowBox[{
              StyleBox[
               SuperscriptBox["v", "r"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]], " ", 
              StyleBox[
               SubscriptBox[
                OverscriptBox["S", "^"], "r"],
               StripOnInput->False,
               LineColor->RGBColor[0.5, 0, 0.5],
               FrontFaceColor->RGBColor[0.5, 0, 0.5],
               BackFaceColor->RGBColor[0.5, 0, 0.5],
               GraphicsColor->RGBColor[0.5, 0, 0.5],
               FontColor->RGBColor[0.5, 0, 0.5]]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  StyleBox["B",
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], "2"], " ", 
                 SuperscriptBox[
                  StyleBox[
                   SubscriptBox["K", "2"],
                   StripOnInput->False,
                   LineColor->RGBColor[0, 0, 1],
                   FrontFaceColor->RGBColor[0, 0, 1],
                   BackFaceColor->RGBColor[0, 0, 1],
                   GraphicsColor->RGBColor[0, 0, 1],
                   FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              StyleBox[
               SubscriptBox["\[Kappa]", "f"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]], " ", 
              SubscriptBox["\[Beta]", "1"]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               StyleBox["B",
                StripOnInput->False,
                LineColor->RGBColor[0, 0, 1],
                FrontFaceColor->RGBColor[0, 0, 1],
                BackFaceColor->RGBColor[0, 0, 1],
                GraphicsColor->RGBColor[0, 0, 1],
                FontColor->RGBColor[0, 0, 1]], "2"], " ", 
              SuperscriptBox[
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   StyleBox[
                    SubscriptBox["K", "1"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]], "-", 
                   StyleBox[
                    SubscriptBox["K", "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[0, 0, 1],
                    FrontFaceColor->RGBColor[0, 0, 1],
                    BackFaceColor->RGBColor[0, 0, 1],
                    GraphicsColor->RGBColor[0, 0, 1],
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], " ", 
                 StyleBox[
                  SubscriptBox[
                   OverscriptBox["K", "~"], "2"],
                  StripOnInput->False,
                  LineColor->RGBColor[1, 0, 0],
                  FrontFaceColor->RGBColor[1, 0, 0],
                  BackFaceColor->RGBColor[1, 0, 0],
                  GraphicsColor->RGBColor[1, 0, 0],
                  FontColor->RGBColor[1, 0, 0]]}], "-", 
                RowBox[{"3", " ", 
                 StyleBox[
                  SubscriptBox["\[Kappa]", "g"],
                  StripOnInput->False,
                  LineColor->RGBColor[0, 0, 1],
                  FrontFaceColor->RGBColor[0, 0, 1],
                  BackFaceColor->RGBColor[0, 0, 1],
                  GraphicsColor->RGBColor[0, 0, 1],
                  FontColor->RGBColor[0, 0, 1]], " ", 
                 SubscriptBox["\[Beta]", "1"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}], "2"]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Removing time dependency of p (alt. view)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    UnderscriptBox["evol$eq$p", "_"], "//.", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       UnderscriptBox["gA", "_"], "\[Rule]", 
       FractionBox[
        RowBox[{
         UnderscriptBox["gB", "_"], "+", 
         RowBox[{"r", " ", 
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["gB", "_"], ",", "r"}], "]"}]}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"k", "[", "r", "]"}]}], ")"}], 
         RowBox[{"1", "/", "2"}]]]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       UnderscriptBox["Lt", "_"], "\[Rule]", "1"}], ",", 
      RowBox[{
       UnderscriptBox["p", "_"], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         UnderscriptBox["p", "_"], ",", "r"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       UnderscriptBox["gAlp", "_"], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         UnderscriptBox["gAlp", "_"], ",", "r"}], "]"}], "\[Rule]", "0"}]}], 
     "\[IndentingNewLine]", "}"}]}], "//", "FullSimplify"}], "//", 
  "printNice"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"r", " ", 
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
     HoldForm], " ", 
    StyleBox["B",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"k", "[", "r", "]"}]}]], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
       HoldForm], "+", 
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], 
  RowBox[{"r", " ", 
   TagBox[
    SubsuperscriptBox[
     RowBox[{"\[LeftAngleBracket]", 
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
    HoldForm], " ", 
   StyleBox["B",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]], " ", 
   StyleBox[
    OverscriptBox["A", "~"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1328, 1102},
WindowMargins->{{221, Automatic}, {Automatic, 0}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "evolutionEquations"->{
  Cell[1861, 64, 321, 13, 83, "Section",
   PageBreakAbove->True,
   CellTags->"evolutionEquations"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"evolutionEquations", 544028, 13630}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 250, 6, 93, "Text"],
Cell[811, 28, 28, 0, 38, "Text"],
Cell[842, 30, 60, 0, 38, "Text"],
Cell[905, 32, 138, 3, 38, "Text"],
Cell[1046, 37, 81, 4, 38, "Text"],
Cell[1130, 43, 207, 4, 38, "Text"],
Cell[1340, 49, 450, 9, 38, "Text"],
Cell[1793, 60, 43, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[1861, 64, 321, 13, 83, "Section",
 PageBreakAbove->True,
 CellTags->"evolutionEquations"],
Cell[2185, 79, 142, 3, 38, "Text"],
Cell[2330, 84, 2109, 54, 221, "Input"],
Cell[4442, 140, 97, 2, 38, "Text"],
Cell[4542, 144, 95, 3, 36, "Input"],
Cell[4640, 149, 548, 16, 62, "Input"],
Cell[5191, 167, 548, 16, 62, "Input"],
Cell[5742, 185, 33, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[5800, 189, 1099, 31, 60, "Input"],
Cell[6902, 222, 9162, 270, 166, "Echo"]
}, Open  ]],
Cell[16079, 495, 126, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[16230, 502, 355, 11, 36, "Input"],
Cell[16588, 515, 129025, 3207, 713, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145650, 3727, 355, 11, 36, "Input"],
Cell[146008, 3740, 124551, 3128, 638, "Echo"]
}, Open  ]],
Cell[270574, 6871, 204, 4, 38, "Text"],
Cell[CellGroupData[{
Cell[270803, 6879, 847, 22, 106, "Input"],
Cell[271653, 6903, 493, 6, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[272183, 6914, 1251, 34, 129, "Input"],
Cell[273437, 6950, 2034, 26, 1302, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[275520, 6982, 256, 10, 78, "Section"],
Cell[CellGroupData[{
Cell[275801, 6996, 752, 24, 39, "Input"],
Cell[276556, 7022, 5105, 144, 55, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[281698, 7171, 4055, 132, 164, "Input"],
Cell[CellGroupData[{
Cell[285778, 7307, 5490, 160, 52, "Echo"],
Cell[291271, 7469, 3455, 102, 51, "Echo"],
Cell[294729, 7573, 26816, 661, 82, "Echo"],
Cell[321548, 8236, 213217, 5135, 554, "Echo"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[534814, 13377, 66, 0, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[534905, 13381, 1208, 36, 159, "Input"],
Cell[536116, 13419, 4307, 129, 69, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
