(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    595636,      18253]
NotebookOptionsPosition[    582071,      17855]
NotebookOutlinePosition[    585854,      17944]
CellTagsIndexPosition[    585767,      17939]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Bimetric equations in standard 3+1 form \nreduced to spherical symmetry ",
 StyleBox["(\[OpenCurlyDoubleQuote]packager\[CloseCurlyDoubleQuote])",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell["Mikica Kocic", "Text"],

Cell["Created 2018-02-08, Last modified 2018-08-07", "Text"],

Cell["\<\
This notebook creates a package with the equations of motion to be used in \
the main notebook.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Requirements",
  FontWeight->"Bold"],
 ":"
}], "Text"],

Cell["\<\
Evaluate first the main notebook: \[OpenCurlyDoubleQuote]bimetric-ss-in-3+1 \
(cpp solver)\[CloseCurlyDoubleQuote]. 
(Don\[CloseCurlyQuote]t forget to set \[OpenCurlyQuote]$debugMode\
\[CloseCurlyQuote] to true before evaluating this notebook.)\
\>", "Text"],

Cell[TextData[{
 StyleBox["Changelog",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.720329745571742*^9, 3.7203297456965427`*^9}, {
  3.7203297847600107`*^9, 3.7203297956508303`*^9}, {3.7205583336652308`*^9, 
  3.7205583361144347`*^9}, {3.7207192650993385`*^9, 3.7207192738041534`*^9}, {
  3.720804920912696*^9, 3.7208050456419153`*^9}, {3.7208050794959755`*^9, 
  3.720805104705619*^9}, {3.720805135145273*^9, 3.720805252292879*^9}}],

Cell[TextData[{
 "2018-08-07  Separated from the main notebook.\n2018-08-15  Split of the \
evolution operators for ",
 Cell[BoxData[
  FormBox["K", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "\[CapitalDelta]"], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$debugMode", "=", "True"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Create a package with the equations of motion", "Section",
 PageBreakAbove->True,
 CellTags->"initializationSection"],

Cell["\<\
Remember all the names in the global space before our definitions of the new \
variables,\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"namesBeforeDefinitions", "=", 
   RowBox[{"Names", "[", "\"\<Global`*\>\"", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Default gauge functions", "Subsubsection"],

Cell["\<\
Note that gW and fW must be instantiated to eq$gW and eq$fW, respectively.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eq$q", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$gAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$fAlp", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"gAlp", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"gW", "[", 
      RowBox[{"t", ",", "r"}], "]"}], "/", 
     RowBox[{"fW", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";"}]}], "Input"],

Cell["In the case of decoupled GR sectors, eq$fAlp is arbitrary.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["eq$gW", "_"], "\[Equal]", "0"}], "/.", 
     RowBox[{"P", "\[Rule]", "eq$esP"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Beta]", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
   "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["eq$fW", "_"], "\[Equal]", "0"}], "/.", 
     RowBox[{"P", "\[Rule]", "eq$esP"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Beta]", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
   "echoNice"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", "True"}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", "True"}]], "Echo"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Instantiate shifts (in terms of ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 "),"
}], "Text"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        UnderscriptBox["eq$Lt", "_"], ",", "r"}], "]"}], "-", 
      RowBox[{
       UnderscriptBox["p", "_"], 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["p", "_"], ",", "r"}], "]"}], "/", 
        UnderscriptBox["eq$Lt", "_"]}]}]}], "]"}], "=!=", "0"}], ",", 
   RowBox[{"Abort", "[", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"instantiateShifts", "[", "e_", "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gBet", ",", "fBet", ",", "v"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"gBet", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"eq$gBet", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fBet", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"eq$fBet", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"v", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"eq$v", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"e", "/.", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "Lt", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        UnderscriptBox["p", "_"], 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           UnderscriptBox["p", "_"], ",", "r"}], "]"}], "/", 
         UnderscriptBox["Lt", "_"]}]}]}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[TextData[{
 "Replace ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " by ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " and \[Lambda] rule: ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"v", "\[Rule]", 
     FractionBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]]}], ",", 
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["v",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], "\[Rule]", 
     FractionBox[
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]]}]}], "}"}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v2p$rule", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        UnderscriptBox["v", "_"], "\[Rule]", 
        FractionBox[
         UnderscriptBox["p", "_"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             UnderscriptBox["p", "_"], "2"]}], ")"}], 
          RowBox[{"1", "/", "2"}]]]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["v", "_"], ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            FractionBox[
             UnderscriptBox["p", "_"], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox[
                 UnderscriptBox["p", "_"], "2"]}], ")"}], 
              RowBox[{"1", "/", "2"}]]], ",", "r"}], "]"}], "//", 
          "Simplify"}], ")"}]}]}], "\[IndentingNewLine]", "}"}], "/.", 
     RowBox[{
      SuperscriptBox[
       UnderscriptBox["p", "_"], "2"], "\[Rule]", " ", 
      RowBox[{
       SuperscriptBox[
        UnderscriptBox["Lt", "_"], "2"], "-", "1"}]}]}], "//", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{
         UnderscriptBox["Lt", "_"], "\[GreaterEqual]", "1"}]}]}], "]"}], 
     "&"}]}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Apparent horizon finders", "Subsubsection"],

Cell[TextData[{
 "See eq. (7.11) in Shibata (2015) where we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", 
      RowBox[{"r", "\[VeryThinSpace]", "r"}]], "=", 
     SuperscriptBox["A", "2"]}], ",", " ", 
    RowBox[{
     SubscriptBox["\[Gamma]", "\[Theta]\[Theta]"], "=", 
     RowBox[{
      SuperscriptBox["B", "2"], "\[VeryThinSpace]", 
      SuperscriptBox["r", "2"]}]}], ",", "  ", 
    RowBox[{
     SubscriptBox[
      SuperscriptBox["K", "\[Theta]"], "\[Theta]"], "=", 
     SubscriptBox["K", "2"]}]}], TraditionalForm]]],
 ".\nAlso eq. (6.7.15) in Alcubierre (2008)."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$gHorz", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "r"}], "+", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"gB", "[", 
         RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}], "/", 
      RowBox[{"gB", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"gA", "[", 
       RowBox[{"t", ",", "r"}], "]"}], 
      RowBox[{"gK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], "//", "Simplify"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$fHorz", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "r"}], "+", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"fB", "[", 
         RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}], "/", 
      RowBox[{"fB", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"fA", "[", 
       RowBox[{"t", ",", "r"}], "]"}], 
      RowBox[{"fK2", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}]}], "//", "Simplify"}]}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The matter equations", "Subsubsection"],

Cell["Note: These definitions should be delayed!", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gT$\[Rho]", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"eq$pf$\[Rho]", "[", 
   RowBox[{"t", ",", "r"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gT$j", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"eq$pf$j", "[", 
   RowBox[{"t", ",", "r"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gT$JK1", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"eq$pf$J1", "[", 
    RowBox[{"t", ",", "r"}], "]"}], "-", 
   RowBox[{
    RowBox[{"1", "/", "2"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"eq$pf$J1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"2", 
       RowBox[{"eq$pf$J2", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}], "-", 
      RowBox[{"eq$pf$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ")"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gT$JK2", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"eq$pf$J2", "[", 
    RowBox[{"t", ",", "r"}], "]"}], "-", 
   RowBox[{
    RowBox[{"1", "/", "2"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"eq$pf$J1", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "+", 
      RowBox[{"2", 
       RowBox[{"eq$pf$J2", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}], "-", 
      RowBox[{"eq$pf$\[Rho]", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ")"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fT$\[Rho]", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fT$j", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fT$JK1", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fT$JK2", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", "0"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The constraint equations,", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$C1", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"eq$gC$\[Rho]", "[", 
     RowBox[{"t", ",", "r"}], "]"}], "-", 
    RowBox[{"k$g", " ", 
     RowBox[{"g$\[Rho]", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$C2", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"eq$fC$\[Rho]", "[", 
     RowBox[{"t", ",", "r"}], "]"}], "-", 
    RowBox[{"k$f", " ", 
     RowBox[{"f$\[Rho]", "[", 
      RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$C3", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"k$f", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gA", "[", 
        RowBox[{"t", ",", "r"}], "]"}], 
       SuperscriptBox[
        RowBox[{"gB", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "2"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"eq$gC$j", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "-", 
       RowBox[{"k$g", " ", 
        RowBox[{"gT$j", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}], "+", 
    "\[IndentingNewLine]", 
    RowBox[{"k$g", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fA", "[", 
        RowBox[{"t", ",", "r"}], "]"}], 
       SuperscriptBox[
        RowBox[{"fB", "[", 
         RowBox[{"t", ",", "r"}], "]"}], "2"]}], ")"}], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"eq$fC$j", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "-", 
       RowBox[{"k$f", " ", 
        RowBox[{"fT$j", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$C4", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
   RowBox[{"eq$bimConsLaw", "[", 
    RowBox[{"t", ",", "r"}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 "-equation,"
}], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$p$g", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     UnderscriptBox["p", "_"], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         UnderscriptBox["eq$gC$j", "_"], "\[Equal]", 
         RowBox[{"k$g", 
          RowBox[{"(", 
           RowBox[{
            UnderscriptBox["eq$gV$j", "_"], "+", 
            UnderscriptBox["gT$j", "_"]}], ")"}]}]}], ",", 
        UnderscriptBox["p", "_"]}], "]"}], "\[LeftDoubleBracket]", "1", 
      "\[RightDoubleBracket]"}]}], "//", "Simplify"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$p$f", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     UnderscriptBox["p", "_"], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         UnderscriptBox["eq$fC$j", "_"], "\[Equal]", 
         RowBox[{"k$f", 
          RowBox[{"(", 
           RowBox[{
            UnderscriptBox["eq$fV$j", "_"], "+", 
            UnderscriptBox["fT$j", "_"]}], ")"}]}]}], ",", 
        UnderscriptBox["p", "_"]}], "]"}], "\[LeftDoubleBracket]", "1", 
      "\[RightDoubleBracket]"}]}], "//", "Simplify"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       UnderscriptBox["eq$gV$j", "_"], 
       RowBox[{"(", 
        RowBox[{
         UnderscriptBox["gA", "_"], 
         SuperscriptBox[
          UnderscriptBox["gB", "_"], "2"]}], ")"}]}], "+", 
      RowBox[{
       UnderscriptBox["eq$fV$j", "_"], 
       RowBox[{"(", 
        RowBox[{
         UnderscriptBox["fA", "_"], 
         SuperscriptBox[
          UnderscriptBox["fB", "_"], "2"]}], ")"}]}]}], "\[NotEqual]", "0"}], 
    "//", "Simplify"}], ",", 
   RowBox[{"FrontEndExecute", "[", 
    RowBox[{"FrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], "]"}]}], 
  "]"}]], "Input"],

Cell["TODO: Fix this", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["eq$p$g", "_"], "\[NotEqual]", 
     RowBox[{
      UnderscriptBox["eq$p", "_"], "/", "k$g"}]}], "//", "Simplify"}], ",", 
   RowBox[{"xFrontEndExecute", "[", 
    RowBox[{"xFrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"pfS", "[", 
      RowBox[{"t", ",", "r"}], "]"}], 
     RowBox[{
      RowBox[{"fA", "[", 
       RowBox[{"t", ",", "r"}], "]"}], " ", 
      RowBox[{"gA", "[", 
       RowBox[{"t", ",", "r"}], "]"}], " ", 
      RowBox[{"gB", "[", 
       RowBox[{"t", ",", "r"}], "]"}], " ", 
      RowBox[{"P", "[", 
       RowBox[{"2", ",", "1", ",", 
        RowBox[{"R", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], "]"}]}]], "\[NotEqual]", "0"}], 
   ",", 
   RowBox[{"xFrontEndExecute", "[", 
    RowBox[{"xFrontEndToken", "[", "\<\"EvaluatorAbort\"\>", "]"}], "]"}]}], 
  "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A change of variables that regularizes the spatial flatness at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "0"}], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eq$g\[Sigma]", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["1", "r"], 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      UnderscriptBox["gA", "_"], 
      UnderscriptBox["gB", "_"]], "-", "1"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eq$f\[Sigma]", "[", 
   RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["1", "r"], 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      UnderscriptBox["fA", "_"], 
      UnderscriptBox["fB", "_"]], "-", "1"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"collectFields", "[", "e_", "]"}], ":=", 
  RowBox[{"Collect", "[", 
   RowBox[{"e", ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", 
      RowBox[{"p", "[", "___", "]"}], ",", "k$f", ",", "k$g", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"g$JK1", "[", "___", "]"}], ",", 
      RowBox[{"g$JK2", "[", "___", "]"}], ",", 
      RowBox[{"gAlp", "[", "___", "]"}], ",", 
      RowBox[{"gA", "[", "___", "]"}], ",", 
      RowBox[{"gB", "[", "___", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"f$JK1", "[", "___", "]"}], ",", 
      RowBox[{"f$JK2", "[", "___", "]"}], ",", 
      RowBox[{"fAlp", "[", "___", "]"}], ",", 
      RowBox[{"fA", "[", "___", "]"}], ",", 
      RowBox[{"fB", "[", "___", "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
    "Simplify"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigma$rule", "[", "e_", "]"}], ":=", 
  RowBox[{"collectFields", "[", 
   RowBox[{"e", "/.", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox[
           UnderscriptBox["gA", "_"], "2"]]}], "+", 
        FractionBox["1", 
         SuperscriptBox[
          UnderscriptBox["gB", "_"], "2"]]}], "\[Rule]", 
       RowBox[{"r", 
        FractionBox[
         UnderscriptBox["g\[Sigma]", "_"], 
         UnderscriptBox["gA", "_"]], 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           UnderscriptBox["gA", "_"]], "+", 
          FractionBox["1", 
           UnderscriptBox["gB", "_"]]}], ")"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox[
           UnderscriptBox["fA", "_"], "2"]]}], "+", 
        FractionBox["1", 
         SuperscriptBox[
          UnderscriptBox["fB", "_"], "2"]]}], "\[Rule]", 
       RowBox[{"r", 
        FractionBox[
         UnderscriptBox["f\[Sigma]", "_"], 
         UnderscriptBox["fA", "_"]], 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           UnderscriptBox["fA", "_"]], "+", 
          FractionBox["1", 
           UnderscriptBox["fB", "_"]]}], ")"}]}]}]}], "\[IndentingNewLine]", 
     "}"}]}], "]"}]}]], "Input"],

Cell[TextData[{
 "Rules for the change of variables ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["D", "A"], "\[Equal]", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], "log"}], "\[VeryThinSpace]", "A"}]}], 
   TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["D", "B"], "\[Equal]", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], "log"}], "\[VeryThinSpace]", "B"}]}], 
   TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["D", "\[Alpha]"], "\[Equal]", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], "log"}], "\[VeryThinSpace]", 
     "\[Alpha]"}]}], TraditionalForm]]],
 ","
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"introduceDs$rule", "[", "e_", "]"}], ":=", 
  RowBox[{"collectFields", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pfV", ",", "pfv", ",", "SpherDel"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"pfV", "[", 
         RowBox[{"t_", ",", "r_"}], "]"}], "=", 
        UnderscriptBox["eq$pfV", "_"]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"pfv", "[", 
           RowBox[{"t_", ",", "r_"}], "]"}], "=", 
          UnderscriptBox["eq$pfv", "_"]}], ";"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"SpherDel", "[", "expr_", "]"}], ":=", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"expr", ",", "r"}], "]"}], "+", 
         RowBox[{"2", 
          RowBox[{"expr", "/", "r"}]}]}]}], ";", "\[IndentingNewLine]", 
       "e"}]}], "]"}], "/.", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"g", " ", "sector"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "gA", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"gDA", "[", 
         RowBox[{"t", ",", "r"}], "]"}], 
        RowBox[{"gA", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "gB", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"gDB", "[", 
         RowBox[{"t", ",", "r"}], "]"}], 
        RowBox[{"gB", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "gAlp", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"gDAlp", "[", 
         RowBox[{"t", ",", "r"}], "]"}], 
        RowBox[{"gAlp", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "2"}], "]"}], "[", "gA", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "gDA", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], "+", 
          SuperscriptBox[
           RowBox[{"gDA", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "2"]}], ")"}], 
        RowBox[{"gA", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "2"}], "]"}], "[", "gB", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "gDB", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], "+", 
          SuperscriptBox[
           RowBox[{"gDB", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "2"]}], ")"}], 
        RowBox[{"gB", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "2"}], "]"}], "[", "gAlp", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "gDAlp", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], "+", 
          SuperscriptBox[
           RowBox[{"gDAlp", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "2"]}], ")"}], 
        RowBox[{"gAlp", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"f", " ", "sector"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "fA", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"fDA", "[", 
         RowBox[{"t", ",", "r"}], "]"}], 
        RowBox[{"fA", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "fB", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"fDB", "[", 
         RowBox[{"t", ",", "r"}], "]"}], 
        RowBox[{"fB", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "fAlp", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"fDAlp", "[", 
         RowBox[{"t", ",", "r"}], "]"}], 
        RowBox[{"fAlp", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "2"}], "]"}], "[", "fA", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "fDA", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], "+", 
          SuperscriptBox[
           RowBox[{"fDA", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "2"]}], ")"}], 
        RowBox[{"fA", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "2"}], "]"}], "[", "fB", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "fDB", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], "+", 
          SuperscriptBox[
           RowBox[{"fDB", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "2"]}], ")"}], 
        RowBox[{"fB", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "2"}], "]"}], "[", "fAlp", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "fDAlp", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], "+", 
          SuperscriptBox[
           RowBox[{"fDAlp", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "2"]}], ")"}], 
        RowBox[{"fAlp", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}]}], "\[IndentingNewLine]", "}"}]}],
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"introduceDs", "[", "e_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"e", "//", "instantiateShifts"}], "//", "introduceDs$rule"}], "//",
    "sigma$rule"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"introduceDs", "[", "e_", "]"}], ":=", 
  RowBox[{"e", "//", "collectFields"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"introduceDs", "[", "e_", "]"}], ":=", 
  RowBox[{
   RowBox[{"e", "//", "introduceDs$rule"}], "//", "sigma$rule", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"keep", " ", "shifts"}], " ", "*)"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A change of variables ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["K", "1"], ",", 
    SubscriptBox["K", "2"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " into ",
 Cell[BoxData[
  FormBox[
   RowBox[{"K", "=", 
    RowBox[{
     SubscriptBox["K", "1"], "+", 
     RowBox[{"2", 
      SubscriptBox["K", "2"]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["K", "\[CapitalDelta]"], "=", 
    RowBox[{
     SubscriptBox["K", "1"], "-", 
     SubscriptBox["K", "2"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"introduce$KTrace", "[", "e_", "]"}], ":=", 
  RowBox[{
   RowBox[{"e", "//", 
    RowBox[{
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"gK1", ",", "gK2", ",", "fK1", ",", "fK2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"gK1", "[", 
          RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"gK", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "+", 
            RowBox[{"2", 
             RowBox[{"gKD", "[", 
              RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"gK2", "[", 
          RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"gK", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "-", 
            RowBox[{"gKD", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"fK1", "[", 
          RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fK", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "+", 
            RowBox[{"2", 
             RowBox[{"fKD", "[", 
              RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"fK2", "[", 
          RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fK", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "-", 
            RowBox[{"fKD", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", "#"}]}], "]"}], "&"}]}], "//", 
   "introduceDs"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The shift derivatives", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       UnderscriptBox["f", "_"], ",", "r"}], "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"r", " ", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}]}], 
      "+", 
      RowBox[{
       UnderscriptBox["f", "_"], "/", "r"}]}]}], "//", "Simplify"}], "//", 
   "echoNice"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", "True"}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$gBet$r", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"eq$gBet", "[", 
         RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}], "/.", 
      "v2p$rule"}], "//", "introduceDs"}], "//", "echoNice"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]]}]}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      UnderscriptBox["eq$gBet$r", "_"], ",", "r"}], "]"}], "//", 
    "instantiateShifts"}], "//", "introduceDs"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$gBet$rr", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"%", "/.", 
       RowBox[{
        SuperscriptBox[
         UnderscriptBox["Lt", "_"], "2"], "\[Rule]", 
        RowBox[{"1", "+", 
         SuperscriptBox[
          UnderscriptBox["p", "_"], "2"]}]}]}], "//", "introduceDs"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{
          UnderscriptBox["p", "_"], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "p", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], ",", 
          UnderscriptBox["Lt", "_"]}], "}"}], ",", "Simplify"}], "]"}], 
      "&"}]}], "//", "echoNice"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "rr"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "rr"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   RowBox[{
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], ")"}], "2"], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "5"]}]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "A"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], ")"}]}]}]}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       UnderscriptBox["gBet", "_"], ",", "r"}], "]"}], "/", "r"}], "-", 
    RowBox[{
     UnderscriptBox["gBet", "_"], "/", 
     SuperscriptBox["r", "2"]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["eq$gBet$r", "_"], "/", "r"}], "-", 
    RowBox[{
     RowBox[{"instantiateShifts", "@", 
      UnderscriptBox["gBet", "_"]}], "/", 
     SuperscriptBox["r", "2"]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["p", "_"], ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"r", " ", 
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["pr", "_"], ",", "r"}], "]"}]}], "+", 
         RowBox[{
          UnderscriptBox["p", "_"], "/", "r"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["q", "_"], ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"r", " ", 
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["qr", "_"], ",", "r"}], "]"}]}], "+", 
         RowBox[{
          UnderscriptBox["q", "_"], "/", "r"}]}]}]}], "\[IndentingNewLine]", 
      "}"}]}], "//", "introduceDs"}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       UnderscriptBox["Lt", "_"], 
       RowBox[{"-", "3"}]], "-", 
      SuperscriptBox[
       UnderscriptBox["Lt", "_"], 
       RowBox[{"-", "1"}]]}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox[
         UnderscriptBox["Lt", "_"], "2"]}], ")"}], 
      SuperscriptBox[
       UnderscriptBox["Lt", "_"], 
       RowBox[{"-", "3"}]]}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SuperscriptBox[
      UnderscriptBox["Lt", "_"], "2"], "\[Rule]", 
     RowBox[{"1", "+", 
      SuperscriptBox[
       UnderscriptBox["p", "_"], "2"]}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$gBetr$r", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1"}], "]"}], "[", "pr", "]"}], "[", 
         RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"HoldForm", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
         "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1"}], "]"}], "[", "qr", "]"}], "[", 
         RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"HoldForm", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"q", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
         "]"}]}]}], "\[IndentingNewLine]", "}"}]}], "//", "echoNice"}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["\[Beta]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], "r"], "-", 
   FractionBox[
    StyleBox["\[Beta]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], 
    SuperscriptBox["r", "2"]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], 
     SuperscriptBox["r", "2"]]}], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], "+", 
     FractionBox[
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       SuperscriptBox[
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "3"]}]], "+", 
     FractionBox[
      RowBox[{
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}]]}], "r"]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], "qr"}],
    HoldForm], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]], "-", 
       FractionBox["1", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], "pr"}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], "qr"}],
    HoldForm], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], "pr"}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox[
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "2"]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], "qr"}],
    HoldForm], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], "pr"}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     FractionBox[
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "r"]}],
    HoldForm], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]]}]}]], "Echo"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eq$fBet$r", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"eq$fBet", "[", 
         RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}], "/.", 
      "v2p$rule"}], "//", "introduceDs"}], "//", "echoNice"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]]}]}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      UnderscriptBox["eq$fBet$r", "_"], ",", "r"}], "]"}], "//", 
    "instantiateShifts"}], "//", "introduceDs"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$fBet$rr", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"%", "/.", 
       RowBox[{
        SuperscriptBox[
         UnderscriptBox["Lt", "_"], "2"], "\[Rule]", 
        RowBox[{"1", "+", 
         SuperscriptBox[
          UnderscriptBox["p", "_"], "2"]}]}]}], "//", "introduceDs"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{
          UnderscriptBox["p", "_"], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", 
             RowBox[{"0", ",", "1"}], "]"}], "[", "p", "]"}], "[", 
           RowBox[{"t", ",", "r"}], "]"}], ",", 
          UnderscriptBox["Lt", "_"]}], "}"}], ",", "Simplify"}], "]"}], 
      "&"}]}], "//", "echoNice"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "rr"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "rr"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], ")"}], "2"], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "5"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "A"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}]}]}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       UnderscriptBox["fBet", "_"], ",", "r"}], "]"}], "/", "r"}], "-", 
    RowBox[{
     UnderscriptBox["fBet", "_"], "/", 
     SuperscriptBox["r", "2"]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["eq$fBet$r", "_"], "/", "r"}], "-", 
    RowBox[{
     RowBox[{"instantiateShifts", "@", 
      UnderscriptBox["fBet", "_"]}], "/", 
     SuperscriptBox["r", "2"]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["p", "_"], ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"r", " ", 
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["pr", "_"], ",", "r"}], "]"}]}], "+", 
         RowBox[{
          UnderscriptBox["p", "_"], "/", "r"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["q", "_"], ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"r", " ", 
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["qr", "_"], ",", "r"}], "]"}]}], "+", 
         RowBox[{
          UnderscriptBox["q", "_"], "/", "r"}]}]}]}], "\[IndentingNewLine]", 
      "}"}]}], "//", "introduceDs"}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       UnderscriptBox["Lt", "_"], 
       RowBox[{"-", "3"}]], "-", 
      SuperscriptBox[
       UnderscriptBox["Lt", "_"], 
       RowBox[{"-", "1"}]]}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox[
         UnderscriptBox["Lt", "_"], "2"]}], ")"}], 
      SuperscriptBox[
       UnderscriptBox["Lt", "_"], 
       RowBox[{"-", "3"}]]}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SuperscriptBox[
      UnderscriptBox["Lt", "_"], "2"], "\[Rule]", 
     RowBox[{"1", "+", 
      SuperscriptBox[
       UnderscriptBox["p", "_"], "2"]}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq$fBetr$r", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1"}], "]"}], "[", "pr", "]"}], "[", 
         RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"HoldForm", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
         "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1"}], "]"}], "[", "qr", "]"}], "[", 
         RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"HoldForm", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"q", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
         "]"}]}]}], "\[IndentingNewLine]", "}"}]}], "//", "echoNice"}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       OverscriptBox["\[Beta]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], "r"], "-", 
   FractionBox[
    StyleBox[
     OverscriptBox["\[Beta]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], 
    SuperscriptBox["r", "2"]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], 
     SuperscriptBox["r", "2"]]}], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], "-", 
     FractionBox[
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], 
      RowBox[{
       SuperscriptBox[
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "3"], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]], "+", 
     FractionBox[
      RowBox[{
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "-", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
      RowBox[{
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]]}], "r"]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], "qr"}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], "pr"}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox[
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "2"]}], ")"}], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], "qr"}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], "pr"}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox[
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "2"]}], ")"}], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], "qr"}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], "pr"}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     FractionBox[
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "r"]}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]]}]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox["D", "A"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Log", "@", 
          UnderscriptBox["gA", "_"]}], ",", "t"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "[", "gA", "]"}], "[", 
          RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
         UnderscriptBox["evol$eq$gA", "_"]}], "}"}]}], ",", "r"}], "]"}], "//",
     "introduceDs"}], "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       UnderscriptBox["gBet", "_"], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "\[Rule]", 
     UnderscriptBox["eq$gBet$rr", "_"]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$gDA", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gBet", "_"], ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$gBet$r", "_"]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        UnderscriptBox["gBet", "_"], "\[Rule]", 
        RowBox[{"instantiateShifts", "@", 
         UnderscriptBox["gBet", "_"]}]}]}], "\[IndentingNewLine]", "}"}]}], "//",
     "echoNice"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "rr"], 
     StyleBox["\[Beta]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}],
    HoldForm], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["D", "A"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox["\[Beta]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["\[Beta]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox[
     SubscriptBox["D", "A"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "1"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "rr"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["D", "A"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox["\[Beta]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "rr"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["\[Beta]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox[
     SubscriptBox["D", "A"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   RowBox[{
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], ")"}], "2"], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "5"]}]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "A"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], ")"}]}], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "1"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "rr"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["D", "A"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "rr"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   RowBox[{
    StyleBox[
     SubscriptBox["D", "A"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], ")"}]}], "+", 
   RowBox[{
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]]}],
            HoldForm], ")"}], "2"], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "5"]}]]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["D", "A"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox["D", "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}],
           HoldForm], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], ")"}]}], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "1"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox[
     OverscriptBox["D", "~"], "A"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Log", "@", 
          UnderscriptBox["fA", "_"]}], ",", "t"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "[", "fA", "]"}], "[", 
          RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
         UnderscriptBox["evol$eq$fA", "_"]}], "}"}]}], ",", "r"}], "]"}], "//",
     "introduceDs"}], "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       UnderscriptBox["fBet", "_"], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "\[Rule]", 
     UnderscriptBox["eq$fBet$rr", "_"]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$fDA", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fBet", "_"], ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$fBet$r", "_"]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        UnderscriptBox["fBet", "_"], "\[Rule]", 
        RowBox[{"instantiateShifts", "@", 
         UnderscriptBox["fBet", "_"]}]}]}], "\[IndentingNewLine]", "}"}]}], "//",
     "echoNice"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "rr"], 
     StyleBox[
      OverscriptBox["\[Beta]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}],
    HoldForm], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "A"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox[
     OverscriptBox["\[Beta]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       OverscriptBox["\[Beta]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox[
     SubscriptBox[
      OverscriptBox["D", "~"], "A"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "1"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "rr"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "rr"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "A"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox[
     OverscriptBox["\[Beta]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       OverscriptBox["\[Beta]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox[
     SubscriptBox[
      OverscriptBox["D", "~"], "A"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], ")"}], "2"], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "5"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "A"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "1"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "rr"], 
     StyleBox["q",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "rr"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "A"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
   RowBox[{
    StyleBox[
     SubscriptBox[
      OverscriptBox["D", "~"], "A"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], ")"}], "2"], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "5"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "-", 
      FractionBox[
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["D", "~"], "A"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "+", 
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "\[Alpha]"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}],
           HoldForm], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"], "-", 
          RowBox[{"2", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "A"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          SuperscriptBox[
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "2"]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "1"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox["D", "B"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Log", "@", 
          UnderscriptBox["gB", "_"]}], ",", "t"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "[", "gB", "]"}], "[", 
          RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
         UnderscriptBox["evol$eq$gB", "_"]}], "}"}]}], ",", "r"}], "]"}], "//",
     "introduceDs"}], "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         UnderscriptBox["gBet", "_"], ",", "r"}], "]"}], "/", "r"}], "-", 
      RowBox[{
       UnderscriptBox["gBet", "_"], "/", 
       SuperscriptBox["r", "2"]}]}], "\[Rule]", 
     UnderscriptBox["eq$gBetr$r", "_"]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$gDB", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gBet", "_"], ",", "r"}], "]"}], "\[Rule]", 
        UnderscriptBox["eq$gBet$r", "_"]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        UnderscriptBox["gBet", "_"], "\[Rule]", 
        RowBox[{"instantiateShifts", "@", 
         UnderscriptBox["gBet", "_"]}]}]}], "\[IndentingNewLine]", "}"}]}], "//",
     "echoNice"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["\[Beta]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], "r"], "-", 
   FractionBox[
    StyleBox["\[Beta]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], 
    SuperscriptBox["r", "2"]], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["D", "B"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox["\[Beta]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["\[Beta]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox[
     SubscriptBox["D", "B"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "2"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     FractionBox[
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "r"]}],
    HoldForm], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["D", "B"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox["\[Beta]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["\[Beta]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox[
     SubscriptBox["D", "B"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "2"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     FractionBox[
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "r"]}],
    HoldForm], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["D", "B"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"]}],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]], "+", 
   RowBox[{
    StyleBox[
     SubscriptBox["D", "B"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "+", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "A"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}]]}], ")"}]}], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "2"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox[
     OverscriptBox["D", "~"], "B"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Log", "@", 
          UnderscriptBox["fB", "_"]}], ",", "t"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "[", "fB", "]"}], "[", 
          RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
         UnderscriptBox["evol$eq$fB", "_"]}], "}"}]}], ",", "r"}], "]"}], "//",
     "introduceDs"}], "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         UnderscriptBox["fBet", "_"], ",", "r"}], "]"}], "/", "r"}], "-", 
      RowBox[{
       UnderscriptBox["fBet", "_"], "/", 
       SuperscriptBox["r", "2"]}]}], "\[Rule]", 
     UnderscriptBox["eq$fBetr$r", "_"]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$fDB", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fBet", "_"], ",", "r"}], "]"}], "\[Rule]", 
        UnderscriptBox["eq$fBet$r", "_"]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        UnderscriptBox["fBet", "_"], "\[Rule]", 
        RowBox[{"instantiateShifts", "@", 
         UnderscriptBox["fBet", "_"]}]}]}], "\[IndentingNewLine]", "}"}]}], "//",
     "echoNice"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       OverscriptBox["\[Beta]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], "r"], "-", 
   FractionBox[
    StyleBox[
     OverscriptBox["\[Beta]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], 
    SuperscriptBox["r", "2"]], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "B"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox[
     OverscriptBox["\[Beta]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       OverscriptBox["\[Beta]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox[
     SubscriptBox[
      OverscriptBox["D", "~"], "B"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "2"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     FractionBox[
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "r"]}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "B"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox[
     OverscriptBox["\[Beta]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       OverscriptBox["\[Beta]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox[
     SubscriptBox[
      OverscriptBox["D", "~"], "B"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "2"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     FractionBox[
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "r"]}],
    HoldForm], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "3"], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["D", "~"], "B"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "-", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
   RowBox[{
    StyleBox[
     SubscriptBox[
      OverscriptBox["D", "~"], "B"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}],
       HoldForm], "-", 
      FractionBox[
       RowBox[{
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox["p",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], 
       RowBox[{
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       RowBox[{
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "2"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], "-", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox["\[Sigma]", "g"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$g\[Sigma]1", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["eq$g\[Sigma]", "_"], ",", "t"}], "]"}], "/.", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Derivative", "[", 
                 RowBox[{"1", ",", "0"}], "]"}], "[", "gA", "]"}], "[", 
               RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
              UnderscriptBox["evol$eq$gA", "_"]}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Derivative", "[", 
                 RowBox[{"1", ",", "0"}], "]"}], "[", "gB", "]"}], "[", 
               RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
              UnderscriptBox["evol$eq$gB", "_"]}]}], "\[IndentingNewLine]", 
            "}"}]}], "//", "introduceDs"}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["q", "_"], ",", "r"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{"D", "[", 
             RowBox[{
              UnderscriptBox["qr", "_"], ",", "r"}], "]"}]}], "+", 
           RowBox[{
            UnderscriptBox["q", "_"], "/", "r"}]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         UnderscriptBox["q", "_"], "\[Rule]", 
         RowBox[{"r", " ", 
          RowBox[{"HoldForm", "[", 
           RowBox[{
            RowBox[{"q", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1"}], "]"}], "[", "qr", "]"}], "[", 
         RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"HoldForm", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"q", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
         "]"}]}], "}"}]}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", 
          UnderscriptBox["gA", "_"], ",", 
          UnderscriptBox["gB", "_"], ",", 
          UnderscriptBox["gAlp", "_"]}], "}"}], ",", "Simplify"}], "]"}], 
      "&"}]}], "//", "echoNice"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Beta]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}]]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox["\[Beta]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "+", 
       RowBox[{
        StyleBox["\[Beta]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
       RowBox[{
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["K", "1"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["K", "2"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]]}]}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "temp$", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], "k$g", " ", 
       UnderscriptBox["fA", "_"], 
       RowBox[{"P", "[", 
        RowBox[{"2", ",", "1", ",", 
         UnderscriptBox["R", "_"]}], "]"}], 
       UnderscriptBox["p", "_"]}], "\[Equal]", 
      RowBox[{
       FractionBox["1", "2"], "k$g", " ", 
       UnderscriptBox["fA", "_"], " ", 
       RowBox[{"P", "[", 
        RowBox[{"2", ",", "1", ",", 
         UnderscriptBox["R", "_"]}], "]"}], 
       UnderscriptBox["eq$p$g", "_"]}]}], ")"}], "//", "introduceDs"}], "//", 
   "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         UnderscriptBox["gK1", "_"]}], "+", 
        UnderscriptBox["gK2", "_"]}], ")"}], "/", "r"}], "\[Rule]", 
     RowBox[{"-", "temp$"}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol$reg$gK", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"%", ",", "temp$"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "//", "Simplify"}], 
    "//", "echoNice"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["eq$g\[Sigma]", "_"], ",", "t"}], "]"}], "/.", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", 
                RowBox[{"1", ",", "0"}], "]"}], "[", "gA", "]"}], "[", 
              RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
             UnderscriptBox["evol$eq$gA", "_"]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", 
                RowBox[{"1", ",", "0"}], "]"}], "[", "gB", "]"}], "[", 
              RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
             UnderscriptBox["evol$eq$gB", "_"]}]}], "\[IndentingNewLine]", 
           "}"}]}], "//", "introduceDs"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           UnderscriptBox["gBet", "_"], ",", "r"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"r", " ", 
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["qr", "_"], ",", "r"}], "]"}]}], "+", 
          RowBox[{
           UnderscriptBox["gBet", "_"], "/", "r"}]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        UnderscriptBox["gBet", "_"], "\[Rule]", 
        RowBox[{"r", " ", 
         RowBox[{"HoldForm", "[", 
          RowBox[{
           RowBox[{"gBet", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "qr", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{"HoldForm", "[", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"gBet", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
        "]"}]}], "}"}]}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", 
         UnderscriptBox["gA", "_"], ",", 
         UnderscriptBox["gB", "_"], ",", 
         UnderscriptBox["gAlp", "_"]}], "}"}], ",", "Simplify"}], "]"}], 
     "&"}]}], "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$g\[Sigma]", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           UnderscriptBox["gB", "_"], "%"}], "/.", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               UnderscriptBox["gK1", "_"]}], "+", 
              UnderscriptBox["gK2", "_"]}], ")"}], "/", "r"}], "\[Rule]", 
           RowBox[{"-", "temp$"}]}]}], "/.", "sol$reg$gK"}], "/.", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"HoldForm", "[", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"gBet", "[", 
                RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}],
             "]"}], "\[Rule]", 
           UnderscriptBox["eq$gBetr$r", "_"]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"HoldForm", "[", 
            RowBox[{
             RowBox[{"gBet", "[", 
              RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"instantiateShifts", "@", 
             UnderscriptBox["gBet", "_"]}], "/", "r"}]}]}], 
         "\[IndentingNewLine]", "}"}]}], "//", 
       RowBox[{
        RowBox[{"Collect", "[", 
         RowBox[{"#", ",", 
          RowBox[{"{", 
           RowBox[{"r", ",", 
            UnderscriptBox["gAlp", "_"], ",", 
            UnderscriptBox["gA", "_"], ",", 
            UnderscriptBox["gB", "_"]}], "}"}], ",", "Simplify"}], "]"}], 
        "&"}]}], ")"}], "/", 
     RowBox[{"(", 
      UnderscriptBox["gB", "_"], ")"}]}], "//", "echoNice"}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
     HoldForm], " ", 
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    StyleBox[
     OverscriptBox["A", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "g"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "\[Equal]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["K", "2"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      StyleBox[
       SubscriptBox["K", "2"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], "r"], "+", 
    RowBox[{
     StyleBox[
      SubscriptBox["D", "B"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}], 
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
     HoldForm], " ", 
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    StyleBox[
     OverscriptBox["A", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "g"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}], "\[Equal]", 
   RowBox[{
    RowBox[{"-", "temp$"}], "+", 
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["K", "2"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], "+", 
    RowBox[{
     StyleBox[
      SubscriptBox["D", "B"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}], 
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{"temp$", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["K", "2"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], "+", 
    RowBox[{
     StyleBox[
      SubscriptBox["D", "B"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
      HoldForm], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "g"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       SubscriptBox["\[Kappa]", "g"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["S", "^"], "r"],
       StripOnInput->False,
       LineColor->RGBColor[0.5, 0, 0.5],
       FrontFaceColor->RGBColor[0.5, 0, 0.5],
       BackFaceColor->RGBColor[0.5, 0, 0.5],
       GraphicsColor->RGBColor[0.5, 0, 0.5],
       FontColor->RGBColor[0.5, 0, 0.5]]}], 
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}]]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         FractionBox[
          StyleBox["\[Beta]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "r"]}],
        HoldForm], "+", 
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox["\[Beta]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "r"],
         HoldForm], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox["D", "A"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}], 
    StyleBox["B",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox["B",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  FractionBox[
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"]}],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "-", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]]}], "r"], "+", 
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          FractionBox[
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], "r"]}],
         HoldForm], 
        SuperscriptBox[
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "3"]], "+", 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox["K", "2"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}],
            HoldForm]}], "+", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              SubscriptBox["K", "1"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], "-", 
             StyleBox[
              SubscriptBox["K", "2"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "2"],
            HoldForm], " ", 
           StyleBox["p",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["A", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox["\[Kappa]", "g"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "-", 
       FractionBox[
        RowBox[{
         StyleBox[
          SubscriptBox["\[Kappa]", "g"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          StripOnInput->False,
          LineColor->RGBColor[0.5, 0, 0.5],
          FrontFaceColor->RGBColor[0.5, 0, 0.5],
          BackFaceColor->RGBColor[0.5, 0, 0.5],
          GraphicsColor->RGBColor[0.5, 0, 0.5],
          FontColor->RGBColor[0.5, 0, 0.5]]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}]]}], ")"}]}]}], 
   StyleBox["B",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox["\[Sigma]", "f"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$f\[Sigma]1", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["eq$f\[Sigma]", "_"], ",", "t"}], "]"}], "/.", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Derivative", "[", 
                 RowBox[{"1", ",", "0"}], "]"}], "[", "fA", "]"}], "[", 
               RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
              UnderscriptBox["evol$eq$fA", "_"]}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Derivative", "[", 
                 RowBox[{"1", ",", "0"}], "]"}], "[", "fB", "]"}], "[", 
               RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
              UnderscriptBox["evol$eq$fB", "_"]}]}], "\[IndentingNewLine]", 
            "}"}]}], "//", "introduceDs"}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["q", "_"], ",", "r"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{"D", "[", 
             RowBox[{
              UnderscriptBox["qr", "_"], ",", "r"}], "]"}]}], "+", 
           RowBox[{
            UnderscriptBox["q", "_"], "/", "r"}]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         UnderscriptBox["q", "_"], "\[Rule]", 
         RowBox[{"r", " ", 
          RowBox[{"HoldForm", "[", 
           RowBox[{
            RowBox[{"q", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1"}], "]"}], "[", "qr", "]"}], "[", 
         RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
        RowBox[{"HoldForm", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"q", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
         "]"}]}], "}"}]}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", 
          UnderscriptBox["fA", "_"], ",", 
          UnderscriptBox["fB", "_"], ",", 
          UnderscriptBox["fAlp", "_"]}], "}"}], ",", "Simplify"}], "]"}], 
      "&"}]}], "//", "echoNice"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      StyleBox[
       OverscriptBox["\[Beta]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          OverscriptBox["\[Beta]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{
        StyleBox[
         OverscriptBox["\[Beta]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
       RowBox[{
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "1"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "2"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]]}]}]], "Echo"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "temp$", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], "k$f", " ", 
       UnderscriptBox["gA", "_"], 
       SuperscriptBox[
        UnderscriptBox["fB", "_"], 
        RowBox[{"-", "2"}]], 
       SuperscriptBox[
        UnderscriptBox["gB", "_"], "2"], 
       RowBox[{"P", "[", 
        RowBox[{"2", ",", "1", ",", 
         UnderscriptBox["R", "_"]}], "]"}], 
       UnderscriptBox["p", "_"]}], "\[Equal]", 
      RowBox[{
       FractionBox["1", "2"], "k$f", " ", 
       UnderscriptBox["gA", "_"], 
       SuperscriptBox[
        UnderscriptBox["fB", "_"], 
        RowBox[{"-", "2"}]], 
       SuperscriptBox[
        UnderscriptBox["gB", "_"], "2"], " ", 
       RowBox[{"P", "[", 
        RowBox[{"2", ",", "1", ",", 
         UnderscriptBox["R", "_"]}], "]"}], 
       UnderscriptBox["eq$p$f", "_"]}]}], ")"}], "//", "introduceDs"}], "//", 
   "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        UnderscriptBox["fK1", "_"], "-", 
        UnderscriptBox["fK2", "_"]}], ")"}], "/", "r"}], "\[Rule]", 
     "temp$"}]}], "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol$reg$fK", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{"%", ",", "temp$"}], "]"}], "\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
      RowBox[{
       UnderscriptBox["fB", "_"], "\[Rule]", 
       RowBox[{
        UnderscriptBox["R", "_"], 
        UnderscriptBox["gB", "_"]}]}]}], "//", "Simplify"}], "//", 
    "echoNice"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["eq$f\[Sigma]", "_"], ",", "t"}], "]"}], "/.", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", 
                RowBox[{"1", ",", "0"}], "]"}], "[", "fA", "]"}], "[", 
              RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
             UnderscriptBox["evol$eq$fA", "_"]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", 
                RowBox[{"1", ",", "0"}], "]"}], "[", "fB", "]"}], "[", 
              RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
             UnderscriptBox["evol$eq$fB", "_"]}]}], "\[IndentingNewLine]", 
           "}"}]}], "//", "introduceDs"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           UnderscriptBox["fBet", "_"], ",", "r"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"r", " ", 
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["qr", "_"], ",", "r"}], "]"}]}], "+", 
          RowBox[{
           UnderscriptBox["fBet", "_"], "/", "r"}]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        UnderscriptBox["fBet", "_"], "\[Rule]", 
        RowBox[{"r", " ", 
         RowBox[{"HoldForm", "[", 
          RowBox[{
           RowBox[{"fBet", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "qr", "]"}], "[", 
        RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
       RowBox[{"HoldForm", "[", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fBet", "[", 
            RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}], 
        "]"}]}], "}"}]}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", 
         UnderscriptBox["fA", "_"], ",", 
         UnderscriptBox["fB", "_"], ",", 
         UnderscriptBox["fAlp", "_"]}], "}"}], ",", "Simplify"}], "]"}], 
     "&"}]}], "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$f\[Sigma]", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           UnderscriptBox["fB", "_"], "%"}], "/.", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               UnderscriptBox["fK1", "_"]}], "+", 
              UnderscriptBox["fK2", "_"]}], ")"}], "/", "r"}], "\[Rule]", 
           RowBox[{"-", "temp$"}]}]}], "/.", "sol$reg$fK"}], "/.", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"HoldForm", "[", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"fBet", "[", 
                RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], "]"}],
             "]"}], "\[Rule]", 
           UnderscriptBox["eq$fBetr$r", "_"]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"HoldForm", "[", 
            RowBox[{
             RowBox[{"fBet", "[", 
              RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"instantiateShifts", "@", 
             UnderscriptBox["fBet", "_"]}], "/", "r"}]}]}], 
         "\[IndentingNewLine]", "}"}]}], "//", 
       RowBox[{
        RowBox[{"Collect", "[", 
         RowBox[{"#", ",", 
          RowBox[{"{", 
           RowBox[{"r", ",", 
            UnderscriptBox["fAlp", "_"], ",", 
            UnderscriptBox["fA", "_"], ",", 
            UnderscriptBox["fB", "_"]}], "}"}], ",", "Simplify"}], "]"}], 
        "&"}]}], ")"}], "/", 
     RowBox[{"(", 
      UnderscriptBox["fB", "_"], ")"}]}], "//", "echoNice"}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "2"]}]], "\[Equal]", 
   RowBox[{
    RowBox[{"-", 
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm]}], "+", 
    FractionBox[
     RowBox[{
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "1"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "-", 
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "2"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], "r"], "+", 
    RowBox[{
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "B"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     SuperscriptBox[
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      SubscriptBox["\[Kappa]", "f"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "2"]}]], "\[Equal]", 
   RowBox[{"temp$", "-", 
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "2"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], "+", 
    RowBox[{
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "B"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "-", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{"temp$", "\[Rule]", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "2"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], "+", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       SubscriptBox["\[Kappa]", "f"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "2"]}]], "+", 
    RowBox[{
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "B"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "1"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         FractionBox[
          StyleBox[
           OverscriptBox["\[Beta]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "r"]}],
        HoldForm], "+", 
       RowBox[{
        TagBox[
         FractionBox[
          StyleBox[
           OverscriptBox["\[Beta]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "r"],
         HoldForm], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "A"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], 
    StyleBox[
     OverscriptBox["B", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]], "+", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "1"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "+", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{"r", " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  FractionBox[
   RowBox[{
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       FractionBox[
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"]}],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"], " ", 
      StyleBox[
       OverscriptBox["\[Alpha]", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       StyleBox["q",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "-", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        StyleBox["p",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "-", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]]}], "r"], "+", 
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           FractionBox[
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], "r"]}],
          HoldForm], 
         SuperscriptBox[
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], "3"]]}], "+", 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           TagBox[
            RowBox[{
             SubscriptBox["\[PartialD]", "r"], 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}],
            HoldForm]}], "-", 
          FractionBox[
           RowBox[{
            TagBox[
             SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
               StyleBox["R",
                StripOnInput->False,
                LineColor->RGBColor[1, 0, 1],
                FrontFaceColor->RGBColor[1, 0, 1],
                BackFaceColor->RGBColor[1, 0, 1],
                GraphicsColor->RGBColor[1, 0, 1],
                FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
              "2"],
             HoldForm], " ", 
            StyleBox["A",
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]], " ", 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]], " ", 
            StyleBox[
             SubscriptBox["\[Kappa]", "f"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], 
           RowBox[{"2", " ", 
            SuperscriptBox[
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "2"]}]], "+", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]], "-", 
             StyleBox[
              SubscriptBox[
               OverscriptBox["K", "~"], "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], 
   StyleBox[
    OverscriptBox["B", "~"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], "p"}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "temp$", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp$", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"introduceDs", "@", 
       UnderscriptBox["evol$eq$p", "_"]}], "/.", 
      RowBox[{
       UnderscriptBox["fB", "_"], "\[Rule]", 
       RowBox[{
        UnderscriptBox["gB", "_"], 
        UnderscriptBox["R", "_"]}]}]}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"Expand", "@", "#"}], ",", 
        RowBox[{"{", "r", "}"}], ",", "FullSimplify"}], "]"}], "&"}]}], "//", 
    "echoNice"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"temp$", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "//",
    "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     UnderscriptBox["fB", "_"], 
     RowBox[{"-", "1"}]], 
    UnderscriptBox["gA", "_"], 
    UnderscriptBox["fA", "_"], 
    RowBox[{"P", "[", 
     RowBox[{"2", ",", "1", ",", 
      UnderscriptBox["R", "_"]}], "]"}], "r"}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", 
    RowBox[{"temp$", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
    "//", "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Times", "[", 
       RowBox[{"2", ",", 
        RowBox[{"gA", "[", 
         RowBox[{"t", ",", "r"}], "]"}], ",", "f_", ",", 
        RowBox[{"R", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"2", "f", " ", 
       UnderscriptBox["gA", "_"], 
       RowBox[{
        UnderscriptBox["fB", "_"], "/", 
        UnderscriptBox["gB", "_"]}]}]}]}], "//", "Expand"}], "//", 
   "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       UnderscriptBox["gA", "_"], "\[Rule]", 
       RowBox[{
        UnderscriptBox["gB", "_"], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           UnderscriptBox["g\[Sigma]", "_"], "r"}]}], ")"}]}]}], ",", 
      RowBox[{
       UnderscriptBox["fA", "_"], "\[Rule]", 
       RowBox[{
        UnderscriptBox["fB", "_"], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           UnderscriptBox["f\[Sigma]", "_"], "r"}]}], ")"}]}]}]}], "}"}]}], "//",
    "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       UnderscriptBox["Lt", "_"]}], ")"}], "%"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "r", ",", "Simplify"}], "]"}], "&"}]}], "//", 
   "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SuperscriptBox[
      UnderscriptBox["Lt", "_"], "2"], "\[Rule]", 
     RowBox[{"1", "+", 
      SuperscriptBox[
       UnderscriptBox["p", "_"], "2"]}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         UnderscriptBox["Lt", "_"]}], ")"}], "r", 
       SuperscriptBox[
        UnderscriptBox["fB", "_"], 
        RowBox[{"-", "1"}]], 
       UnderscriptBox["gA", "_"], 
       UnderscriptBox["fA", "_"], 
       RowBox[{"P", "[", 
        RowBox[{"2", ",", "1", ",", 
         UnderscriptBox["R", "_"]}], "]"}]}], ")"}]}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "r", ",", "Simplify"}], "]"}], "&"}]}], "//", 
   "echoNice"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$p2", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "+", 
      RowBox[{"temp$", "\[LeftDoubleBracket]", 
       RowBox[{"2", ";;", "All"}], "\[RightDoubleBracket]"}]}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"Expand", "@", "#"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", 
          UnderscriptBox["p", "_"], ",", 
          RowBox[{"P", "[", 
           RowBox[{"2", ",", "1", ",", 
            UnderscriptBox["R", "_"]}], "]"}]}], "}"}], ",", "Simplify"}], 
       "]"}], "&"}]}], "//", "echoNice"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]]}], "+", 
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
           "1"],
          HoldForm], " ", 
         StyleBox[
          OverscriptBox["\[Alpha]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["R",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 1],
       FrontFaceColor->RGBColor[1, 0, 1],
       BackFaceColor->RGBColor[1, 0, 1],
       GraphicsColor->RGBColor[1, 0, 1],
       FontColor->RGBColor[1, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "+", 
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
           "1"],
          HoldForm], " ", 
         StyleBox["\[Lambda]",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], " ", 
         StyleBox[
          OverscriptBox["\[Alpha]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], 
    RowBox[{"r", " ", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             StyleBox["\[Alpha]",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "+", 
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], " ", 
             StyleBox["\[Lambda]",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             StyleBox[
              OverscriptBox["\[Alpha]", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         RowBox[{
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "2"],
           HoldForm], " ", 
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["A", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          TagBox[
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], 
            StyleBox["p",
             StripOnInput->False,
             LineColor->RGBColor[0, 
               Rational[2, 3], 0],
             FrontFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             BackFaceColor->RGBColor[0, 
               Rational[2, 3], 0],
             GraphicsColor->RGBColor[0, 
               Rational[2, 3], 0],
             FontColor->RGBColor[0, 
               Rational[2, 3], 0]]}],
           HoldForm], " ", 
          TagBox[
           SubsuperscriptBox[
            RowBox[{"\[LeftAngleBracket]", 
             StyleBox["R",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 1],
              FrontFaceColor->RGBColor[1, 0, 1],
              BackFaceColor->RGBColor[1, 0, 1],
              GraphicsColor->RGBColor[1, 0, 1],
              FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
            "2"],
           HoldForm], " ", 
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["q",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]]}], "+", 
         RowBox[{
          StyleBox["\[Alpha]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "2"],
              HoldForm], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]]}], " ", 
                StyleBox[
                 SubscriptBox["D", "\[Alpha]"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               RowBox[{
                StyleBox["A",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], " ", 
                StyleBox["p",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], " ", 
                StyleBox[
                 SubscriptBox["K", "1"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1",
                "1"],
              HoldForm], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 StyleBox["\[Lambda]",
                  StripOnInput->False,
                  LineColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FrontFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  BackFaceColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  GraphicsColor->RGBColor[0, 
                    Rational[2, 3], 0],
                  FontColor->RGBColor[0, 
                    Rational[2, 3], 0]]}], " ", 
                StyleBox[
                 SubscriptBox["D", "B"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}], "+", 
               RowBox[{
                StyleBox["A",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]], " ", 
                StyleBox["p",
                 StripOnInput->False,
                 LineColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FrontFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 BackFaceColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 GraphicsColor->RGBColor[0, 
                   Rational[2, 3], 0],
                 FontColor->RGBColor[0, 
                   Rational[2, 3], 0]], " ", 
                StyleBox[
                 SubscriptBox["K", "2"],
                 StripOnInput->False,
                 LineColor->RGBColor[0, 0, 1],
                 FrontFaceColor->RGBColor[0, 0, 1],
                 BackFaceColor->RGBColor[0, 0, 1],
                 GraphicsColor->RGBColor[0, 0, 1],
                 FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          StyleBox[
           OverscriptBox["\[Alpha]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             TagBox[
              SubsuperscriptBox[
               RowBox[{"\[LeftAngleBracket]", 
                StyleBox["R",
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 1],
                 FrontFaceColor->RGBColor[1, 0, 1],
                 BackFaceColor->RGBColor[1, 0, 1],
                 GraphicsColor->RGBColor[1, 0, 1],
                 FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2",
                "1"],
              HoldForm], " ", 
             StyleBox[
              SubscriptBox["D", "B"],
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]]}], "+", 
            RowBox[{
             StyleBox["A",
              StripOnInput->False,
              LineColor->RGBColor[0, 0, 1],
              FrontFaceColor->RGBColor[0, 0, 1],
              BackFaceColor->RGBColor[0, 0, 1],
              GraphicsColor->RGBColor[0, 0, 1],
              FontColor->RGBColor[0, 0, 1]], " ", 
             StyleBox["p",
              StripOnInput->False,
              LineColor->RGBColor[0, 
                Rational[2, 3], 0],
              FrontFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              BackFaceColor->RGBColor[0, 
                Rational[2, 3], 0],
              GraphicsColor->RGBColor[0, 
                Rational[2, 3], 0],
              FontColor->RGBColor[0, 
                Rational[2, 3], 0]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "1"],
                 HoldForm], " ", 
                StyleBox[
                 SubscriptBox[
                  OverscriptBox["K", "~"], "2"],
                 StripOnInput->False,
                 LineColor->RGBColor[1, 0, 0],
                 FrontFaceColor->RGBColor[1, 0, 0],
                 BackFaceColor->RGBColor[1, 0, 0],
                 GraphicsColor->RGBColor[1, 0, 0],
                 FontColor->RGBColor[1, 0, 0]]}], "+", 
               RowBox[{
                TagBox[
                 SubsuperscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                   StyleBox["R",
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 1],
                    FrontFaceColor->RGBColor[1, 0, 1],
                    BackFaceColor->RGBColor[1, 0, 1],
                    GraphicsColor->RGBColor[1, 0, 1],
                    FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], 
                  "1", "2"],
                 HoldForm], " ", 
                RowBox[{"(", 
                 RowBox[{
                  StyleBox[
                   SubscriptBox[
                    OverscriptBox["K", "~"], "1"],
                   StripOnInput->False,
                   LineColor->RGBColor[1, 0, 0],
                   FrontFaceColor->RGBColor[1, 0, 0],
                   BackFaceColor->RGBColor[1, 0, 0],
                   GraphicsColor->RGBColor[1, 0, 0],
                   FontColor->RGBColor[1, 0, 0]], "+", 
                  RowBox[{"2", " ", 
                   StyleBox[
                    SubscriptBox[
                    OverscriptBox["K", "~"], "2"],
                    StripOnInput->False,
                    LineColor->RGBColor[1, 0, 0],
                    FrontFaceColor->RGBColor[1, 0, 0],
                    BackFaceColor->RGBColor[1, 0, 0],
                    GraphicsColor->RGBColor[1, 0, 0],
                    FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}], "+", 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["R",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 1],
      FrontFaceColor->RGBColor[1, 0, 1],
      BackFaceColor->RGBColor[1, 0, 1],
      GraphicsColor->RGBColor[1, 0, 1],
      FontColor->RGBColor[1, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
         HoldForm], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], 
   RowBox[{"r", " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
     HoldForm], " ", 
    StyleBox["A",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    StyleBox[
     OverscriptBox["A", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}]]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  FractionBox[
   RowBox[{"r", " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
     HoldForm], " ", 
    StyleBox["A",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    StyleBox[
     OverscriptBox["A", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox[
    OverscriptBox["B", "~"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}], "+", 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["R",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 1],
      FrontFaceColor->RGBColor[1, 0, 1],
      BackFaceColor->RGBColor[1, 0, 1],
      GraphicsColor->RGBColor[1, 0, 1],
      FontColor->RGBColor[1, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
         HoldForm], " ", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], 
   StyleBox[
    OverscriptBox["B", "~"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    StyleBox["B",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
      HoldForm], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    StyleBox[
     OverscriptBox["B", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    StyleBox["B",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
      HoldForm], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    StyleBox[
     OverscriptBox["B", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{"2", " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
     HoldForm], " ", 
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r", " ", 
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
     HoldForm], " ", 
    StyleBox["\[Lambda]",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r", " ", 
       StyleBox["\[Sigma]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "-", 
   RowBox[{"2", " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
     HoldForm], " ", 
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    StyleBox["\[Lambda]",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r", " ", 
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "-", 
   RowBox[{"2", " ", 
    TagBox[
     SubsuperscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       StyleBox["R",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 1],
        FrontFaceColor->RGBColor[1, 0, 1],
        BackFaceColor->RGBColor[1, 0, 1],
        GraphicsColor->RGBColor[1, 0, 1],
        FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
     HoldForm], " ", 
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r", " ", 
       StyleBox[
        OverscriptBox["\[Sigma]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox[
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
        HoldForm], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "-", 
   RowBox[{"2", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}], " ", 
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
        HoldForm], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         RowBox[{
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox[
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
        HoldForm], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "-", 
   RowBox[{"2", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      StyleBox["\[Lambda]",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
        HoldForm], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}], " ", 
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
      RowBox[{
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
        HoldForm], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         RowBox[{
          StyleBox["\[Lambda]",
           StripOnInput->False,
           LineColor->RGBColor[0, 
             Rational[2, 3], 0],
           FrontFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           BackFaceColor->RGBColor[0, 
             Rational[2, 3], 0],
           GraphicsColor->RGBColor[0, 
             Rational[2, 3], 0],
           FontColor->RGBColor[0, 
             Rational[2, 3], 0]], " ", 
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox[
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], "2"], " ", 
      StyleBox[
       OverscriptBox["B", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm], " ", 
         StyleBox["\[Alpha]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        RowBox[{
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
           "1"],
          HoldForm], " ", 
         StyleBox[
          OverscriptBox["\[Alpha]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      TagBox[
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", 
         StyleBox["R",
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 1],
          FrontFaceColor->RGBColor[1, 0, 1],
          BackFaceColor->RGBColor[1, 0, 1],
          GraphicsColor->RGBColor[1, 0, 1],
          FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
       HoldForm], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        StyleBox["\[Lambda]",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]]}], ")"}], " ", 
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox["\[Sigma]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "-", 
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
         HoldForm], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "-", 
          RowBox[{
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["\[Sigma]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], 
    RowBox[{
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]]}],
     HoldForm], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      StyleBox["p",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], "2"], " ", 
     StyleBox[
      OverscriptBox["B", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         TagBox[
          SubsuperscriptBox[
           RowBox[{"\[LeftAngleBracket]", 
            StyleBox["R",
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 1],
             FrontFaceColor->RGBColor[1, 0, 1],
             BackFaceColor->RGBColor[1, 0, 1],
             GraphicsColor->RGBColor[1, 0, 1],
             FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
           "1"],
          HoldForm]}], " ", 
        StyleBox["\[Alpha]",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "+", 
       RowBox[{
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", "1"],
         HoldForm], " ", 
        StyleBox[
         OverscriptBox["\[Alpha]", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}], ")"}], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "-", 
   FractionBox[
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      SubscriptBox["D", "\[Alpha]"],
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    StyleBox["A",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        StyleBox[
         OverscriptBox["B", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               StyleBox["\[Lambda]",
                StripOnInput->False,
                LineColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FrontFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                BackFaceColor->RGBColor[0, 
                  Rational[2, 3], 0],
                GraphicsColor->RGBColor[0, 
                  Rational[2, 3], 0],
                FontColor->RGBColor[0, 
                  Rational[2, 3], 0]]}], " ", 
              StyleBox["\[Sigma]",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], "+", 
             StyleBox[
              OverscriptBox["\[Sigma]", "~"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontColor->RGBColor[1, 0, 0]]}], ")"}]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["\[Alpha]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              StyleBox["\[Sigma]",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontColor->RGBColor[0, 0, 1]]}], "+", 
             RowBox[{
              StyleBox["\[Lambda]",
               StripOnInput->False,
               LineColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FrontFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               BackFaceColor->RGBColor[0, 
                 Rational[2, 3], 0],
               GraphicsColor->RGBColor[0, 
                 Rational[2, 3], 0],
               FontColor->RGBColor[0, 
                 Rational[2, 3], 0]], " ", 
              StyleBox[
               OverscriptBox["\[Sigma]", "~"],
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 0],
               FrontFaceColor->RGBColor[1, 0, 0],
               BackFaceColor->RGBColor[1, 0, 0],
               GraphicsColor->RGBColor[1, 0, 0],
               FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["\[Alpha]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
        StyleBox[
         SubscriptBox["D", "B"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "-", 
       RowBox[{
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], " ", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", 
             "1"],
            HoldForm], " ", 
           StyleBox["\[Alpha]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          RowBox[{
           TagBox[
            SubsuperscriptBox[
             RowBox[{"\[LeftAngleBracket]", 
              StyleBox["R",
               StripOnInput->False,
               LineColor->RGBColor[1, 0, 1],
               FrontFaceColor->RGBColor[1, 0, 1],
               BackFaceColor->RGBColor[1, 0, 1],
               GraphicsColor->RGBColor[1, 0, 1],
               FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "2", 
             "1"],
            HoldForm], " ", 
           StyleBox["\[Lambda]",
            StripOnInput->False,
            LineColor->RGBColor[0, 
              Rational[2, 3], 0],
            FrontFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            BackFaceColor->RGBColor[0, 
              Rational[2, 3], 0],
            GraphicsColor->RGBColor[0, 
              Rational[2, 3], 0],
            FontColor->RGBColor[0, 
              Rational[2, 3], 0]], " ", 
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "B"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
    RowBox[{
     TagBox[
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
        StyleBox["R",
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 1],
         FrontFaceColor->RGBColor[1, 0, 1],
         BackFaceColor->RGBColor[1, 0, 1],
         GraphicsColor->RGBColor[1, 0, 1],
         FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
      HoldForm], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     StyleBox[
      SubscriptBox[
       OverscriptBox["D", "~"], "\[Alpha]"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    StyleBox[
     OverscriptBox["A", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]], "+", 
   RowBox[{
    StyleBox["p",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "1"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "+", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "2"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        TagBox[
         SubsuperscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
           StyleBox["R",
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 1],
            FrontFaceColor->RGBColor[1, 0, 1],
            BackFaceColor->RGBColor[1, 0, 1],
            GraphicsColor->RGBColor[1, 0, 1],
            FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "1"],
         HoldForm], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           StyleBox["\[Alpha]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[
            SubscriptBox["K", "2"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "-", 
          RowBox[{
           StyleBox[
            OverscriptBox["\[Alpha]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["K", "~"], "2"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}], 
       TagBox[
        SubsuperscriptBox[
         RowBox[{"\[LeftAngleBracket]", 
          StyleBox["R",
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 1],
           FrontFaceColor->RGBColor[1, 0, 1],
           BackFaceColor->RGBColor[1, 0, 1],
           GraphicsColor->RGBColor[1, 0, 1],
           FontColor->RGBColor[1, 0, 1]], "\[RightAngleBracket]"}], "1", "2"],
        HoldForm]]}], ")"}]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"3", ",", "2", ",", 
         UnderscriptBox["R", "_"]}], "]"}], "/.", 
       RowBox[{"P", "\[Rule]", "eq$esP"}]}], ",", "r"}], "]"}], "==", 
    RowBox[{"3", 
     RowBox[{"P", "[", 
      RowBox[{"2", ",", "3", ",", 
       UnderscriptBox["R", "_"]}], "]"}], 
     RowBox[{"D", "[", 
      RowBox[{
       UnderscriptBox["R", "_"], ",", "r"}], "]"}]}]}], "/.", 
   RowBox[{"P", "\[Rule]", "eq$esP"}]}], "//", "Simplify"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], "K"}], TraditionalForm]]],
 " and  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox["K", "\[CapitalDelta]"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soL$gKD", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        UnderscriptBox["gK", "_"], "\[Equal]", 
        RowBox[{
         UnderscriptBox["gK1", "_"], "+", 
         RowBox[{"2", 
          UnderscriptBox["gK2", "_"]}]}]}], ",", 
       RowBox[{
        UnderscriptBox["gKD", "_"], "\[Equal]", 
        RowBox[{
         UnderscriptBox["gK1", "_"], "-", 
         UnderscriptBox["gK2", "_"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       UnderscriptBox["gK1", "_"], ",", 
       UnderscriptBox["gK2", "_"]}], "}"}]}], "]"}], "\[LeftDoubleBracket]", 
   "1", "\[RightDoubleBracket]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"gK1", "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gK", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"gKD", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"gK2", "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gK", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "-", 
       RowBox[{"gKD", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   UnderscriptBox["evol$eq$gK1", "_"], "+", 
   RowBox[{"2", 
    UnderscriptBox["evol$eq$gK2", "_"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"introduceDs", "@", 
    RowBox[{"instantiateShifts", "@", 
     RowBox[{"Simplify", "@", "%"}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", 
       SuperscriptBox[
        UnderscriptBox["gA", "_"], "2"]]}], "+", 
     FractionBox["2", 
      SuperscriptBox[
       UnderscriptBox["gB", "_"], "2"]]}], "\[Rule]", 
    RowBox[{"2", "r", 
     FractionBox[
      UnderscriptBox["g\[Sigma]", "_"], 
      UnderscriptBox["gA", "_"]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        UnderscriptBox["gA", "_"]], "+", 
       FractionBox["1", 
        UnderscriptBox["gB", "_"]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$gK", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "//", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"gK1", ",", "gK2"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"gK1", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"gK", "[", 
               RowBox[{"t", ",", "r"}], "]"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"gKD", "[", 
                RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"gK2", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"gK", "[", 
               RowBox[{"t", ",", "r"}], "]"}], "-", 
              RowBox[{"gKD", "[", 
               RowBox[{"t", ",", "r"}], "]"}]}], ")"}]}]}], ";", 
          "\[IndentingNewLine]", "#"}]}], "]"}], "&"}]}], "//", 
     "introduceDs"}], "//", "echoNice"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm], "+", 
      RowBox[{"2", " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "2"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}]}], ")"}], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["2", 
         SuperscriptBox[
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]]}], "+", 
       FractionBox["2", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    SuperscriptBox["r", "2"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "1"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "+", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["K", "2"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm]}]}], ")"}], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        StyleBox[
         SubscriptBox["D", "A"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], "+", 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          SubscriptBox["K", "1"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "+", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox["K", "2"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]}], ")"}], "2"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox[
         SubscriptBox["gJK", "1"],
         Background->RGBColor[0.87, 0.94, 1],
         BaseStyle->RGBColor[0, 0, 1],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{"2", " ", 
       FrameBox[
        SubscriptBox["gJK", "2"],
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "g"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox["K",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox["K",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         StyleBox["\[Sigma]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        RowBox[{
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           StyleBox["\[Sigma]",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "+", 
           RowBox[{"2", " ", 
            StyleBox[
             SubscriptBox["D", "A"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           RowBox[{"6", " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "-", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       StyleBox["K",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox["D", "B"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], "2"]}], "-", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            StyleBox[
             SubscriptBox["D", "B"],
             StripOnInput->False,
             LineColor->RGBColor[0, 0, 1],
             FrontFaceColor->RGBColor[0, 0, 1],
             BackFaceColor->RGBColor[0, 0, 1],
             GraphicsColor->RGBColor[0, 0, 1],
             FontColor->RGBColor[0, 0, 1]]}], "+", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox[
         SubscriptBox["gJK", "1"],
         Background->RGBColor[0.87, 0.94, 1],
         BaseStyle->RGBColor[0, 0, 1],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{"2", " ", 
       FrameBox[
        SubscriptBox["gJK", "2"],
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "g"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   UnderscriptBox["evol$eq$gK1", "_"], "-", 
   UnderscriptBox["evol$eq$gK2", "_"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"introduceDs", "@", 
    RowBox[{"instantiateShifts", "@", 
     RowBox[{"Simplify", "@", "%"}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       UnderscriptBox["gA", "_"], "2"]], "-", 
     FractionBox["1", 
      SuperscriptBox[
       UnderscriptBox["gB", "_"], "2"]]}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "r"}], 
     FractionBox[
      UnderscriptBox["g\[Sigma]", "_"], 
      UnderscriptBox["gA", "_"]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        UnderscriptBox["gA", "_"]], "+", 
       FractionBox["1", 
        UnderscriptBox["gB", "_"]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$gKD", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"%", "//", "introduce$KTrace"}], "//", "echoNice"}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox["K", "1"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm], "-", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox["K", "2"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}],
       HoldForm]}], ")"}], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]], "-", 
       FractionBox["1", 
        SuperscriptBox[
         StyleBox["B",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    SuperscriptBox["r", "2"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "1"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm], "-", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox["K", "2"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}],
        HoldForm]}], ")"}], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox["D", "A"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "+", 
       StyleBox[
        SubscriptBox["D", "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], ")"}]}], 
    RowBox[{"r", " ", 
     SuperscriptBox[
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], "2"]}]], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "+", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
      SuperscriptBox[
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"], "+", 
      RowBox[{
       StyleBox[
        SubscriptBox["K", "1"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "2"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox["K", "2"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox[
         SubscriptBox["gJK", "1"],
         Background->RGBColor[0.87, 0.94, 1],
         BaseStyle->RGBColor[0, 0, 1],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      RowBox[{
       FrameBox[
        SubscriptBox["gJK", "2"],
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "g"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox["K", "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "+", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}],
      HoldForm], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}], 
    RowBox[{
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]]}]], "+", 
   FractionBox[
    RowBox[{
     StyleBox["\[Alpha]",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         StyleBox["\[Sigma]",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          StyleBox["A",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]], " ", 
          StyleBox["B",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}]]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          StyleBox["\[Sigma]",
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}], "+", 
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "+", 
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]]}], ")"}]}], "r"], "+", 
   RowBox[{
    StyleBox["\[Alpha]",
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}],
          HoldForm]}], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox["D", "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[0, 0, 1],
           FrontFaceColor->RGBColor[0, 0, 1],
           BackFaceColor->RGBColor[0, 0, 1],
           GraphicsColor->RGBColor[0, 0, 1],
           FontColor->RGBColor[0, 0, 1]]}],
         HoldForm], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "B"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "-", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox["D", "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox["D", "A"],
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], " ", 
         RowBox[{"(", 
          RowBox[{
           StyleBox[
            SubscriptBox["D", "B"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]], "+", 
           StyleBox[
            SubscriptBox["D", "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]], "+", 
      RowBox[{
       StyleBox["K",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["K", "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox[
         SubscriptBox["gJK", "1"],
         Background->RGBColor[0.87, 0.94, 1],
         BaseStyle->RGBColor[0, 0, 1],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      RowBox[{
       FrameBox[
        SubscriptBox["gJK", "2"],
        Background->RGBColor[0.87, 0.94, 1],
        BaseStyle->RGBColor[0, 0, 1],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "g"],
     StripOnInput->False,
     LineColor->RGBColor[0, 0, 1],
     FrontFaceColor->RGBColor[0, 0, 1],
     BackFaceColor->RGBColor[0, 0, 1],
     GraphicsColor->RGBColor[0, 0, 1],
     FontColor->RGBColor[0, 0, 1]]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Establish ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    OverscriptBox["K", "~"]}], TraditionalForm]]],
 " and  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox[
     OverscriptBox["K", "~"], "\[CapitalDelta]"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soL$fKD", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        UnderscriptBox["fK", "_"], "\[Equal]", 
        RowBox[{
         UnderscriptBox["fK1", "_"], "+", 
         RowBox[{"2", 
          UnderscriptBox["fK2", "_"]}]}]}], ",", 
       RowBox[{
        UnderscriptBox["fKD", "_"], "\[Equal]", 
        RowBox[{
         UnderscriptBox["fK1", "_"], "-", 
         UnderscriptBox["fK2", "_"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       UnderscriptBox["fK1", "_"], ",", 
       UnderscriptBox["fK2", "_"]}], "}"}]}], "]"}], "\[LeftDoubleBracket]", 
   "1", "\[RightDoubleBracket]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"fK1", "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fK", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"fKD", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"fK2", "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fK", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "-", 
       RowBox[{"fKD", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   UnderscriptBox["evol$eq$fK1", "_"], "+", 
   RowBox[{"2", 
    UnderscriptBox["evol$eq$fK2", "_"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"introduceDs", "@", 
    RowBox[{"instantiateShifts", "@", 
     RowBox[{"Simplify", "@", "%"}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", 
       SuperscriptBox[
        UnderscriptBox["fA", "_"], "2"]]}], "+", 
     FractionBox["2", 
      SuperscriptBox[
       UnderscriptBox["fB", "_"], "2"]]}], "\[Rule]", 
    RowBox[{"2", "r", 
     FractionBox[
      UnderscriptBox["f\[Sigma]", "_"], 
      UnderscriptBox["fA", "_"]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        UnderscriptBox["fA", "_"]], "+", 
       FractionBox["1", 
        UnderscriptBox["fB", "_"]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$fK", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "//", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"fK1", ",", "fK2"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"fK1", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"fK", "[", 
               RowBox[{"t", ",", "r"}], "]"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"fKD", "[", 
                RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"fK2", "[", 
            RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"fK", "[", 
               RowBox[{"t", ",", "r"}], "]"}], "-", 
              RowBox[{"fKD", "[", 
               RowBox[{"t", ",", "r"}], "]"}]}], ")"}]}]}], ";", 
          "\[IndentingNewLine]", "#"}]}], "]"}], "&"}]}], "//", 
     "introduceDs"}], "//", "echoNice"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "1"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm], "+", 
      RowBox[{"2", " ", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "2"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}]}], ")"}], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "1"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm], "+", 
       RowBox[{"2", " ", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "2"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}]}], ")"}], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["2", 
         SuperscriptBox[
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]]}], "+", 
       FractionBox["2", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    SuperscriptBox["r", "2"]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox[
         SubscriptBox["fJK", "1"],
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      RowBox[{"2", " ", 
       FrameBox[
        SubscriptBox["fJK", "2"],
        Background->RGBColor[1, 0.85, 0.85],
        BaseStyle->RGBColor[1, 0, 0],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "f"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        StyleBox[
         SubscriptBox[
          OverscriptBox["D", "~"], "A"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], "+", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     SuperscriptBox[
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "2"]}]], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "+", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "1"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "+", 
         RowBox[{"2", " ", 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "2"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]}], ")"}], "2"]}], 
     ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       OverscriptBox["K", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        OverscriptBox["K", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox[
         SubscriptBox["fJK", "1"],
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      RowBox[{"2", " ", 
       FrameBox[
        SubscriptBox["fJK", "2"],
        Background->RGBColor[1, 0.85, 0.85],
        BaseStyle->RGBColor[1, 0, 0],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "f"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], 
        RowBox[{
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           StyleBox[
            OverscriptBox["\[Sigma]", "~"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "+", 
           RowBox[{"2", " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "A"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           RowBox[{"6", " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "-", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       StyleBox[
        OverscriptBox["K", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "B"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], "2"]}], "-", 
        RowBox[{"2", " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            StyleBox[
             SubscriptBox[
              OverscriptBox["D", "~"], "B"],
             StripOnInput->False,
             LineColor->RGBColor[1, 0, 0],
             FrontFaceColor->RGBColor[1, 0, 0],
             BackFaceColor->RGBColor[1, 0, 0],
             GraphicsColor->RGBColor[1, 0, 0],
             FontColor->RGBColor[1, 0, 0]]}], "+", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   UnderscriptBox["evol$eq$fK1", "_"], "-", 
   UnderscriptBox["evol$eq$fK2", "_"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"introduceDs", "@", 
    RowBox[{"instantiateShifts", "@", 
     RowBox[{"Simplify", "@", "%"}]}]}], "//", "echoNice"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       UnderscriptBox["fA", "_"], "2"]], "-", 
     FractionBox["1", 
      SuperscriptBox[
       UnderscriptBox["fB", "_"], "2"]]}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "r"}], 
     FractionBox[
      UnderscriptBox["f\[Sigma]", "_"], 
      UnderscriptBox["fA", "_"]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        UnderscriptBox["fA", "_"]], "+", 
       FractionBox["1", 
        UnderscriptBox["fB", "_"]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"evol$eq$fKD", "[", 
    RowBox[{"t_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"%", "//", "introduce$KTrace"}], "//", "echoNice"}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "1"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm], "-", 
      TagBox[
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "2"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]]}],
       HoldForm]}], ")"}], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["K", "~"], "1"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm]}], "+", 
       TagBox[
        RowBox[{
         SubscriptBox["\[PartialD]", "r"], 
         StyleBox[
          SubscriptBox[
           OverscriptBox["K", "~"], "2"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}],
        HoldForm]}], ")"}], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]], "-", 
       FractionBox["1", 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["B", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    SuperscriptBox["r", "2"]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox[
         SubscriptBox["fJK", "1"],
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       FrameBox[
        SubscriptBox["fJK", "2"],
        Background->RGBColor[1, 0.85, 0.85],
        BaseStyle->RGBColor[1, 0, 0],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "f"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "A"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "+", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["D", "~"], "\[Alpha]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], ")"}]}], 
    RowBox[{"r", " ", 
     SuperscriptBox[
      StyleBox[
       OverscriptBox["A", "~"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], "2"]}]], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "+", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
      SuperscriptBox[
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], "2"], "+", 
      RowBox[{
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "1"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "2"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "~"], "2"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]}]}], ")"}]}]}]}]], "Echo"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], 
      StyleBox[
       SubscriptBox[
        OverscriptBox["K", "~"], "\[CapitalDelta]"],
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]]}],
     HoldForm], " ", 
    StyleBox["q",
     StripOnInput->False,
     LineColor->RGBColor[0, 
       Rational[2, 3], 0],
     FrontFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     BackFaceColor->RGBColor[0, 
       Rational[2, 3], 0],
     GraphicsColor->RGBColor[0, 
       Rational[2, 3], 0],
     FontColor->RGBColor[0, 
       Rational[2, 3], 0]]}], "-", 
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}],
      HoldForm], " ", 
     StyleBox["p",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}], 
    RowBox[{
     StyleBox["\[Lambda]",
      StripOnInput->False,
      LineColor->RGBColor[0, 
        Rational[2, 3], 0],
      FrontFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      BackFaceColor->RGBColor[0, 
        Rational[2, 3], 0],
      GraphicsColor->RGBColor[0, 
        Rational[2, 3], 0],
      FontColor->RGBColor[0, 
        Rational[2, 3], 0]], " ", 
     StyleBox[
      OverscriptBox["A", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FrameBox[
         SubscriptBox["fJK", "1"],
         Background->RGBColor[1, 0.85, 0.85],
         BaseStyle->RGBColor[1, 0, 0],
         FrameMargins->Tiny,
         StripOnInput->False]}], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}], "+", 
      RowBox[{
       FrameBox[
        SubscriptBox["fJK", "2"],
        Background->RGBColor[1, 0.85, 0.85],
        BaseStyle->RGBColor[1, 0, 0],
        FrameMargins->Tiny,
        StripOnInput->False], " ", 
       StyleBox[
        OverscriptBox["\[Alpha]", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}], " ", 
    StyleBox[
     SubscriptBox["\[Kappa]", "f"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]]}], "+", 
   FractionBox[
    RowBox[{
     StyleBox[
      OverscriptBox["\[Alpha]", "~"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         StyleBox[
          OverscriptBox["\[Sigma]", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          StyleBox[
           OverscriptBox["A", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], " ", 
          StyleBox[
           OverscriptBox["B", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}]]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          StyleBox[
           OverscriptBox["\[Sigma]", "~"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}], "+", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "+", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], 
        SuperscriptBox[
         StyleBox[
          OverscriptBox["A", "~"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"]]}], ")"}]}], "r"], "+", 
   RowBox[{
    StyleBox[
     OverscriptBox["\[Alpha]", "~"],
     StripOnInput->False,
     LineColor->RGBColor[1, 0, 0],
     FrontFaceColor->RGBColor[1, 0, 0],
     BackFaceColor->RGBColor[1, 0, 0],
     GraphicsColor->RGBColor[1, 0, 0],
     FontColor->RGBColor[1, 0, 0]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         TagBox[
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}],
          HoldForm]}], "-", 
        TagBox[
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], 
          StyleBox[
           SubscriptBox[
            OverscriptBox["D", "~"], "\[Alpha]"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]]}],
         HoldForm], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "B"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]]}], "-", 
        SuperscriptBox[
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "\[Alpha]"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], "2"], "+", 
        RowBox[{
         StyleBox[
          SubscriptBox[
           OverscriptBox["D", "~"], "A"],
          StripOnInput->False,
          LineColor->RGBColor[1, 0, 0],
          FrontFaceColor->RGBColor[1, 0, 0],
          BackFaceColor->RGBColor[1, 0, 0],
          GraphicsColor->RGBColor[1, 0, 0],
          FontColor->RGBColor[1, 0, 0]], " ", 
         RowBox[{"(", 
          RowBox[{
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "B"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]], "+", 
           StyleBox[
            SubscriptBox[
             OverscriptBox["D", "~"], "\[Alpha]"],
            StripOnInput->False,
            LineColor->RGBColor[1, 0, 0],
            FrontFaceColor->RGBColor[1, 0, 0],
            BackFaceColor->RGBColor[1, 0, 0],
            GraphicsColor->RGBColor[1, 0, 0],
            FontColor->RGBColor[1, 0, 0]]}], ")"}]}]}], 
       SuperscriptBox[
        StyleBox[
         OverscriptBox["A", "~"],
         StripOnInput->False,
         LineColor->RGBColor[1, 0, 0],
         FrontFaceColor->RGBColor[1, 0, 0],
         BackFaceColor->RGBColor[1, 0, 0],
         GraphicsColor->RGBColor[1, 0, 0],
         FontColor->RGBColor[1, 0, 0]], "2"]], "+", 
      RowBox[{
       StyleBox[
        OverscriptBox["K", "~"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]], " ", 
       StyleBox[
        SubscriptBox[
         OverscriptBox["K", "~"], "\[CapitalDelta]"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontColor->RGBColor[1, 0, 0]]}]}], ")"}]}]}]}]], "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equations of Motion", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Evolution", " ", "equations", " ", "for", " ", "g", " ", 
    RowBox[{"(", 
     RowBox[{"without", " ", "sources"}], ")"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$gEvol", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_gA_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gA", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          RowBox[{"instantiateShifts", "@", 
           UnderscriptBox["evol$eq$gA", "_"]}]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gB_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gB", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          RowBox[{"instantiateShifts", "@", 
           UnderscriptBox["evol$eq$gB", "_"]}]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Sequence", "@@", 
       RowBox[{"If", "[", 
        RowBox[{"True", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<eq_gK1_t\>\"", ",", 
             RowBox[{"D", "[", 
              RowBox[{
               UnderscriptBox["gK1", "_"], ",", "t"}], "]"}], ",", 
             RowBox[{"introduce$KTrace", "@", 
              RowBox[{"introduceDs", "@", 
               RowBox[{"instantiateShifts", "@", 
                UnderscriptBox["evol$eq$gK1", "_"]}]}]}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"\"\<eq_gK2_t\>\"", ",", 
             RowBox[{"D", "[", 
              RowBox[{
               UnderscriptBox["gK2", "_"], ",", "t"}], "]"}], ",", 
             RowBox[{"introduce$KTrace", "@", 
              RowBox[{"introduceDs", "@", 
               RowBox[{"instantiateShifts", "@", 
                UnderscriptBox["evol$eq$gK2", "_"]}]}]}]}], "}"}]}], 
          "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"{", "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gDA_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gDA", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["evol$eq$gDA", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gDB_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gDB", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["evol$eq$gDB", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gK_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gK", "_"], ",", "t"}], "]"}], ",", 
        UnderscriptBox["evol$eq$gK", "_"]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gKD_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gKD", "_"], ",", "t"}], "]"}], ",", 
        UnderscriptBox["evol$eq$gKD", "_"]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gSig_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["g\[Sigma]", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         UnderscriptBox["evol$eq$g\[Sigma]", "_"]}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Evolution", " ", "equations", " ", "for", " ", "f", " ", 
    RowBox[{"(", 
     RowBox[{"without", " ", "sources"}], ")"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$fEvol", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_fA_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fA", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          RowBox[{"instantiateShifts", "@", 
           UnderscriptBox["evol$eq$fA", "_"]}]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fB_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fB", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          RowBox[{"instantiateShifts", "@", 
           UnderscriptBox["evol$eq$fB", "_"]}]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Sequence", "@@", 
       RowBox[{"If", "[", 
        RowBox[{"True", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<eq_fK1_t\>\"", ",", 
             RowBox[{"D", "[", 
              RowBox[{
               UnderscriptBox["fK1", "_"], ",", "t"}], "]"}], ",", 
             RowBox[{"introduce$KTrace", "@", 
              RowBox[{"introduceDs", "@", 
               RowBox[{"instantiateShifts", "@", 
                UnderscriptBox["evol$eq$fK1", "_"]}]}]}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"\"\<eq_fK2_t\>\"", ",", 
             RowBox[{"D", "[", 
              RowBox[{
               UnderscriptBox["fK2", "_"], ",", "t"}], "]"}], ",", 
             RowBox[{"introduce$KTrace", "@", 
              RowBox[{"introduceDs", "@", 
               RowBox[{"instantiateShifts", "@", 
                UnderscriptBox["evol$eq$fK2", "_"]}]}]}]}], "}"}]}], 
          "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"{", "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fDA_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fDA", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["evol$eq$fDA", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fDB_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fDB", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["evol$eq$fDB", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fK_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fK", "_"], ",", "t"}], "]"}], ",", 
        UnderscriptBox["evol$eq$fK", "_"]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fKD_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fKD", "_"], ",", "t"}], "]"}], ",", 
        UnderscriptBox["evol$eq$fKD", "_"]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fSig_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["f\[Sigma]", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         UnderscriptBox["evol$eq$f\[Sigma]", "_"]}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"addTinyReal", "[", "e_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Numerator", "[", "e", "]"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Denominator", "[", "e", "]"}], "/.", 
     RowBox[{
      UnderscriptBox["pfD", "_"], "\[Rule]", 
      RowBox[{
       UnderscriptBox["pfD", "_"], "+", "TINY$Real"}]}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Evolution", " ", "equations", " ", "for", " ", "the", " ", "perfect", " ", 
    RowBox[{"fluid", " ", "/", " ", "dust"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$mEvol", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_D_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["pfD", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["evol$eq$pfD", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_S_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["pfS", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["evol$eq$pfS", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_tau_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["pf\[Tau]", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["evol$eq$pf\[Tau]", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_v\>\"", ",", 
        UnderscriptBox["pfv", "_"], ",", 
        RowBox[{
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$pfv", "_"]}], "//", "addTinyReal"}]}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<eq_pf_V\>\"", ",", 
          UnderscriptBox["pfV", "_"], ",", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["eq$pfV", "_"]}]}], "}"}], ","}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_v_r\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["pfv", "_"], ",", "r"}], "]"}], ",", 
        RowBox[{
         RowBox[{"Simplify", "@", 
          RowBox[{"introduceDs", "@", 
           RowBox[{"D", "[", 
            RowBox[{
             UnderscriptBox["eq$pfv", "_"], ",", "r"}], "]"}]}]}], "//", 
         "addTinyReal"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_rho\>\"", ",", 
        UnderscriptBox["pf$\[Rho]", "_"], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$pf$\[Rho]", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_j\>\"", ",", 
        UnderscriptBox["pf$j", "_"], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$pf$j", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_J1\>\"", ",", 
        UnderscriptBox["pf$J1", "_"], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$pf$J1", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_pf_J2\>\"", ",", 
        UnderscriptBox["pf$J2", "_"], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$pf$J2", "_"]}]}], "}"}]}], "\[IndentingNewLine]", 
     "}"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Constraint", " ", "equations", " ", 
    RowBox[{"(", 
     RowBox[{"without", " ", "sources"}], " "}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$constr1", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_gC_rho\>\"", ",", 
        SubscriptBox["C", 
         RowBox[{"g", ",", "sc"}]], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$gC$\[Rho]", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fC_rho\>\"", ",", 
        SubscriptBox["C", 
         RowBox[{"f", ",", "sc"}]], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$fC$\[Rho]", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gC_j\>\"", ",", 
        SubscriptBox["C", 
         RowBox[{"g", ",", "vec"}]], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$gC$j", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fC_j\>\"", ",", 
        SubscriptBox["C", 
         RowBox[{"f", ",", "vec"}]], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$fC$j", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_C_bimConsLaw\>\"", ",", 
        SubscriptBox["C", "bim"], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"introduce$KTrace", "@", 
           RowBox[{"introduceDs", "@", 
            UnderscriptBox["eq$bimConsLaw", "_"]}]}], "/.", 
          RowBox[{
           UnderscriptBox["fB", "_"], "\[Rule]", 
           RowBox[{
            UnderscriptBox["gB", "_"], 
            UnderscriptBox["R", "_"]}]}]}], "//", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "k$f", ",", "k$g"}], "}"}], ",", "Simplify"}], 
           "]"}], "&"}]}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}], 
   ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "constraints"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$constr2", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_C_1\>\"", ",", 
        SubscriptBox["C", "1"], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$C1", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_C_2\>\"", ",", 
        SubscriptBox["C", "2"], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$C2", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_C_3\>\"", ",", 
        SubscriptBox["C", "3"], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"-", "1"}]], 
           SuperscriptBox[
            UnderscriptBox["gB", "_"], 
            RowBox[{"-", "2"}]], 
           RowBox[{"introduce$KTrace", "@", 
            RowBox[{"introduceDs", "@", 
             UnderscriptBox["eq$C3", "_"]}]}]}], "/.", 
          RowBox[{
           UnderscriptBox["fB", "_"], "\[Rule]", 
           RowBox[{
            UnderscriptBox["gB", "_"], 
            UnderscriptBox["R", "_"]}]}]}], "//", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "k$f", ",", "k$g"}], "}"}], ",", "Simplify"}], 
           "]"}], "&"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_C_4\>\"", ",", 
        SubscriptBox["C", "4"], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"introduce$KTrace", "@", 
           RowBox[{"introduceDs", "@", 
            UnderscriptBox["eq$C4", "_"]}]}], "/.", 
          RowBox[{
           UnderscriptBox["fB", "_"], "\[Rule]", 
           RowBox[{
            UnderscriptBox["gB", "_"], 
            UnderscriptBox["R", "_"]}]}]}], "//", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "k$f", ",", "k$g"}], "}"}], ",", "Simplify"}], 
           "]"}], "&"}]}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}], 
   ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "combined", " ", "stress"}], "-", 
    RowBox[{"energy", " ", "sources"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$sources", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_g_rho\>\"", ",", 
        UnderscriptBox["g$\[Rho]", "_"], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"introduceDs", "@", " ", 
           UnderscriptBox["eq$gV$\[Rho]", "_"]}], "+", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["gT$\[Rho]", "_"]}]}], ")"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_g_j\>\"", ",", 
        UnderscriptBox["g$j", "_"], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"introduceDs", "@", " ", 
           UnderscriptBox["eq$gV$j", "_"]}], "+", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["gT$j", "_"]}]}], ")"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_g_JK1\>\"", ",", 
        UnderscriptBox["g$JK1", "_"], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["eq$gV$JK1", "_"]}], "+", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["gT$JK1", "_"]}]}], ")"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_g_JK2\>\"", ",", 
        UnderscriptBox["g$JK2", "_"], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["eq$gV$JK2", "_"]}], "+", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["gT$JK2", "_"]}]}], ")"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_f_rho\>\"", ",", 
        UnderscriptBox["f$\[Rho]", "_"], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["eq$fV$\[Rho]", "_"]}], "+", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["fT$\[Rho]", "_"]}]}], ")"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_f_j\>\"", ",", 
        UnderscriptBox["f$j", "_"], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"introduceDs", "@", " ", 
           UnderscriptBox["eq$fV$j", "_"]}], "+", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["fT$j", "_"]}]}], ")"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_f_JK1\>\"", ",", 
        UnderscriptBox["f$JK1", "_"], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["eq$fV$JK1", "_"]}], "+", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["fT$JK1", "_"]}]}], ")"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_f_JK2\>\"", ",", 
        UnderscriptBox["f$JK2", "_"], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["eq$fV$JK2", "_"]}], "+", 
          RowBox[{"introduceDs", "@", 
           UnderscriptBox["fT$JK2", "_"]}]}], ")"}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "p", " ", "equations"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$pEqs", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_p_g\>\"", ",", 
        SubscriptBox["p", "g"], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$p$g", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_p_f\>\"", ",", 
        SubscriptBox["p", "f"], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$p$f", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_p_t\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["p", "_"], ",", "t"}], "]"}], ",", 
        RowBox[{"introduce$KTrace", "@", 
         UnderscriptBox["evol$eq$p2", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{"True", ",", "Nothing", ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<eq_p1_t\>\"", ",", 
          RowBox[{"D", "[", 
           RowBox[{
            UnderscriptBox["p", "_"], ",", "t"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"introduce$KTrace", "@", 
             RowBox[{"introduceDs", "@", 
              UnderscriptBox["evol$eq$p", "_"]}]}], "/.", 
            RowBox[{
             UnderscriptBox["fB", "_"], "\[Rule]", 
             RowBox[{
              UnderscriptBox["gB", "_"], 
              UnderscriptBox["R", "_"]}]}]}], "//", 
           RowBox[{
            RowBox[{"Collect", "[", 
             RowBox[{
              RowBox[{"Expand", "@", "#"}], ",", 
              RowBox[{"{", "r", "}"}], ",", "FullSimplify"}], "]"}], 
            "&"}]}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
   ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "lapse", " ", "ratios"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$lapseRatios", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_gW\>\"", ",", 
        SubscriptBox["W", "g"], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"introduce$KTrace", "@", 
           RowBox[{"introduceDs", "@", 
            UnderscriptBox["eq$gW", "_"]}]}], "/.", 
          RowBox[{
           UnderscriptBox["fB", "_"], "\[Rule]", 
           RowBox[{
            UnderscriptBox["gB", "_"], 
            UnderscriptBox["R", "_"]}]}]}], "//", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "k$f", ",", "k$g"}], "}"}], ",", "Simplify"}], 
           "]"}], "&"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fW\>\"", ",", 
        SubscriptBox["W", "f"], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"introduce$KTrace", "@", 
           RowBox[{"introduceDs", "@", 
            UnderscriptBox["eq$fW", "_"]}]}], "/.", 
          RowBox[{
           UnderscriptBox["fB", "_"], "\[Rule]", 
           RowBox[{
            UnderscriptBox["gB", "_"], 
            UnderscriptBox["R", "_"]}]}]}], "//", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "k$f", ",", "k$g"}], "}"}], ",", "Simplify"}], 
           "]"}], "&"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_cW\>\"", ",", 
        SubscriptBox["W", "c"], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"introduce$KTrace", "@", 
           RowBox[{"introduceDs", "@", 
            UnderscriptBox["eq$cW", "_"]}]}], "/.", 
          RowBox[{
           UnderscriptBox["fB", "_"], "\[Rule]", 
           RowBox[{
            UnderscriptBox["gB", "_"], 
            UnderscriptBox["R", "_"]}]}]}], "//", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "k$f", ",", "k$g"}], "}"}], ",", "Simplify"}], 
           "]"}], "&"}]}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}], 
   ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "horizon", " ", "finders"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$horizonFinders", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_gHorz\>\"", ",", 
        SubscriptBox["\[DoubleStruckZ]", "g"], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$gHorz", "_"]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fHorz\>\"", ",", 
        SubscriptBox["\[DoubleStruckZ]", "f"], ",", 
        RowBox[{"introduce$KTrace", "@", 
         RowBox[{"introduceDs", "@", 
          UnderscriptBox["eq$fHorz", "_"]}]}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "shifts"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EoM$shifts", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<eq_gBet\>\"", ",", 
        UnderscriptBox["gBet", "_"], ",", 
        RowBox[{"instantiateShifts", "@", 
         UnderscriptBox["eq$gBet", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fBet\>\"", ",", 
        UnderscriptBox["fBet", "_"], ",", 
        RowBox[{"instantiateShifts", "@", 
         UnderscriptBox["eq$fBet", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gBet_r\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["gBet", "_"], ",", "r"}], "]"}], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$gBet$r", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fBet_r\>\"", ",", 
        RowBox[{"D", "[", 
         RowBox[{
          UnderscriptBox["fBet", "_"], ",", "r"}], "]"}], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$fBet$r", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_gBetr_r\>\"", ",", 
        RowBox[{"HoldForm", "@", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            UnderscriptBox["gBet", "_"], "/", "r"}], ",", "r"}], "]"}]}], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$gBetr$r", "_"]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<eq_fBetr_r\>\"", ",", 
        RowBox[{"HoldForm", "@", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            UnderscriptBox["fBet", "_"], "/", "r"}], ",", "r"}], "]"}]}], ",", 
        RowBox[{"introduceDs", "@", 
         UnderscriptBox["eq$fBetr$r", "_"]}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}]}]], "Input"],

Cell["\<\
The exported C++ equations also include the gauge functions that are case \
dependent. Because of that, we have a delayed assignment below!\
\>", "Text"],

Cell[BoxData[
 RowBox[{"EoM$gaugeFunctions", ":=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<eq_q\>\"", ",", 
      UnderscriptBox["q", "_"], ",", 
      UnderscriptBox["eq$q", "_"]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<eq_gAlp\>\"", ",", 
      UnderscriptBox["gAlp", "_"], ",", 
      UnderscriptBox["eq$gAlp", "_"]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<eq_fAlp\>\"", ",", 
      UnderscriptBox["fAlp", "_"], ",", 
      UnderscriptBox["eq$fAlp", "_"]}], "}"}]}], "\[IndentingNewLine]", 
   "}"}]}]], "Input"],

Cell[CellGroupData[{

Cell["The split operator form", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"splitOperator", "[", "eom_", "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "temp", ",", "TIMES$r$p$q", ",", "TIMES$r$p", ",", "TIMES$r", ",", 
      "pRemoved", ",", "qRemoved"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"First", ",", " ", 
      RowBox[{"extract", " ", 
       RowBox[{"p", "/", "r"}], " ", 
       RowBox[{"terms", ".", " ", "TIMES$r$p"}], " ", "has", " ", "three", 
       " ", 
       RowBox[{"arguments", ":", " ", 
        RowBox[{
        "the", " ", "first", " ", "is", " ", "power", " ", "of", " ", 
         "r"}]}]}], ",", " ", 
      RowBox[{"the", " ", "second", " ", "power", " ", "of", " ", "p"}], ",", 
      " ", 
      RowBox[{"and", " ", "the", " ", "third", " ", "is", " ", "an", " ", 
       RowBox[{"expression", ".", " ", "TIMES$r"}], " ", "has", " ", "only", 
       " ", "power", " ", "of"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"temp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{
            RowBox[{
            "eom", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", 
              UnderscriptBox["p", "_"], ",", 
              UnderscriptBox["q", "_"]}], "}"}], ",", "Framed"}], "]"}], "//",
           "Expand"}], ")"}], "/.", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Times", "[", 
          RowBox[{"a___", ",", 
           RowBox[{"Framed", "[", "e_", "]"}], ",", "b___"}], "]"}], 
         "\[RuleDelayed]", 
         RowBox[{"TIMES$r$p$q", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{
             RowBox[{"a", " ", "b"}], ",", "r"}], "]"}], ",", 
           RowBox[{"Exponent", "[", 
            RowBox[{
             RowBox[{"a", " ", "b"}], ",", 
             UnderscriptBox["p", "_"]}], "]"}], ",", 
           RowBox[{"Exponent", "[", 
            RowBox[{
             RowBox[{"a", " ", "b"}], ",", 
             UnderscriptBox["q", "_"]}], "]"}], ",", "e"}], 
          "\[IndentingNewLine]", "]"}]}]}], "/.", 
       RowBox[{
        RowBox[{"Framed", "[", "e_", "]"}], "\[RuleDelayed]", 
        RowBox[{"TIMES$r$p$q", "[", 
         RowBox[{"0", ",", "0", ",", "0", ",", "e"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "@", "temp"}], "===", "Plus"}], ",", 
        RowBox[{"List", "@@", "temp"}], ",", 
        RowBox[{"{", "temp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"temp", "=", 
      RowBox[{
       RowBox[{"temp", "/.", 
        RowBox[{
         RowBox[{"TIMES$r$p$q", "[", 
          RowBox[{"rPow_", ",", " ", "pPow_", ",", "qPow_", ",", "expr_"}], 
          "]"}], "\[RuleDelayed]", 
         RowBox[{"If", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"rPow", "<", "0"}], "&&", 
            RowBox[{
             RowBox[{"rPow", "+", "pPow", "+", "qPow"}], "\[GreaterEqual]", 
             "0"}], "&&", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"pPow", "\[GreaterEqual]", "1"}], "||", 
              RowBox[{"qPow", "\[GreaterEqual]", "1"}]}], ")"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"pRemoved", "=", 
             RowBox[{"Min", "[", 
              RowBox[{"pPow", ",", 
               RowBox[{"-", "rPow"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"qRemoved", "=", 
             RowBox[{"Min", "[", 
              RowBox[{"qPow", ",", 
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"rPow", "+", "pRemoved"}], ")"}]}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"TIMES$r", "[", 
             RowBox[{
              RowBox[{"rPow", "+", "pRemoved", "+", "qRemoved"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Power", "[", 
                RowBox[{
                 RowBox[{"HoldForm", "[", 
                  RowBox[{
                   RowBox[{"p", "[", 
                    RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}], ",", 
                 "pRemoved"}], "]"}], "*", 
               RowBox[{"Power", "[", 
                RowBox[{
                 UnderscriptBox["p", "_"], ",", 
                 RowBox[{"pPow", "-", "pRemoved"}]}], "]"}], "*", 
               "\[IndentingNewLine]", 
               RowBox[{"Power", "[", 
                RowBox[{
                 RowBox[{"HoldForm", "[", 
                  RowBox[{
                   RowBox[{"q", "[", 
                    RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}], ",", 
                 "qRemoved"}], "]"}], "*", 
               RowBox[{"Power", "[", 
                RowBox[{
                 UnderscriptBox["q", "_"], ",", 
                 RowBox[{"qPow", "-", "qRemoved"}]}], "]"}], "*", 
               "\[IndentingNewLine]", "expr"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"TIMES$r", "[", 
            RowBox[{"rPow", ",", 
             RowBox[{
              RowBox[{"Power", "[", 
               RowBox[{
                UnderscriptBox["p", "_"], ",", "pPow"}], "]"}], 
              RowBox[{"Power", "[", 
               RowBox[{
                UnderscriptBox["q", "_"], ",", "qPow"}], "]"}], "expr"}]}], 
            "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "/.", 
       RowBox[{"TIMES$r", "\[Rule]", "List"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Second", ",", " ", 
       RowBox[{
       "Join", " ", "the", " ", "terms", " ", "with", " ", "the", " ", "same",
         " ", "power", " ", "of", " ", "r", " ", "terms"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"temp", "=", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Total", "[", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{"temp", ",", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "\[Equal]", "i"}], "&"}]}], "]"}], "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}]}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}], "//", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{"#", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
            "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "=!=",
             "0"}], "&"}]}], "]"}], "&"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"temp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
            "eom", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            ",", 
            RowBox[{"\"\<eq_\>\"", "\[RuleDelayed]", 
             RowBox[{"Switch", "[", 
              RowBox[{
               RowBox[{
               "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               ",", "\[IndentingNewLine]", "0", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Length", "@", "temp"}], "\[Equal]", "1"}], ",", 
                 "\"\<eq_\>\"", ",", "\"\<eq_base_\>\""}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"_", "?", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"#", "\[Equal]", "1"}], "&"}], ")"}]}], ",", 
               "\"\<eq_r_\>\"", ",", "\[IndentingNewLine]", 
               RowBox[{"_", "?", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"#", "\[Equal]", 
                   RowBox[{"-", "1"}]}], "&"}], ")"}]}], ",", 
               "\"\<eq_invr_\>\"", ",", "\[IndentingNewLine]", 
               RowBox[{"_", "?", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"#", ">", "1"}], "&"}], ")"}]}], ",", 
               RowBox[{"\"\<eq_r\>\"", "<>", 
                RowBox[{"ToString", "@", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], "<>", "\"\<_\>\""}], ",", 
               "\[IndentingNewLine]", "_", ",", 
               RowBox[{"\"\<eq_invr\>\"", "<>", 
                RowBox[{"ToString", "[", 
                 RowBox[{"-", 
                  RowBox[{
                  "#", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}]}], "]"}], "<>", "\"\<_\>\""}]}], 
              "\[IndentingNewLine]", "]"}]}]}], "]"}], ",", 
          RowBox[{
           SuperscriptBox["r", 
            RowBox[{"-", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], 
           RowBox[{
           "eom", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          ",", 
          RowBox[{
          "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         "}"}], "&"}], "/@", "temp"}]}], ";", "\[IndentingNewLine]", 
     "temp"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"echoNice", "/@", 
   RowBox[{"splitOperator", "@", 
    RowBox[{
    "EoM$gEvol", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"\"\>",
   "EchoLabel"], " ", 
  RowBox[{"{", 
   RowBox[{"\<\"eq_gB_t\"\>", ",", 
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", "t"], 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}],
     HoldForm], ",", 
    RowBox[{
     RowBox[{
      TagBox[
       FractionBox[
        StyleBox["q",
         StripOnInput->False,
         LineColor->RGBColor[0, 
           Rational[2, 3], 0],
         FrontFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         BackFaceColor->RGBColor[0, 
           Rational[2, 3], 0],
         GraphicsColor->RGBColor[0, 
           Rational[2, 3], 0],
         FontColor->RGBColor[0, 
           Rational[2, 3], 0]], "r"],
       HoldForm], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], "+", 
     FractionBox[
      RowBox[{
       TagBox[
        FractionBox[
         StyleBox["p",
          StripOnInput->False,
          LineColor->RGBColor[0, 
            Rational[2, 3], 0],
          FrontFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          BackFaceColor->RGBColor[0, 
            Rational[2, 3], 0],
          GraphicsColor->RGBColor[0, 
            Rational[2, 3], 0],
          FontColor->RGBColor[0, 
            Rational[2, 3], 0]], "r"],
        HoldForm], " ", 
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}]], "+", 
     RowBox[{
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["q",
       StripOnInput->False,
       LineColor->RGBColor[0, 
         Rational[2, 3], 0],
       FrontFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       BackFaceColor->RGBColor[0, 
         Rational[2, 3], 0],
       GraphicsColor->RGBColor[0, 
         Rational[2, 3], 0],
       FontColor->RGBColor[0, 
         Rational[2, 3], 0]], " ", 
      StyleBox[
       SubscriptBox["D", "B"],
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]]}], "+", 
     FractionBox[
      RowBox[{
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["p",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]], " ", 
       StyleBox["\[Alpha]",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox[
        SubscriptBox["D", "B"],
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]]}], 
      RowBox[{
       StyleBox["A",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], " ", 
       StyleBox["\[Lambda]",
        StripOnInput->False,
        LineColor->RGBColor[0, 
          Rational[2, 3], 0],
        FrontFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        BackFaceColor->RGBColor[0, 
          Rational[2, 3], 0],
        GraphicsColor->RGBColor[0, 
          Rational[2, 3], 0],
        FontColor->RGBColor[0, 
          Rational[2, 3], 0]]}]], "+", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      StyleBox["B",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      StyleBox["\[Alpha]",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         StyleBox["K",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]]}], "+", 
        StyleBox[
         SubscriptBox["K", "\[CapitalDelta]"],
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}]}], "}"}]}]], "Echo"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"splitEoM$gEvol", "=", 
   RowBox[{"Join", "@@", 
    RowBox[{"(", 
     RowBox[{"splitOperator", "/@", "EoM$gEvol"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"splitEoM$fEvol", "=", 
   RowBox[{"Join", "@@", 
    RowBox[{"(", 
     RowBox[{"splitOperator", "/@", "EoM$fEvol"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"splitEoM$constr1", "=", 
   RowBox[{"Join", "@@", 
    RowBox[{"(", 
     RowBox[{"splitOperator", "/@", "EoM$constr1"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"splitEoM$constr2", "=", 
   RowBox[{"Join", "@@", 
    RowBox[{"(", 
     RowBox[{"splitOperator", "/@", "EoM$constr2"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"splitEoM$pEqs", "=", 
   RowBox[{"Join", "@@", 
    RowBox[{"(", 
     RowBox[{"splitOperator", "/@", "EoM$pEqs"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"splitEoM$lapseRatios", "=", 
   RowBox[{"Join", "@@", 
    RowBox[{"(", 
     RowBox[{"splitOperator", "/@", "EoM$lapseRatios"}], ")"}]}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export C++ EoM and save the EoM package", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Complement", "[", 
    RowBox[{
     RowBox[{"Names", "[", "\"\<Global`*\>\"", "]"}], ",", 
     "namesBeforeDefinitions", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<newNames\>\"", ",", "\"\<namesBeforeDefinitions\>\""}], 
      "}"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"ToString", "@", 
      RowBox[{"Definition", "@", "#"}]}], "=!=", "\"\<Null\>\""}], "&"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ToString", "[", 
     RowBox[{"InputForm", "@", 
      RowBox[{"Definition", "@", "#"}]}], "]"}], "&"}], "/@", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
    "\"\<collectFields\>\"", ",", "\"\<eq$C1\>\"", ",", "\"\<eq$C2\>\"", ",", 
     "\"\<eq$C3\>\"", ",", "\"\<eq$C4\>\"", ",", "\"\<eq$fAlp\>\"", ",", 
     "\"\<eq$fBetr$r\>\"", ",", "\"\<eq$fBet$r\>\"", ",", 
     "\"\<eq$fBet$rr\>\"", ",", "\"\<eq$fHorz\>\"", ",", 
     "\"\<eq$f\[Sigma]\>\"", ",", "\"\<eq$gAlp\>\"", ",", 
     "\"\<eq$gBetr$r\>\"", ",", "\"\<eq$gBet$r\>\"", ",", 
     "\"\<eq$gBet$rr\>\"", ",", "\"\<eq$gHorz\>\"", ",", 
     "\"\<eq$g\[Sigma]\>\"", ",", "\"\<eq$p$f\>\"", ",", "\"\<eq$p$g\>\"", 
     ",", "\"\<eq$q\>\"", ",", "\"\<evol$eq$fDA\>\"", ",", 
     "\"\<evol$eq$fDB\>\"", ",", "\"\<evol$eq$f\[Sigma]\>\"", ",", 
     "\"\<evol$eq$f\[Sigma]1\>\"", ",", "\"\<evol$eq$gDA\>\"", ",", 
     "\"\<evol$eq$gDB\>\"", ",", "\"\<evol$eq$gKD\>\"", ",", 
     "\"\<evol$eq$gK\>\"", ",", "\"\<evol$eq$g\[Sigma]\>\"", ",", 
     "\"\<evol$eq$g\[Sigma]1\>\"", ",", "\"\<evol$eq$p2\>\"", ",", 
     "\[IndentingNewLine]", "\"\<gT$\[Rho]\>\"", ",", "\"\<gT$j\>\"", ",", 
     "\"\<gT$JK1\>\"", ",", "\"\<gT$JK2\>\"", ",", "\[IndentingNewLine]", 
     "\"\<fT$\[Rho]\>\"", ",", "\"\<fT$j\>\"", ",", "\"\<fT$JK1\>\"", ",", 
     "\"\<fT$JK2\>\"", ",", "\[IndentingNewLine]", 
     "\"\<instantiateShifts\>\"", ",", "\"\<introduceDs\>\"", ",", 
     "\"\<introduceDs$rule\>\"", ",", "\"\<sigma$rule\>\"", ",", 
     "\"\<soL$gKD\>\"", ",", "\"\<sol$reg$fK\>\"", ",", "\"\<sol$reg$gK\>\"", 
     ",", "\"\<v2p$rule\>\"", ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "EOM", " ", "*)"}], "\[IndentingNewLine]", 
     "\"\<EoM$constr1\>\"", ",", "\"\<EoM$constr2\>\"", ",", 
     "\"\<EoM$fEvol\>\"", ",", "\"\<EoM$gaugeFunctions\>\"", ",", 
     "\"\<EoM$gEvol\>\"", ",", "\"\<EoM$horizonFinders\>\"", ",", 
     "\"\<EoM$lapseRatios\>\"", ",", "\"\<EoM$mEvol\>\"", ",", 
     "\"\<EoM$pEqs\>\"", ",", "\"\<EoM$shifts\>\"", ",", 
     "\"\<EoM$sources\>\"", ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Split", " ", "form", " ", "of", " ", "EOM"}], " ", "*)"}], 
     "\[IndentingNewLine]", "\"\<splitEoM$gEvol\>\"", ",", 
     "\"\<splitEoM$fEvol\>\"", ",", "\"\<splitEoM$constr1\>\"", ",", 
     "\"\<splitEoM$constr2\>\"", ",", "\[IndentingNewLine]", 
     "\"\<splitEoM$pEqs\>\"", ",", "\"\<splitEoM$lapseRatios\>\""}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<bimetric-ss-solver.m\>\"", ",", 
   RowBox[{"\"\<\\n\>\"", "<>", 
    RowBox[{"StringJoin", "@", 
     RowBox[{"Riffle", "[", 
      RowBox[{"%", ",", "\"\<;\\n\\n\>\""}], "]"}]}], "<>", "\"\<;\\n\>\""}], 
   ",", "\"\<String\>\""}], "]"}]}], "Input"],

Cell[BoxData["\<\"bimetric-ss-solver.m\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"False", ",", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Export", " ", "in", " ", "the", " ", "original", " ", "form"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"exportCppEoM", "[", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Export", " ", "eqs", " ", "in", " ", "the", " ", "split", " ", 
     "operator", " ", "form"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Block", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"EoM$gEvol", ",", "EoM$fEvol", ",", "EoM$pEqs"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"EoM$gEvol", "=", "splitEoM$gEvol"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"EoM$fEvol", "=", "splitEoM$fEvol"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"EoM$pEqs", "=", "splitEoM$pEqs"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"EoM$lapseRatios", " ", "=", " ", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<eq_gW\>\"", ",", 
             SubscriptBox["W", "g"], ",", 
             UnderscriptBox["optimized$eq$gW", "_"]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"\"\<eq_fW\>\"", ",", 
             SubscriptBox["W", "f"], ",", 
             UnderscriptBox["optimized$eq$fW", "_"]}], "}"}]}], 
          "\[IndentingNewLine]", "}"}]}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"exportCppEoM", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"bim-solver/src/eom/eomEvolution.h\"\>", 
   ",", "\<\"bim-solver/src/eom/eomConstraints.h\"\>", 
   ",", "\<\"bim-solver/src/eom/eomSources.h\"\>", 
   ",", "\<\"bim-solver/src/eom/eomMatter.h\"\>", 
   ",", "\<\"bim-solver/src/eom/eomMiscEquations.h\"\>", 
   ",", "\<\"bim-solver/src/eom/eomLapseRatios.h\"\>"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1328, 1102},
WindowMargins->{{221, Automatic}, {Automatic, 0}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "initializationSection"->{
  Cell[2211, 78, 123, 2, 78, "Section",
   PageBreakAbove->True,
   CellTags->"initializationSection"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"initializationSection", 585639, 17932}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 243, 6, 93, "Text"],
Cell[804, 28, 28, 0, 38, "Text"],
Cell[835, 30, 60, 0, 38, "Text"],
Cell[898, 32, 119, 3, 38, "Text"],
Cell[1020, 37, 81, 4, 38, "Text"],
Cell[1104, 43, 268, 5, 63, "Text"],
Cell[1375, 50, 450, 9, 38, "Text"],
Cell[1828, 61, 276, 9, 63, "Text"],
Cell[2107, 72, 79, 2, 36, "Input"],
Cell[CellGroupData[{
Cell[2211, 78, 123, 2, 78, "Section",
 PageBreakAbove->True,
 CellTags->"initializationSection"],
Cell[2337, 82, 113, 3, 38, "Text"],
Cell[2453, 87, 136, 3, 36, "Input"],
Cell[CellGroupData[{
Cell[2614, 94, 48, 0, 42, "Subsubsection"],
Cell[2665, 96, 98, 2, 38, "Text"],
Cell[2766, 100, 645, 23, 83, "Input"],
Cell[3414, 125, 74, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[3513, 129, 1021, 32, 64, "Input"],
Cell[CellGroupData[{
Cell[4559, 165, 85, 3, 29, "Echo"],
Cell[4647, 170, 85, 3, 29, "Echo"]
}, Open  ]]
}, Open  ]],
Cell[4759, 177, 120, 5, 38, "Text"],
Cell[4882, 184, 498, 16, 41, "Input"],
Cell[5383, 202, 1323, 38, 180, "Input"],
Cell[6709, 242, 2416, 84, 45, "Text"],
Cell[9128, 328, 1514, 46, 195, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10679, 379, 49, 0, 101, "Subsubsection"],
Cell[10731, 381, 632, 19, 63, "Text"],
Cell[11366, 402, 582, 20, 36, "Input"],
Cell[11951, 424, 582, 20, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12570, 449, 45, 0, 101, "Subsubsection"],
Cell[12618, 451, 58, 0, 38, "Text"],
Cell[12679, 453, 175, 5, 36, "Input"],
Cell[12857, 460, 165, 5, 36, "Input"],
Cell[13025, 467, 527, 17, 36, "Input"],
Cell[13555, 486, 527, 17, 36, "Input"],
Cell[14085, 505, 112, 3, 36, "Input"],
Cell[14200, 510, 107, 3, 36, "Input"],
Cell[14310, 515, 109, 3, 36, "Input"],
Cell[14422, 520, 109, 3, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14568, 528, 50, 0, 42, "Subsubsection"],
Cell[14621, 530, 311, 10, 36, "Input"],
Cell[14935, 542, 311, 10, 36, "Input"],
Cell[15249, 554, 1095, 36, 68, "Input"],
Cell[16347, 592, 194, 6, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16578, 603, 109, 5, 43, "Subsubsection"],
Cell[16690, 610, 624, 19, 39, "Input"],
Cell[17317, 631, 624, 19, 39, "Input"],
Cell[17944, 652, 695, 23, 42, "Input"],
Cell[18642, 677, 30, 0, 38, "Text"],
Cell[CellGroupData[{
Cell[18697, 681, 347, 10, 39, "Input"],
Cell[19047, 693, 674, 21, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19770, 720, 177, 5, 42, "Subsubsection"],
Cell[19950, 727, 286, 10, 65, "Input"],
Cell[20239, 739, 286, 10, 59, "Input"],
Cell[20528, 751, 822, 19, 106, "Input"],
Cell[21353, 772, 1448, 46, 187, "Input"],
Cell[22804, 820, 729, 29, 38, "Text"],
Cell[23536, 851, 7738, 216, 527, "Input"],
Cell[31277, 1069, 208, 6, 36, "Input"],
Cell[31488, 1077, 125, 3, 36, "Input"],
Cell[31616, 1082, 241, 6, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31894, 1093, 662, 26, 42, "Subsubsection"],
Cell[32559, 1121, 2100, 62, 271, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34696, 1188, 46, 0, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[34767, 1192, 506, 18, 36, "Input"],
Cell[35276, 1212, 85, 3, 29, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35398, 1220, 373, 13, 36, "Input"],
Cell[35774, 1235, 3853, 126, 47, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39664, 1366, 1096, 35, 90, "Input"],
Cell[40763, 1403, 9488, 286, 49, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50288, 1694, 3570, 117, 315, "Input"],
Cell[CellGroupData[{
Cell[53883, 1815, 744, 25, 46, "Echo"],
Cell[54630, 1842, 5971, 185, 56, "Echo"],
Cell[60604, 2029, 5020, 161, 58, "Echo"],
Cell[65627, 2192, 4968, 160, 49, "Echo"],
Cell[70598, 2354, 4525, 146, 49, "Echo"],
Cell[75126, 2502, 5313, 172, 53, "Echo"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[80488, 2680, 373, 13, 36, "Input"],
Cell[80864, 2695, 3990, 131, 52, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84891, 2831, 1096, 35, 90, "Input"],
Cell[85990, 2868, 9882, 300, 57, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95909, 3173, 3570, 117, 314, "Input"],
Cell[CellGroupData[{
Cell[99504, 3294, 798, 27, 51, "Echo"],
Cell[100305, 3323, 6178, 192, 62, "Echo"],
Cell[106486, 3517, 5182, 168, 52, "Echo"],
Cell[111671, 3687, 5182, 168, 52, "Echo"],
Cell[116856, 3857, 4716, 153, 52, "Echo"],
Cell[121575, 4012, 5504, 179, 54, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[127140, 4198, 177, 7, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[127342, 4209, 1607, 49, 162, "Input"],
Cell[CellGroupData[{
Cell[128974, 4262, 2989, 95, 29, "Echo"],
Cell[131966, 4359, 12058, 366, 49, "Echo"],
Cell[144027, 4727, 17437, 527, 92, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[161525, 5261, 203, 8, 46, "Subsubsection"],
Cell[CellGroupData[{
Cell[161753, 5273, 1607, 49, 160, "Input"],
Cell[CellGroupData[{
Cell[163385, 5326, 3244, 104, 33, "Echo"],
Cell[166632, 5432, 12680, 388, 57, "Echo"],
Cell[179315, 5822, 18217, 554, 113, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[197593, 6383, 177, 7, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[197795, 6394, 1657, 51, 166, "Input"],
Cell[CellGroupData[{
Cell[199477, 6449, 3314, 105, 46, "Echo"],
Cell[202794, 6556, 7883, 252, 53, "Echo"],
Cell[210680, 6810, 13262, 413, 53, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[224003, 7230, 203, 8, 46, "Subsubsection"],
Cell[CellGroupData[{
Cell[224231, 7242, 1657, 51, 164, "Input"],
Cell[CellGroupData[{
Cell[225913, 7297, 3596, 115, 51, "Echo"],
Cell[229512, 7414, 8302, 267, 54, "Echo"],
Cell[237817, 7683, 13839, 433, 58, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[251717, 8123, 184, 7, 45, "Subsubsection"],
Cell[CellGroupData[{
Cell[251926, 8134, 2662, 75, 139, "Input"],
Cell[254591, 8211, 3879, 113, 47, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258507, 8329, 5687, 167, 361, "Input"],
Cell[CellGroupData[{
Cell[264219, 8500, 4563, 140, 50, "Echo"],
Cell[268785, 8642, 3968, 122, 50, "Echo"],
Cell[272756, 8766, 3988, 121, 50, "Echo"],
Cell[276747, 8889, 3541, 106, 54, "Echo"],
Cell[280291, 8997, 11278, 327, 69, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[291630, 9331, 184, 7, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[291839, 9342, 2662, 75, 139, "Input"],
Cell[294504, 9419, 4241, 125, 54, "Echo"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298782, 9549, 6130, 181, 351, "Input"],
Cell[CellGroupData[{
Cell[304937, 9734, 4103, 127, 52, "Echo"],
Cell[309043, 9863, 3427, 106, 51, "Echo"],
Cell[312473, 9971, 3199, 98, 49, "Echo"],
Cell[315675, 10071, 3866, 117, 61, "Echo"],
Cell[319544, 10190, 11084, 323, 77, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[330689, 10520, 153, 6, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[330867, 10530, 4366, 141, 289, "Input"],
Cell[CellGroupData[{
Cell[335258, 10675, 24250, 635, 81, "Echo"],
Cell[359511, 11312, 5686, 163, 54, "Echo"],
Cell[365200, 11477, 1255, 39, 50, "Echo"],
Cell[366458, 11518, 5028, 144, 50, "Echo"],
Cell[371489, 11664, 5665, 170, 50, "Echo"],
Cell[377157, 11836, 4907, 148, 29, "Echo"],
Cell[382067, 11986, 6288, 181, 30, "Echo"],
Cell[388358, 12169, 6181, 178, 30, "Echo"],
Cell[394542, 12349, 8844, 250, 54, "Echo"],
Cell[403389, 12601, 22479, 632, 110, "Echo"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[425917, 13239, 576, 18, 36, "Input"],
Cell[426496, 13259, 31, 0, 36, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[426576, 13265, 305, 12, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[426906, 13281, 701, 22, 39, "Input"],
Cell[427610, 13305, 737, 25, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[428384, 13335, 2284, 72, 269, "Input"],
Cell[CellGroupData[{
Cell[430693, 13411, 12194, 362, 105, "Echo"],
Cell[442890, 13775, 10923, 318, 58, "Echo"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[453862, 14099, 1129, 39, 142, "Input"],
Cell[CellGroupData[{
Cell[455016, 14142, 11673, 350, 105, "Echo"],
Cell[466692, 14494, 10370, 305, 58, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[477123, 14806, 356, 14, 46, "Subsubsection"],
Cell[CellGroupData[{
Cell[477504, 14824, 701, 22, 36, "Input"],
Cell[478208, 14848, 737, 25, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[478982, 14878, 2284, 72, 263, "Input"],
Cell[CellGroupData[{
Cell[481291, 14954, 13101, 392, 116, "Echo"],
Cell[494395, 15348, 11762, 345, 71, "Echo"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[506206, 15699, 1129, 39, 136, "Input"],
Cell[CellGroupData[{
Cell[507360, 15742, 12591, 380, 116, "Echo"],
Cell[519954, 16124, 11168, 331, 66, "Echo"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[531183, 16462, 41, 0, 53, "Subsection"],
Cell[531227, 16464, 3754, 96, 358, "Input"],
Cell[534984, 16562, 3754, 96, 358, "Input"],
Cell[538741, 16660, 368, 11, 41, "Input"],
Cell[539112, 16673, 3194, 85, 335, "Input"],
Cell[542309, 16760, 2261, 62, 234, "Input"],
Cell[544573, 16824, 2375, 66, 189, "Input"],
Cell[546951, 16892, 3325, 89, 285, "Input"],
Cell[550279, 16983, 2001, 54, 209, "Input"],
Cell[552283, 17039, 2367, 66, 160, "Input"],
Cell[554653, 17107, 837, 22, 135, "Input"],
Cell[555493, 17131, 2045, 55, 235, "Input"],
Cell[557541, 17188, 163, 3, 38, "Text"],
Cell[557707, 17193, 631, 16, 137, "Input"],
Cell[CellGroupData[{
Cell[558363, 17213, 48, 0, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[558436, 17217, 9817, 244, 749, "Input"],
Cell[568256, 17463, 6918, 209, 52, "Echo"]
}, Open  ]],
Cell[575189, 17675, 1123, 36, 152, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[576349, 17716, 64, 0, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[576438, 17720, 465, 14, 60, "Input"],
Cell[576906, 17736, 45, 1, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[576988, 17742, 2860, 52, 405, "Input"],
Cell[579851, 17796, 55, 0, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[579943, 17801, 1697, 39, 415, "Input"],
Cell[581643, 17842, 376, 7, 60, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
