(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    143159,       3871]
NotebookOptionsPosition[    135832,       3678]
NotebookOutlinePosition[    139569,       3766]
CellTagsIndexPosition[    139490,       3761]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Bimetric equations in standard 3+1 form \nreduced to spherical symmetry ",
 StyleBox["(data reader)",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell["Mikica Kocic", "Text"],

Cell["Created 2018-02-08, Last modified 2018-08-18", "Text"],

Cell["\<\
This notebook analyzes an output from the bim-solver simulation. When \
evaluated as a standalone, it first reads the simulation info from \
\[OpenCurlyQuote]config.m\[CloseCurlyQuote] .\
\>", "Text"],

Cell[TextData[{
 "To gather results from several \[OpenCurlyQuote]output-*.dat\
\[CloseCurlyQuote] files, set  ",
 Cell[BoxData[
  RowBox[{"$gatherOutput", "=", "True"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$gatherOutput", "=", "False"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
 CellTags->"initialization"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ValueQ", "@", "$binPath"}], "===", "False"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SetDirectory", "@", 
      RowBox[{"NotebookDirectory", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Check", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Get", "[", "\"\<config.m\>\"", "]"}], "=!=", "$Failed"}], 
         ",", 
         RowBox[{"$binPath", "=", "\"\<\>\""}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"FrontEndExecute", "[", 
        RowBox[{"FrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], 
        "]"}]}], "]"}]}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NotebookLocate", "[", "\"\<initialization\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"FrontEndToken", "[", "\"\<OpenCloseGroup\>\"", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"NotebookLocate", "[", "\"\<none\>\"", "]"}]}], "Input"],

Cell[CellGroupData[{

Cell["Utility to read the header from the output file", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"readHeader", "[", "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dataMarker", "=", "\"\<*** DATA ***\>\""}], ",", "fileName", 
      ",", "dataf", ",", "header", ",", "tmp"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{"$gatherOutput", ",", "\[IndentingNewLine]", 
       RowBox[{"fileName", "=", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"FileNames", "[", 
           RowBox[{"$binPath", "<>", "\"\<output-*.dat\>\""}], "]"}], "]"}], "//", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"#", "=!=", 
             RowBox[{"{", "}"}]}], ",", 
            RowBox[{
            "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
            "\"\<output-*.dat\>\""}], "]"}], "&"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"fileName", "=", 
        RowBox[{"$binPath", "<>", "\"\<output.dat\>\""}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"fieldNames", "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"dataf", "=", 
      RowBox[{"OpenRead", "[", "fileName", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"dataf", "=!=", "$Failed"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Seek", " ", "the", " ", "data", " ", "marker"}], " ", "*)"}],
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Find", "[", 
            RowBox[{"dataf", ",", "dataMarker"}], "]"}], "=!=", "EndOfFile"}],
           ",", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"Read", " ", "header", " ", 
            RowBox[{"(", 
             RowBox[{
             "the", " ", "text", " ", "before", " ", "the", " ", "data", " ", 
              "marker"}], " "}]}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SetStreamPosition", "[", 
            RowBox[{"dataf", ",", "0"}], "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"header", "=", 
            RowBox[{"ReadString", "[", 
             RowBox[{"dataf", ",", "dataMarker"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{
             "The", " ", "header", " ", "size", " ", "includes", " ", "also", 
              " ", "the", " ", "data", " ", "marker"}], " ", "+", " ", 
             RowBox[{"'", 
              RowBox[{"\\n", "'"}], " ", "at", " ", "the", " ", "end"}]}], 
            " ", "*)"}], "\[IndentingNewLine]", 
           RowBox[{"headerBytes", "=", 
            RowBox[{
             RowBox[{"StreamPosition", "[", "dataf", "]"}], "+", 
             RowBox[{"StringLength", "@", "dataMarker"}], "+", "1"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{
             "Read", " ", "the", " ", "header", " ", "lines", " ", "in", " ", 
              "the", " ", 
              RowBox[{"format", " ", "'"}], "name"}], " ", "\[Rule]", " ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"texString", "'"}], ".", " ", "The"}], " ", "lines", 
               " ", "are", " ", "splitted", " ", 
               RowBox[{"at", " ", "'"}]}], "\[Rule]", "'"}]}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"tmp", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"StringSplit", "[", 
               RowBox[{"#", ",", 
                RowBox[{
                "RegularExpression", "[", "\"\<\\\\s\\\\-\\\\>\\\\s\>\"", 
                 "]"}]}], "]"}], "&"}], "/@", 
             RowBox[{"ReadList", "[", 
              RowBox[{
               RowBox[{"StringToStream", "[", "header", "]"}], ",", 
               "String"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"Parse", " ", "the", " ", "field", " ", 
             RowBox[{"names", ".", " ", "The"}], " ", "tex", " ", "is", " ", 
             "converted", " ", "to", " ", "expressions", " ", "and", " ", 
             "then", " ", "replaced", " ", "by", " ", "mathematica", " ", 
             RowBox[{"boxes", ".", " ", "The"}], " ", "color", " ", "is", " ",
              "adjusted", " ", "depending", " ", "on", " ", "the", " ", 
             "field", " ", 
             RowBox[{"name", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
           RowBox[{"fieldNames", "=", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"ToExpression", "[", 
                RowBox[{
                 RowBox[{"StringReplace", "[", 
                  RowBox[{
                   RowBox[{
                   "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{"\"\<_\>\"", "\[Rule]", "\"\<$\>\""}]}], "]"}], 
                 "<>", "\"\<$\>\""}], "]"}], "\[Rule]", 
               RowBox[{"\"\<\\!\\(\\*\>\"", "<>", "\[IndentingNewLine]", 
                RowBox[{"ToString", "@", 
                 RowBox[{"FullForm", "@", 
                  RowBox[{"StyleBox", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"ToBoxes", "[", 
                    RowBox[{"ToExpression", "[", 
                    RowBox[{
                    RowBox[{"StringTrim", "[", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", "\"\<\\\"\>\""}], "]"}], 
                    ",", "TeXForm", ",", "HoldForm"}], "]"}], "]"}], 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"StringMatchQ", "[", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"RegularExpression", "[", "\"\<g.+\>\"", "]"}]}], 
                    "]"}], ",", "Blue", ",", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"StringMatchQ", "[", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"RegularExpression", "[", "\"\<f.+\>\"", "]"}]}], 
                    "]"}], ",", "Red", ",", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"StringMatchQ", "[", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"RegularExpression", "[", "\"\<pf.+\>\"", "]"}]}],
                     "]"}], ",", "Purple", ",", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"StringMatchQ", "[", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{
                    "RegularExpression", "[", "\"\<(p.*|q.*)\>\"", "]"}]}], 
                    "]"}], ",", 
                    RowBox[{"Darker", "@", "Green"}], ",", 
                    "\[IndentingNewLine]", "Black"}], "]"}]}], "]"}]}], 
                    "]"}]}], "]"}]}], "]"}]}]}], "<>", "\"\<\\)\>\""}]}], 
              "&"}], "/@", "tmp"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
        ";", "\[IndentingNewLine]", " ", 
        RowBox[{"Close", "[", "dataf", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"fieldCount", "=", 
      RowBox[{"Length", "@", "fieldNames"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"fieldCount", "\[Equal]", "0"}], ",", 
       RowBox[{"FrontEndExecute", "[", 
        RowBox[{"FrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], 
        "]"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Evaluate an expression, hiding the code (i.e., expression that generated \
output)\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"showOutNoFrameHideCode", "[", 
   RowBox[{"e_", ",", "uniqueTag_", ",", "cellOptions___"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CellPrint", "@", 
     RowBox[{"ExpressionCell", "[", 
      RowBox[{"e", ",", "\"\<Output\>\"", ",", 
       RowBox[{"CellTags", "\[Rule]", "uniqueTag"}], ",", "cellOptions"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"Not", "@", "$debugMode"}], ",", 
      RowBox[{
       RowBox[{"NotebookLocate", "[", "uniqueTag", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FrontEndExecute", "[", 
        RowBox[{"FrontEndToken", "[", "\"\<OpenCloseGroup\>\"", "]"}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"NotebookLocate", "[", "\"\<none\>\"", "]"}]}]}], "]"}], ";"}],
    ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"showOutHideCode", "[", 
   RowBox[{"e_", ",", "uniqueTag_", ",", "cellOptions___"}], "]"}], ":=", 
  RowBox[{"showOutNoFrameHideCode", "[", 
   RowBox[{"e", ",", "uniqueTag", ",", "\[IndentingNewLine]", 
    RowBox[{"CellFrame", "\[Rule]", "0.1"}], ",", 
    RowBox[{"CellMargins", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"40", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", "cellOptions"}], 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Utilities to tabulate the values of a variable ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " across ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 ", or ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"t", ",", "r"}], ")"}], TraditionalForm]]],
 " in 2D and 3D"
}], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tableT", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"skip_:", "1"}]}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t$", "[", 
       RowBox[{"m", ",", "nPos"}], "]"}], ",", 
      RowBox[{"f", "[", 
       RowBox[{"m", ",", "nPos"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "mFrom", ",", "mPos", ",", "skip"}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tableR", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"skip_:", "1"}]}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r$", "[", 
       RowBox[{"mPos", ",", "n"}], "]"}], ",", 
      RowBox[{"f", "[", 
       RowBox[{"mPos", ",", "n"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "nFrom", ",", "nPos", ",", "skip"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tableR", "[", 
   RowBox[{
    RowBox[{"f_", "?", "ListQ"}], ",", 
    RowBox[{"skip_:", "1"}]}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"mPos", ",", "n"}], "]"}], "&"}], "/@", "f"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "nFrom", ",", "nPos", ",", "skip"}], "}"}]}], 
   "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tableTR", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"mSkip_:", "1"}], ",", 
    RowBox[{"nSkip_:", "1"}]}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], ",", 
      RowBox[{"Log10\[Epsilon]", "[", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", "n"}], "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "mFrom", ",", "mPos", ",", "mSkip"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "nFrom", ",", "nPos", ",", "nSkip"}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tableTR3D", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"mSkip_:", "1"}], ",", 
    RowBox[{"nSkip_:", "1"}]}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], ",", 
      RowBox[{"t$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], ",", 
      RowBox[{"Log10\[Epsilon]", "[", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", "n"}], "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "mFrom", ",", "mPos", ",", "mSkip"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "nFrom", ",", "nPos", ",", "nSkip"}], "}"}]}], 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Reduction of the grid functions", "Subsubsection"],

Cell[TextData[{
 "Spatial derivatives for any grid function (",
 StyleBox["for this to work, nSkip must be 1",
  FontColor->RGBColor[1, 0, 0]],
 "),"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GF$r", "[", 
    RowBox[{"f_", ",", "m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "n"}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", 
         RowBox[{"1", "+", "n"}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", 
         RowBox[{"2", "+", "n"}]}], "]"}]}]}], ")"}], "/", 
    "\[CapitalDelta]r"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GF$r", "[", 
   RowBox[{"f_", ",", "m_", ",", "1"}], "]"}], ":=", 
  "Indeterminate"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GF$r", "[", 
   RowBox[{"f_", ",", "m_", ",", "2"}], "]"}], ":=", 
  "Indeterminate"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GF$rr", "[", 
    RowBox[{"f_", ",", "m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "12"]}], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "n"}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["4", "3"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", "n"}], "]"}]}], "+", 
      RowBox[{
       FractionBox["4", "3"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", 
         RowBox[{"1", "+", "n"}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"m", ",", 
         RowBox[{"2", "+", "n"}]}], "]"}]}]}], ")"}], "/", 
    SuperscriptBox["\[CapitalDelta]r", "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GF$rr", "[", 
   RowBox[{"f_", ",", "m_", ",", "1"}], "]"}], ":=", 
  "Indeterminate"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GF$rr", "[", 
   RowBox[{"f_", ",", "m_", ",", "2"}], "]"}], ":=", 
  "Indeterminate"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"GF$rrr", "[", 
   RowBox[{"f_", ",", "m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"f", "[", 
       RowBox[{"m", ",", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "n"}]}], "]"}]}], "+", 
     RowBox[{"f", "[", 
      RowBox[{"m", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "n"}]}], "]"}], "-", 
     RowBox[{"f", "[", 
      RowBox[{"m", ",", 
       RowBox[{"1", "+", "n"}]}], "]"}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"f", "[", 
       RowBox[{"m", ",", 
        RowBox[{"2", "+", "n"}]}], "]"}]}]}], ")"}], "/", 
   SuperscriptBox["\[CapitalDelta]r", "3"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GF$rrr", "[", 
   RowBox[{"f_", ",", "m_", ",", "1"}], "]"}], ":=", 
  "Indeterminate"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GF$rrr", "[", 
   RowBox[{"f_", ",", "m_", ",", "2"}], "]"}], ":=", 
  "Indeterminate"}]}], "Input"],

Cell["The extrinsic curavature,", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gK1$", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"gK$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "+", 
      RowBox[{"2", 
       RowBox[{"gKD$", "[", 
        RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}], "/", "3"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gK2$", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"gK$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "-", 
      RowBox[{"gKD$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}], ")"}], "/", "3"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fK1$", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"fK$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "+", 
      RowBox[{"2", 
       RowBox[{"fKD$", "[", 
        RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}], "/", "3"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fK2$", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"fK$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "-", 
      RowBox[{"fKD$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}], ")"}], "/", "3"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"False", ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gK$", "[", 
      RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gK1$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "+", 
      RowBox[{"2", 
       RowBox[{"gK2$", "[", 
        RowBox[{"m", ",", "n"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gKD$", "[", 
      RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gK1$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "-", 
      RowBox[{"gK2$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}]}], ";"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell["The Lorentz factor,", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{
   InterpretationBox[
    StyleBox["W",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W,
    Editable->False], "\[Equal]", 
   FractionBox["1", 
    SqrtBox[
     RowBox[{"1", "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          RowBox[{"(", 
           SuperscriptBox["v", "r"], ")"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`pfv,
         Editable->False], "2"], " ", 
       SuperscriptBox[
        StyleBox["A",
         StripOnInput->False,
         LineColor->RGBColor[0, 0, 1],
         FrontFaceColor->RGBColor[0, 0, 1],
         BackFaceColor->RGBColor[0, 0, 1],
         GraphicsColor->RGBColor[0, 0, 1],
         FontColor->RGBColor[0, 0, 1]], "2"]}]}]]]}]]]
}], "Text"],

Cell[TextData[{
 "Note that the above value can be imaginary. Much better way to calculate ",
 Cell[BoxData[
  FormBox["W", TraditionalForm]]],
 " is using the following relations (since they always give real values ",
 Cell[BoxData[
  FormBox[
   RowBox[{"W", "\[GreaterEqual]", "1"}], TraditionalForm]]],
 ")!"
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{"Wpfv", "\[Equal]", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["S", "^"], "r"],
      ShowAutoStyles->False,
      AutoSpacing->False,
      FontColor->RGBColor[0.5, 0, 0.5]],
     $CellContext`pfS,
     Editable->False], 
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox["D", "^"],
       ShowAutoStyles->False,
       AutoSpacing->False,
       FontColor->RGBColor[0.5, 0, 0.5]],
      $CellContext`pfD,
      Editable->False], " ", 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]}]]}]]],
 ",\t  ",
 Cell[BoxData[
  RowBox[{
   InterpretationBox[
    StyleBox["W",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W,
    Editable->False], "\[Equal]", 
   SqrtBox[
    RowBox[{"1", "+", 
     SuperscriptBox["Wpfv", "2"]}]]}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pfW$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{"1", "+", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"pfS$", "[", 
        RowBox[{"m", ",", "n"}], "]"}], 
       RowBox[{
        RowBox[{"pfD$", "[", 
         RowBox[{"m", ",", "n"}], "]"}], 
        RowBox[{"gA$", "[", 
         RowBox[{"m", ",", "n"}], "]"}]}]], ")"}], "2"]}]]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pf\[Delta]W$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"pfv$", "[", 
        RowBox[{"m", ",", "n"}], "]"}], "2"], 
      SuperscriptBox[
       RowBox[{"gA$", "[", 
        RowBox[{"m", ",", "n"}], "]"}], "2"]}], "<", "1"}], ",", 
    RowBox[{
     RowBox[{"(", 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"pfv$", "[", 
             RowBox[{"m", ",", "n"}], "]"}], "2"], 
           SuperscriptBox[
            RowBox[{"gA$", "[", 
             RowBox[{"m", ",", "n"}], "]"}], "2"]}]}], ")"}], 
        RowBox[{"1", "/", "2"}]]], ")"}], "-", 
     RowBox[{"pfW$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], ",", "Indeterminate"}], 
   "]"}]}]], "Input"],

Cell[TextData[{
 "We also know that ",
 Cell[BoxData[
  FormBox[
   InterpretationBox[
    StyleBox[
     OverscriptBox["\[Tau]", "^"],
     ShowAutoStyles->False,
     AutoSpacing->False,
     FontColor->RGBColor[0.5, 0, 0.5]],
    $CellContext`pf\[Tau],
    Editable->False], TraditionalForm]]],
 " is not an independent variable (which we can verify),"
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{
   InterpretationBox[
    StyleBox[
     OverscriptBox["\[Tau]", "^"],
     ShowAutoStyles->False,
     AutoSpacing->False,
     FontColor->RGBColor[0.5, 0, 0.5]],
    $CellContext`pf\[Tau],
    Editable->False], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       OverscriptBox["D", "^"],
       ShowAutoStyles->False,
       AutoSpacing->False,
       FontColor->RGBColor[0.5, 0, 0.5]],
      $CellContext`pfD,
      Editable->False]}], "+", 
    FractionBox[
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox[
           OverscriptBox["S", "^"], "r"],
          ShowAutoStyles->False,
          AutoSpacing->False,
          FontColor->RGBColor[0.5, 0, 0.5]],
         $CellContext`pfS,
         Editable->False], "2"], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox["D", "^"],
           ShowAutoStyles->False,
           AutoSpacing->False,
           FontColor->RGBColor[0.5, 0, 0.5]],
          $CellContext`pfD,
          Editable->False], "2"], " ", 
        SuperscriptBox[
         StyleBox["A",
          StripOnInput->False,
          LineColor->RGBColor[0, 0, 1],
          FrontFaceColor->RGBColor[0, 0, 1],
          BackFaceColor->RGBColor[0, 0, 1],
          GraphicsColor->RGBColor[0, 0, 1],
          FontColor->RGBColor[0, 0, 1]], "2"]}]}]], 
     StyleBox["A",
      StripOnInput->False,
      LineColor->RGBColor[0, 0, 1],
      FrontFaceColor->RGBColor[0, 0, 1],
      BackFaceColor->RGBColor[0, 0, 1],
      GraphicsColor->RGBColor[0, 0, 1],
      FontColor->RGBColor[0, 0, 1]]]}]}]], "Output"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pf\[Delta]\[Tau]$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"pfD$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}], "+", 
     FractionBox[
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"pfS$", "[", 
          RowBox[{"m", ",", "n"}], "]"}], "2"], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"gA$", "[", 
           RowBox[{"m", ",", "n"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"pfD$", "[", 
           RowBox[{"m", ",", "n"}], "]"}], "2"]}]}]], 
      RowBox[{"gA$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]]}], ")"}], "-", 
   RowBox[{"pf\[Tau]$", "[", 
    RowBox[{"m", ",", "n"}], "]"}]}]}]], "Input"],

Cell[TextData[{
 "The barion number density ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "0"], TraditionalForm]]],
 " is obtained from ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox["D", "^"],
      ShowAutoStyles->False,
      AutoSpacing->False,
      FontColor->RGBColor[0.5, 0, 0.5]],
     $CellContext`pfD,
     Editable->False], "/", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}], "\[Equal]", 
   RowBox[{
    InterpretationBox[
     StyleBox["W",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`W,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox["\[Rho]", "0"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Rho]0,
     Editable->False], " "}]}]]],
 ". Hence,"
}], "Text"],

Cell[TextData[{
 "\t  ",
 Cell[BoxData[
  RowBox[{
   InterpretationBox[
    StyleBox["W",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W,
    Editable->False], "\[Equal]", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox["D", "^"],
      ShowAutoStyles->False,
      AutoSpacing->False,
      FontColor->RGBColor[0.5, 0, 0.5]],
     $CellContext`pfD,
     Editable->False], "/", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["W",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`W,
       Editable->False], " ", 
      StyleBox["A",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], " ", 
      SuperscriptBox[
       StyleBox["B",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontColor->RGBColor[0, 0, 1]], "2"]}], ")"}]}]}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pf\[Rho]B$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"pfD$", "[", 
    RowBox[{"m", ",", "n"}], "]"}], 
   RowBox[{
    RowBox[{"pfW$", "[", 
     RowBox[{"m", ",", "n"}], "]"}], 
    RowBox[{"gA$", "[", 
     RowBox[{"m", ",", "n"}], "]"}], 
    SuperscriptBox[
     RowBox[{"gB$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "2"]}]]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Test the nonsmoothness of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox[
     OverscriptBox["K", "~"], "1"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gP1$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"gAlp$", "[", 
     RowBox[{"m", ",", "n"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"gDA$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"gDB$", "[", 
        RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"r$", "[", 
     RowBox[{"m", ",", "n"}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"gA$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "2"]}]]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gP2$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"gDA$", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"gDB$", "[", 
     RowBox[{"m", ",", "n"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gP2$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p$", "[", 
      RowBox[{"m", ",", 
       RowBox[{"n", "-", "1"}]}], "]"}], "+", 
     RowBox[{"p$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "+", 
     RowBox[{"p$", "[", 
      RowBox[{"m", ",", 
       RowBox[{"n", "+", "1"}]}], "]"}], "+", 
     RowBox[{"p$", "[", 
      RowBox[{"m", ",", 
       RowBox[{"n", "+", "2"}]}], "]"}]}], ")"}], "/", 
   "4"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gP2$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"C$1$", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "/", 
   RowBox[{"g$rho$", "[", 
    RowBox[{"m", ",", "n"}], "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fK1evol$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"fAlp$", "[", 
     RowBox[{"m", ",", "n"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"fA$", "[", 
          RowBox[{"m", ",", "n"}], "]"}], "2"]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{"fDAlp$", "[", 
            RowBox[{"m", ",", "n"}], "]"}], "2"]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            RowBox[{"fDAlp$", "[", 
             RowBox[{"m", ",", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], "+", 
           RowBox[{"fDAlp$", "[", 
            RowBox[{"m", ",", 
             RowBox[{"1", "+", "n"}]}], "]"}]}], 
          RowBox[{"2", " ", "\[CapitalDelta]r"}]], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"fDB$", "[", 
            RowBox[{"m", ",", "n"}], "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"fDA$", "[", 
           RowBox[{"m", ",", "n"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fDAlp$", "[", 
             RowBox[{"m", ",", "n"}], "]"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"fDB$", "[", 
              RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            RowBox[{"fDB$", "[", 
             RowBox[{"m", ",", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], "+", 
           RowBox[{"fDB$", "[", 
            RowBox[{"m", ",", 
             RowBox[{"1", "+", "n"}]}], "]"}]}], "\[CapitalDelta]r"]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"fK1$", "[", 
        RowBox[{"m", ",", "n"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fK1$", "[", 
          RowBox[{"m", ",", "n"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"fK2$", "[", 
           RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
   "\[IndentingNewLine]", 
   RowBox[{"2", 
    RowBox[{"(*", "k$f$", "*)"}], " ", 
    RowBox[{"fAlp$", "[", 
     RowBox[{"m", ",", "n"}], "]"}], " ", 
    RowBox[{"f$JK1$", "[", 
     RowBox[{"m", ",", "n"}], "]"}]}], "-", "\[IndentingNewLine]", 
   FractionBox[
    RowBox[{
     RowBox[{"fAlp$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"fK1$", "[", 
         RowBox[{"m", ",", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], "+", 
       RowBox[{"fK1$", "[", 
        RowBox[{"m", ",", 
         RowBox[{"1", "+", "n"}]}], "]"}]}], ")"}], " ", 
     RowBox[{"p$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], 
    RowBox[{"2", " ", "\[CapitalDelta]r", " ", 
     RowBox[{"fA$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"p$", "[", 
          RowBox[{"m", ",", "n"}], "]"}], "2"]}], ")"}], 
      RowBox[{"1", "/", "2"}]]}]], "+", "\[IndentingNewLine]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"fK1$", "[", 
         RowBox[{"m", ",", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], "+", 
       RowBox[{"fK1$", "[", 
        RowBox[{"m", ",", 
         RowBox[{"1", "+", "n"}]}], "]"}]}], ")"}], " ", 
     RowBox[{"q$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], 
    RowBox[{"2", " ", "\[CapitalDelta]r"}]], "+", "\[IndentingNewLine]", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"fAlp$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fDA$", "[", 
        RowBox[{"m", ",", "n"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"fDB$", "[", 
         RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"fA$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "2"], " ", 
     RowBox[{"r$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}]]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fK1evol$1", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"fDAlp$", "[", 
     RowBox[{"m", ",", 
      RowBox[{"1", "+", "n"}]}], "]"}], "-", 
    RowBox[{"fDAlp$", "[", 
     RowBox[{"m", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], 
   RowBox[{"2", " ", "\[CapitalDelta]r"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fK1evol$2", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"fDB$", "[", 
     RowBox[{"m", ",", 
      RowBox[{"1", "+", "n"}]}], "]"}], "-", 
    RowBox[{"fDB$", "[", 
     RowBox[{"m", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], 
   RowBox[{"2", "\[CapitalDelta]r"}]]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fK1evol$3", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], 
    RowBox[{"(*", "k$f$", "*)"}], " ", 
    RowBox[{"fAlp$", "[", 
     RowBox[{"m", ",", "n"}], "]"}], " ", 
    RowBox[{"f$JK1$", "[", 
     RowBox[{"m", ",", "n"}], "]"}]}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"fAlp$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"fK1$", "[", 
         RowBox[{"m", ",", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], "+", 
       RowBox[{"fK1$", "[", 
        RowBox[{"m", ",", 
         RowBox[{"1", "+", "n"}]}], "]"}]}], ")"}], " ", 
     RowBox[{"p$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], 
    RowBox[{"2", " ", "\[CapitalDelta]r", " ", 
     RowBox[{"fA$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"p$", "[", 
          RowBox[{"m", ",", "n"}], "]"}], "2"]}], ")"}], 
      RowBox[{"1", "/", "2"}]]}]], "+", "\[IndentingNewLine]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"fK1$", "[", 
         RowBox[{"m", ",", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}]}], "]"}]}], "+", 
       RowBox[{"fK1$", "[", 
        RowBox[{"m", ",", 
         RowBox[{"1", "+", "n"}]}], "]"}]}], ")"}], " ", 
     RowBox[{"q$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], 
    RowBox[{"2", " ", "\[CapitalDelta]r"}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"fAlp$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fDA$", "[", 
        RowBox[{"m", ",", "n"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"fDB$", "[", 
         RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"fA$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "2"], " ", 
     RowBox[{"r$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}]]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"relC$1", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"C$1$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "/", 
     RowBox[{"g$rho$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"relC$2", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"C$2$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "/", 
     RowBox[{"f$rho$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"relC$3", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"C$3$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "/", 
     RowBox[{"pfS$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"relC$4", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"C$4$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "/", 
     RowBox[{"g$rho$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], "]"}]}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gBet$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"q$", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "+", 
   RowBox[{
    FractionBox[
     RowBox[{"gAlp$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], 
     RowBox[{"gA$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"p$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", " ", 
        SuperscriptBox[
         RowBox[{"p$", "[", 
          RowBox[{"m", ",", "n"}], "]"}], "2"]}], ")"}], 
      RowBox[{"1", "/", "2"}]]]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fBet$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"q$", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "-", 
   RowBox[{
    FractionBox[
     RowBox[{"fAlp$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], 
     RowBox[{"fA$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"p$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", " ", 
        SuperscriptBox[
         RowBox[{"p$", "[", 
          RowBox[{"m", ",", "n"}], "]"}], "2"]}], ")"}], 
      RowBox[{"1", "/", "2"}]]]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fAlpDiff$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"gAlp$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}], 
    RowBox[{
     RowBox[{"gW$", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "/", 
     RowBox[{"fW$", "[", 
      RowBox[{"m", ",", "n"}], "]"}]}]}], "-", 
   RowBox[{"fAlp$", "[", 
    RowBox[{"m", ",", "n"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"R$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"fB$", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "/", 
   RowBox[{"gB$", "[", 
    RowBox[{"m", ",", "n"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Lt$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox[
      RowBox[{"p$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "2"]}], ")"}], 
   RowBox[{"1", "/", "2"}]]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Wgf$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"gAlp$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], 
      RowBox[{"gW$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"fAlp$", "[", 
       RowBox[{"m", ",", "n"}], "]"}], 
      RowBox[{"fW$", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}], "/", 
   RowBox[{"cW$", "[", 
    RowBox[{"m", ",", "n"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Wgf$", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"gW$", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "/", 
   RowBox[{"cW$", "[", 
    RowBox[{"m", ",", "n"}], "]"}]}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\"\<C4B$[m_,n_]:=\>\"", "<>", 
   RowBox[{"StringReplace", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          UnderscriptBox["eq$C4", "_"], "/.", 
          RowBox[{"P", "\[Rule]", "eq$esP"}]}], "/.", 
         RowBox[{"Thread", "[", 
          RowBox[{"modelParamNames", "\[Rule]", "id$modelParams"}], "]"}]}], "/.", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"0", ",", "1"}], "]"}], "[", "f_", "]"}], "[", 
          RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
         RowBox[{
          RowBox[{"Symbol", "[", 
           RowBox[{
            RowBox[{"ToString", "@", "f"}], "<>", "\"\<$r\>\""}], "]"}], "[", 
          RowBox[{"t", ",", "r"}], "]"}]}]}], "//", "InputForm"}], "//", 
      "ToString"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<[t, r]\>\"", "\[Rule]", "\"\<$[m,n]\>\""}], ",", 
       RowBox[{"\"\<r*\>\"", "\[Rule]", "\"\<r$[m,n]*\>\""}]}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToExpression", "@", "%"}], ";"}]}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Read the results", "Subsection"],

Cell["\<\
Read the header from the output files (the header contains the list of grid \
functions):\
\>", "Text"],

Cell[BoxData[
 RowBox[{"readHeader", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"showOutNoFrameHideCode", "[", 
  RowBox[{
   RowBox[{"Column", "@", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Row", "@", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Found \>\"", ",", "fieldCount", ",", 
         "\"\< grid functions:\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Row", "@", 
       RowBox[{"{", 
        RowBox[{"\"\<  \>\"", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"ArrayReshape", "[", 
            RowBox[{
             RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"3", ";;"}], ",", "2"}], "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"11", ",", "8"}], "}"}], ",", "\"\<\>\""}], "]"}], "//",
            "Transpose"}], "//", "TableForm"}]}], "}"}]}]}], 
     "\[IndentingNewLine]", "}"}]}], ",", "\"\<gridFunctions\>\""}], 
  "]"}]], "Input"],

Cell[TextData[{
 "Now, read and partition the actual data. The rows in the resulting table \
are grouped by ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " then ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 ". \nEach row has ",
 Cell[BoxData["fieldCount"]],
 " columns, which is obtained from the header. The total number of rows \
should be  ",
 Cell[BoxData[
  RowBox[{"mSize", "\[Times]", "nSize"}]]],
 "."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Not", "@", "$gatherOutput"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Then", ":", " ", 
      RowBox[{"Read", " ", "a", " ", "single", " ", "file"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dlNames", "=", "\"\<output.dat\>\""}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dlTime", "=", 
      RowBox[{
       RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
        RowBox[{"data", "=", 
         RowBox[{"Partition", "[", 
          RowBox[{
           RowBox[{"Import", "[", 
            RowBox[{
             RowBox[{"$binPath", "<>", "\"\<output.dat\>\""}], ",", 
             "$realBinaryFormat", ",", 
             RowBox[{"\"\<HeaderBytes\>\"", "\[Rule]", "headerBytes"}]}], 
            "]"}], ",", "fieldCount"}], "]"}]}], "\[IndentingNewLine]", "]"}],
        "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Else", ":", " ", 
      RowBox[{
      "Gather", " ", "output", " ", "from", " ", "several", " ", "files", " ",
        "produced", " ", "using", " ", "MPI"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dlNames", "=", 
      RowBox[{"Sort", "@", 
       RowBox[{"FileNames", "[", 
        RowBox[{"$binPath", "<>", "\"\<output-*.dat\>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dlTime", "=", 
      RowBox[{
       RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"dl", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Partition", "[", 
             RowBox[{
              RowBox[{"Import", "[", 
               RowBox[{"#", ",", "$realBinaryFormat", ",", 
                RowBox[{"\"\<HeaderBytes\>\"", "\[Rule]", "headerBytes"}]}], 
               "]"}], ",", "fieldCount"}], "]"}], "&"}], "/@", "dlNames"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"dlSizes", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Block", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"nSize", ",", "mSize"}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"nSize", "=", 
                RowBox[{"Count", "[", 
                 RowBox[{"#", ",", 
                  RowBox[{"u_", "/;", 
                   RowBox[{
                    RowBox[{
                    "u", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", 
                    RowBox[{"#", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
                 "]"}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"mSize", "=", 
                RowBox[{"Floor", "[", 
                 RowBox[{
                  RowBox[{"Length", "@", "#"}], "/", "nSize"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"nSize", " ", "\[LessEqual]", "0"}], "\[Or]", 
                  RowBox[{"mSize", "\[LessEqual]", "0"}], "\[Or]", 
                  RowBox[{
                   RowBox[{"mSize", " ", "*", " ", "nSize"}], "\[NotEqual]", 
                   RowBox[{"Length", "@", "#"}]}]}], ",", 
                 RowBox[{
                  RowBox[{"Print", "@", 
                   RowBox[{"Style", "[", 
                    RowBox[{
                    "\"\<Error!\>\"", ",", "Bold", ",", "Red", ",", "13"}], 
                    "]"}]}], ";", 
                  RowBox[{"FrontEndExecute", "[", 
                   RowBox[{
                   "FrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], 
                   "]"}]}], ",", "\"\<\>\""}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"nSize", ",", "mSize"}], "}"}]}]}], 
             "\[IndentingNewLine]", "]"}], "&"}], "/@", "dl"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"dlNames", "=", 
          RowBox[{"Row", "@", 
           RowBox[{"{", 
            RowBox[{"dlNames", ",", "\"\<, dimensions \>\"", ",", "dlSizes"}],
             "}"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "Gather", " ", "data", " ", "ignoring", " ", "the", " ", 
           "overlapping", " ", "ghost", " ", "areas"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"data", "=", 
          RowBox[{"With", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"nSize", "=", 
              RowBox[{"dlSizes", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "}"}], 
            ",", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Join", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "dl", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", " ", "nSize"}], "+", "1"}], ";;", 
                    RowBox[{
                    RowBox[{"m", " ", "nSize"}], "+", "ghostCells"}]}], 
                   "\[RightDoubleBracket]"}], ",", "\[IndentingNewLine]", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"m", "  ", "nSize"}], "+", "ghostCells", "+", 
                    "1"}], ";;", 
                    RowBox[{
                    RowBox[{"m", " ", "nSize"}], "+", "nSize", "-", 
                    "ghostCells"}]}], "\[RightDoubleBracket]"}], "&"}], "/@", 
                    "dl"}], ",", "1"}], "]"}], ",", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"dl", "\[LeftDoubleBracket]", 
                    RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], 
                   "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", " ", "nSize"}], "+", "nSize", "-", 
                    "ghostCells", "+", "1"}], ";;", 
                    RowBox[{
                    RowBox[{"m", "  ", "nSize"}], "+", "nSize"}]}], 
                   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", "]"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "0", ",", 
                  RowBox[{
                   RowBox[{"dlSizes", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
                   "1"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], "]"}]}], 
         ";"}], "\[IndentingNewLine]", "]"}], "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Row", "@", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "\"\<Imported \>\"", ",", "dlNames", ",", "\"\<\\n\>\"", ",", 
     "\[IndentingNewLine]", "\"\<Data dimension: \>\"", ",", 
     RowBox[{"Dimensions", "@", "data"}], ",", "\"\<\\n\>\"", ",", 
     "\[IndentingNewLine]", "\"\<nSize = \>\"", ",", 
     RowBox[{"nSize", "=", 
      RowBox[{"Count", "[", 
       RowBox[{"data", ",", 
        RowBox[{"u_", "/;", 
         RowBox[{
          RowBox[{"u", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "\[Equal]", 
          RowBox[{"data", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], "]"}]}], 
     ",", "\[IndentingNewLine]", "\"\<, mSize = \>\"", ",", 
     RowBox[{"mSize", "=", 
      RowBox[{"Floor", "[", 
       RowBox[{
        RowBox[{"Length", "@", "data"}], "/", "nSize"}], "]"}]}], ",", 
     "\[IndentingNewLine]", "\"\<, m \[Times] n = \>\"", ",", " ", 
     RowBox[{"mSize", " ", "*", " ", "nSize"}], ",", "\[IndentingNewLine]", 
     "\"\<\\nElapsed: \>\"", ",", "dlTime", ",", "\"\< s\>\"", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"nSize", " ", "\[LessEqual]", "0"}], "\[Or]", 
        RowBox[{"mSize", "\[LessEqual]", "0"}], "\[Or]", 
        RowBox[{
         RowBox[{"mSize", " ", "*", " ", "nSize"}], "\[NotEqual]", 
         RowBox[{"Length", "@", "data"}]}]}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\\nError! ($Aborted)\>\"", ",", "Bold", ",", "Red"}], 
        "]"}], ",", "\"\<\>\""}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutNoFrameHideCode", "[", 
  RowBox[{"%", ",", "\"\<importOut\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"nSize", " ", "\[LessEqual]", "0"}], "\[Or]", 
    RowBox[{"mSize", "\[LessEqual]", "0"}], "\[Or]", 
    RowBox[{
     RowBox[{"mSize", " ", "*", " ", "nSize"}], "\[NotEqual]", 
     RowBox[{"Length", "@", "data"}]}]}], ",", 
   RowBox[{"FrontEndExecute", "[", 
    RowBox[{"FrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], "]"}]}], 
  "]"}]}], "Input"],

Cell[TextData[{
 "For each column, we create a function to access the data. \nAn example \
below is for the field ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "(", 
    RowBox[{"m", ",", "n"}], ")"}], TraditionalForm]]],
 ":"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ToExpression", "[", 
       RowBox[{
        RowBox[{"ToString", "[", 
         RowBox[{"#", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
         "]"}], "<>", "\"\<[m_,n_] := data[[(m-1) * nSize + n,\>\"", "<>", 
        RowBox[{"ToString", "@", "n"}], "<>", "\"\<]]\>\""}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ToExpression", "[", 
       RowBox[{"\"\<Attributes[\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"#", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
         "]"}], "<>", "\"\<] = .\>\""}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"n", ",", "fieldCount"}], "}"}]}], "]"}], "&"}], "@", 
  RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
   RowBox[{"All", ",", "1"}], 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"showOutNoFrameHideCode", "[", 
  RowBox[{
   RowBox[{"r$", "//", "Definition"}], ",", "\"\<rDef\>\""}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell["Derived variables", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fieldNames", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
      RowBox[{"1", ";;", "fieldCount"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pf\[Rho]B$", "\[Rule]", "\"\<\!\(\*
StyleBox[SubscriptBox[\"\[Rho]\", \"0\"],
FontColor->RGBColor[0.5, 0, 0.5]]\)\>\""}], ",", "\[IndentingNewLine]", 
       RowBox[{"gK2$", "\[Rule]", "\"\<\!\(\*
StyleBox[SubscriptBox[\"K\", \"2\"],
FontColor->RGBColor[0, 0, 1]]\)\>\""}], ",", 
       RowBox[{"fK2$", "\[Rule]", "\"\<\!\(\*
StyleBox[SubscriptBox[OverscriptBox[\"K\", \"~\"], \"2\"],
FontColor->RGBColor[1, 0, 0]]\)\>\""}], ",", 
       RowBox[{"fDAlp$", "\[Rule]", "\"\<\!\(\*
StyleBox[SubscriptBox[OverscriptBox[\"D\", \"~\"], \"\[Alpha]\"],
FontColor->RGBColor[1, 0, 0]]\)\>\""}], ",", "\[IndentingNewLine]", 
       RowBox[{"pfW$", "\[Rule]", "\"\<\!\(\*
StyleBox[\"W\",
FontColor->RGBColor[0.5, 0, 0.5]]\)\>\""}], ",", 
       RowBox[{"pf\[Delta]W$", "\[Rule]", "\"\<\!\(\*
StyleBox[\"\[Delta]W\",
FontColor->RGBColor[0.5, 0, 0.5]]\)\>\""}], ",", 
       RowBox[{"pf\[Delta]\[Tau]$", "\[Rule]", "\"\<\!\(\*
StyleBox[\"\[Delta]\",
FontColor->RGBColor[0.5, 0, 0.5]]\)\!\(\*
StyleBox[OverscriptBox[\"\[Tau]\", \"^\"],
FontColor->RGBColor[0.5, 0, 0.5]]\)\>\""}], ",", "\[IndentingNewLine]", 
       RowBox[{"gBet$", "\[Rule]", "\"\<\[Beta]\>\""}], ",", 
       RowBox[{
       "fBet$", "\[Rule]", 
        "\"\<\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\)\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "fAlpDiff$", "\[Rule]", 
        "\"\<\!\(\*OverscriptBox[\(\[Alpha]\), \
\(~\)]\)-\!\(\*OverscriptBox[\(\[Alpha]\), \(~\)]\)\>\""}], " ", ",", 
       RowBox[{
       "Wgf$", "\[Rule]", 
        "\"\<\!\(\*SubscriptBox[\(\[Alpha]W\), \
\(g\)]\)+\!\(\*OverscriptBox[\(\[Alpha]\), \(~\)]\)\!\(\*SubscriptBox[\(W\), \
\(f\)]\)\>\""}]}], "\[IndentingNewLine]", "}"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Display of the results", "Subsection"],

Cell[CellGroupData[{

Cell["Legend", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<g:\>\"", ",", 
        RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "3", ",", "4", ",", "5", ",", "6", ",", "19", ",", "20", ",", 
            "21"}], "}"}], ",", "2"}], "\[RightDoubleBracket]"}], ",", 
        "\"\<  Evolution:\>\"", ",", 
        RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "11", ",", "12", ",", "13", ",", "14", ",", "27", ",", "28", ",", 
            "29"}], "}"}], ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<f:\>\"", ",", 
        RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "3", ",", "4", ",", "5", ",", "6", ",", "19", ",", "20", ",", 
             "21"}], "}"}], "+", "4"}], ",", "2"}], "\[RightDoubleBracket]"}],
         ",", "\"\<\>\"", ",", 
        RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "11", ",", "12", ",", "13", ",", "14", ",", "27", ",", "28", ",", 
             "29"}], "}"}], "+", "4"}], ",", "2"}], 
         "\[RightDoubleBracket]"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<Matter:\>\"", ",", 
        RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"51", ",", "52", ",", "53"}], "}"}], ",", "2"}], 
         "\[RightDoubleBracket]"}], ",", "\"\<\>\"", ",", 
        RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"51", ",", "52", ",", "53"}], "}"}], "+", "4"}], ",", 
          "2"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<Gauge:\>\"", ",", 
        RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "37", ",", "30", ",", "38", ",", "22", ",", "26", ",", "34"}], 
           "}"}], ",", "2"}], "\[RightDoubleBracket]"}], ",", 
        "\"\<  Constraints:\>\"", ",", 
        RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"39", ";;", "42"}], ",", "2"}], "\[RightDoubleBracket]"}]}],
        "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutHideCode", "[", 
  RowBox[{"%", ",", "\"\<fieldsLegend\>\""}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The collapse of the lapse", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"propTime", "=", 
   RowBox[{
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mMax", "=", 
         RowBox[{"Max", "[", 
          RowBox[{"1", ",", 
           RowBox[{"Round", "[", 
            RowBox[{"0.9", "mSize"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"mStep", "=", 
         RowBox[{"5", "+", 
          RowBox[{"0", 
           RowBox[{"Max", "[", 
            RowBox[{"1", ",", 
             RowBox[{"Round", "[", 
              RowBox[{"mSize", "/", "100"}], "]"}]}], "]"}]}]}]}]}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Transpose", "@", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"r$", "[", 
              RowBox[{"m", ",", "n"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"m", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"1", ",", "mMax", ",", "mStep"}], "]"}]}], "}"}]}], 
            "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Accumulate", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"gAlp$", "[", 
                RowBox[{"m", ",", "n"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", 
                 RowBox[{"Range", "[", 
                  RowBox[{"1", ",", "mMax", ",", "mStep"}], "]"}]}], "}"}]}], 
              "]"}], "*", "\[IndentingNewLine]", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", "\[CapitalDelta]t", "}"}], ",", 
               RowBox[{"Differences", "@", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"t$", "[", 
                   RowBox[{"m", ",", "n"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"m", ",", 
                    RowBox[{"Range", "[", 
                    RowBox[{"1", ",", "mMax", ",", "mStep"}], "]"}]}], 
                   "}"}]}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]", "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"t$", "[", 
              RowBox[{"m", ",", "n"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"m", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"1", ",", "mMax", ",", "mStep"}], "]"}]}], "}"}]}], 
            "]"}]}], "\[IndentingNewLine]", "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"1", "+", "ghostCells"}], ",", 
          RowBox[{"nSize", "-", "ghostCells"}], ",", "mStep"}], "}"}]}], 
       "]"}]}], "]"}], "//", "Transpose"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figLapseCollapse", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Tooltip", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "propTime", "\[LeftDoubleBracket]", "i", 
             "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
            RowBox[{"All", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}]}], "\[RightDoubleBracket]"}], 
           ",", 
           RowBox[{"\"\<t = \>\"", "<>", 
            RowBox[{"ToString", "@", 
             RowBox[{
              RowBox[{
              "propTime", "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}]}]}], "]"}],
          ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "@", "propTime"}], ",", 
           RowBox[{"Max", "[", 
            RowBox[{"1", ",", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{"Length", "@", "propTime"}], "/", "30"}], "]"}]}], 
            "]"}]}], "}"}]}], "\[IndentingNewLine]", "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{
             "propTime", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", "propTime", "]"}], 
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
              "1"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"0.75", 
             RowBox[{"propTime", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", "2"}], "\[RightDoubleBracket]"}]}]}], 
           "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RGBColor", "[", 
            RowBox[{"0", ",", "0.4", ",", "0.7"}], "]"}], ",", "Thin"}], 
          "}"}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"r", ",", "Black", ",", "15"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Rotate", "[", 
             RowBox[{
              RowBox[{"HoldForm", "[", 
               RowBox[{"\[Integral]", 
                RowBox[{"\[Alpha]", "\[VeryThinSpace]", 
                 RowBox[{"\[DifferentialD]", "t"}]}]}], "]"}], ",", 
              RowBox[{
               RowBox[{"-", "90"}], "\[Degree]"}]}], "]"}], ",", "Black", ",",
             "15"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0.4", ",", "0.7"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"StringReplace", "[", 
             RowBox[{
              RowBox[{"ToString", "@", 
               RowBox[{"NumberForm", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "propTime", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Dimensions", "[", "propTime", "]"}], 
                    "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                    "-", "1"}], ",", "3"}], "\[RightDoubleBracket]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"5", ",", "1"}], "}"}]}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"RegularExpression", "[", "\"\<\\\\.$\>\"", "]"}], 
               "\[Rule]", "\"\<\>\""}]}], "]"}], ",", 
            RowBox[{
             RowBox[{
             "propTime", "\[LeftDoubleBracket]", "i", 
              "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Dimensions", "[", "propTime", "]"}], 
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "-", 
               "1"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "2"}], "}"}]}], "\[RightDoubleBracket]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "@", "propTime"}], ",", 
            RowBox[{"Max", "[", 
             RowBox[{"1", ",", 
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"Length", "@", "propTime"}], "/", "30"}], "]"}]}], 
             "]"}]}], "}"}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutHideCode", "[", 
  RowBox[{
   RowBox[{"Column", "@", 
    RowBox[{"{", 
     RowBox[{"figLapseCollapse", ",", 
      RowBox[{"Style", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
        "Text", "[", 
         "\"\<The slicing represented by the proper time of the Eulerian \
observer.\>\"", "]"}], ",", "14"}], "]"}]}], "}"}]}], ",", 
   "\"\<lapseCollapse\>\""}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The collapse of the Lagrange shells", "Subsubsection"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"Not", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"id$setup", "\[Equal]", "4"}], "\[Or]", 
      RowBox[{"id$setup", "\[Equal]", "5"}]}], ")"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"showOutHideCode", "[", 
    RowBox[{"\"\<(not shown)\>\"", ",", "\"\<lagrangeShells\>\""}], "]"}], 
   ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"pf$massProfile", "[", "m_", "]"}], ":=", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]Acc", "=", 
         RowBox[{"Accumulate", "[", "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox[
              RowBox[{"r$", "[", 
               RowBox[{"m", ",", "n"}], "]"}], "2"], 
             RowBox[{"pf\[Rho]B$", "[", 
              RowBox[{"m", ",", "n"}], "]"}], "\[CapitalDelta]r"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"n", ",", 
              RowBox[{"1", "+", "ghostCells"}], ",", 
              RowBox[{"nSize", "-", "ghostCells"}]}], "}"}]}], 
           "\[IndentingNewLine]", "]"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"mtr", "=", 
           RowBox[{"Transpose", "@", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"r$", "[", 
                 RowBox[{"m", ",", "n"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n", ",", 
                  RowBox[{"1", "+", "ghostCells"}], ",", 
                  RowBox[{"nSize", "-", "ghostCells"}]}], "}"}]}], "]"}], ",",
               "\[IndentingNewLine]", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"t$", "[", 
                 RowBox[{"m", ",", "n"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n", ",", 
                  RowBox[{"1", "+", "ghostCells"}], ",", 
                  RowBox[{"nSize", "-", "ghostCells"}]}], "}"}]}], "]"}], ",",
               "\[IndentingNewLine]", 
              RowBox[{"\[Rho]Acc", "/", 
               RowBox[{"\[Rho]Acc", "\[LeftDoubleBracket]", 
                RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}]}], 
             "\[IndentingNewLine]", "}"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"With", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"v", "=", 
               RowBox[{"SelectFirst", "[", 
                RowBox[{"mtr", ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "#", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "i"}], 
                  "&"}]}], "]"}]}], "}"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"v", "===", 
                RowBox[{"Missing", "[", "\"\<NotFound\>\"", "]"}]}], ",", 
               "Nothing", ",", "v"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "1", ",", "0.01"}], "}"}]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"pf$massInShell", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"pf$massProfile", "[", "m", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"1", ",", "mSize", ",", "5"}], "]"}], ",", 
           RowBox[{"Range", "[", 
            RowBox[{
             RowBox[{"mSize", "-", 
              RowBox[{"Mod", "[", 
               RowBox[{
                RowBox[{"mSize", "-", "1"}], ",", "5"}], "]"}]}], ",", 
             "mSize"}], "]"}]}], "]"}]}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"pf$apparentHorizon", "=", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"pts", "=", 
           RowBox[{"Reap", "[", 
            RowBox[{"Do", "[", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Sign", "@", 
                  RowBox[{"gHorz$", "[", 
                   RowBox[{"m", ",", "n"}], "]"}]}], ">", 
                 RowBox[{"Sign", "@", 
                  RowBox[{"gHorz$", "[", 
                   RowBox[{"m", ",", 
                    RowBox[{"n", "-", "1"}]}], "]"}]}]}], ",", 
                RowBox[{"Sow", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"t$", "[", 
                    RowBox[{"m", ",", "n"}], "]"}], ",", 
                   RowBox[{"r$", "[", 
                    RowBox[{"m", ",", "n"}], "]"}]}], "}"}], "]"}]}], 
               "\[IndentingNewLine]", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", 
                RowBox[{"2", "+", "ghostCells"}], ",", 
                RowBox[{"nSize", "-", "ghostCells"}]}], "}"}]}], "]"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"pts", "=!=", 
            RowBox[{"{", 
             RowBox[{"Null", ",", 
              RowBox[{"{", "}"}]}], "}"}]}], ",", 
           RowBox[{"pts", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1", ",", 
             RowBox[{"-", "1"}]}], "\[RightDoubleBracket]"}], ",", 
           "Nothing"}], "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"1", ",", "mSize", ",", "5"}], "]"}], ",", 
           RowBox[{"Range", "[", 
            RowBox[{
             RowBox[{"mSize", "-", 
              RowBox[{"Mod", "[", 
               RowBox[{
                RowBox[{"mSize", "-", "1"}], ",", "5"}], "]"}]}], ",", 
             "mSize"}], "]"}]}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
      "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"pf$apparentHorizon", "=!=", 
       RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"pf$rM", "=", 
       RowBox[{"2", "/", 
        RowBox[{"pf$apparentHorizon", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "\[RightDoubleBracket]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pf$rM", "=", "1"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"figLagcells", "=", 
     RowBox[{"Show", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ListContourPlot", "[", 
        RowBox[{
         RowBox[{"pf$massInShell", "//", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"#", ",", "1"}], "]"}], "&"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"r", ",", "Black", ",", "15"}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"Rotate", "[", 
               RowBox[{"t", ",", 
                RowBox[{
                 RowBox[{"-", "90"}], "\[Degree]"}]}], "]"}], ",", "Black", 
              ",", "15"}], "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", "Automatic", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
         RowBox[{"PlotRangeClipping", "\[Rule]", "False"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ColorFunction", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{
            RowBox[{"{", "z", "}"}], ",", 
            RowBox[{"RGBColor", "[", 
             RowBox[{
              RowBox[{"0.8", "+", 
               RowBox[{"0.25", "z"}]}], ",", 
              RowBox[{"0.7", "+", 
               RowBox[{"0.35", "z"}]}], ",", 
              RowBox[{"0.2", "+", 
               RowBox[{"0.85", "z"}]}]}], "]"}]}], "]"}]}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"Contours", "\[Rule]", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], " ", ",", 
         RowBox[{"PlotLegends", "\[Rule]", 
          RowBox[{"Placed", "[", 
           RowBox[{"Automatic", ",", "Right"}], "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ListLinePlot", "[", 
        RowBox[{
         RowBox[{"pf$apparentHorizon", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "1"}], "}"}]}], "\[RightDoubleBracket]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"InterpolationOrder", "\[Rule]", "1"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Dashed"}], "}"}]}]}], "]"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"showOutHideCode", "[", 
     RowBox[{
      RowBox[{"Column", "@", 
       RowBox[{"{", 
        RowBox[{"figLagcells", ",", 
         RowBox[{"Style", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
           "Text", "[", 
            "\"\<The time variation of the radius of each Lagrange shell \
(solid lines). The dashed line shows the apparent horizon.\>\"", "]"}], ",", 
           "14"}], "]"}]}], "}"}]}], ",", "\"\<lagrangeShells\>\""}], 
     "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"Not", "[", 
    RowBox[{
     RowBox[{"id$setup", "\[Equal]", "4"}], "\[Or]", 
     RowBox[{"id$setup", "\[Equal]", "5"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"showOutHideCode", "[", 
    RowBox[{"\"\<(AH not found)\>\"", ",", "\"\<shellVideoFrame\>\""}], "]"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"shellVideoFrame", "[", 
      RowBox[{"m_", ",", 
       RowBox[{"nPts_:", "20"}]}], "]"}], ":=", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"t", "=", 
          RowBox[{"t$", "[", 
           RowBox[{"m", ",", "1"}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"aH", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"pf$apparentHorizon", "===", 
             RowBox[{"{", "}"}]}], ",", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", "r", "}"}], ",", "Indeterminate"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Quiet", "@", 
             RowBox[{"Interpolation", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"pf$apparentHorizon", ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "#1", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], "===", 
                  RowBox[{
                  "#2", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}]}], "&"}]}], "]"}], "]"}]}]}], 
           "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "}"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ListDensityPlot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Table", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"pf$rM", " ", 
                 RowBox[{"r$", "[", 
                  RowBox[{"m", ",", "n"}], "]"}], 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", "\[Pi]", " ", 
                   RowBox[{"i\[Theta]", "/", "36"}]}], "]"}]}], ",", 
                RowBox[{"pf$rM", " ", 
                 RowBox[{"r$", "[", 
                  RowBox[{"m", ",", "n"}], "]"}], 
                 RowBox[{"Sin", "[", 
                  RowBox[{"2", "\[Pi]", " ", 
                   RowBox[{"i\[Theta]", "/", "36"}]}], "]"}]}], ",", 
                RowBox[{"10", 
                 RowBox[{"pf\[Rho]B$", "[", 
                  RowBox[{"m", ",", "n"}], "]"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", 
                RowBox[{"1", "+", "ghostCells"}], ",", 
                RowBox[{"nSize", "-", "ghostCells"}], ",", 
                RowBox[{"Max", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"Round", "[", 
                   RowBox[{"nSize", "/", "nPts"}], "]"}]}], "]"}]}], "}"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"i\[Theta]", ",", "0", ",", "35"}], "}"}]}], "]"}], "//", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{"#", ",", "1"}], "]"}], "&"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Background", "\[Rule]", "Black"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "30"}], "}"}]}], "}"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"BoundaryStyle", "\[Rule]", "White"}], ",", 
           RowBox[{"ClippingStyle", "\[Rule]", "White"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "1"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", "z", "}"}], ",", 
              RowBox[{"RGBColor", "[", 
               RowBox[{
                RowBox[{"Min", "[", 
                 RowBox[{"z", ",", "1"}], "]"}], ",", 
                RowBox[{"Min", "[", 
                 RowBox[{"z", ",", "1"}], "]"}], ",", 
                RowBox[{"Min", "[", 
                 RowBox[{
                  RowBox[{"z", "-", "1"}], ",", "1"}], "]"}]}], "]"}]}], 
             "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"FrameStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Darker", "@", "Cyan"}], "]"}]}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"RGBColor", "[", 
             RowBox[{"0.05", ",", "0.05", ",", "0"}], "]"}], ",", 
            RowBox[{"Opacity", "[", "0.2", "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"With", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"mprof", "=", 
                 RowBox[{"DeleteDuplicates", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"pf$massProfile", "[", "m", "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"All", ",", 
                    RowBox[{"{", 
                    RowBox[{"3", ",", "1"}], "}"}]}], 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    "#1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "===", 
                    RowBox[{
                    "#2", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "&"}]}], "]"}]}], "}"}], ",",
                "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"mprof", "===", 
                  RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Circle", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"pf$rM", " ", "#"}]}], "]"}], "&"}], "/@", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Interpolation", "[", "mprof", "]"}], "/@", 
                    RowBox[{"Range", "[", 
                    RowBox[{"0.099", ",", "1", ",", "0.1"}], "]"}]}], ")"}]}],
                   "}"}]}], "\[IndentingNewLine]", "]"}]}], 
              "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"pf$apparentHorizon", "===", 
                 RowBox[{"{", "}"}]}], "\[Or]", 
                RowBox[{"t", "<", 
                 RowBox[{"pf$apparentHorizon", "\[LeftDoubleBracket]", 
                  RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}], ",", 
               RowBox[{"{", "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"Black", ",", 
                 RowBox[{"Opacity", "[", "0.8", "]"}], ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                   RowBox[{"pf$rM", " ", 
                    RowBox[{"Quiet", "@", 
                    RowBox[{"aH", "[", "t", "]"}]}]}]}], "]"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"Darker", "@", "Red"}], ",", 
                 RowBox[{"Opacity", "[", "1", "]"}], ",", 
                 RowBox[{"Circle", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                   RowBox[{"pf$rM", " ", 
                    RowBox[{"Quiet", "@", 
                    RowBox[{"aH", "[", "t", "]"}]}]}]}], "]"}]}], "}"}]}], 
              "]"}]}], ",", "\[IndentingNewLine]", "White", ",", 
            RowBox[{"Opacity", "[", "1", "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"Row", "@", 
                 RowBox[{"{", 
                  RowBox[{"\"\<t = \>\"", ",", 
                   RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"pf$rM", " ", "t"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"3", ",", "1"}], "}"}]}], "]"}], ",", 
                   "\"\< M\>\""}], "}"}]}], ",", "Bold", ",", "15"}], "]"}], 
              ",", 
              RowBox[{"Scaled", "@", 
               RowBox[{"{", 
                RowBox[{"0.15", ",", "0.9"}], "}"}]}]}], "]"}]}], 
           "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", 
        "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{"False", ",", 
      RowBox[{"Export", "[", 
       RowBox[{"\"\<dustCollapse.avi\>\"", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"shellVideoFrame", "[", 
           RowBox[{"m", ",", "40"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", "1", ",", "mSize", ",", "2"}], "}"}]}], "]"}], 
        ",", 
        RowBox[{"\"\<FrameRate\>\"", "\[Rule]", "10"}], ",", 
        RowBox[{"ImageResolution", "\[Rule]", "100"}]}], "]"}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"showOutHideCode", "[", 
     RowBox[{
      RowBox[{"Manipulate", "[", 
       RowBox[{
        RowBox[{"shellVideoFrame", "[", 
         RowBox[{"m", ",", "40"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"m", ",", "1", ",", "\"\<t\>\""}], "}"}], ",", "1", ",", 
          "mSize", ",", "1"}], "}"}], ",", 
        RowBox[{"AppearanceElements", "\[Rule]", "None"}]}], "]"}], ",", 
      "\"\<shellVideoFrame\>\""}], "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The component fields", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Block", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mFrom", "=", "from$m"}], ",", 
        RowBox[{"mPos", "=", "cur$m"}], ",", "\[IndentingNewLine]", 
        RowBox[{"nFrom", "=", "from$n"}], ",", 
        RowBox[{"nPos", "=", "cur$n"}], ",", "\[IndentingNewLine]", 
        "tableF"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"onXAxis", "===", "r"}], ",", 
         RowBox[{"tableF", "=", "tableR"}], ",", 
         RowBox[{"tableF", "=", "tableT"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"interpolate", "\[Equal]", 
          RowBox[{"-", "2"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"Grid", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "n", ",", 
                  RowBox[{"Sequence", "@@", 
                   RowBox[{"Join", "[", 
                    RowBox[{
                    RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"1", ";;", "2"}], ",", "2"}], 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"plotNr", "/.", "fieldNames"}]}], "]"}]}]}], 
                 "}"}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"Table", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Join", "[", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"cur$m", ",", "n"}], "}"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"cur$m", ",", "n"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"10", ",", "6"}], "}"}], ",", 
                    RowBox[{"NumberSigns", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"\"\<-\>\"", ",", "\"\< \>\""}], "}"}]}]}], "]"}],
                     "&"}], "/@", 
                    RowBox[{"Join", "[", 
                    RowBox[{
                    RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"1", ";;", "2"}], ",", "1"}], 
                    "\[RightDoubleBracket]"}], ",", "plotNr"}], "]"}]}]}], 
                  "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{"n", ",", 
                   RowBox[{"Min", "[", 
                    RowBox[{
                    RowBox[{"nSize", "-", "6"}], ",", "cur$n"}], "]"}], ",", 
                   RowBox[{"Min", "[", 
                    RowBox[{"nSize", ",", 
                    RowBox[{"cur$n", "+", "6"}]}], "]"}], ",", "1"}], "}"}]}],
                 "]"}]}], "\[IndentingNewLine]", "]"}], "/.", 
             RowBox[{"Indeterminate", "\[Rule]", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\< NaN\>\"", ",", 
                RowBox[{"GrayLevel", "[", "0.9", "]"}]}], "]"}]}]}], "//", 
            "Transpose"}], ",", 
           RowBox[{"ItemSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"3", ",", 
               RowBox[{"{", "9", "}"}]}], "}"}], "}"}]}], ",", 
           RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
           RowBox[{"Frame", "\[Rule]", "All"}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", 
            RowBox[{"GrayLevel", "[", "0.95", "]"}]}], ",", 
           RowBox[{"BaseStyle", "\[Rule]", 
            RowBox[{"Directive", "[", "10", "]"}]}], ",", 
           RowBox[{"Background", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Automatic", ",", 
              RowBox[{"{", 
               RowBox[{"Join", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{"LightGreen", ",", "4"}], "]"}], ",", 
                 RowBox[{"Table", "[", 
                  RowBox[{"White", ",", "4"}], "]"}]}], "]"}], "}"}]}], 
             "}"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"onXAxis", "===", "tr"}], "\[And]", 
              RowBox[{
               RowBox[{"Length", "@", "plotNr"}], "\[GreaterEqual]", "1"}]}], 
             ",", "\[IndentingNewLine]", 
             RowBox[{"tableTR", "[", 
              RowBox[{
               RowBox[{
               "plotNr", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", "skip", ",", "skip"}], "]"}], 
             ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"tableF", "[", 
                RowBox[{"#", ",", "skip"}], "]"}], "&"}], "/@", "plotNr"}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"(*", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"PlotLabel", "\[Rule]", 
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"Row", "@", 
                 RowBox[{"{", 
                  RowBox[{"id$title", ",", "\"\< (Method = \>\"", ",", 
                   RowBox[{"verboseIntMethod", "[", "iMethod", "]"}], ",", 
                   "\"\<)\>\""}], "}"}]}], ",", "Blue", ",", "14"}], "]"}]}], 
             ","}], "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"Placed", "[", 
             RowBox[{
              RowBox[{"LineLegend", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"plotNr", "/.", "fieldNames"}], ",", 
                RowBox[{"(*", " ", 
                 RowBox[{"Exclude", " ", "t$", " ", "and", " ", "r$"}], " ", 
                 "*)"}], "\[IndentingNewLine]", 
                RowBox[{"LegendLayout", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Column\>\"", ",", "6"}], "}"}]}], ",", 
                RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
                   "14"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"0.63", ",", "0.78"}], "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Sequence", "@@", 
               RowBox[{
                RowBox[{"ColorData", "[", 
                 RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"1", ";;", "8"}], "\[RightDoubleBracket]"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{
                RowBox[{"ColorData", "[", 
                 RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"9", ";;", "12"}], "\[RightDoubleBracket]"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"Thread", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"ColorData", "[", 
                    RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                   "\[LeftDoubleBracket]", 
                   RowBox[{"1", ";;", "8"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"Table", "[", 
                   RowBox[{"Dotted", ",", "8"}], "]"}]}], "}"}], "]"}]}], ",",
               "\[IndentingNewLine]", "Automatic", ",", "Automatic", ",", 
              "Automatic", ",", "Automatic"}], "\[IndentingNewLine]", "}"}]}],
            ",", "\[IndentingNewLine]", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"If", "[", 
             RowBox[{"yAuto", ",", 
              RowBox[{"If", "[", 
               RowBox[{"yFull", ",", "Full", ",", "Automatic"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"yMin", ",", "yMax"}], "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Joined", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{"interpolate", "\[GreaterEqual]", "0"}], ")"}]}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "interpolate"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Text", "[", 
               RowBox[{
                RowBox[{"Row", "@", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "\"\< = \>\"", ",", 
                   RowBox[{"t$", "[", 
                    RowBox[{"mPos", ",", "nPos"}], "]"}], ",", "\"\<, \>\"", 
                   ",", " ", "r", ",", "\"\< = \>\"", ",", 
                   RowBox[{"r$", "[", 
                    RowBox[{"mPos", ",", "nPos"}], "]"}]}], "}"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Scaled", "@", 
                 RowBox[{"{", 
                  RowBox[{"0.5", ",", "0.95"}], "}"}]}], ",", 
                RowBox[{"BaseStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
                   " ", "14"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{"Text", "[", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{"Row", "@", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"onXAxis", "===", "tr"}], ",", "r", ",", 
                    "onXAxis"}], "]"}], ",", "\"\<   \[LongRightArrow]\>\""}],
                     "}"}]}], ",", "Blue", ",", "14"}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Scaled", "@", 
                 RowBox[{"{", 
                  RowBox[{"0.9", ",", "0.05"}], "}"}]}], ",", 
                RowBox[{"BaseStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
                   " ", "14"}], "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
             "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Row", "@", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Column", "@", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Row", "@", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{"\"\<X-axis\>\"", ",", 
             RowBox[{"Control", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"onXAxis", ",", "r", ",", "\"\<\>\""}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"r", ",", "t", ",", "tr"}], "}"}], ",", 
                RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], 
              "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Spacer", "[", "15", "]"}], ",", "\[IndentingNewLine]", 
             "\"\<Show\>\"", ",", 
             RowBox[{"Control", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"interpolate", ",", "1", ",", "\"\<\>\""}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], "\[Rule]", "\"\<Tab\>\""}], ",", 
                  RowBox[{
                   RowBox[{"-", "1"}], "\[Rule]", "\"\<Pts\>\""}], ",", "0", 
                  ",", "1"}], "}"}], ",", 
                RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], 
              "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Control", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"skip", ",", "1", ",", "\"\<\>\""}], "}"}], ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", "10"}], "]"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"40", ",", "22"}], "}"}]}]}], "}"}], "]"}]}], 
            "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Grid", "@", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["m", "L"], ",", 
               RowBox[{"Control", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"from$m", ",", "1", ",", "\"\<\>\""}], "}"}], ",", 
                  "1", ",", "mSize", ",", "1"}], "}"}], "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"m", ",", 
               RowBox[{"Control", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"cur$m", ",", 
                    RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"mSize", "/", "2"}], "+", "0.5"}], "]"}], ",", 
                    "\"\<\>\""}], "}"}], ",", "1", ",", "mSize", ",", "1"}], 
                 "}"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["n", "L"], ",", 
               RowBox[{"Control", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"from$n", ",", 
                    RowBox[{"1", "+", "ghostCells"}], ",", "\"\<\>\""}], 
                   "}"}], ",", "1", ",", "nSize", ",", "1"}], "}"}], "]"}]}], 
              "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"n", ",", 
               RowBox[{"Control", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"cur$n", ",", 
                    RowBox[{"nSize", "-", "ghostCells"}], ",", "\"\<\>\""}], 
                   "}"}], ",", "1", ",", "nSize", ",", "1"}], "}"}], "]"}]}], 
              "}"}]}], "\[IndentingNewLine]", "}"}]}]}], 
         "\[IndentingNewLine]", "}"}]}], ",", 
       RowBox[{"Spacer", "[", "20", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Column", "@", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Row", "@", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Spacer", "[", "8", "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Button", "[", 
              RowBox[{"\"\< \!\(\*
StyleBox[\"\[TabKey]\",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"\[ThinSpace]\",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"g\",
FontColor->RGBColor[0, 0, 1]]\) \>\"", ",", 
               RowBox[{
                RowBox[{"interpolate", "=", 
                 RowBox[{"-", "2"}]}], ";", 
                RowBox[{"plotNr", "=", 
                 RowBox[{"{", 
                  RowBox[{
                  "gA$t", ",", "gB$t", ",", "gK1$t", ",", "gK2$t", ",", 
                   "gDA$t", ",", "gDB$t", ",", "g\[Sigma]$t", ",", "p$t", ",",
                    "p$"}], "}"}]}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Appearance", "->", "\"\<FramedPalette\>\""}]}], "]"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"Button", "[", 
              RowBox[{"\"\< \!\(\*
StyleBox[\"\[TabKey]\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"\[ThinSpace]\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"f\",
FontColor->RGBColor[1, 0, 0]]\) \>\"", ",", 
               RowBox[{
                RowBox[{"interpolate", "=", 
                 RowBox[{"-", "2"}]}], ";", 
                RowBox[{"plotNr", "=", 
                 RowBox[{"{", 
                  RowBox[{
                  "fA$t", ",", "fB$t", ",", "fK1$t", ",", "fK2$t", ",", 
                   "fDA$t", ",", "fDB$t", ",", "f\[Sigma]$t", ",", "p$t", ",",
                    "p$"}], "}"}]}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Appearance", "->", "\"\<FramedPalette\>\""}]}], "]"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"Button", "[", 
              RowBox[{"\"\< r-plot \>\"", ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"onXAxis", "=", "r"}], ";", 
                RowBox[{"from$m", "=", "1"}], ";", 
                RowBox[{"cur$m", "=", 
                 RowBox[{"Round", "[", 
                  RowBox[{
                   RowBox[{"mSize", "/", "2"}], "+", "0.5"}], "]"}]}], ";", 
                RowBox[{"from$n", "=", "1"}], ";", 
                RowBox[{"cur$n", "=", "nSize"}], ";", "\[IndentingNewLine]", 
                RowBox[{"interpolate", "=", "1"}], ";", 
                RowBox[{"plotNr", "=", 
                 RowBox[{"{", 
                  RowBox[{"gDA$t", ",", "p$"}], "}"}]}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Appearance", "->", "\"\<FramedPalette\>\""}]}], "]"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"Button", "[", 
              RowBox[{"\"\< t-plot \>\"", ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"onXAxis", "=", "t"}], ";", 
                RowBox[{"from$m", "=", "1"}], ";", 
                RowBox[{"cur$m", "=", "mSize"}], ";", "\[IndentingNewLine]", 
                RowBox[{"from$n", "=", 
                 RowBox[{"1", "+", "ghostCells"}]}], ";", 
                RowBox[{"cur$n", "=", 
                 RowBox[{"nSize", "-", "ghostCells"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"interpolate", "=", "1"}], ";", 
                RowBox[{"plotNr", "=", 
                 RowBox[{"{", 
                  RowBox[{"gDA$t", ",", "p$"}], "}"}]}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Appearance", "->", "\"\<FramedPalette\>\""}]}], "]"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"Spacer", "[", "30", "]"}], ",", "\[IndentingNewLine]", 
             "\"\<Y-axis\>\"", ",", 
             RowBox[{"Control", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"yAuto", ",", "True", ",", "\"\<\>\""}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"True", ",", "False"}], "}"}]}], "}"}], "]"}], ",", 
             RowBox[{"Control", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"yFull", ",", "False", ",", "\"\<\>\""}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"True", ",", "False"}], "}"}]}], "}"}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Control", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"yMin", ",", 
                  RowBox[{"-", "0.01"}], ",", "\"\<\>\""}], "}"}], ",", 
                RowBox[{"ControlType", "\[Rule]", "InputField"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "50"}]}], "}"}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Control", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"yMax", ",", "0.01", ",", "\"\<  \[Ellipsis]\>\""}], 
                 "}"}], ",", 
                RowBox[{"ControlType", "\[Rule]", "InputField"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "50"}]}], "}"}], "]"}]}], 
            "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Control", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"plotNr", ",", 
               RowBox[{"{", 
                RowBox[{"gDA$t$", ",", "p$"}], "}"}], ",", "\"\<\>\""}], 
              "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "\[Rule]", 
                RowBox[{"\"\< \>\"", "<>", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                 "<>", "\"\< \>\""}]}], "&"}], "/@", 
              RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
               RowBox[{"3", ";;"}], "\[RightDoubleBracket]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"ControlType", "\[Rule]", "TogglerBar"}], ",", 
             RowBox[{"Appearance", "\[Rule]", 
              RowBox[{"\"\<Vertical\>\"", "\[Rule]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Length", "@", "fieldNames"}], ">", "70"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"8", ",", "16"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"4", ",", "30"}], "}"}]}], "]"}]}]}]}], "}"}], 
           "]"}]}], "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Paneled", "\[Rule]", "False"}], ",", 
    RowBox[{"AppearanceElements", "\[Rule]", "None"}], ",", 
    RowBox[{"ControlPlacement", "\[Rule]", "Top"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Initialization", "\[RuleDelayed]", 
     RowBox[{"(", 
      RowBox[{"skip", "=", 
       RowBox[{"Min", "[", 
        RowBox[{"10", ",", 
         RowBox[{"Max", "[", 
          RowBox[{"1", ",", 
           RowBox[{"Round", "[", 
            RowBox[{"nSize", "/", "400"}], "]"}]}], "]"}]}], "]"}]}], 
      ")"}]}]}], "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutHideCode", "[", 
  RowBox[{"%", ",", "\"\<fieldsPlot\>\""}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The domain of dependence", "Subsubsection"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"True", ",", 
   RowBox[{"showOutHideCode", "[", 
    RowBox[{"\"\<(DoD disabled)\>\"", ",", "\"\<domOfDependence\>\""}], "]"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"plotSol3D", "[", 
      RowBox[{
      "f$_", ",", "mSize_", ",", "nSize_", ",", "cutPlane_", ",", 
       "cutPlaneHight_", ",", "plotOptions___"}], "]"}], ":=", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"mFrom", "=", "1"}], ",", 
         RowBox[{"mPos", "=", "mSize"}], ",", 
         RowBox[{"nFrom", "=", "1"}], ",", 
         RowBox[{"nPos", "=", "nSize"}], ",", 
         RowBox[{"delta$r", "=", "\[CapitalDelta]r"}], ",", 
         RowBox[{"delta$t", "=", "\[CapitalDelta]t"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPointPlot3D", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"tableTR3D", "[", 
            RowBox[{"f$", ",", 
             RowBox[{"Max", "[", 
              RowBox[{"1", ",", 
               RowBox[{"Floor", "[", 
                RowBox[{"mSize", "/", "60"}], "]"}]}], "]"}], ",", 
             RowBox[{"Max", "[", 
              RowBox[{"1", ",", 
               RowBox[{"Floor", "[", 
                RowBox[{"nSize", "/", "60"}], "]"}]}], "]"}]}], "]"}], ",", 
           "\[IndentingNewLine]", "plotOptions", ",", "\[IndentingNewLine]", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"r", ",", "t", ",", "f"}], "}"}], ",", 
              RowBox[{"Hue", "[", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["10", "4"], "f"}], ",", "1", ",", "0.8"}], 
               "]"}]}], "]"}]}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"AxesEdge", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"BoxRatios", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", ",", "1", ",", "0.5"}], "}"}]}], ",", 
           RowBox[{"ViewPoint", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], ",", 
           RowBox[{"ViewAngle", "\[Rule]", 
            RowBox[{"35", "\[Degree]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"550", ",", "450"}], "}"}]}], ",", 
           RowBox[{"ImagePadding", "\[Rule]", "None"}], ",", " ", 
           RowBox[{"PlotTheme", "\[Rule]", "\"\<Classic\>\""}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"BaseStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], "}"}]}]}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{",", 
            RowBox[{"ViewPoint", "\[Rule]", 
             RowBox[{"Evaluate", "@", 
              RowBox[{"Dynamic", "[", 
               RowBox[{
                RowBox[{"RotationMatrix", "[", 
                 RowBox[{
                  RowBox[{"Clock", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}], ",", "5"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], ".", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "]"}]}]}]}], 
           "*)"}], "\[IndentingNewLine]", "]"}], ",", 
         RowBox[{"Graphics3D", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{"cutPlane", 
              RowBox[{"(*", 
               RowBox[{
                RowBox[{"plotNr", "===", "gHZ$"}], "\[Or]", 
                RowBox[{"plotNr", "===", "fHZ$"}]}], "*)"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Black", ",", 
                RowBox[{"InfinitePlane", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0", ",", 
                    RowBox[{"Log10\[Epsilon]", "@", "cutPlaneHight"}]}], 
                   "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}]}], 
                 "]"}]}], "}"}], ",", 
              RowBox[{"{", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"t", ",", "20", ",", "Blue", ",", "Bold"}], "]"}], ",", 
              RowBox[{"Scaled", "[", 
               RowBox[{"{", 
                RowBox[{"0.03", ",", "0.63", ",", 
                 RowBox[{"1", "-", "0.05"}]}], "}"}], "]"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"r", ",", "20", ",", "Blue", ",", "Bold"}], "]"}], ",", 
              RowBox[{"Scaled", "[", 
               RowBox[{"{", 
                RowBox[{"0.63", ",", "0.03", ",", 
                 RowBox[{"1", "-", "0.05"}]}], "}"}], "]"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"Row", "@", 
                 RowBox[{"{", 
                  RowBox[{
                  "\"\<\!\(\*SubscriptBox[\(log\[Epsilon]\), \(10\)]\)\
\[ThinSpace]\>\"", ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"f$", "/.", "fieldNames"}], ",", "Bold"}], "]"}], 
                   ",", "\[IndentingNewLine]", "\"\< (\>\"", ",", 
                   RowBox[{"verboseIntMethod", "[", "iMethod", "]"}], ",", 
                   "\"\<)\>\""}], "}"}]}], ",", "18", ",", "Black"}], "]"}], 
              ",", 
              RowBox[{"Scaled", "[", 
               RowBox[{"{", 
                RowBox[{"0.5", ",", "0.98", ",", "0.95"}], "}"}], "]"}]}], 
             "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Thickness", "[", "Large", "]"}], ",", "Blue", ",", 
            RowBox[{"EdgeForm", "@", 
             RowBox[{"{", 
              RowBox[{"Blue", ",", 
               RowBox[{"Thickness", "[", "Medium", "]"}]}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.02", ",", "0.4", ",", 
                  RowBox[{"1", "-", "0.05"}]}], "}"}]}], ",", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.02", ",", "0.56", ",", 
                  RowBox[{"1", "-", "0.05"}]}], "}"}]}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Pyramid", "[", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.01", ",", "0.55", ",", 
                  RowBox[{"1", "-", "0.03"}]}], "}"}]}], ",", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.03", ",", "0.55", ",", 
                  RowBox[{"1", "-", "0.03"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.03", ",", "0.55", ",", 
                  RowBox[{"1", "-", "0.07"}]}], "}"}]}], ",", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.01", ",", "0.55", ",", 
                  RowBox[{"1", "-", "0.07"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.02", ",", "0.6", ",", 
                  RowBox[{"1", "-", "0.05"}]}], "}"}]}]}], 
              "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.4", ",", "0.02", ",", 
                  RowBox[{"1", "-", "0.05"}]}], "}"}]}], ",", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.56", ",", "0.02", ",", 
                  RowBox[{"1", "-", "0.05"}]}], "}"}]}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Pyramid", "[", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.55", ",", "0.01", ",", 
                  RowBox[{"1", "-", "0.03"}]}], "}"}]}], ",", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.55", ",", "0.01", ",", 
                  RowBox[{"1", "-", "0.07"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.55", ",", "0.03", ",", 
                  RowBox[{"1", "-", "0.07"}]}], "}"}]}], ",", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.55", ",", "0.03", ",", 
                  RowBox[{"1", "-", "0.03"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Scaled", "@", 
                RowBox[{"{", 
                 RowBox[{"0.6", ",", "0.02", ",", 
                  RowBox[{"1", "-", "0.05"}]}], "}"}]}]}], "}"}], "]"}]}], 
           "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"figDoD", "=", 
     RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Quiet", "@", 
        RowBox[{"Framed", "[", 
         RowBox[{
          RowBox[{"plotSol3D", "[", 
           RowBox[{
           "plotNr", ",", "mSize", ",", "nSize", ",", "cutPlane", ",", 
            "cutPlaneHight", ",", 
            RowBox[{"Background", "\[Rule]", 
             RowBox[{"If", "[", 
              RowBox[{"cutPlane", ",", "Gray", ",", "Automatic"}], "]"}]}]}], 
           "]"}], ",", 
          RowBox[{"FrameStyle", "\[Rule]", "LightGray"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Column", "@", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\""}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"plotNr", ",", "p$", ",", "\"\<\>\""}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             "\[Rule]", 
             RowBox[{"\"\< \>\"", "<>", 
              RowBox[{
              "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "<>", "\"\< \>\""}]}], "&"}], "/@", 
           RowBox[{"fieldNames", "\[LeftDoubleBracket]", 
            RowBox[{"3", ";;"}], "\[RightDoubleBracket]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"ControlType", "\[Rule]", "SetterBar"}], ",", 
          RowBox[{"Appearance", "\[Rule]", 
           RowBox[{"\"\<Vertical\>\"", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"8", ",", "11"}], "}"}]}]}]}], "}"}], "]"}], ",", 
       "\[IndentingNewLine]", "\"\<\>\"", ",", "\[IndentingNewLine]", 
       RowBox[{"Row", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Spacer", "[", "10", "]"}], ",", 
          "\"\<Horizontal cut at 0: \>\"", ",", 
          RowBox[{"Control", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"cutPlane", ",", "False", ",", "\"\<\>\""}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"True", ",", "False"}], "}"}]}], "}"}], "]"}]}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Row", "@", 
        RowBox[{"{", 
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"cutPlaneHight", ",", "0", ",", "\"\<\>\""}], "}"}], ",", 
            RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "}"}], "]"}], "}"}]}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"Paneled", "\[Rule]", "False"}], ",", 
       RowBox[{"AppearanceElements", "\[Rule]", "None"}], ",", 
       RowBox[{"ControlPlacement", "\[Rule]", "Right"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"showOutHideCode", "[", 
     RowBox[{"figDoD", ",", "\"\<domOfDependence\>\""}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kretschmann scalars", "Subsubsection"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"True", ",", 
   RowBox[{"showOutHideCode", "[", 
    RowBox[{
    "\"\<(Kretschman plot disabled)\>\"", ",", "\"\<kretschmannPlot\>\""}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"figKr", "=", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"mFrom", "=", "1"}], ",", 
         RowBox[{"mPos", "=", 
          RowBox[{"mSize", "-", "5", " ", "+", 
           RowBox[{"0", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"mSize", "/", "2"}], "+", "0.5"}], "]"}], "+", "10"}],
              ")"}]}]}]}], ",", 
         RowBox[{"nFrom", "=", "1"}], ",", 
         RowBox[{"nPos", "=", "500"}], ",", 
         RowBox[{"delta$r", "=", "\[CapitalDelta]r"}], ",", 
         RowBox[{"delta$t", "=", "\[CapitalDelta]t"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Quiet", "@", 
        RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"r$", "[", 
                 RowBox[{"mPos", ",", "n"}], "]"}], ",", 
                RowBox[{"Log10\[Epsilon]", "@", 
                 RowBox[{"gKretschmann", "[", 
                  RowBox[{"mPos", ",", "n"}], "]"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "nPos"}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"r$", "[", 
                 RowBox[{"mPos", ",", "n"}], "]"}], ",", 
                RowBox[{"Log10\[Epsilon]", "@", 
                 RowBox[{"fKretschmann", "[", 
                  RowBox[{"mPos", ",", "n"}], "]"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "nPos"}], "}"}]}], "]"}]}], 
           "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"id$setup", "\[Equal]", "2"}], ",", "Automatic", ",", 
             "Full"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"InterpolationOrder", "\[Rule]", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Style", "[", 
             RowBox[{"r", ",", "16", ",", "Blue"}], "]"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Darker", "@", "Blue"}], ",", 
               RowBox[{"Opacity", "[", "0.7", "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Darker", "@", "Red"}], ",", 
               RowBox[{"Opacity", "[", "0.7", "]"}], ",", "Dashed"}], "}"}]}],
             "}"}]}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"Row", "@", 
              RowBox[{"{", 
               RowBox[{
               "\"\<\!\(\*SubscriptBox[\(log\[Epsilon]\), \(10\)]\) of \
Kretschmann at \!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\) = \>\"", ",", 
                RowBox[{"t$", "[", 
                 RowBox[{"mPos", ",", "nPos"}], "]"}]}], "}"}]}], ",", "14", 
             ",", "Blue"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"Placed", "[", 
            RowBox[{
             RowBox[{"LineLegend", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["K", "g"], ",", 
                 SubscriptBox["K", "f"]}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"LabelStyle", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
                  "14"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"0.63", ",", "0.78"}], "}"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"If", "[", 
            RowBox[{"$exportPDFs", ",", 
             RowBox[{"Scaled", "[", "0.8", "]"}], ",", "600"}], "]"}]}]}], 
         "\[IndentingNewLine]", "]"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{"$exportPDFs", ",", 
      RowBox[{"Export", "[", 
       RowBox[{
        RowBox[{"\"\<figures/fig-\>\"", "<>", 
         RowBox[{"ToString", "@", "id$setup"}], "<>", "\"\<-gKtsch.pdf\>\""}],
         ",", "figKr"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"showOutHideCode", "[", 
     RowBox[{"figKr", ",", "\"\<kretschmannPlot\>\""}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1294, 1102},
WindowMargins->{{81, Automatic}, {Automatic, 0}},
WindowStatusArea->Automatic,
DockedCells->None,
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "initialization"->{
  Cell[1367, 52, 65, 1, 53, "Subsection",
   CellTags->"initialization"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"initialization", 139392, 3755}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 199, 6, 93, "Text"],
Cell[760, 28, 28, 0, 38, "Text"],
Cell[791, 30, 60, 0, 38, "Text"],
Cell[854, 32, 210, 4, 38, "Text"],
Cell[1067, 38, 189, 6, 39, "Text"],
Cell[1259, 46, 83, 2, 36, "Input"],
Cell[CellGroupData[{
Cell[1367, 52, 65, 1, 53, "Subsection",
 CellTags->"initialization"],
Cell[1435, 55, 746, 21, 106, "Input"],
Cell[2184, 78, 342, 8, 83, "Input"],
Cell[CellGroupData[{
Cell[2551, 90, 72, 0, 42, "Subsubsection"],
Cell[2626, 92, 8551, 189, 966, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[11214, 286, 115, 3, 33, "Subsubsection"],
Cell[11332, 291, 880, 21, 161, "Input"],
Cell[12215, 314, 547, 14, 75, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12799, 333, 384, 16, 34, "Subsubsection"],
Cell[13186, 351, 452, 15, 45, "Input"],
Cell[13641, 368, 868, 29, 75, "Input"],
Cell[14512, 399, 625, 19, 45, "Input"],
Cell[15140, 420, 698, 21, 75, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[15875, 446, 56, 0, 33, "Subsubsection"],
Cell[15934, 448, 161, 5, 47, "Text"],
Cell[16098, 455, 1155, 38, 128, "Input"],
Cell[17256, 495, 1328, 43, 128, "Input"],
Cell[18587, 540, 1048, 34, 128, "Input"],
Cell[19638, 576, 41, 0, 47, "Text"],
Cell[19682, 578, 684, 24, 75, "Input"],
Cell[20369, 604, 684, 24, 75, "Input"],
Cell[21056, 630, 688, 21, 132, "Input"],
Cell[21747, 653, 35, 0, 47, "Text"],
Cell[21785, 655, 848, 31, 68, "Text"],
Cell[22636, 688, 324, 9, 47, "Text"],
Cell[22963, 699, 1080, 42, 68, "Text"],
Cell[24046, 743, 441, 15, 102, "Input"],
Cell[24490, 760, 920, 30, 83, "Input"],
Cell[25413, 792, 367, 13, 47, "Text"],
Cell[25783, 807, 1760, 60, 91, "Text"],
Cell[27546, 869, 799, 26, 96, "Input"],
Cell[28348, 897, 1367, 49, 52, "Text"],
Cell[29718, 948, 1181, 42, 52, "Text"],
Cell[30902, 992, 418, 14, 75, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[31357, 1011, 219, 8, 37, "Subsubsection"],
Cell[31579, 1021, 595, 20, 75, "Input"],
Cell[32177, 1043, 1043, 35, 103, "Input"],
Cell[33223, 1080, 4244, 131, 458, "Input"],
Cell[37470, 1213, 784, 26, 126, "Input"],
Cell[38257, 1241, 2135, 69, 142, "Input"],
Cell[40395, 1312, 1267, 40, 132, "Input"],
Cell[41665, 1354, 1335, 46, 147, "Input"],
Cell[43003, 1402, 439, 15, 45, "Input"],
Cell[43445, 1419, 240, 8, 45, "Input"],
Cell[43688, 1429, 291, 10, 51, "Input"],
Cell[43982, 1441, 774, 26, 75, "Input"],
Cell[44759, 1469, 1173, 32, 195, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[45981, 1507, 38, 0, 42, "Subsection"],
Cell[46022, 1509, 113, 3, 38, "Text"],
Cell[46138, 1514, 58, 1, 36, "Input"],
Cell[46199, 1517, 958, 26, 106, "Input"],
Cell[47160, 1545, 437, 15, 64, "Text"],
Cell[47600, 1562, 9454, 218, 888, "Input"],
Cell[57057, 1782, 237, 8, 63, "Text"],
Cell[57297, 1792, 1083, 25, 129, "Input"],
Cell[CellGroupData[{
Cell[58405, 1821, 42, 0, 42, "Subsubsection"],
Cell[58450, 1823, 2006, 45, 180, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60505, 1874, 44, 0, 53, "Subsection"],
Cell[CellGroupData[{
Cell[60574, 1878, 31, 0, 42, "Subsubsection"],
Cell[60608, 1880, 2812, 70, 175, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63457, 1955, 50, 0, 42, "Subsubsection"],
Cell[63510, 1957, 9004, 228, 717, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72551, 2190, 60, 0, 42, "Subsubsection"],
Cell[72614, 2192, 10241, 252, 1104, "Input"],
Cell[82858, 2446, 10505, 247, 842, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93400, 2698, 45, 0, 42, "Subsubsection"],
Cell[93448, 2700, 23002, 509, 2222, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116487, 3214, 49, 0, 42, "Subsubsection"],
Cell[116539, 3216, 13857, 323, 1128, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130433, 3544, 44, 0, 42, "Subsubsection"],
Cell[130480, 3546, 5324, 128, 520, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
