(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    197931,       5090]
NotebookOptionsPosition[    178698,       4635]
NotebookOutlinePosition[    190698,       4894]
CellTagsIndexPosition[    190533,       4887]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Bimetric equations in standard 3+1 form \nreduced to spherical symmetry ",
 StyleBox["(C++ solver)",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 FontSize->24,
 FontWeight->"Bold"],

Cell["Mikica Kocic", "Text"],

Cell["Created 2018-02-08, Last modified 2018-08-25 (v0.26)", "Text"],

Cell[TextData[StyleBox["Requirements",
 FontWeight->"Bold"]], "Text"],

Cell[TextData[{
 "The evaluation of this notebook needs a C++ compiler (such as gcc). On \
Windows, one can use ",
 ButtonBox["mingw-w64",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://sourceforge.net/projects/mingw-w64/"], None},
  ButtonNote->"https://sourceforge.net/projects/mingw-w64/"],
 ".\nWhen installing mingw, select ",
 StyleBox["x86_64",
  FontWeight->"Bold"],
 " architecture. Also, do not forget to configure ",
 Cell[BoxData["$mingwPath"]],
 " below."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Changelog",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[TextData[{
 "2018-02-08  The verification of 3+1 in spherical symmetry for the geometric \
mean paper\n2018-04-23  Numerical solving for the initial data where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["K", "1"], "=", "0"}], ",", 
    RowBox[{
     SubscriptBox["K", "2"], "=", "0"}], ",", 
    RowBox[{"B", "=", "r"}], ",", 
    RowBox[{
     OverscriptBox["B", "~"], "=", "r"}]}], TraditionalForm]]],
 ".\n2018-04-26  Numerical solving for Minkowski and the Schwarzschild in the \
Panlev\[EAcute]-Gullstrand coordinates.\n2018-04-29  Instability when \
\[OpenCurlyQuote]eq$p\[CloseCurlyQuote] is not exactly zero. Removed \
\[OpenCurlyQuote]",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 "\[CloseCurlyQuote] and recollected EoM grouped by \[OpenCurlyQuote]",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 "\[CloseCurlyQuote] and \[OpenCurlyQuote]",
 Cell[BoxData[
  FormBox["\[Lambda]", TraditionalForm]]],
 "\[CloseCurlyQuote].\n2018-05-01  Added ICN. Added a possibility to do the \
first integration step in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".\n2018-05-03  Increased the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 "-grid spacing \[CapitalDelta]r, which resulted in better numerical \
stability.\n2018-05-04  Apparent horizon finder (using the equation for a \
marginal outer trapped 2-surface in SS).\n2018-05-04  Evaluation of the \
Kretschmann scalar.\n2018-05-05  Implemented the reversed-time integration. \
Concatenation of the results for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "<", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "\[GreaterEqual]", "0"}], TraditionalForm]]],
 ".\n2018-05-06  Restructured the ICN method.\n2018-05-08  The initial data \
with flat ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " is coupled with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "PF"], TraditionalForm]]],
 ".\n2018-05-09  The initial data at the moment of time symmetry in ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " with an ODE for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "PF"], TraditionalForm]]],
 ".\n2018-05-14  Implemented the lapse factors ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "g"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "f"], TraditionalForm]]],
 " (such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]", "\[VeryThinSpace]", 
      SubscriptBox["W", "g"]}], "+", "\[VeryThinSpace]", 
     RowBox[{
      OverscriptBox["\[Alpha]", "~"], 
      SubscriptBox["W", "f"]}]}], "=", "0"}], TraditionalForm]]],
 ").\n2018-05-19  Fixed the toolbar and automatized export to PDFs.\n\
2018-06-25  Regularized version (introduced variables ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", 
    RowBox[{"A", ",", "B", ",", "\[Alpha]"}]], TraditionalForm]]],
 ") and the left BC.\n2018-07-14  The initial data with flat ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ", and the Gaussian ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "PF"], TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ". Conserved EoM for PF.\n2018-07-25  The GR initial data with he Gaussian ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "PF"], TraditionalForm]]],
 ".\n2018-07-27  The right BC (4th order accuracy extrapolation using 4th \
order Taylor).\n2018-08-02  The maximal slicing (two-point BVP solver for ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]]],
 ").\n2018-08-10  The cubic spline interpolation (used for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "\[Alpha]"], TraditionalForm]]],
 ").\n2018-08-18  Converted the evolution equations into the split operator \
form."
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["TODO",
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],

Cell[TextData[{
 "- Check the signs in C3. Also check ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "r"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["j", "~"], "r"], TraditionalForm]]],
 ".\n- Benchmarks: i3, i5, i7, xenon, some HPC, OpenMP/MPI\n- Test 128-bit \
float arithmetic\n- Upwind fd for the advection terms with p and q\n- Gamma \
driver, shift minimal distortion\n- Arithmetical roundoff errors (error \
propagation + inspection of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " generated expressions)"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
 StyleBox["Usage",
  FontWeight->"Bold"],
 ":\n\t(1) select  ",
 Cell[BoxData[
  ButtonBox["\<\" Init \"\>",
   Appearance->"FramedPalette",
   ButtonFunction:>Null,
   Evaluator->Automatic,
   Method->"Preemptive"]]],
 ",\n\t(2) select a case, then  ",
 Cell[BoxData[
  ButtonBox["\<\" Solve Constraints \"\>",
   Appearance->"FramedPalette",
   ButtonFunction:>Null,
   Evaluator->Automatic,
   Method->"Preemptive"]]],
 "   (this will create a run-vault for the simulation)\n\t(3) optionally \
select  ",
 Cell[BoxData[
  ButtonBox["\<\" Params \"\>",
   Appearance->"FramedPalette",
   ButtonFunction:>Null,
   Evaluator->Automatic,
   Method->"Preemptive"]]],
 ",  then  ",
 Cell[BoxData[
  ButtonBox["\<\" Evolve \"\>",
   Appearance->"FramedPalette",
   ButtonFunction:>Null,
   Evaluator->Automatic,
   Method->"Preemptive"]]],
 "."
}], "Text"],

Cell["\<\
Then repeat the steps. Step (1) is needed only once (but can be repeated).\
\>", "Text"],

Cell["\<\
To customize a path to the compiler and similar, see \
\[OpenCurlyDoubleQuote]Configuration\[CloseCurlyDoubleQuote] section.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Overview of used variables", "Subsection"],

Cell[TextData[{
 "Note: The state variables are uninstantiated by default (for example, the \
unassigned ",
 Cell[BoxData["p"]],
 " gets its value from the equation ",
 Cell[BoxData["eq$p"]],
 ")."
}], "Text"],

Cell["Bimetric model (parameters):", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData["k$g"]],
 ",\n\t",
 Cell[BoxData["k$f"]],
 ",\n\t",
 Cell[BoxData[
  RowBox[{"\[Beta]", "[", "n", "]"}]]],
 ".\t\t// aliases:  ",
 Cell[BoxData["b$0"]],
 ",  ",
 Cell[BoxData["b$1"]],
 ",  ...,  ",
 Cell[BoxData["b$4"]]
}], "Text"],

Cell["Primary dynamical variables:", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  StyleBox["gA",
   FontWeight->"Bold",
   FontColor->RGBColor[0, 0, 1]]]],
 ",\t\t\t",
 Cell[BoxData[
  StyleBox["fA",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 0]]]],
 ",\n\t",
 Cell[BoxData[
  StyleBox["gB",
   FontWeight->"Bold",
   FontColor->RGBColor[0, 0, 1]]]],
 ",\t\t\t",
 Cell[BoxData[
  StyleBox["fB",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 0]]]],
 ",\n\t",
 Cell[BoxData[
  StyleBox["gK1",
   FontWeight->"Bold",
   FontColor->RGBColor[0, 0, 1]]]],
 ",\t\t\t",
 Cell[BoxData[
  StyleBox["fK1",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 0]]]],
 ",\n\t",
 Cell[BoxData[
  StyleBox["gK2",
   FontWeight->"Bold",
   FontColor->RGBColor[0, 0, 1]]]],
 ",\t\t\t",
 Cell[BoxData[
  StyleBox["fK2",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 0]]]],
 ","
}], "Text"],

Cell["Primary kinematical variables:", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  StyleBox["q",
   FontWeight->"Bold",
   FontColor->RGBColor[0., 0.5019607843137255, 0.]]]],
 ",\n\t",
 Cell[BoxData[
  StyleBox["gAlp",
   FontWeight->"Bold",
   FontColor->RGBColor[0., 0.5019607843137255, 0.]]]],
 ",\n\t",
 Cell[BoxData[
  RowBox[{"fAlp", ":=", "eq$fAlp"}]]],
 ","
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{"eq$fAlp", ":=", 
   RowBox[{
    RowBox[{"-", "gW"}], " ", 
    RowBox[{"gAlp", "/", "fW"}]}]}]]],
 ",\n\t",
 Cell[BoxData[
  RowBox[{"gW", ":=", "eq$gW"}]]],
 ",\n\t",
 Cell[BoxData[
  RowBox[{"fW", ":=", "eq$fW"}]]],
 "."
}], "Text"],

Cell["Auxiliary variables:", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{"p", ":=", "eq$p"}]]],
 ","
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{"eq$p", "\[Equal]", 
   RowBox[{
    RowBox[{"-", "gC$j"}], "/", 
    RowBox[{"(", "...", ")"}]}]}]]],
 "."
}], "Text"],

Cell["Intermediate variables: ", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{"Lt", ":=", "eq$Lt"}]]],
 ",\t\t",
 Cell[BoxData[
  RowBox[{"eq$Lt", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["p", "2"]}], ")"}], 
    RowBox[{"1", "/", "2"}]]}]]],
 ",\n\t",
 Cell[BoxData[
  RowBox[{"v", ":=", "eq$v"}]]],
 ",\t\t",
 Cell[BoxData[
  RowBox[{"eq$v", "=", 
   RowBox[{"p", "/", "Lt"}]}]]],
 ",\n\t",
 Cell[BoxData[
  RowBox[{"R", ":=", 
   RowBox[{"fB", "/", "fA"}]}]]],
 ".\n\t\n\tadd also:  gDA, gDB, gDAlp, fDA, fDB, fDAlp"
}], "Text"],

Cell["\<\
Constraint equations constitutes (these should be combined with the sources):\
\>", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData["gC$\[Rho]"]],
 ",\t\t\t",
 Cell[BoxData["fC$\[Rho]"]],
 ",\n\t",
 Cell[BoxData["gC$j"]],
 ",\t\t\t",
 Cell[BoxData["fC$j"]],
 "."
}], "Text"],

Cell["Evolution equations:", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData["evol$eq$gA"]],
 ",\t\t",
 Cell[BoxData["evol$eq$fA"]],
 ",\t\t// source-free\n\t",
 Cell[BoxData["evol$eq$gB"]],
 ",\t\t",
 Cell[BoxData["evol$eq$fB"]],
 ",\t\t// source-free\n\t",
 Cell[BoxData["evol$eq$gK1"]],
 ",\t",
 Cell[BoxData["evol$eq$fK1"]],
 ",\t// these include the sources  ",
 Cell[BoxData["g$JK1"]],
 ",  . . .\n\t",
 Cell[BoxData["evol$eq$gK2"]],
 ",\t",
 Cell[BoxData["evol$eq$fK2"]],
 ",\t// these include the sources  ",
 Cell[BoxData["g$JK1"]],
 ",  . . ."
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData["evol$eq$p"]],
 ".\t// The evolution equation for ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 ".  (Note: ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 "  is calculated from ",
 Cell[BoxData["eq$p"]],
 ".)"
}], "Text"],

Cell["Source terms:", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{"g$\[Rho]", "=", 
   RowBox[{
    StyleBox[
     RowBox[{"g", 
      StyleBox["V",
       FontWeight->"Bold",
       FontColor->RGBColor[0.6, 0.4, 0.2]], "$\[Rho]"}]], "+", 
    StyleBox[
     RowBox[{"g", 
      StyleBox["T",
       FontWeight->"Bold",
       FontColor->RGBColor[0.5, 0, 0.5]], "$\[Rho]"}]]}]}]]],
 ",\tand so on . . . \t\t// ",
 Cell[BoxData[
  StyleBox["V",
   FontWeight->"Bold",
   FontColor->RGBColor[0.6, 0.4, 0.2]]]],
 " = bimetric, ",
 Cell[BoxData[
  StyleBox["T",
   FontWeight->"Bold",
   FontColor->RGBColor[0.5, 0, 0.5]]]],
 " = matter"
}], "Text"],

Cell["\<\
Bimetric source terms (components of the effective stress-energy tensors):\
\>", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData["gV$\[Rho]"]],
 ",\t\t\t",
 Cell[BoxData["fV$\[Rho]"]],
 ",\n\t",
 Cell[BoxData["gV$j"]],
 ",\t\t\t",
 Cell[BoxData["fV$j"]],
 ",\n\t",
 Cell[BoxData["gV$JK1"]],
 ",\t\t",
 Cell[BoxData["fV$JK1"]],
 ",\n\t",
 Cell[BoxData["gV$JK2"]],
 ",\t\t",
 Cell[BoxData["fV$JK2"]],
 "."
}], "Text"],

Cell["\<\
Matter source terms (components of the matter stress-energy tensors):\
\>", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData["gT$\[Rho]"]],
 ",\t\t\t",
 Cell[BoxData["fT$\[Rho]"]],
 ",\n\t",
 Cell[BoxData["gT$j"]],
 ",\t\t\t",
 Cell[BoxData["fT$j"]],
 ",\n\t",
 Cell[BoxData["gT$JK1"]],
 ",\t\t",
 Cell[BoxData["fT$JK1"]],
 ",\n\t",
 Cell[BoxData["gT$JK2"]],
 ",\t\t",
 Cell[BoxData["fT$JK2"]],
 "."
}], "Text"],

Cell[TextData[{
 "Note: ",
 Cell[BoxData["JK1"]],
 " and ",
 Cell[BoxData["JK2"]],
 " label the compound expressions coming from:"
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    SuperscriptBox["JK", "i"], "k"], "=", 
   RowBox[{
    SubscriptBox[
     SuperscriptBox["J", "i"], "k"], " ", "-", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     SubscriptBox[
      SuperscriptBox["\[Delta]", "i"], "k"], " ", 
     RowBox[{"(", 
      RowBox[{"J", "-", "\[Rho]"}], ")"}]}]}]}]]],
 "."
}], "Text"],

Cell["Kretschmann scalars:", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData["gKretschmann"]],
 ",\t",
 Cell[BoxData["fKretschmann"]],
 "."
}], "Text"],

Cell["Apparent horizon finders:", "Text"],

Cell[TextData[{
 "\t",
 Cell[BoxData["gHorz"]],
 ",\t\t\t",
 Cell[BoxData["fHorz"]],
 "."
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load the bimetric 3+1 equations", "Section",
 PageBreakAbove->True,
 CellTags->"initializationSection"],

Cell[CellGroupData[{

Cell["Load the packages", "Subsection"],

Cell[BoxData[
 RowBox[{"FrontEndExecute", "[", 
  RowBox[{"FrontEndToken", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "@", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "\"\<resourceTracker.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{"<<", "\"\<bimetric-ss-nr.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{"<<", "\"\<bimetric-ss-PF.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{"<<", "\"\<bimetric-lapses-nr.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{"<<", "\"\<Kretschmann.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"Row", "@", 
    RowBox[{"{", 
     RowBox[{"\"\<The V-sign convention is: \>\"", ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"$Vsign", ">", "0"}], ",", "\"\<+\>\"", ",", "\"\<\>\""}], 
       "]"}], ",", "$Vsign"}], "}"}]}], ",", "Bold", ",", "Red"}], 
  "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"useEqr$", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<bimetric-ss-solver.m\>\""}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Configuration", "Subsection"],

Cell[TextData[{
 "The initial data is setup by solving the constraint equations at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 " in several different ways (for more details, see section \
\[OpenCurlyDoubleQuote]Solve the constraint \
equations\[CloseCurlyDoubleQuote]). The variable ",
 Cell[BoxData["id$setup"]],
 " selects the particular setup that will be used (the other cases will be \
ignored during the notebook evaluation). The value ",
 Cell[BoxData["All"]],
 "  for ",
 Cell[BoxData["id$setup"]],
 "  forces the evaluation of all the cases (while also exporting the PDFs)."
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Not", "@", 
     RowBox[{"ValueQ", "[", "id$setup", "]"}]}], ",", 
    RowBox[{"(*", " ", "Default", " ", "*)"}], "  ", 
    RowBox[{"id$setup", "=", "1"}]}], " ", "]"}], ";"}]], "Input"],

Cell["The folder where the exported C++ source files reside:", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$cppPath", "=", "\"\<bim-solver/src/eom/\>\""}], ";"}]], "Input"],

Cell["The folder where the top C++ source files reside:", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$cppPathTop", "=", "\"\<bim-solver/src/\>\""}], ";"}]], "Input"],

Cell["The folder where the binaries reside:", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$binPath", "=", "\"\<run/\>\""}], ";"}]], "Input"],

Cell["On Windows, we need to give a path to 64-bit mingw binaries:", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$mingwPath", "=", 
   RowBox[{"SelectFirst", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
      "\"\<C:\\\\MinGW\\\\mingw-w64\\\\x86_64-8.1.0-posix-seh-rt_v6-rev0\\\\\
mingw64\\\\bin\>\"", ",", "\[IndentingNewLine]", 
       "\"\<C:\\\\MinGW\\\\mingw-w64\\\\x86_64-7.3.0-posix-seh-rt_v5-rev0\\\\\
mingw64\\\\bin\>\""}], "\[IndentingNewLine]", "}"}], ",", "DirectoryQ"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"$OperatingSystem", "\[Equal]", "\"\<Windows\>\""}], "\[And]", 
    RowBox[{"$mingwPath", "===", 
     RowBox[{"Missing", "[", "\"\<NotFound\>\"", "]"}]}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Style", "[", 
      RowBox[{"\"\<Error: MinGW path not found!\>\"", ",", "Red"}], "]"}], 
     "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"FrontEndExecute", "[", 
     RowBox[{"FrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], "]"}]}]}],
   "]"}]}], "Input"],

Cell["\<\
Real number binary data format (either \[OpenCurlyDoubleQuote]Real64\
\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]Real128\
\[CloseCurlyDoubleQuote]):\
\>", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$realBinaryFormat", "=", "\"\<Real64\>\""}], ";"}]], "Input"],

Cell[TextData[{
 "Many cells has the auto-collapse feature (after evaluating the code and \
producing the output, the expression cell will collapse). If ",
 Cell[BoxData["$debugMode"]],
 " is enabled, the auto-collapse feature will be suppressed."
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Not", "@", 
     RowBox[{"ValueQ", "[", "$debugMode", "]"}]}], ",", 
    RowBox[{"(*", " ", "Default", " ", "*)"}], " ", 
    RowBox[{"$debugMode", "=", "False"}]}], " ", "]"}], ";"}]], "Input"],

Cell[TextData[{
 "The flag ",
 Cell[BoxData["$exportPDFs"]],
 " controls whether to export figures to PDFs."
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Not", "@", 
      RowBox[{"ValueQ", "[", "$exportPDFs", "]"}]}], ",", 
     RowBox[{"(*", " ", "Default", " ", "*)"}], " ", 
     RowBox[{"$exportPDFs", "=", "False"}]}], " ", "]"}], ";"}], 
  " "}]], "Input"],

Cell["\<\
Whether to include more diagnostics (e.g., the spatial derivatives) in the \
output.\
\>", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$outputDiagnostics", "=", "False"}], ";"}]], "Input"],

Cell["The default working precision.", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$workingPrecision", "=", "MachinePrecision"}], ";"}]], "Input"],

Cell[TextData[{
 "The value ",
 Cell[BoxData["All"]],
 "  for ",
 Cell[BoxData["id$setup"]],
 "  forces the evaluation of all the cases (while also exporting the PDFs)."
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{50, 10}, {7, 7}}],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"id$setup", "===", "All"}], ",", 
   RowBox[{
    RowBox[{"Quiet", "@", 
     RowBox[{"CreateDirectory", "[", "\"\<figures\>\"", "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"id$setup", "=", "1"}], ";", 
    RowBox[{"$exportPDFs", "=", "True"}], ";", 
    RowBox[{"$recursiveExportPDFs", "=", "True"}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Utility functions (printNice, etc.)", "Subsection"],

Cell["The names of the bimetric model parameters:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"modelParamNames", "=", 
   RowBox[{"{", 
    RowBox[{"k$g", ",", "k$f", ",", 
     RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
     RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
     RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
     RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
     RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}]}], ";"}]], "Input"],

Cell[TextData[{
 "The component fields are in the local chart ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"t", ",", "r"}], ")"}], TraditionalForm]]],
 ","
}], "Text"],

Cell[BoxData[
 RowBox[{
  UnderscriptBox["f_", "_"], ":=", 
  RowBox[{"f", "[", 
   RowBox[{"t", ",", "r"}], "]"}]}]], "Input"],

Cell["\<\
Print equations in a more readable and colorful form (this should be copied \
from \[OpenCurlyDoubleQuote]toy-model bimetric-SS-3+1 two lapses.nb\
\[CloseCurlyDoubleQuote]),\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$usersPrintNiceMap", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"printNice", "[", 
   RowBox[{"e_", ",", 
    RowBox[{"esP_:", "P"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"e", "/.", "$usersPrintNiceMap"}], "/.", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gA", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"A", ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"gB", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"B", ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"gK1", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["K", "1"], ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"gK2", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["K", "2"], ",", "Blue"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"gK", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"K", ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"gKD", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["K", "\[CapitalDelta]"], ",", "Blue"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"gAlp", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"\[Alpha]", ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"gBet", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"\[Beta]", ",", "Blue"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"gDA", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["D", "A"], ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"gDB", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["D", "B"], ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"gDAlp", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["D", "\[Alpha]"], ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"g\[Sigma]", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"\[Sigma]", ",", "Blue"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"fA", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["A", "~"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{"fB", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["B", "~"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{"fK1", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["K", "~"], "1"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{"fK2", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["K", "~"], "2"], ",", "Red"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"fK", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["K", "~"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{"fKD", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["K", "~"], "\[CapitalDelta]"], ",", "Red"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"fAlp", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["\[Alpha]", "~"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{"fBet", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["\[Beta]", "~"], ",", "Red"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"fDA", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "~"], "A"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{"fDB", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "~"], "B"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{"fDAlp", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "~"], "\[Alpha]"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{"f\[Sigma]", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["\[Sigma]", "~"], ",", "Red"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"R", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"R", ",", "Magenta"}], "]"}]}], ",", 
      RowBox[{"q", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"q", ",", 
         RowBox[{"Darker", "@", "Green"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"p", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"p", ",", 
         RowBox[{"Darker", "@", "Green"}]}], "]"}]}], ",", 
      RowBox[{"v", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"v", ",", 
         RowBox[{"Darker", "@", "Green"}]}], "]"}]}], ",", 
      RowBox[{"Lt", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"Darker", "@", "Green"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"g$\[Rho]", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{"g\[Rho]", ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Blue"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightBlue"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"g$j", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{"gj", ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Blue"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightBlue"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"g$JK1", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{
         SubscriptBox["gJK", "1"], ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Blue"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightBlue"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"g$JK2", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{
         SubscriptBox["gJK", "2"], ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Blue"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightBlue"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"f$\[Rho]", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{"f\[Rho]", ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Red"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightRed"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"f$j", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{"fj", ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Red"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightRed"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"f$JK1", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{
         SubscriptBox["fJK", "1"], ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Red"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightRed"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"f$JK2", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{
         SubscriptBox["fJK", "2"], ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Red"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightRed"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"gT$\[Rho]", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"T\[Rho]", ",", 
         RowBox[{"Darker", "@", "Red"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"gT$JK1", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["TJ", "1"], ",", 
         RowBox[{"Darker", "@", "Red"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"gT$JK2", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["TJ", "2"], ",", 
         RowBox[{"Darker", "@", "Red"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"fT$\[Rho]", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["T\[Rho]", "~"], ",", 
         RowBox[{"Darker", "@", "Red"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"fT$JK1", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["TJ", "~"], "1"], ",", 
         RowBox[{"Darker", "@", "Blue"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"fT$JK2", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["TJ", "~"], "2"], ",", 
         RowBox[{"Darker", "@", "Blue"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"pf$\[Rho]", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{"pf\[Rho]", ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Orange"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightOrange"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"pf$j", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{"pfj", ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Orange"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightOrange"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"pf$J1", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{
         SubscriptBox["pfJ", "1"], ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Orange"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightOrange"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"pf$J2", "\[Rule]", 
       RowBox[{"Framed", "[", 
        RowBox[{
         SubscriptBox["pfJ", "2"], ",", 
         RowBox[{"BaseStyle", "\[Rule]", "Orange"}], ",", 
         RowBox[{"Background", "\[Rule]", "LightOrange"}], ",", 
         RowBox[{"FrameMargins", "\[Rule]", "Tiny"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"pfV", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SuperscriptBox["V", "r"], ",", "Purple"}], "]"}]}], ",", 
      RowBox[{"pfv", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SuperscriptBox["v", "r"], ",", "Purple"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"pfD", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["D", "^"], ",", "Purple"}], "]"}]}], ",", 
      RowBox[{"pfS", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["S", "^"], "r"], ",", "Purple"}], "]"}]}], ",", 
      RowBox[{"pf\[Tau]", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         OverscriptBox["\[Tau]", "^"], ",", "Purple"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"k$g", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["\[Kappa]", "g"], ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"k$f", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["\[Kappa]", "f"], ",", "Red"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "n_", "]"}], "\[RuleDelayed]", 
       SubscriptBox["\[Beta]", "n"]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\[Phi]g", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["\[Phi]", "g"], ",", "Blue"}], "]"}]}], ",", 
      RowBox[{"\[Phi]f", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
         SubscriptBox["\[Phi]", "f"], ",", "Red"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}]}], "//.", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f_", "]"}], "[", "r", 
       "]"}], "\[RuleDelayed]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], "f"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "2", "]"}], "[", "f_", "]"}], "[", "r", 
       "]"}], "\[RuleDelayed]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "rr"], "f"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"0", ",", "1"}], "]"}], "[", "f_", "]"}], "[", 
       RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], "f"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"0", ",", "2"}], "]"}], "[", "f_", "]"}], "[", 
       RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "rr"], "f"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"1", ",", "0"}], "]"}], "[", "f_", "]"}], "[", 
       RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], "f"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "[", "f_", "]"}], "[", 
       RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "tt"], "f"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "f_", "]"}], "[", 
       RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "tr"], "f"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f_", "[", 
       RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", "f"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"esP", "[", 
       RowBox[{"n_", ",", "k_", ",", "R_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"HoldForm", "[", 
       SubsuperscriptBox[
        RowBox[{"\[LeftAngleBracket]", "R", "\[RightAngleBracket]"}], "k", 
        "n"], "]"}]}]}], "\[IndentingNewLine]", "}"}]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"echoNice", "[", "e_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Echo", "[", 
    RowBox[{"e", ",", "\"\<\>\"", ",", "printNice"}], "]"}], "/;", 
   RowBox[{"$debugMode", "===", "True"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"echoNice", "[", "e_", "]"}], ":=", 
  RowBox[{"e", "/;", 
   RowBox[{"$debugMode", "===", "False"}]}]}]}], "Input"],

Cell[TextData[{
 "Convert a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expression to C code,"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"toStringCForm", "[", "e_", "]"}], ":=", 
  RowBox[{"ToString", "@", 
   RowBox[{"CForm", "@", "e"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"StringTemplate", "[", "\"\<Real p = <* eq$p *>;\>\"", "]"}], "/.", 
    RowBox[{"TemplateExpression", "\[Rule]", "toStringCForm"}]}], "//", 
   "TemplateApply"}], ";"}]], "Input"],

Cell["\<\
Logarithmic compression of a variable. Shows the exponent for larger values \
and the variable itself for very small values around 0.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Log10\[Epsilon]", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sign", "[", "x", "]"}], " ", 
    RowBox[{"Log10", "[", 
     RowBox[{"1", "+", 
      RowBox[{"Abs", "[", "x", "]"}]}], "]"}]}]}], ";"}]], "Input"],

Cell["Note. The function Log10\[Epsilon] is not so steep at 0 as tanh.", \
"Text"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"False", ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Tanh", "[", "x", "]"}], ",", 
       RowBox[{"Log10\[Epsilon]", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "30"}], ",", "30"}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell["\<\
Close all sections with different cases of the constraint equations.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"closeConstraintEquations", "[", 
   RowBox[{"enabled_:", "True"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"enabled", "\[And]", 
       RowBox[{"Not", "@", "$debugMode"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"NotebookLocate", "[", "#", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"FrontEndExecute", "[", 
           RowBox[{
           "FrontEndToken", "[", "\"\<SelectionCloseAllGroups\>\"", "]"}], 
           "]"}]}], "\[IndentingNewLine]", ")"}], "&"}], "/@", 
       RowBox[{"{", "\"\<constraintEquations\>\"", "}"}]}]}], "]"}], ";", 
    RowBox[{"NotebookLocate", "[", "\"\<none\>\"", "]"}], ";"}], 
   ")"}]}]], "Input"],

Cell["\<\
Prints the output cell, but hiding the very code that produced the output. \
The resulting cell will be put in a frame.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"showOutFrame", "[", 
   RowBox[{"e_", ",", "uniqueTag_", ",", "cellOptions___"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CellPrint", "@", 
     RowBox[{"ExpressionCell", "[", 
      RowBox[{"e", ",", "\"\<Output\>\"", ",", 
       RowBox[{"CellTags", "\[Rule]", "uniqueTag"}], ",", 
       RowBox[{"CellFrame", "\[Rule]", "0.1"}], ",", 
       RowBox[{"CellMargins", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"40", ",", "5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", "cellOptions"}], 
      "]"}]}], ";"}], ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"showOutNoFrameHideCode", "[", 
   RowBox[{"e_", ",", "uniqueTag_", ",", "cellOptions___"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CellPrint", "@", 
     RowBox[{"ExpressionCell", "[", 
      RowBox[{"e", ",", "\"\<Output\>\"", ",", 
       RowBox[{"CellTags", "\[Rule]", "uniqueTag"}], ",", "cellOptions"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"Not", "@", "$debugMode"}], ",", 
      RowBox[{
       RowBox[{"NotebookLocate", "[", "uniqueTag", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FrontEndExecute", "[", 
        RowBox[{"FrontEndToken", "[", "\"\<OpenCloseGroup\>\"", "]"}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"NotebookLocate", "[", "\"\<none\>\"", "]"}]}]}], "]"}], ";"}],
    ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"showOutHideCode", "[", 
   RowBox[{"e_", ",", "uniqueTag_", ",", "cellOptions___"}], "]"}], ":=", 
  RowBox[{"showOutNoFrameHideCode", "[", 
   RowBox[{"e", ",", "uniqueTag", ",", "\[IndentingNewLine]", 
    RowBox[{"CellFrame", "\[Rule]", "0.1"}], ",", 
    RowBox[{"CellMargins", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"40", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", "cellOptions"}], 
   "]"}]}]], "Input"],

Cell["Return the name of the integration method,", "Text"],

Cell["\<\
Evaluate the notebook for a specific \[OpenCurlyQuote]id$setup\
\[CloseCurlyQuote] and export the PDFs,\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"exportPDFs", "[", "idCase_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"$recursiveExportPDFs", "===", "True"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"id$setup", "=", "idCase"}], ";", 
     RowBox[{"$exportPDFs", "=", "True"}], ";", "\[IndentingNewLine]", 
     RowBox[{"FrontEndExecute", "[", 
      RowBox[{"FrontEndToken", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"CheckAbort", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"NotebookLocate", "[", "\"\<constraintEquations\>\"", "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"SelectionMove", "[", 
         RowBox[{
          RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
          "CellGroup"}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"FrontEndExecute", "[", 
         RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}], "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"NotebookLocate", "[", "\"\<evolutionEquations\>\"", "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"SelectionMove", "[", 
         RowBox[{
          RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
          "CellGroup"}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"FrontEndExecute", "[", 
         RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}], 
         "]"}]}], ",", "\[IndentingNewLine]", "Null"}], "\[IndentingNewLine]",
       "]"}], ";"}]}], "]"}]}]], "Input"],

Cell["\<\
Disable dimming of the \[OpenCurlyDoubleQuote]EvaluationUnmatched\
\[CloseCurlyDoubleQuote] output cells on a global level,\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CurrentValue", "[", 
    RowBox[{"$FrontEnd", ",", 
     RowBox[{"{", 
      RowBox[{"PrivateCellOptions", ",", "\"\<EvaluationUnmatchedStyle\>\""}],
       "}"}]}], "]"}], "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Toolbar", "Subsection"],

Cell["\<\
The following cell is deactivated for evaluation. In order to replace the \
toolbar, select the text inside the cell and Evaluate in Place (\[ShiftKey]+\
\[ControlKey]+\[EnterKey]).\
\>", "Text",
 CellChangeTimes->{{3.67998245953806*^9, 3.6799824619560647`*^9}, {
  3.679982508568947*^9, 3.679982534496192*^9}, {3.6799826287515574`*^9, 
  3.6799826304207606`*^9}, {3.680075444447624*^9, 3.6800754464756274`*^9}, {
  3.680098698784053*^9, 3.680098765052969*^9}, {3.6800988006522317`*^9, 
  3.6800988020094337`*^9}, {3.6800988468907127`*^9, 3.6800988470935135`*^9}}],

Cell[BoxData[
 RowBox[{"SetOptions", "[", " ", 
  RowBox[{
   RowBox[{"EvaluationNotebook", "[", "]"}], ",", " ", "\n", "  ", 
   RowBox[{"InitializationCellEvaluation", " ", "\[Rule]", " ", "False"}], 
   ",", "\n", "  ", 
   RowBox[{"InitializationCellWarning", " ", "\[Rule]", " ", "False"}], ",", 
   "\n", "  ", 
   RowBox[{"DockedCells", " ", "\[Rule]", " ", 
    RowBox[{"Cell", "[", " ", 
     RowBox[{
      RowBox[{"BoxData", "@", " ", 
       RowBox[{"ToBoxes", "@", " ", 
        RowBox[{"Row", "@", " ", 
         RowBox[{"{", "\n", 
          RowBox[{"(*", "\n", "  ", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\< Batch:\[ThinSpace]\>\"", ",", "Gray"}], "]"}], ",",
             "\n", "  ", 
            RowBox[{"Button", "[", " ", 
             RowBox[{"\"\< Case 1 \>\"", ",", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"id$setup", " ", "=", " ", "1"}], ";", "\n", "    ", 
                RowBox[{"SelectionMove", "[", 
                 RowBox[{
                  RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
                  "Notebook"}], "]"}], ";", "\n", "    ", 
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}],
                  "]"}], ";"}], ")"}], ",", "\n", "    ", 
              RowBox[{"Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
             "\n", "  ", "]"}], ",", "\n", "  ", 
            RowBox[{"Button", "[", " ", 
             RowBox[{"\"\< 2 \>\"", ",", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"id$setup", " ", "=", " ", "2"}], ";", "\n", "    ", 
                RowBox[{"SelectionMove", "[", 
                 RowBox[{
                  RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
                  "Notebook"}], "]"}], ";", "\n", "    ", 
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}],
                  "]"}], ";"}], ")"}], ",", "\n", "    ", 
              RowBox[{"Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
             "\n", "  ", "]"}], ",", "\n", "  ", 
            RowBox[{"Button", "[", " ", 
             RowBox[{"\"\< 4 \>\"", ",", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"id$setup", " ", "=", " ", "4"}], ";", "\n", "    ", 
                RowBox[{"SelectionMove", "[", 
                 RowBox[{
                  RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
                  "Notebook"}], "]"}], ";", "\n", "    ", 
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}],
                  "]"}], ";"}], ")"}], ",", "\n", "    ", 
              RowBox[{"Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
             "\n", "  ", "]"}], ",", "\n", "  ", 
            RowBox[{"Button", "[", " ", 
             RowBox[{"\"\< 5 \>\"", ",", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"id$setup", " ", "=", " ", "5"}], ";", "\n", "    ", 
                RowBox[{"SelectionMove", "[", 
                 RowBox[{
                  RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
                  "Notebook"}], "]"}], ";", "\n", "    ", 
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}],
                  "]"}], ";"}], ")"}], ",", "\n", "    ", 
              RowBox[{"Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
             "\n", "  ", "]"}], ",", "\n", "  ", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\< | \>\"", ",", "Gray"}], "]"}], ","}], "\n", "*)"}],
           "\n", "  ", 
          RowBox[{"\"\<Debug:\[MediumSpace]\>\"", ",", "\n", "  ", 
           RowBox[{"Checkbox", "[", 
            RowBox[{"Dynamic", "[", "$debugMode", "]"}], "]"}], ",", "\n", 
           "  ", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\< | \>\"", ",", "Gray"}], "]"}], ",", "\n", "  ", 
           RowBox[{"Button", "[", " ", 
            RowBox[{"\"\< Initialize \>\"", ",", " ", "\n", "    ", 
             RowBox[{"CheckAbort", "[", "\[IndentingNewLine]", "      ", 
              RowBox[{
               RowBox[{
                RowBox[{
                "NotebookLocate", "[", "\"\<initializationSection\>\"", "]"}],
                 ";", "\[IndentingNewLine]", "      ", 
                RowBox[{"SelectionMove", "[", 
                 RowBox[{
                  RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
                  "CellGroup"}], "]"}], ";", "\[IndentingNewLine]", "      ", 
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}],
                  "]"}]}], ",", "\[IndentingNewLine]", "      ", "Null"}], 
              "\[IndentingNewLine]", "   ", "]"}], ",", "\n", "    ", 
             RowBox[{"Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
            "\n", "  ", "]"}], ",", "\n", "  ", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\< | Case:\[MediumSpace]\>\"", ",", "Gray"}], "]"}], 
           ",", "\n", "  ", 
           RowBox[{"PopupMenu", "[", " ", 
            RowBox[{
             RowBox[{"Dynamic", "[", "id$setup", "]"}], ",", " ", 
             RowBox[{"$knownCases", " ", "=", " ", 
              RowBox[{"{", "\[IndentingNewLine]", "     ", 
               RowBox[{
                RowBox[{"1", " ", "\[Rule]", " ", "\"\<1: Minkowski\>\""}], 
                ",", "\[IndentingNewLine]", "     ", 
                RowBox[{
                "2", " ", "\[Rule]", " ", "\"\<2: Bim Minkowski\>\""}], ",", 
                "\[IndentingNewLine]", "     ", 
                RowBox[{"3", " ", "\[Rule]", " ", "\"\<3: Bim FLRW\>\""}], 
                ",", "\[IndentingNewLine]", "     ", 
                RowBox[{"4", " ", "\[Rule]", " ", "\"\<4: GR dust\>\""}], ",",
                 "\[IndentingNewLine]", "     ", 
                RowBox[{"5", " ", "\[Rule]", " ", "\"\<5: Bim dust\>\""}], 
                ",", "\[IndentingNewLine]", "     ", 
                RowBox[{"6", " ", "\[Rule]", " ", "\"\<6: Const K\>\""}]}], 
               "\[IndentingNewLine]", "     ", "}"}]}]}], "]"}], ",", "\n", 
           "  ", 
           RowBox[{"Button", "[", " ", 
            RowBox[{"\"\< Solve Constraints \>\"", ",", " ", "\n", "    ", 
             RowBox[{"CheckAbort", "[", "\n", "      ", 
              RowBox[{
               RowBox[{
                RowBox[{
                "NotebookLocate", "[", "\"\<constraintEquations\>\"", "]"}], 
                ";", "\[IndentingNewLine]", "      ", 
                RowBox[{"SelectionMove", "[", 
                 RowBox[{
                  RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
                  "CellGroup"}], "]"}], ";", "\n", "       ", 
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{
                 "FrontEndToken", "[", "\"\<SelectionCloseAllGroups\>\"", 
                  "]"}], "]"}], ";", "\[IndentingNewLine]", "      ", 
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}],
                  "]"}], ";"}], ",", "\[IndentingNewLine]", "      ", 
               "Null"}], "\[IndentingNewLine]", "   ", "]"}], ",", "\n", 
             "    ", 
             RowBox[{"Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
            "\n", "  ", "]"}], ",", "\n", "  ", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\< | \[MediumSpace]\>\"", ",", "Gray"}], "]"}], ",", 
           "\n", "  ", 
           RowBox[{"Button", "[", " ", 
            RowBox[{"\"\< Params \>\"", ",", "\n", "  ", 
             RowBox[{"CreateDialog", "[", 
              RowBox[{
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Spacer", "[", "20", "]"}], ",", 
                  "\[IndentingNewLine]", "\t", 
                  RowBox[{"Grid", "[", 
                   RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"\"\<r0\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "r0"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", "\t\t\t", "\"\<t0\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "t0"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<r1\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "r1"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", "\t\t\t", "\"\<t1\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "t1"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<n cells\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "nLen"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", "\t\t\t", "\"\<m cells\>\"", ",", 
                    RowBox[{"Dynamic", "@", 
                    RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"t1", "-", "t0"}], ")"}], "/", 
                    "\[CapitalDelta]t"}], "]"}]}]}], "}"}], ",", 
                    "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<\[CapitalDelta]r\>\"", ",", 
                    RowBox[{"Dynamic", "@", 
                    RowBox[{"N", "@", "\[CapitalDelta]r"}]}], ",", 
                    "\[IndentingNewLine]", "\t\t\t", 
                    "\"\<\[CapitalDelta]t\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "\[CapitalDelta]t"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<n skip\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "nSkip"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", "\t\t\t", "\"\<m skip\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "mSkip"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<CFDS order\>\"", ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "$cfdsOrder"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "4", ",", "6"}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"60", ",", "22"}], "}"}]}]}], "]"}], ",", 
                    "\[IndentingNewLine]", "\t\t\t", "\"\<Method\>\"", ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "iMethod"}], ",", 
                    RowBox[{"{", "\[IndentingNewLine]", "\t\t\t", 
                    RowBox[{
                    RowBox[{
                    "\"\<Euler\>\"", "\[Rule]", 
                    "\"\<FTCS\[ThinSpace](Euler)\>\""}], ",", 
                    "\[IndentingNewLine]", "\t\t\t", 
                    RowBox[{
                    "\"\<avgICN2\>\"", "\[Rule]", 
                    "\"\<ICN-avg,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]2\>\""}\
], ",", 
                    RowBox[{
                    "\"\<avgICN3\>\"", "\[Rule]", 
                    "\"\<ICN-avg,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]3\>\""}\
], ",", 
                    RowBox[{
                    "\"\<avgICN4\>\"", "\[Rule]", 
                    "\"\<ICN-avg,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]4\>\""}\
], ",", "\[IndentingNewLine]", "\t\t\t", 
                    RowBox[{
                    "\"\<ICN2\>\"", "\[Rule]", 
                    "\"\<ICN,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]2\>\""}], 
                    ",", 
                    RowBox[{
                    "\"\<ICN3\>\"", "\[Rule]", 
                    "\"\<ICN,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]3\>\""}], 
                    ",", "\[IndentingNewLine]", "\t\t\t", 
                    RowBox[{
                    "\"\<RK1\>\"", "\[Rule]", 
                    "\"\<RK,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]1\
\[ThinSpace](Euler)\>\""}], ",", 
                    RowBox[{
                    "\"\<RK2\>\"", "\[Rule]", "\"\<RK,\[ThinSpace]N=2\>\""}], 
                    ",", 
                    RowBox[{
                    "\"\<RK3\>\"", "\[Rule]", 
                    "\"\<RK,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]3\>\""}], 
                    ",", 
                    RowBox[{
                    "\"\<RK4\>\"", "\[Rule]", 
                    "\"\<RK,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]4\>\""}]}], 
                    "\[IndentingNewLine]", "\t\t\t", "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"90", ",", "22"}], "}"}]}]}], "]"}]}], "}"}], ",",
                     "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Ghost cells\>\"", ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "ghostCells"}], ",", 
                    RowBox[{"Range", "[", 
                    RowBox[{"1", ",", "10"}], "]"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"60", ",", "22"}], "}"}]}]}], "]"}], ",", 
                    "\[IndentingNewLine]", "\t\t\t", "\"\<Dissipation\>\"", 
                    ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "$dissipation"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}]}], "}"}], 
                    ",", "\n", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<n out\>\"", ",", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "nOut"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "60"}]}], "]"}], ",", 
                    "\n", "\t\t\t", 
                    RowBox[{"Row", "@", 
                    RowBox[{"{", " ", 
                    RowBox[{"\"\<\[Rule]\[ThinSpace]\>\"", ",", " ", 
                    RowBox[{"Dynamic", "@", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"NumericQ", "@", "fieldCount"}], "===", "True"}], 
                    ",", 
                    RowBox[{"Round", "[", "\n", "\t\t\t", 
                    RowBox[{
                    RowBox[{"If", "[", " ", 
                    RowBox[{"$intBackward", ",", " ", "2", ",", " ", "1"}], 
                    " ", "]"}], " ", "*", " ", "8", " ", "*", " ", 
                    "fieldCount", " ", "*", " ", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", " ", 
                    RowBox[{"t1", " ", "-", " ", "t0"}], " ", ")"}], " ", "/",
                     " ", "\n", "\t\t\t\t", "\[CapitalDelta]t"}], " ", "/", 
                    " ", "mSkip"}], " ", "*", " ", 
                    RowBox[{
                    RowBox[{"(", " ", 
                    RowBox[{
                    RowBox[{"nOut", " ", "/", " ", "nSkip"}], " ", "+", " ", 
                    RowBox[{"2", " ", "*", " ", "ghostCells"}]}], " ", ")"}], 
                    " ", "/", " ", 
                    SuperscriptBox["10", "6"]}]}], "]"}], ",", "\"\<?\>\""}], 
                    "]"}]}], ",", " ", "\"\<\[ThinSpace]MB\>\""}], "}"}]}]}], 
                    "\n", "\t\t\t", "}"}]}], "\[IndentingNewLine]", "\t\t", 
                    "}"}], ",", 
                    RowBox[{"Spacings", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "Automatic"}], "}"}]}], ",", " ", 
                    RowBox[{"Alignment", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Left", ",", "Center"}], "}"}]}], ",", 
                    RowBox[{"BaseStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FontFamily", "\[Rule]", "\"\<Cambria\>\""}], ",", 
                    RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}]}], "]"}],
                   ",", 
                  RowBox[{"Spacer", "[", "30", "]"}], ",", 
                  "\[IndentingNewLine]", "\t", 
                  RowBox[{"Grid", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"\"\<Slicing method:\>\"", ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "slicingMethod"}], ",", "\n", 
                    "\t\t\t", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<const\>\"", ",", "\"\<constgf\>\"", ",", 
                    "\"\<MS2OPT\>\"", ",", "\"\<MS2\>\"", ",", "\"\<MS4\>\"", 
                    ",", "\"\<BM\>\""}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"65", ",", "22"}], "}"}]}]}], "]"}]}], "}"}], ",",
                     "\n", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Smoothing?\>\"", ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "@", "smoothingMethod"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"65", ",", "22"}], "}"}]}]}], "]"}]}], "}"}], ",",
                     "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Use OpenMP?\>\"", ",", 
                    RowBox[{"Checkbox", "[", 
                    RowBox[{"Dynamic", "@", "$useOpenMP"}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Recompile C++?\>\"", ",", 
                    RowBox[{"Checkbox", "[", 
                    RowBox[{"Dynamic", "@", "$recompileCpp"}], "]"}]}], "}"}],
                     ",", "\n", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Out diagnostics?\>\"", ",", 
                    RowBox[{"Checkbox", "[", 
                    RowBox[{"Dynamic", "@", "$outputDiagnostics"}], "]"}]}], 
                    "}"}], ",", "\[IndentingNewLine]", "\t\t", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Integrate backward?\>\"", ",", 
                    RowBox[{"Checkbox", "[", 
                    RowBox[{"Dynamic", "@", "$intBackward"}], "]"}]}], "}"}], 
                    ",", "\n", "\t", 
                    RowBox[{"{", 
                    RowBox[{"Row", "@", 
                    RowBox[{"{", " ", 
                    RowBox[{
                    RowBox[{"Spacer", "[", "10", "]"}], ",", " ", 
                    RowBox[{"Button", "[", " ", 
                    RowBox[{
                    RowBox[{"Style", "[", " ", 
                    RowBox[{"\"\< Evolve \>\"", ",", " ", "Red"}], "]"}], ",",
                     " ", "\n", "\t\t", 
                    RowBox[{"CheckAbort", "[", "\n", "       ", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"DialogReturn", "[", "]"}], ";", "\n", "       ", 
                    RowBox[{"SetSelectedNotebook", "[", "$bimNotebook", "]"}],
                     ";", "\n", "       ", 
                    RowBox[{"FrontEndExecute", "[", 
                    RowBox[{
                    "FrontEndToken", "[", "\"\<DeleteGeneratedCells\>\"", 
                    "]"}], "]"}], ";", "\n", "       ", 
                    RowBox[{"NotebookLocate", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "$bimNotebook", ",", "\"\<evolutionEquations\>\""}], 
                    "}"}], "]"}], ";", "\[IndentingNewLine]", "      ", 
                    RowBox[{"SelectionMove", "[", 
                    RowBox[{"$bimNotebook", ",", "All", ",", "CellGroup"}], 
                    "]"}], ";", "\n", "       ", 
                    RowBox[{"FrontEndExecute", "[", 
                    RowBox[{
                    "FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}], 
                    "]"}]}], ",", "\[IndentingNewLine]", "      ", "Null"}], 
                    "\[IndentingNewLine]", "   ", "]"}], ",", 
                    RowBox[{
                    "Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
                    "]"}], ",", " ", 
                    RowBox[{"Spacer", "[", "10", "]"}], ",", " ", 
                    RowBox[{"Button", "[", 
                    RowBox[{"\"\< Cancel \>\"", ",", 
                    RowBox[{"DialogReturn", "[", "]"}]}], "]"}]}], "}"}]}], 
                    "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"Spacings", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "1"}], "}"}]}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
                    RowBox[{"BaseStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FontFamily", "\[Rule]", "\"\<Cambria\>\""}], ",", 
                    RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}]}], 
                   "]"}]}], "\[IndentingNewLine]", "}"}], "]"}], ",", 
               RowBox[{"Modal", "\[Rule]", "True"}], ",", 
               RowBox[{"Magnification", "\[Rule]", "1.3"}], ",", 
               RowBox[{"WindowSize", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"890", ",", "300"}], "}"}]}], ",", 
               RowBox[{"WindowTitle", "\[Rule]", "\"\<Parameters\>\""}]}], 
              "]"}]}], "\n", "  ", "]"}], ",", "\n", "  ", 
           RowBox[{"Button", "[", " ", 
            RowBox[{"\"\< Evolve \>\"", ",", " ", "\n", "    ", 
             RowBox[{"CheckAbort", "[", "\n", "      ", 
              RowBox[{
               RowBox[{
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{
                 "FrontEndToken", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
                 "]"}], ";", "\[IndentingNewLine]", "      ", 
                RowBox[{
                "NotebookLocate", "[", "\"\<evolutionEquations\>\"", "]"}], 
                ";", "\[IndentingNewLine]", "      ", 
                RowBox[{"SelectionMove", "[", 
                 RowBox[{
                  RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
                  "CellGroup"}], "]"}], ";", "\[IndentingNewLine]", "      ", 
                RowBox[{"FrontEndExecute", "[", 
                 RowBox[{"FrontEndToken", "[", "\"\<EvaluateCells\>\"", "]"}],
                  "]"}]}], ",", "\[IndentingNewLine]", "      ", "Null"}], 
              "\[IndentingNewLine]", "   ", "]"}], ",", "\n", "    ", 
             RowBox[{"Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
            "\n", "  ", "]"}], ",", "\n", "  ", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\< | \>\"", ",", "Gray"}], "]"}], ",", "\n", " ", 
           RowBox[{"Button", "[", 
            RowBox[{"\"\< Show Results \>\"", ",", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"nb$reader", "=", 
                RowBox[{"NotebookOpen", "[", 
                 RowBox[{"StringReplace", "[", 
                  RowBox[{
                   RowBox[{"NotebookFileName", "[", "]"}], ",", 
                   RowBox[{
                   "\"\<3+1 (solver)\>\"", "\[Rule]", 
                    "\"\<3+1 (reader)\>\""}]}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", " ", 
               RowBox[{"SetSelectedNotebook", "[", "nb$reader", "]"}], ";", 
               "\[IndentingNewLine]", " ", 
               RowBox[{"FrontEndExecute", "[", 
                RowBox[{
                "FrontEndToken", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
                "]"}], ";", "\[IndentingNewLine]", " ", 
               RowBox[{"FrontEndExecute", "[", 
                RowBox[{
                "FrontEndToken", "[", "\"\<EvaluateNotebook\>\"", "]"}], 
                "]"}]}], ")"}], ",", "\[IndentingNewLine]", " ", 
             RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}], ",", 
           "\n", " ", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\< | \>\"", ",", "Gray"}], "]"}], ",", "\n", "  ", 
           RowBox[{"Button", "[", " ", 
            RowBox[{"\"\< Delete Output \>\"", ",", " ", "\n", "    ", 
             RowBox[{"FrontEndExecute", "[", 
              RowBox[{
              "FrontEndToken", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
              "]"}], ",", "\n", "    ", 
             RowBox[{"Method", " ", "\[Rule]", " ", "\"\<Queued\>\""}]}], 
            "\n", "  ", "]"}]}], "\n", "  ", "}"}]}]}]}], ",", 
      "\[IndentingNewLine]", "  ", "\"\<DockedCell\>\"", ",", "\n", "  ", 
      RowBox[{"Background", " ", "\[Rule]", " ", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"1", ",", " ", "0.99", ",", " ", "0.95"}], "]"}]}], ",", " ", 
      "\n", "  ", 
      RowBox[{"CellFrameMargins", " ", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"5", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}]}], " ", "\n", "  ", 
     "]"}]}]}], " ", 
  RowBox[{"(*", " ", "Cell", "*)"}], "\[IndentingNewLine]", "]"}]], "Code",
 Evaluatable->False,
 InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate, compile, and run the C++ code", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"exportCppFunction", "[", 
   RowBox[{"{", 
    RowBox[{"name_", ",", "symbol_", ",", "e_"}], "}"}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"str", ",", "out", ",", 
      RowBox[{"j", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"str", "=", 
      RowBox[{"Characters", "@", 
       RowBox[{"StringReplace", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"InsertLinebreaks", "[", 
          RowBox[{
           RowBox[{"StringReplace", "[", 
            RowBox[{
             RowBox[{"toStringCForm", "[", "e", "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\"\<\[Rho]\>\"", "\[Rule]", "\"\<rho\>\""}], ",", 
               RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", "\"\<tau\>\""}], ",", 
               RowBox[{"\"\<g\[Sigma]\>\"", "\[Rule]", "\"\<gSig\>\""}], ",", 
               RowBox[{"\"\<f\[Sigma]\>\"", "\[Rule]", "\"\<fSig\>\""}], ",", 
               RowBox[{"\"\<*\>\"", "\[Rule]", "\"\< * \>\""}], ",", 
               RowBox[{"\"\</\>\"", "\[Rule]", "\"\< / \>\""}]}], "}"}]}], 
            "\[IndentingNewLine]", "]"}], ",", "75"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<+\\n\>\"", "\[Rule]", "\"\<\\n+ \>\""}], ",", 
           RowBox[{"\"\<-\\n\>\"", "\[Rule]", "\"\<\\n- \>\""}], ",", 
           RowBox[{"\"\<*\\n\>\"", "\[Rule]", "\"\<\\n* \>\""}], ",", 
           RowBox[{"\"\</\\n\>\"", "\[Rule]", "\"\<\\n/ \>\""}]}], "}"}]}], 
        "\[IndentingNewLine]", "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"out", "=", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "str", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "===", "\"\<(\>\""}], ",", 
           RowBox[{"++", "j"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "str", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "===", "\"\<)\>\""}], ",", 
             RowBox[{"--", "j"}]}], "]"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "str", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "===", "\"\<\\n\>\""}], ",", 
           RowBox[{"\"\<\\n    /*\>\"", "<>", 
            RowBox[{"ToString", "@", "j"}], "<>", "\"\<*/  \>\""}], ",", 
           RowBox[{
           "str", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "@", "str"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
     "\"\<Real BimetricEvolve::\>\"", "<>", "name", "<>", 
      "\"\<( Int m, Int n )\\n{\\n    return \>\"", "<>", 
      RowBox[{"StringJoin", "[", "out", "]"}], "<>", "\"\<;\\n}\\n\>\""}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"powerCppRules", "[", "e_", "]"}], ":=", 
  RowBox[{"e", "//.", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Beta]", "[", "n_", "]"}], "\[RuleDelayed]", 
      RowBox[{"Symbol", "[", 
       RowBox[{"\"\<b$\>\"", "<>", 
        RowBox[{"ToString", "@", "n"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"\[ExponentialE]", ",", "x_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"exp", "[", "x", "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Sqrt", "[", "v_", "]"}], "\[RuleDelayed]", 
      RowBox[{"sqrt", "[", "v", "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", 
        RowBox[{"-", "1"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"1", "/", "v"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", 
        RowBox[{"1", "/", "2"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"1", "/", 
       RowBox[{"sqrt", "[", "v", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"1", "/", 
       RowBox[{"sqrt", "[", "v", "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", "2"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"pow2", "[", "v", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", 
        RowBox[{"-", "2"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"1", "/", 
       RowBox[{"pow2", "[", "v", "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", "3"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"pow3", "[", "v", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", 
        RowBox[{"-", "3"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"1", "/", 
       RowBox[{"pow3", "[", "v", "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", 
        RowBox[{"3", "/", "2"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"pow15", "[", "v", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Power", "[", 
       RowBox[{"v_", ",", 
        RowBox[{
         RowBox[{"-", "3"}], "/", "2"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"1", "/", 
       RowBox[{"pow15", "[", "v", "]"}]}]}]}], "\[IndentingNewLine]", 
    "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"riffleCppLines", "[", "e_", "]"}], ":=", 
  RowBox[{"StringReplace", "[", 
   RowBox[{
    RowBox[{"StringJoin", "[", 
     RowBox[{"Riffle", "[", 
      RowBox[{"e", ",", "\"\<\\n\>\""}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<$\>\"", "\[Rule]", "\"\<_\>\""}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"toCpp", "[", "eom_", "]"}], ":=", 
  RowBox[{"riffleCppLines", "[", 
   RowBox[{"exportCppFunction", "/@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"eom", "//.", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"gV$\[Rho]", "\[Rule]", "eq$gV$\[Rho]"}], ",", 
           RowBox[{"gV$JK1", "\[Rule]", "eq$gV$JK1"}], ",", 
           RowBox[{"gV$JK2", "\[Rule]", "eq$gV$JK2"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"fV$\[Rho]", "\[Rule]", "eq$fV$\[Rho]"}], ",", 
           RowBox[{"fV$JK1", "\[Rule]", "eq$fV$JK1"}], ",", 
           RowBox[{"fV$JK2", "\[Rule]", "eq$fV$JK2"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"P", "[", 
             RowBox[{"n_", ",", "k_", ",", "R_"}], "]"}], "\[RuleDelayed]", 
            " ", 
            RowBox[{
             RowBox[{"Symbol", "[", 
              RowBox[{"\"\<P$\>\"", "<>", 
               RowBox[{"ToString", "@", "n"}], "<>", "\"\<$\>\"", "<>", 
               RowBox[{"ToString", "@", "k"}]}], "]"}], "[", "R", "]"}]}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"f_", "[", 
             RowBox[{"t", ",", "r"}], "]"}], "\[RuleDelayed]", 
            RowBox[{"f", "[", 
             RowBox[{"m", ",", "n"}], "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", 
               RowBox[{"0", ",", "1"}], "]"}], "[", "f_", "]"}], "[", 
             RowBox[{"m", ",", "n"}], "]"}], "\[RuleDelayed]", 
            RowBox[{
             RowBox[{"Symbol", "[", 
              RowBox[{
               RowBox[{"ToString", "@", "f"}], "<>", "\"\<$r\>\""}], "]"}], 
             "[", 
             RowBox[{"m", ",", "n"}], "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", 
               RowBox[{"0", ",", "2"}], "]"}], "[", "f_", "]"}], "[", 
             RowBox[{"m", ",", "n"}], "]"}], "\[RuleDelayed]", 
            RowBox[{
             RowBox[{"Symbol", "[", 
              RowBox[{
               RowBox[{"ToString", "@", "f"}], "<>", "\"\<$rr\>\""}], "]"}], 
             "[", 
             RowBox[{"m", ",", "n"}], "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"HoldForm", "[", 
             RowBox[{
              RowBox[{"p", "[", 
               RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}], "\[Rule]", 
            RowBox[{"eq$pr", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"HoldForm", "[", 
             RowBox[{
              RowBox[{"q", "[", 
               RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], "]"}], "\[Rule]", 
            RowBox[{"eq$qr", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"HoldForm", "[", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"p", "[", 
                 RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], 
              "]"}], "]"}], "\[Rule]", 
            RowBox[{"eq$pr$r", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"HoldForm", "[", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"q", "[", 
                 RowBox[{"t", ",", "r"}], "]"}], "/", "r"}], ",", "r"}], 
              "]"}], "]"}], "\[Rule]", 
            RowBox[{"eq$qr$r", "[", 
             RowBox[{"t", ",", "r"}], "]"}]}]}], "\[IndentingNewLine]", 
          "}"}]}], "/.", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"t", "\[Rule]", 
           RowBox[{"t", "[", 
            RowBox[{"m", ",", "n"}], "]"}]}], ",", 
          RowBox[{"r", "\[Rule]", 
           RowBox[{"r", "[", 
            RowBox[{"m", ",", "n"}], "]"}]}]}], "\[IndentingNewLine]", 
         "}"}]}], "/.", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{"HoldForm", "\[Rule]", "disabledHoldForm"}], 
        "\[IndentingNewLine]", "}"}]}], "//", "powerCppRules"}], ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"exportCppEoM", "[", "]"}], ":=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"$cppPath", "<>", "\"\<eomEvolution.h\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
      "\"\</** @file  eomEvolution.h\\n\>\"", "<>", "\[IndentingNewLine]", 
       "\"\< *  @brief The evolution equations for metrics.\\n\>\"", "<>", 
       "\[IndentingNewLine]", "\"\< *  @image html evolution.png\\n\>\"", "<>",
        "\[IndentingNewLine]", "\"\< */\\n\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$gEvol"}], "<>", "\"\<\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$fEvol"}], "<>", "\"\<\\n\>\""}], ",", 
      "\[IndentingNewLine]", "\"\<Text\>\""}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Export", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"$cppPath", "<>", "\"\<eomConstraints.h\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
      "\"\</** @file  eomConstraints.h\\n\>\"", "<>", "\[IndentingNewLine]", 
       "\"\< *  @brief The constraint equations (without sources).\\n\>\"", "<>",
        "\[IndentingNewLine]", "\"\< *  @image html constraints.png\\n\>\"", "<>",
        "\[IndentingNewLine]", "\"\< */\\n\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$constr1"}], "<>", "\"\<\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$constr2"}]}], ",", "\[IndentingNewLine]", 
      "\"\<Text\>\""}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Export", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"$cppPath", "<>", "\"\<eomSources.h\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
      "\"\</** @file  eomSources.h\\n\>\"", "<>", "\[IndentingNewLine]", 
       "\"\< *  @brief The stress-energy tensor components.\\n\>\"", "<>", 
       "\[IndentingNewLine]", "\"\< *  @image html sources.png\\n\>\"", "<>", 
       "\[IndentingNewLine]", "\"\< */\\n\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$sources"}]}], ",", "\[IndentingNewLine]", 
      "\"\<Text\>\""}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Export", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"$cppPath", "<>", "\"\<eomMatter.h\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
      "\"\</** @file  eomMatter.h\\n\>\"", "<>", "\[IndentingNewLine]", 
       "\"\< *  @brief The equations of motion for a perfect fluid.\\n\>\"", "<>",
        "\[IndentingNewLine]", "\"\< *  @image html matter.png\\n\>\"", "<>", 
       "\[IndentingNewLine]", "\"\< */\\n\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$mEvol"}]}], ",", "\[IndentingNewLine]", 
      "\"\<Text\>\""}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Export", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"$cppPath", "<>", "\"\<eomMiscEquations.h\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
      "\"\</** @file  eomMiscEquations.h\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       "\"\< *  @brief Contains p, gHorz, fHorz, gBet, fBet and sigma eqs.\\n\
\>\"", "<>", "\[IndentingNewLine]", "\"\< */\\n\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$pEqs"}], "<>", "\"\<\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$shifts"}], "<>", "\"\<\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$horizonFinders"}]}], ",", 
      "\[IndentingNewLine]", "\"\<Text\>\""}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Export", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"$cppPath", "<>", "\"\<eomLapseRatios.h\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
      "\"\</** @file  eomLapseRatios.h\\n\>\"", "<>", "\[IndentingNewLine]", 
       "\"\< *  @brief The lapse factors BimetricEvolve::eq_gW and \
BimetricEvolve::eq_fW.\\n\>\"", "<>", "\[IndentingNewLine]", 
       "\"\< */\\n\\n\>\"", "<>", "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$lapseRatios"}]}], ",", 
      "\[IndentingNewLine]", "\"\<Text\>\""}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{"False", ",", 
      RowBox[{"Export", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"$cppPath", "<>", "\"\<eomKretschmann.h\>\""}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\"\</** @file  eomKretschmann.h\\n\>\"", "<>", 
         "\[IndentingNewLine]", 
         "\"\< *  @brief Expressions for the Kretschmann scalars.\\n\>\"", "<>",
          "\[IndentingNewLine]", "\"\< */\\n\\n\>\"", "<>", 
         "\[IndentingNewLine]", 
         RowBox[{"toCpp", "@", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<gKretschmann\>\"", ",", "gKretschmann", ",", 
              UnderscriptBox["gKretschmannTR", "_"]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"\"\<fKretschmann\>\"", ",", "fKretschmann", ",", 
              UnderscriptBox["fKretschmannTR", "_"]}], "}"}]}], "}"}]}]}], 
        ",", "\[IndentingNewLine]", "\"\<Text\>\""}], "]"}], ",", "Nothing"}],
      "]"}]}], "}"}]}]], "Input"],

Cell["Export the gauge functions (,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"exportCppGaugeFunctions", "[", "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Export", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"$cppPath", "<>", "\"\<eomGauge.h\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
      "\"\</** @file  eomGauge.h\\n\>\"", "<>", "\[IndentingNewLine]", 
       "\"\< *  @brief The gauge functions BimetricEvolve::eq_q, \
BimetricEvolve::eq_gAlp, and BimetricEvolve::eq_fAlp.\\n\>\"", "<>", 
       "\[IndentingNewLine]", "\"\< *  @image html gauge.png\\n\>\"", "<>", 
       "\[IndentingNewLine]", "\"\< */\\n\\n\>\"", "<>", 
       "\[IndentingNewLine]", 
       RowBox[{"toCpp", "@", "EoM$gaugeFunctions"}]}], ",", 
      "\[IndentingNewLine]", "\"\<Text\>\""}], "]"}], ";"}], ")"}]}]], "Input"],

Cell["Recompile the C++ code,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"recompileEvolutionCpp", "[", 
   RowBox[{"exeName_", ",", "flags___"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cmd", ",", "rc"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"$OperatingSystem", "\[Equal]", "\"\<Windows\>\""}], "\[And]",
         " ", 
        RowBox[{"Not", "@", 
         RowBox[{"StringContainsQ", "[", 
          RowBox[{
           RowBox[{"Environment", "[", "\"\<PATH\>\"", "]"}], ",", 
           "$mingwPath"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"SetEnvironment", "[", 
        RowBox[{"\"\<PATH\>\"", "\[Rule]", 
         RowBox[{"$mingwPath", "<>", "\"\<;\>\"", "<>", 
          RowBox[{"Environment", "[", "\"\<PATH\>\"", "]"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"cmd", "=", 
      RowBox[{"{", 
       RowBox[{
       "\"\<g++\>\"", ",", "\[IndentingNewLine]", "\"\<-Wall\>\"", ",", 
        "\"\<-pedantic\>\"", ",", "\"\<-m64\>\"", ",", "\"\<-std=c++14\>\"", 
        ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$Vsign", ">", "0"}], ",", "\"\<-DV_SIGN\>\"", ",", 
          "\"\<-DV_SIGN=-\>\""}], "]"}], ",", "flags", ",", 
        "\[IndentingNewLine]", "\"\<-c\>\"", ",", 
        RowBox[{"$cppPathTop", "<>", "\"\<bim-solver.cpp\>\""}], ",", 
        "\[IndentingNewLine]", "\"\<-o\>\"", ",", 
        RowBox[{"exeName", "<>", "\"\<.o\>\""}]}], "\[IndentingNewLine]", 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"CellPrint", "@", 
      RowBox[{"Cell", "[", 
       RowBox[{
        RowBox[{
        "\"\<Compiling \\\"\>\"", "<>", "exeName", "<>", "\"\<\\\"...\>\""}], 
        ",", "\"\<Text\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "@", 
      RowBox[{"Row", "@", 
       RowBox[{"Riffle", "[", 
        RowBox[{"cmd", ",", "\"\< \>\""}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rc", "=", 
      RowBox[{"RunProcess", "[", "cmd", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"rc", "[", "\"\<ExitCode\>\"", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cmd", "=", 
         RowBox[{"{", 
          RowBox[{
          "\"\<g++\>\"", ",", "\[IndentingNewLine]", "\"\<-Wall\>\"", ",", 
           "\"\<-pedantic\>\"", ",", "\"\<-m64\>\"", ",", 
           "\"\<-std=c++14\>\"", ",", 
           RowBox[{"exeName", "<>", "\"\<.o\>\""}], ",", 
           "\[IndentingNewLine]", "\"\<-static\>\"", ",", "flags", ",", 
           "\"\<-s\>\"", ",", "\"\<-o\>\"", ",", "exeName"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "@", 
         RowBox[{"Row", "@", 
          RowBox[{"Riffle", "[", 
           RowBox[{"cmd", ",", "\"\< \>\""}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"rc", "=", 
         RowBox[{"RunProcess", "[", "cmd", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Quiet", "@", 
         RowBox[{"DeleteFile", "[", 
          RowBox[{"exeName", "<>", "\"\<.o\>\""}], "]"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", "rc"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell["Run the C++ code,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"runBimSolver", "[", "args___", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "rc", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SetDirectory", "[", "$binPath", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rc", "=", 
      RowBox[{"Run", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"$bimSolver", "<>", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"$OperatingSystem", "\[Equal]", "\"\<Windows\>\""}], ",", 
           "\"\<.exe\>\"", ",", "\"\<\>\""}], "]"}], "<>", "\"\< \>\"", "<>", 
         "\[IndentingNewLine]", 
         RowBox[{"StringRiffle", "[", 
          RowBox[{
           RowBox[{"{", "args", "}"}], ",", "\"\< \>\""}], "]"}], "<>", 
         "\"\< 2> run.log\>\""}], "//", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"$OperatingSystem", "\[Equal]", "\"\<Windows\>\""}], ",", 
           RowBox[{"StringReplace", "[", 
            RowBox[{"#", ",", 
             RowBox[{"\"\</\>\"", "\[Rule]", " ", "\"\<\\\\\>\""}]}], "]"}], 
           ",", "#"}], "]"}], "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ResetDirectory", "[", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"CellPrint", "@", 
      RowBox[{"Cell", "[", 
       RowBox[{"\"\<The solver report:\>\"", ",", "\"\<Text\>\""}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Echo", "@", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ReadString", "[", 
            RowBox[{"$binPath", "<>", "\"\<run.log\>\""}], "]"}], "//", 
           RowBox[{
            RowBox[{"StringReplace", "[", 
             RowBox[{"#", ",", 
              RowBox[{"\"\<\\r\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], 
            "&"}]}], "//", 
          RowBox[{
           RowBox[{"StringReplace", "[", 
            RowBox[{"#", ",", 
             RowBox[{"\"\<\\n\\n\>\"", "\[Rule]", "\"\<\\n\>\""}]}], "]"}], 
           "&"}]}], "//", 
         RowBox[{
          RowBox[{"StringDrop", "[", 
           RowBox[{"#", ",", 
            RowBox[{"-", "1"}]}], "]"}], "&"}]}], ",", "Purple"}], "]"}]}], 
     ";", "\[IndentingNewLine]", "rc"}]}], "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Instantiate and display the initial data", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"instantiateEoM", "[", "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "gA", ",", "gB", ",", "gK1", ",", "gK2", ",", "\[IndentingNewLine]", 
      "fA", ",", "fB", ",", "fK1", ",", "fK2", ",", "\[IndentingNewLine]", 
      "gAlp", ",", "fAlp", ",", "gBet", ",", "fBet", ",", 
      "\[IndentingNewLine]", "v", ",", "Lt", ",", "p", ",", "q", ",", "R", 
      ",", "\[IndentingNewLine]", "P", ",", "\[Beta]", ",", "k$g", ",", "k$f",
       ",", "isGR", ",", "\[IndentingNewLine]", "g$\[Rho]", ",", "g$JK1", ",",
       "g$JK2", ",", "f$\[Rho]", ",", "f$JK1", ",", "f$JK2", ",", 
      "\[IndentingNewLine]", "pfD", ",", "pfS", ",", "pf\[Tau]", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"t0", "=", "Indeterminate"}], ",", "\[IndentingNewLine]", "gK", 
      ",", "gKD", ",", "gDA", ",", "gDB", ",", "g\[Sigma]", ",", "gDAlp", ",",
       "\[IndentingNewLine]", "fK", ",", "fKD", ",", "fDA", ",", "fDB", ",", 
      "f\[Sigma]", ",", "fDAlp"}], "\[IndentingNewLine]", "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{
      "id$g$\[Rho]", ",", "id$g$JK1", ",", "id$g$JK2", ",", "id$f$\[Rho]", 
       ",", "id$f$JK1", ",", "id$f$JK2", ",", "\[IndentingNewLine]", "id$q", 
       ",", "id$gAlp", ",", "id$fAlp", ",", "id$gDAlp", ",", 
       "id$gKretschmann", ",", "id$fKretschmann", ",", "id$gW", ",", 
       "id$fW"}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"k$g", ",", "k$f", ",", 
        RowBox[{"\[Beta]", "[", "0", "]"}], ",", 
        RowBox[{"\[Beta]", "[", "1", "]"}], ",", 
        RowBox[{"\[Beta]", "[", "2", "]"}], ",", 
        RowBox[{"\[Beta]", "[", "3", "]"}], ",", 
        RowBox[{"\[Beta]", "[", "4", "]"}]}], "}"}], "=", "id$modelParams"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"isGR", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Beta]", "[", "1", "]"}], "\[Equal]", "0"}], "&&", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "2", "]"}], "\[Equal]", "0"}], "&&", 
        RowBox[{
         RowBox[{"\[Beta]", "[", "3", "]"}], "\[Equal]", "0"}]}], ")"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gBet", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"eq$gBet", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fBet", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"eq$fBet", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"v", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"eq$v", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"P", "[", 
       RowBox[{"n_", ",", "k_", ",", "ev_"}], "]"}], ":=", 
      RowBox[{"eq$esP", "[", 
       RowBox[{"n", ",", "k", ",", "ev"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g$\[Rho]", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"eq$gV$\[Rho]", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"gT$\[Rho]", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g$JK1", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"eq$gV$JK1", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"gT$JK1", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g$JK2", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"eq$gV$JK2", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"gT$JK2", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f$\[Rho]", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"eq$fV$\[Rho]", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"fT$\[Rho]", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f$JK1", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"eq$fV$JK1", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"fT$JK1", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f$JK2", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"eq$fV$JK2", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"fT$JK2", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Determined", " ", "from", " ", 
        RowBox[{"earlier", ":", " ", "id$gA"}]}], ",", " ", "id$gB", ",", " ", 
       RowBox[{"...", " ", "id$p"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gA", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$gA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gB", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$gB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gK1", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$gK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gK2", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$gK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gDA", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$gDA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gDB", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$gDB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g\[Sigma]", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$g\[Sigma]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gK", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"gK1", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"2", 
        RowBox[{"gK2", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gKD", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"gK1", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "-", 
       RowBox[{"gK2", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fA", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$fA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fB", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$fB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fK1", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$fK1", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fK2", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$fK2", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fDA", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$fDA", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fDB", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$fDB", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f\[Sigma]", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$f\[Sigma]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fK", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"fK1", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "+", 
       RowBox[{"2", 
        RowBox[{"fK2", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fKD", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"fK1", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "-", 
       RowBox[{"fK2", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pfD", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$pfD", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pfS", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$pfS", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pf\[Tau]", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"R", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"fB", "[", 
        RowBox[{"t", ",", "r"}], "]"}], "/", 
       RowBox[{"gB", "[", 
        RowBox[{"t", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$p", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Lt", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"p", "[", 
          RowBox[{"t", ",", "r"}], "]"}]}], ")"}], 
       RowBox[{"1", "/", "2"}]]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$q", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gAlp", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$gAlp", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gDAlp", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$gDAlp", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fAlp", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{"id$fAlp", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fDAlp", "[", 
       RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", "1", "]"}], "[", "id$fAlp", "]"}], "[", 
        "r", "]"}], "/", 
       RowBox[{"id$fAlp", "[", "r", "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$gDA", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "gA", "]"}], "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "/", 
       RowBox[{"gA", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$gDB", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "gB", "]"}], "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "/", 
       RowBox[{"gB", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$g\[Sigma]", "[", "r_", "]"}], "=", 
      RowBox[{"eq$g\[Sigma]", "[", 
       RowBox[{"t0", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$fDA", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "fA", "]"}], "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "/", 
       RowBox[{"fA", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$fDB", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"0", ",", "1"}], "]"}], "[", "fB", "]"}], "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "/", 
       RowBox[{"fB", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$f\[Sigma]", "[", "r_", "]"}], "=", 
      RowBox[{"eq$f\[Sigma]", "[", 
       RowBox[{"t0", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$g$\[Rho]", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{"eq$gV$\[Rho]", "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "+", 
       RowBox[{"gT$\[Rho]", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$g$JK1", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{"eq$gV$JK1", "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "+", 
       RowBox[{"gT$JK1", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$g$JK2", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{"eq$gV$JK2", "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "+", 
       RowBox[{"gT$JK2", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$f$\[Rho]", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{"eq$fV$\[Rho]", "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "+", 
       RowBox[{"fT$\[Rho]", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$f$JK1", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{"eq$fV$JK1", "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "+", 
       RowBox[{"fT$JK1", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$f$JK2", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{"eq$fV$JK2", "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "+", 
       RowBox[{"fT$JK2", "[", 
        RowBox[{"t0", ",", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$gKretschmann", "[", "r_", "]"}], "=", 
      RowBox[{"gKretschmannTR", "[", 
       RowBox[{"t0", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$fKretschmann", "[", "r_", "]"}], "=", 
      RowBox[{"fKretschmannTR", "[", 
       RowBox[{"t0", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"id$setup", "\[Equal]", "6"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Interpolated", " ", "gW", " ", "and", " ", "fW"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"id$r$range", "=", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{
             RowBox[{"r0", "+", 
              RowBox[{"\[CapitalDelta]r", "/", "2"}]}], ",", 
             RowBox[{"r1", "+", 
              RowBox[{"20", "\[CapitalDelta]r"}]}], ",", "\[CapitalDelta]r"}],
             "]"}], ",", "$workingPrecision"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"id$setup", "\[Equal]", "6"}], ",", "\[IndentingNewLine]", 
          RowBox[{"id$r$range", "=", 
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"r0", ",", "r1", ",", "\[CapitalDelta]r"}], "]"}], ",", 
             "$workingPrecision"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"PrintTemporary", "@", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<Interpolating \>\"", ",", "gW"}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"id$gW", "=", 
         RowBox[{"Interpolation", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"r", ",", 
              RowBox[{"eq$gW", "[", 
               RowBox[{"t0", ",", "r"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "id$r$range"}], "}"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"PrintTemporary", "@", 
         RowBox[{"Row", "@", 
          RowBox[{"{", 
           RowBox[{"\"\<Interpolating \>\"", ",", "fW"}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"id$fW", "=", 
         RowBox[{"Interpolation", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"r", ",", 
              RowBox[{"eq$fW", "[", 
               RowBox[{"t0", ",", "r"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "id$r$range"}], "}"}]}], "]"}], "]"}]}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"(*", " ", "Else", " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"id$r$range", "=", "Null"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"id$gW", "[", "r_", "]"}], "=", 
         RowBox[{"eq$gW", "[", 
          RowBox[{"t0", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"id$fW", "[", "r_", "]"}], "=", 
         RowBox[{"eq$fW", "[", 
          RowBox[{"t0", ",", "r"}], "]"}]}]}]}], "\[IndentingNewLine]", "]"}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$q", "[", "r_", "]"}], "=", 
      RowBox[{"eq$q", "[", 
       RowBox[{"t0", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$gAlp", "[", "r_", "]"}], "=", 
      RowBox[{"eq$gAlp", "[", 
       RowBox[{"t0", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$fAlp", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{"eq$fAlp", "[", 
        RowBox[{"t0", ",", "r"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"gW", "[", 
           RowBox[{"t0", ",", "r"}], "]"}], "\[Rule]", 
          RowBox[{"id$gW", "[", "r", "]"}]}], ",", 
         RowBox[{
          RowBox[{"fW", "[", 
           RowBox[{"t0", ",", "r"}], "]"}], "\[Rule]", 
          RowBox[{"id$fW", "[", "r", "]"}]}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id$gDAlp", "[", "r_", "]"}], "=", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"id$gAlp", "[", "r", "]"}], ",", "r"}], "]"}], "/", 
       RowBox[{"id$gAlp", "[", "r", "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"id$EoM$gEvol", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"EoM$gEvol", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "3"}], "\[RightDoubleBracket]"}], "/.", 
        RowBox[{"{", 
         RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", 
       "ReleaseHold"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"id$EoM$fEvol", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"EoM$fEvol", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "3"}], "\[RightDoubleBracket]"}], "/.", 
        RowBox[{"{", 
         RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", 
       "ReleaseHold"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"id$EoM$pEqs", "=", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{"isGR", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"EoM$pEqs", "\[LeftDoubleBracket]", 
           RowBox[{"All", ",", "3"}], "\[RightDoubleBracket]"}], "/.", 
          RowBox[{"{", 
           RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}]}], 
        "\[IndentingNewLine]", "]"}], "//", "ReleaseHold"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"id$EoM$constr1", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"EoM$constr1", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "3"}], "\[RightDoubleBracket]"}], "/.", 
        RowBox[{"{", 
         RowBox[{"Framed", "\[Rule]", "Identity"}], "}"}]}], "//", 
       "ReleaseHold"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"showOutNoFrameHideCode", "[", 
      RowBox[{
       RowBox[{"Style", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "\"\<id$EoM instantiated for the initial data \
\[OpenCurlyDoubleQuote]\>\"", "<>", "id$title", "<>", 
          "\"\<\[CloseCurlyDoubleQuote]\>\""}], ",", "\[IndentingNewLine]", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Purple", 
         ",", "16"}], "]"}], ",", "\"\<instEoM\>\""}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"displayInitialData", "[", 
   RowBox[{"r$range_:", 
    RowBox[{"{", 
     RowBox[{"0.01", ",", "10"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"plotOptions", ",", "plot$range", ",", 
      RowBox[{"chop", "=", "Identity"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"plot$range", "=", "r$range"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "@", "id$gA"}], "===", "Interpolation"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"plot$range", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"id$gA", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], "+",
            "0.01"}], ",", 
          RowBox[{
           RowBox[{"id$gA", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], "-",
            "0.01"}]}], "}"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"plotOptions", "[", "legends_", "]"}], ":=", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"Placed", "[", 
          RowBox[{"legends", ",", 
           RowBox[{"{", 
            RowBox[{"0.85", ",", "0.72"}], "}"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"Scaled", "[", "0.48", "]"}]}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", 
         RowBox[{"1", "/", "1.8"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "@", "Blue"}], ",", 
             RowBox[{"Opacity", "[", "0.7", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "@", "Red"}], ",", 
             RowBox[{"Opacity", "[", "0.7", "]"}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "Dashed"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "Dotted"}], "}"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"LabelStyle", "\[Rule]", "Black"}]}], "\[IndentingNewLine]", 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"id$gA", "[", "r", "]"}], ",", 
               RowBox[{"id$gB", "[", "r", "]"}], ",", 
               RowBox[{"id$gK1", "[", "r", "]"}], ",", 
               RowBox[{"id$gK2", "[", "r", "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
             "PlotLabel", "\[Rule]", "\"\<The dynamical fields in the \!\(\*
StyleBox[\"g\",
FontSlant->\"Italic\"]\) sector at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{"A", ",", "B", ",", 
                  SubscriptBox["K", "1"], ",", 
                  SubscriptBox["K", "2"]}], "}"}], "]"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"id$fA", "[", "r", "]"}], ",", 
               RowBox[{"id$fB", "[", "r", "]"}], ",", 
               RowBox[{"id$fK1", "[", "r", "]"}], ",", 
               RowBox[{"id$fK2", "[", "r", "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
             "PlotLabel", "\[Rule]", "\"\<The dynamical fields in the \!\(\*
StyleBox[\"f\",
FontSlant->\"Italic\"]\) sector at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                  OverscriptBox["A", "~"], ",", 
                  OverscriptBox["B", "~"], ",", 
                  SubscriptBox[
                   OverscriptBox["K", "~"], "1"], ",", 
                  SubscriptBox[
                   OverscriptBox["K", "~"], "2"]}], "}"}], "]"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], ",",
          "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$gEvol", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$gEvol", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$gEvol", "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$gEvol", "\[LeftDoubleBracket]", "4", 
                 "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
             "PlotLabel", "\[Rule]", "\"\<The time derivatives in the \!\(\*
StyleBox[\"g\",
FontSlant->\"Italic\"]\) sector at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)\!\(\*
StyleBox[\"A\",
FontSlant->\"Italic\"]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)\!\(\*
StyleBox[\"B\",
FontSlant->\"Italic\"]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \
\(t\)]\)\!\(\*SubscriptBox[\(K\), \(1\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \
\(t\)]\)\!\(\*SubscriptBox[\(K\), \(2\)]\)\>\""}], "}"}], "]"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$fEvol", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$fEvol", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$fEvol", "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$fEvol", "\[LeftDoubleBracket]", "4", 
                 "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
             "PlotLabel", "\[Rule]", "\"\<The time derivatives in the \!\(\*
StyleBox[\"f\",
FontSlant->\"Italic\"]\) sector at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \
\(t\)]\)\!\(\*OverscriptBox[\(A\), \(~\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \
\(t\)]\)\!\(\*OverscriptBox[\(B\), \(~\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \
\(t\)]\)\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(1\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \
\(t\)]\)\!\(\*SubscriptBox[OverscriptBox[\(K\), \(~\)], \(2\)]\)\>\""}], 
                 "}"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"chop", "@", 
                RowBox[{"id$g$\[Rho]", "[", "r", "]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{"id$g$JK1", "[", "r", "]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{"id$g$JK2", "[", "r", "]"}]}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotLabel", "\[Rule]", "\"\<The sources the \!\(\*
StyleBox[\"g\",
FontSlant->\"Italic\"]\) sector at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<\[Rho]\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(JK\), \(1\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(JK\), \(2\)]\)\>\""}], "}"}], 
                "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"chop", "@", 
                RowBox[{"id$f$\[Rho]", "[", "r", "]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{"id$f$JK1", "[", "r", "]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{"id$f$JK2", "[", "r", "]"}]}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotLabel", "\[Rule]", "\"\<The sources the \!\(\*
StyleBox[\"f\",
FontSlant->\"Italic\"]\) sector at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<\!\(\*OverscriptBox[\(\[Rho]\), \(~\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[OverscriptBox[\(JK\), \(~\)], \
\(1\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[OverscriptBox[\(JK\), \(~\)], \
\(2\)]\)\>\""}], "}"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"id$pfD", "[", "r", "]"}], ",", 
               RowBox[{"id$pfS", "[", "r", "]"}], ",", 
               RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
             "PlotLabel", "\[Rule]", 
              "\"\<Dust D, S, and \[Tau] at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<\!\(\*OverscriptBox[\(D\), \(~\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[OverscriptBox[\(S\), \(~\)], \(r\)]\
\)\>\"", ",", "\"\<\!\(\*OverscriptBox[\(\[Tau]\), \(~\)]\)\>\""}], "}"}], 
                "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"DiscretePlot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$constr1", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$constr1", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$constr1", "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"chop", "@", 
                RowBox[{
                "id$EoM$constr1", "\[LeftDoubleBracket]", "4", 
                 "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                  "plot$range", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}], "-", 
                  RowBox[{
                  "plot$range", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}]}], ")"}], "/", "50"}]}], "}"}], 
             ",", "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}], 
               SuperscriptBox["10", 
                RowBox[{"-", "6"}]]}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"ExtentSize", "\[Rule]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                 "plot$range", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}], "-", 
                 RowBox[{
                 "plot$range", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], ")"}], "/", "100"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
             "PlotLabel", "\[Rule]", 
              "\"\<The constraints at \!\(\*SubscriptBox[\(t\), \
\(0\)]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                  SubscriptBox["C", "1"], ",", 
                  SubscriptBox["C", "2"], ",", 
                  SubscriptBox["C", "3"], ",", 
                  SubscriptBox["C", "4"]}], "}"}], "]"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], ",",
          "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Log10\[Epsilon]", "@", 
                RowBox[{"id$gKretschmann", "[", "r", "]"}]}], ",", 
               RowBox[{"Log10\[Epsilon]", "@", 
                RowBox[{"id$fKretschmann", "[", "r", "]"}]}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
             "PlotLabel", "\[Rule]", 
              "\"\<\!\(\*SubscriptBox[\(Log\[Epsilon]\), \(10\)]\) of the \
Kretschmann scalars at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                  SubscriptBox["K", "g"], ",", 
                  SubscriptBox["K", "f"]}], "}"}], "]"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "id$EoM$pEqs", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "id$EoM$pEqs", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "id$EoM$pEqs", "\[LeftDoubleBracket]", "3", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotLabel", "\[Rule]", "\"\<The separation \!\(\*
StyleBox[\"p\",
FontSlant->\"Italic\"]\) and \!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)\!\(\*
StyleBox[\"p\",
FontSlant->\"Italic\"]\) at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                  SubscriptBox["p", "g"], ",", 
                  SubscriptBox["p", "f"], ",", 
                  "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)\!\(\*
StyleBox[\"p\",
FontSlant->\"Italic\"]\)\>\""}], "}"}], "]"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], ",",
          "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Quiet", "@", 
            RowBox[{"Plot", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"id$gAlp", "[", "r", "]"}], ",", 
                RowBox[{"id$fAlp", "[", "r", "]"}], ",", 
                RowBox[{"id$q", "[", "r", "]"}]}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"r", ",", 
                RowBox[{
                "plot$range", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                "plot$range", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"FrameLabel", "\[Rule]", "r"}], ",", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
               "\"\<The gauge variables at \!\(\*SubscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"0\"]\)\>\""}], ",", "\[IndentingNewLine]", 
              RowBox[{"Evaluate", "[", 
               RowBox[{"Sequence", "@@", 
                RowBox[{"plotOptions", "[", 
                 RowBox[{"{", 
                  RowBox[{"\[Alpha]", ",", 
                   OverscriptBox["\[Alpha]", "~"], ",", "q", ",", 
                   SubscriptBox["W", "h"]}], "}"}], "]"}]}], "]"}]}], 
             "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Log10\[Epsilon]", "[", 
                RowBox[{
                 RowBox[{"id$gW", "[", "r", "]"}], "/", 
                 SuperscriptBox["r", "2"]}], "]"}], ",", 
               RowBox[{"Log10\[Epsilon]", "[", 
                RowBox[{
                 RowBox[{"id$fW", "[", "r", "]"}], "/", 
                 SuperscriptBox["r", "2"]}], "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "plot$range", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"FrameLabel", "\[Rule]", "r"}], ",", 
             RowBox[{
             "PlotLabel", "\[Rule]", 
              "\"\<\!\(\*SubscriptBox[\(Log\[Epsilon]\), \(10\)]\) of the \
lapse factors at \!\(\*SubscriptBox[\(t\), \(0\)]\) (\[Alpha]\[ThinSpace]\!\(\
\*SubscriptBox[\(W\), \(g\)]\)\[ThinSpace]+\[ThinSpace]\!\(\*OverscriptBox[\(\
\[Alpha]\), \(~\)]\)\[ThinSpace]\!\(\*SubscriptBox[\(W\), \
\(f\)]\)\[ThinSpace]=\[ThinSpace]0)\>\""}], ",", "\[IndentingNewLine]", 
             RowBox[{"Evaluate", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"plotOptions", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["W", "g"], 
                   SuperscriptBox["r", "\"\<-2\>\""]}], ",", 
                  RowBox[{
                   SubscriptBox["W", "f"], 
                   SuperscriptBox["r", "\"\<-2\>\""]}]}], "}"}], "]"}]}], 
              "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
          "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
       RowBox[{"Spacings", "->", 
        RowBox[{"{", 
         RowBox[{"2", ",", "0"}], "}"}]}]}], "]"}]}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constraint equations", "Section",
 PageBreakAbove->True,
 CellTags->"constraintEquations"],

Cell["\<\
In this section, we solve the constraint equations for the initial data \
needed for the evolution.\
\>", "Text"],

Cell["Running this section creates a \[OpenCurlyDoubleQuote]run vault\
\[CloseCurlyDoubleQuote] for the results:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$binPath", "=", 
   RowBox[{"DateString", "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<run-\>\"", ",", "\"\<Year\>\"", ",", "\"\<Month\>\"", ",", 
      "\"\<Day\>\"", ",", "\"\<-\>\"", ",", "\"\<Hour\>\"", ",", 
      "\"\<Minute\>\"", ",", "\"\<Second\>\"", ",", "\"\</\>\""}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$binPath", "=", "\"\<run/\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Quiet", "@", 
   RowBox[{"CreateDirectory", "[", "$binPath", "]"}]}], ";"}]}], "Input"],

Cell[TextData[{
 "The initial data needed for the evolution of the HR equations cannot be \
freely specified in their entirety. Rather they are subject to certain \
constraints which must be satisfied. Because of the nonlinearity of Einstein\
\[CloseCurlyQuote]s equations, there is no unique way of choosing which \
pieces of the initial data can be freely specified and which are constrained. \
For a review, see, e.g., Cook, ",
 StyleBox["Initial Data for Numerical Relativity",
  FontSlant->"Italic"],
 ", Living Rev. (2000)]"
}], "Text"],

Cell["\<\
The first two cases of  the initial data setups that we treat are the \
bi-Einstein solutions which are used as test beds for assessing the numerical \
code. For the rest, we exploit as much as possible the \
\[OpenCurlyQuote]freedom\[CloseCurlyQuote] in specifying data to get some \
sensible (physical) or interesting bimetric solutions.\
\>", "Text"],

Cell[TextData[{
 "The variables in the initial data are prefixed with \[OpenCurlyDoubleQuote]",
 StyleBox["id$", "Output"],
 "\[CloseCurlyDoubleQuote]. The prime dynamical variables determined at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 " are ",
 StyleBox["id$gA", "Output"],
 ", ..., ",
 StyleBox["id$fK2", "Output"],
 ", and ",
 StyleBox["id$p", "Output"],
 ". The prime kinematical variables are ",
 StyleBox["id$q", "Output"],
 ", ",
 StyleBox["id$gAlp", "Output"],
 ", and ",
 StyleBox["id$fAlp", "Output"],
 ". The lapse ",
 StyleBox["id$fAlp", "Output"],
 " is determined from ",
 StyleBox["id$gAlp", "Output"],
 " using ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "g"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "f"], TraditionalForm]]],
 " (this is done in the subsequent section)."
}], "Text"],

Cell[CellGroupData[{

Cell["The default integration parameters", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r0", "        ", "=", " ", "0"}], "       ", 
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["r", "min"], ",", " ", 
    RowBox[{"the", " ", "spatial", " ", "grid", " ", "starts", " ", 
     RowBox[{"here", "."}]}]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1", "        ", "=", " ", "100"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["r", "max"], ",", " ", 
    RowBox[{"the", " ", "spatial", " ", "grid", " ", "ends", " ", 
     RowBox[{"here", "."}]}]}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nLen", "   ", "=", " ", "500"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "number", " ", "of", " ", "points", " ", "in", " ", "the", " ",
     "spatial", " ", 
    RowBox[{"grid", "."}]}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nOut", "   ", "=", " ", "nLen"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Collect", " ", "the", " ", "results", " ", "up", " ", "to", " ", "this", 
    " ", "grid", " ", 
    RowBox[{"point", "."}]}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nSkip", " ", "=", " ", "1"}], "       ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Collect", " ", "the", " ", "results", " ", "every", " ", "nSkip", " ", 
    RowBox[{"points", "."}]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ghostCells", " ", "=", "10"}], "   ", 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "virtual", " ", 
    RowBox[{"(", "ghost", ")"}], " ", "cells", " ", "on", " ", "the", " ", 
    "boundary"}], " ", "*)"}], ";"}]}], "Input",
 CellFrame->True,
 InitializationCell->False,
 Background->RGBColor[1, 1, 0.95]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"iMethod", " ", "=", " ", "\"\<Euler\>\""}], "        ", 
  RowBox[{"(*", " ", 
   RowBox[{"MoL", ":", " ", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"0", " ", "\[Rule]", " ", "FTCS"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"1", ".."}], "3"}], " ", "\[Rule]", " ", 
       RowBox[{"ICN", "-", "avg"}]}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"4", ".."}], "5"}], " ", "\[Rule]", " ", "ICN"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"6", ".."}], "9"}], " ", "\[Rule]", " ", "RK"}]}], " ", 
     "}"}]}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"t0", "            ", "=", " ", "0"}], "         ", 
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "initial", " ", 
    RowBox[{"t", "."}]}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"t1", "            ", "=", " ", "0.100"}], "   ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Integrate", " ", "up", " ", "to", " ", "this"}], " ", 
    "\[PlusMinus]", 
    RowBox[{"t", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"backward", " ", "and", " ", "forward", " ", "in", " ", "t"}], 
       ")"}], "."}]}]}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[CapitalDelta]t", "            ", "=", " ", "0.001"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "integration", " ", "resolution", " ", "along", " ", 
    RowBox[{"t", "."}]}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mSkip", "     ", "=", " ", "1"}], "       ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Collect", " ", "the", " ", "result", " ", "every", " ", "mSkip", " ", 
    RowBox[{"rows", "."}]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"slicingMethod", " ", "=", " ", "\"\<const\>\""}], "      ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "const", ",", " ", "MS2OPT", ",", " ", "MS2", ",", " ", "MS4", ",", " ", 
    "BM"}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"smoothingMethod", "=", "0"}], " ", 
  RowBox[{"(*", " ", "smoothing", " ", "*)"}], ";"}]}], "Input",
 CellFrame->True,
 InitializationCell->False,
 Background->RGBColor[1, 1, 0.95]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$useOpenMP", "        ", "=", "True"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"enable", " ", "parallelized", " ", "code"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$cfdsOrder", "        ", "=", "4"}], "         ", 
  RowBox[{"(*", " ", 
   RowBox[{"accuracy", " ", "order", " ", "of", " ", "the", " ", "CFDS"}], 
   " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$dissipation", "    ", "=", " ", "0.03"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Kreiss", "-", 
     RowBox[{"Oliger", " ", "dissipation"}]}], ";", " ", 
    RowBox[{"use", " ", "0", " ", "to", " ", "disable"}]}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$recompileCpp", " ", "=", "True"}], "   ", 
  RowBox[{"(*", " ", 
   RowBox[{"force", " ", "recompilation"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$intBackward", "   ", "=", " ", "False"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Integrate", " ", "also", " ", "backward", " ", "in", " ", "time"}], " ", 
   "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$bimSolver", "        ", "=", "\"\<bim-solver\>\""}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"name", " ", "of", " ", "the", " ", "executable"}], " ", "*)"}], 
  ";"}]}], "Input",
 CellFrame->True,
 InitializationCell->False,
 Background->RGBColor[1, 1, 0.95]],

Cell[TextData[{
 "We use the cell-centered (staggered) grid points such that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", 
    RowBox[{
     SubscriptBox["r", "0"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "-", 
        RowBox[{"1", "/", "2"}]}], ")"}], "\[CapitalDelta]", 
      "\[VeryThinSpace]", "r"}]}]}], TraditionalForm]]],
 "  where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "1"}], ",", "2", ",", "...", ",", "nLen"}], 
   TraditionalForm]]],
 "."
}], "Text"],

Cell["The grid spacing is calculated as,", "Text"],

Cell[BoxData[
 RowBox[{"\[CapitalDelta]r", ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"r1", "-", "r0"}], ")"}], "/", "nLen"}]}]], "Input"],

Cell["Solve the constraints by evaluating an external notebook,", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$bimNotebook", "=", 
   RowBox[{"EvaluationNotebook", "[", "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"prepareID", "[", "id_", "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nb$ID", "=", 
     RowBox[{"NotebookOpen", "[", 
      RowBox[{"StringReplace", "[", 
       RowBox[{
        RowBox[{"NotebookFileName", "[", "]"}], ",", 
        RowBox[{"\"\<3+1 (solver)\>\"", "\[Rule]", 
         RowBox[{"\"\<3+1 (ID \>\"", "<>", "id", "<>", "\"\<)\>\""}]}]}], 
       "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"nb$ID", "=!=", "$Failed"}], ",", "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"SetSelectedNotebook", "[", "nb$ID", "]"}], ";", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"FrontEndExecute", "[", 
        RowBox[{"FrontEndToken", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
        "]"}], ";", "\[IndentingNewLine]", " ", 
       RowBox[{"FrontEndExecute", "[", 
        RowBox[{"FrontEndToken", "[", "\"\<EvaluateNotebook\>\"", "]"}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}], ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"NotebookLocate", "[", "\"\<constraintEquations\>\"", "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"FrontEndExecute", "[", 
    RowBox[{"FrontEndToken", "[", "\"\<SelectionCloseAllGroups\>\"", "]"}], 
    "]"}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"prepareID", "[", 
  RowBox[{"\"\<Case \>\"", "<>", 
   RowBox[{"ToString", "@", "id$setup"}]}], "]"}]], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Evolution equations", "Section",
 PageBreakAbove->True,
 CellTags->"evolutionEquations"],

Cell["\<\
In this section, we evolve the initial data obtained in the previous section.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"closeConstraintEquations", "[", "]"}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
Setup the initial data (obtained from the solved constraint equations)\
\>", "Subsection"],

Cell["Instantiate equations of motion.", "Text"],

Cell[BoxData[{
 RowBox[{"instantiateEoM", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Head", "@", "id$r$range"}], "===", "List"}], ",", 
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
         RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{
         RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
          RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], "-", 
         RowBox[{"id$r$range", "\[LeftDoubleBracket]", 
          RowBox[{";;", 
           RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}]}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"Row", "@", 
       RowBox[{"{", 
        RowBox[{"\"\<Discretization of \!\(\*
StyleBox[\"r\",
FontSlant->\"Italic\"]\) : \>\"", ",", 
         RowBox[{"Length", "@", "id$r$range"}], ",", "\"\< points\>\""}], 
        "}"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"r", ",", "\"\<\[CapitalDelta]r\>\""}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "12", "]"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"12", ",", "Black"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"Scaled", "[", "0.6", "]"}]}]}], "\[IndentingNewLine]", "]"}]}],
   "]"}]}], "Input"],

Cell["\<\
Write the integration parameters, the bimetric model parameters, and the \
initial values into \[OpenCurlyQuote]input\[CloseCurlyQuote] cpp file.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"track$id", "=", "\"\<Generating initial data...\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutNoFrameHideCode", "[", 
  RowBox[{
   RowBox[{"Dynamic", "@", "track$id"}], ",", "\"\<genInitialData\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"track$id", "=", 
   RowBox[{"Row", "@", 
    RowBox[{"{", 
     RowBox[{"\"\<Generating initial data... Done. Elapsed \>\"", ",", 
      RowBox[{
       RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
        RowBox[{"id$data", "=", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", " ", 
          RowBox[{
           RowBox[{"Block", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"r", "=", 
               RowBox[{"N", "[", 
                RowBox[{
                 RowBox[{"r0", "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "-", 
                    RowBox[{"1", "/", "2"}]}], ")"}], "\[CapitalDelta]r"}]}], 
                 ",", "$workingPrecision"}], "]"}]}], "}"}], ",", " ", 
             RowBox[{"(*", " ", 
              StyleBox[
               RowBox[{"Cell", "-", 
                RowBox[{"centered", " ", "grid", " ", "points"}]}],
               FontColor->RGBColor[0, 0, 1]], " ", "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"track$id", "=", 
               RowBox[{"Row", "@", 
                RowBox[{"{", 
                 RowBox[{"\"\<r = \>\"", ",", 
                  RowBox[{"Round", "@", "r"}]}], "}"}]}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"r", ",", "\[IndentingNewLine]", 
                RowBox[{"id$gA", "[", "r", "]"}], ",", 
                RowBox[{"id$gB", "[", "r", "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"id$gK1", "[", "r", "]"}], "+", 
                 RowBox[{"2", 
                  RowBox[{"id$gK2", "[", "r", "]"}]}]}], ",", 
                RowBox[{
                 RowBox[{"id$gK1", "[", "r", "]"}], "-", 
                 RowBox[{"id$gK2", "[", "r", "]"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"id$gDA", "[", "r", "]"}], ",", 
                RowBox[{"id$gDB", "[", "r", "]"}], ",", 
                RowBox[{"id$g\[Sigma]", "[", "r", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"id$fA", "[", "r", "]"}], ",", 
                RowBox[{"id$fB", "[", "r", "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"id$fK1", "[", "r", "]"}], "+", 
                 RowBox[{"2", 
                  RowBox[{"id$fK2", "[", "r", "]"}]}]}], ",", 
                RowBox[{
                 RowBox[{"id$fK1", "[", "r", "]"}], "-", 
                 RowBox[{"id$fK2", "[", "r", "]"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"id$fDA", "[", "r", "]"}], ",", 
                RowBox[{"id$fDB", "[", "r", "]"}], ",", 
                RowBox[{"id$f\[Sigma]", "[", "r", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"id$q", "[", "r", "]"}], ",", 
                RowBox[{"id$gAlp", "[", "r", "]"}], ",", 
                RowBox[{"id$fAlp", "[", "r", "]"}], ",", 
                RowBox[{"id$gDAlp", "[", "r", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"id$p", "[", "r", "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{"id$pfD", "[", "r", "]"}], ",", 
                RowBox[{"id$pfS", "[", "r", "]"}], ",", 
                RowBox[{"id$pf\[Tau]", "[", "r", "]"}]}], 
               "\[IndentingNewLine]", "}"}]}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"n", ",", "nLen"}], "}"}]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}], "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}], ",", "\"\< s\>\""}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"nLen", "\[NotEqual]", 
    RowBox[{"Length", "@", "id$data"}]}], ",", 
   RowBox[{"FrontEndExecute", "[", 
    RowBox[{"FrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{"False", ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"id$data", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "8"}], "\[RightDoubleBracket]"}], ",", 
      RowBox[{"id$data", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "11"}], "\[RightDoubleBracket]"}]}], "}"}], 
    "]"}]}], "]"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "@", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Quiet", "@", 
   RowBox[{"CreateDirectory", "[", "$binPath", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Row", "@", 
   RowBox[{"{", 
    RowBox[{"\"\<Exporting input.dat... Done. Elapsed \>\"", ",", 
     RowBox[{
      RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
       RowBox[{"Export", "[", 
        RowBox[{
         RowBox[{"$binPath", "<>", "\"\<input.dat\>\""}], ",", "id$data", ",",
          "$realBinaryFormat"}], "]"}], "\[IndentingNewLine]", "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
     "\"\< s. File size = \>\"", ",", 
     RowBox[{"FileByteCount", "[", 
      RowBox[{"$binPath", "<>", "\"\<input.dat\>\""}], "]"}], ",", " ", 
     "\"\< bytes\>\""}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"showOutNoFrameHideCode", "[", 
  RowBox[{"%", ",", "\"\<writingInputDat\>\""}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Free evolution of the initial data", "Subsection"],

Cell[CellGroupData[{

Cell["Solve the evolution equations using the external C++ program", \
"Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   StyleBox[
    RowBox[{"Create", " ", "the", " ", "parameter", " ", "file"}],
    FontColor->RGBColor[0., 0.5019607843137255, 0.]], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"config$ini", " ", "=", "\n", 
     RowBox[{"{", "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{"\"\<model.title     =\>\"", ",", " ", "id$title"}], " ", 
        "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<model.k_g       =\>\"", ",", " ", 
         RowBox[{"N", "@", 
          RowBox[{
          "id$modelParams", "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}]}]}], " ", "}"}], ",", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<model.k_f       =\>\"", ",", " ", 
         RowBox[{"N", "@", 
          RowBox[{
          "id$modelParams", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}]}]}], " ", "}"}], ",", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<model.b_0       =\>\"", ",", " ", 
         RowBox[{"N", "@", 
          RowBox[{
          "id$modelParams", "\[LeftDoubleBracket]", "3", 
           "\[RightDoubleBracket]"}]}]}], " ", "}"}], ",", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<model.b_1       =\>\"", ",", " ", 
         RowBox[{"N", "@", 
          RowBox[{
          "id$modelParams", "\[LeftDoubleBracket]", "4", 
           "\[RightDoubleBracket]"}]}]}], " ", "}"}], ",", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<model.b_2       =\>\"", ",", " ", 
         RowBox[{"N", "@", 
          RowBox[{
          "id$modelParams", "\[LeftDoubleBracket]", "5", 
           "\[RightDoubleBracket]"}]}]}], " ", "}"}], ",", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<model.b_3       =\>\"", ",", " ", 
         RowBox[{"N", "@", 
          RowBox[{
          "id$modelParams", "\[LeftDoubleBracket]", "6", 
           "\[RightDoubleBracket]"}]}]}], " ", "}"}], ",", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<model.b_4       =\>\"", ",", " ", 
         RowBox[{"N", "@", 
          RowBox[{
          "id$modelParams", "\[LeftDoubleBracket]", "7", 
           "\[RightDoubleBracket]"}]}]}], " ", "}"}], ",", " ", 
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<grid.nLen       =\>\"", ",", " ", "nLen"}], " ", "}"}], 
       ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<grid.nGhost     =\>\"", ",", " ", "ghostCells"}], " ", 
        "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<grid.delta_r    =\>\"", ",", " ", 
         RowBox[{"N", "@", "\[CapitalDelta]r"}]}], " ", "}"}], ",", " ", 
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<input.file      =\>\"", ",", " ", "\"\<input.dat\>\""}], 
        " ", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<input.binary    =\>\"", ",", " ", "1"}], " ", "}"}], ",",
        " ", 
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<output.file     =\>\"", ",", " ", "\"\<output.dat\>\""}],
         " ", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<output.binary   =\>\"", ",", " ", "1"}], " ", "}"}], ",",
        "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<output.nOut     =\>\"", ",", " ", "nOut"}], " ", "}"}], 
       ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<output.nSkip    =\>\"", ",", " ", "nSkip"}], " ", "}"}], 
       ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<output.mSkip    =\>\"", ",", " ", "mSkip"}], " ", "}"}], 
       ",", " ", "\n", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<checkNaNs.nFrom =\>\"", ",", " ", 
         RowBox[{"Round", "[", 
          RowBox[{"0.4", " ", "*", " ", "nOut"}], " ", "]"}]}], " ", "}"}], 
       ",", " ", "\n", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<checkNaNs.nTo   =\>\"", ",", " ", 
         RowBox[{"Round", "[", 
          RowBox[{"0.6", " ", "*", " ", "nOut"}], " ", "]"}]}], " ", "}"}], 
       ",", " ", 
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"Sequence", "@@", 
        RowBox[{"If", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"id$setup", " ", "\[Equal]", " ", "4"}], " ", "\[And]", 
           " ", 
           RowBox[{"slicingMethod", " ", "\[Equal]", " ", "\"\<const\>\""}]}],
           ",", " ", "\n", "\t  ", 
          RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
           RowBox[{
            RowBox[{"{", " ", 
             RowBox[{"\"\<at1.t       = \>\"", ",", " ", "14"}], " ", "}"}], 
            ",", "\[IndentingNewLine]", "\t\t", 
            RowBox[{"{", " ", 
             RowBox[{"\"\<at1.mSkip   = \>\"", ",", " ", "1"}], " ", "}"}], 
            ",", "\[IndentingNewLine]", "\t\t", 
            RowBox[{"{", " ", 
             RowBox[{"\"\<at1.delta_t = \>\"", ",", " ", 
              RowBox[{"\[CapitalDelta]t", "/", "2"}]}], " ", "}"}], ",", " ", 
            RowBox[{"{", "}"}]}], "\n", "\t  ", "}"}], ",", " ", 
          RowBox[{"{", "}"}]}], " ", "]"}]}], ",", "\[IndentingNewLine]", 
       "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<integ.method    =\>\"", ",", " ", "iMethod"}], " ", 
        "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<integ.t_0       =\>\"", ",", " ", 
         RowBox[{"N", "@", "t0"}]}], " ", "}"}], ",", "\[IndentingNewLine]", 
       "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<integ.t_1       =\>\"", ",", " ", 
         RowBox[{"N", "@", "t1"}]}], " ", "}"}], ",", "\[IndentingNewLine]", 
       "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<integ.delta_t   =\>\"", ",", " ", 
         RowBox[{"N", "@", "\[CapitalDelta]t"}]}], " ", "}"}], ",", " ", 
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<integ.dissip    =\>\"", ",", " ", 
         RowBox[{"N", "@", "$dissipation"}]}], " ", "}"}], ",", " ", 
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<slicing.method  =\>\"", ",", " ", "slicingMethod"}], " ",
         "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<slicing.smooth  =\>\"", ",", " ", "smoothingMethod"}], 
        " ", "}"}], ",", "\[IndentingNewLine]", "\t", 
       RowBox[{"{", " ", 
        RowBox[{"\"\<out.diagnostics =\>\"", ",", " ", 
         RowBox[{"If", "[", " ", 
          RowBox[{"$outputDiagnostics", ",", " ", "1", ",", " ", "0"}], " ", 
          "]"}]}], " ", "}"}]}], "\[IndentingNewLine]", "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", " ", 
     RowBox[{
      RowBox[{"$binPath", " ", "<>", " ", "\"\<config.ini\>\""}], ",", " ", 
      "\n", "\t", 
      RowBox[{"StringReplace", "[", " ", 
       RowBox[{
        RowBox[{"ExportString", "[", " ", 
         RowBox[{"config$ini", ",", " ", "\"\<Table\>\""}], " ", "]"}], ",", 
        " ", 
        RowBox[{"\"\<\\t\>\"", " ", "\[Rule]", " ", "\"\< \>\""}]}], " ", 
       "]"}], ",", "\n", "\t", "\"\<Text\>\""}], "\n", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", " ", 
     RowBox[{"False", ",", "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{
        RowBox[{"StringReplace", "[", " ", 
         RowBox[{
          RowBox[{"StringJoin", "@", 
           RowBox[{"Riffle", "[", " ", 
            RowBox[{
             RowBox[{"ToString", " ", "/@", " ", 
              RowBox[{"Flatten", "@", "#"}]}], ",", " ", "\"\< \>\""}], " ", 
            "]"}]}], ",", " ", "\n", "\t\t", 
          RowBox[{
           RowBox[{"\"\< \>\"", ".."}], " ", "\[Rule]", " ", "\"\< \>\""}]}], 
         " ", "]"}], " ", "&"}], " ", "/@", " ", "config$ini"}]}], "\n", 
     "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    StyleBox[
     RowBox[{
     "Show", " ", "some", " ", "of", " ", "the", " ", "parameters", " ", "to",
       " ", "the", " ", "user"}],
     FontColor->RGBColor[0., 0.5019607843137255, 0.]], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Column", " ", "@", "\n", 
     RowBox[{"{", "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"Row", "@", 
        RowBox[{"{", " ", 
         RowBox[{
         "\"\<Case:   \>\"", ",", " ", "\n", "\t\t", "id$title", ",", " ", 
          "\"\<. Using \>\"", ",", " ", 
          RowBox[{"ToString", "@", "iMethod"}], ",", " ", 
          "\"\< method.\>\""}], " ", "\n", "\t", "}"}]}], ",", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"Row", "@", 
        RowBox[{"{", " ", 
         RowBox[{
         "\"\<Params: \>\"", ",", " ", "\n", "\t\t", 
          "\"\<\!\(\*SubscriptBox[\(t\), \(0\)]\) = \>\"", ",", " ", "t0", 
          ",", " ", "\"\<, \!\(\*SubscriptBox[\(t\), \(1\)]\) = \>\"", ",", 
          " ", "t1", ",", " ", "\"\<, \[CapitalDelta]t = \>\"", ",", " ", 
          "\[CapitalDelta]t", ",", " ", "\"\<, \[CapitalDelta]r = \>\"", ",", 
          " ", 
          RowBox[{"N", "@", "\[CapitalDelta]r"}], ",", "\n", "\t\t", 
          "\"\<, m : skip = \>\"", ",", " ", "mSkip", ",", " ", 
          "\"\<, n : len = \>\"", ",", " ", "nLen", ",", " ", "\n", "\t\t", 
          "\"\<, nGhost = \>\"", ",", " ", "ghostCells", ",", " ", 
          "\"\<, out \>\"", ",", " ", "nOut", ",", " ", "\"\<, skip = \>\"", 
          ",", " ", "nSkip"}], " ", "\n", "\t", "}"}]}], ",", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"Row", "@", 
        RowBox[{"{", " ", 
         RowBox[{"\"\<Model:  \>\"", ",", " ", "\n", "\t\t", 
          RowBox[{"Sequence", "@@", 
           RowBox[{"Riffle", "[", " ", 
            RowBox[{
             RowBox[{"Thread", "[", " ", 
              RowBox[{
               RowBox[{"modelParamNames", " ", "\[Rule]", " ", 
                RowBox[{"N", "@", "id$modelParams"}]}], " ", "//", " ", 
               "printNice"}], "]"}], ",", " ", "\n", "\t\t\t", "\"\<, \>\""}],
             " ", "]"}]}]}], "\n", "\t", "}"}]}]}], "\[IndentingNewLine]", 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"showOutHideCode", "[", " ", 
    RowBox[{"%", ",", " ", "\"\<infoParams\>\""}], " ", "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    StyleBox[
     RowBox[{"Recompile", " ", "the", " ", 
      RowBox[{"C", "++"}], " ", "code"}],
     FontColor->RGBColor[0., 0.5019607843137255, 0.]], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"If", "[", " ", 
    RowBox[{
     RowBox[{"$recompileCpp", " ", "\[Or]", " ", 
      RowBox[{"recompiled$case", " ", "=!=", " ", "id$setup"}]}], ",", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"exportCppGaugeFunctions", "[", "]"}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"rc", " ", "=", " ", 
       RowBox[{"recompileEvolutionCpp", "[", " ", 
        RowBox[{
         RowBox[{"$binPath", " ", "<>", " ", "$bimSolver"}], ",", " ", 
         "\"\<-O3\>\"", ",", "\[IndentingNewLine]", "\t\t", 
         RowBox[{"Sequence", "@@", 
          RowBox[{"If", "[", " ", 
           RowBox[{"$useOpenMP", ",", " ", 
            RowBox[{"{", "\"\<-fopenmp\>\"", "}"}], ",", " ", 
            RowBox[{"{", "}"}]}], " ", "]"}]}], ",", "\[IndentingNewLine]", 
         "\t\t", 
         RowBox[{"\"\<-DCFDS_ORDER=\>\"", " ", "<>", " ", 
          RowBox[{"ToString", "@", "$cfdsOrder"}]}], ",", 
         "\[IndentingNewLine]", "\t\t", 
         RowBox[{"Sequence", "@@", 
          RowBox[{"If", "[", " ", 
           RowBox[{
            RowBox[{
            "$realBinaryFormat", " ", "\[Equal]", " ", "\"\<Real128\>\""}], 
            ",", " ", "\n", "\t\t\t", 
            RowBox[{"{", 
             RowBox[{"\"\<-DUSE_QUADMATH\>\"", ",", "\"\<-lquadmath\>\""}], 
             "}"}], ",", " ", 
            RowBox[{"{", "}"}]}], " ", "]"}]}]}], "\[IndentingNewLine]", "\t",
         "]"}]}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"If", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"rc", "[", "\"\<ExitCode\>\"", "]"}], " ", "\[NotEqual]", 
         " ", "0"}], ",", "\[IndentingNewLine]", "\t\t", 
        RowBox[{
         RowBox[{"Print", "[", " ", 
          RowBox[{"\"\<Compilation FAILED. Error:\\n\>\"", ",", " ", 
           RowBox[{"Style", "[", " ", 
            RowBox[{
             RowBox[{"rc", "[", "\"\<StandardError\>\"", "]"}], ",", " ", 
             RowBox[{"Darker", "@", "Red"}]}], " ", "]"}]}], " ", "]"}], ";", 
         "\[IndentingNewLine]", "\t\t", 
         RowBox[{"FrontEndExecute", "[", " ", 
          RowBox[{"FrontEndToken", "[", "\"\<EvaluatorAbort\>\"", "]"}], " ", 
          "]"}]}]}], "\n", "\t", "]"}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"recompiled$case", "=", "id$setup"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    StyleBox[
     RowBox[{
      RowBox[{
       RowBox[{"Put", " ", "'"}], 
       RowBox[{"reader", ".", 
        RowBox[{"nb", "'"}]}], " ", "in", " ", "the", " ", "run"}], "-", 
      "vault"}],
     FontColor->RGBColor[0., 0.5019607843137255, 0.]], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Quiet", "@", 
     RowBox[{"CopyFile", "[", " ", 
      RowBox[{
       RowBox[{"StringReplace", "[", " ", 
        RowBox[{
         RowBox[{"NotebookFileName", "[", "]"}], ",", " ", "\n", "\t", 
         RowBox[{
         "\"\<3+1 (solver)\>\"", " ", "\[Rule]", " ", 
          "\"\<3+1 (reader)\>\""}]}], " ", "]"}], ",", " ", 
       RowBox[{"$binPath", " ", "<>", " ", "\"\<reader.nb\>\""}]}], " ", 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    StyleBox[
     RowBox[{
      RowBox[{"Create", " ", "an", " ", "m"}], "-", 
      RowBox[{"file", " ", "containing", " ", "the", " ", "parameters", " ", 
       RowBox[{"(", 
        RowBox[{"which", " ", "will", " ", "be", " ", "used", " ", 
         RowBox[{"by", " ", "'"}], 
         RowBox[{"reader", ".", 
          RowBox[{"nb", "'"}]}]}], ")"}]}]}],
     FontColor->RGBColor[0., 0.5019607843137255, 0.]], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Quiet", "@", 
     RowBox[{"DeleteFile", "[", " ", 
      RowBox[{"$binPath", " ", "<>", " ", "\"\<config.m\>\""}], " ", "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Save", "[", " ", 
    RowBox[{
     RowBox[{"$binPath", " ", "<>", " ", "\"\<config.m\>\""}], ",", "\n", 
     RowBox[{"{", "\[IndentingNewLine]", "\t", 
      RowBox[{
      "\"\<id$setup\>\"", ",", " ", "\"\<id$title\>\"", ",", " ", 
       "\"\<\[CapitalDelta]t\>\"", ",", " ", "\"\<\[CapitalDelta]r\>\"", ",", 
       " ", "\n", "\t", "\"\<ghostCells\>\"", ",", " ", 
       "\"\<$realBinaryFormat\>\"", ",", " ", "\"\<$debugMode\>\""}], 
      "\[IndentingNewLine]", "}"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    StyleBox[
     RowBox[{"Run", " ", "the", " ", "simulation"}],
     FontColor->RGBColor[0., 0.5019607843137255, 0.]], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PrintTemporary", "[", " ", 
     RowBox[{"Style", "[", " ", 
      RowBox[{"\"\<Integrating forward in time...\>\"", ",", " ", "Red"}], 
      " ", "]"}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rc", " ", "=", " ", 
     RowBox[{"runBimSolver", "[", " ", "\"\<config.ini\>\"", " ", "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", " ", 
    RowBox[{
     RowBox[{"rc", " ", "\[NotEqual]", " ", "0"}], ",", "\[IndentingNewLine]",
      "\t", 
     RowBox[{"FrontEndExecute", "[", " ", 
      RowBox[{"FrontEndToken", "[", " ", "\"\<EvaluatorAbort\>\"", " ", "]"}],
       " ", "]"}], ",", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"Quiet", "@", 
       RowBox[{"DeleteFile", "[", " ", 
        RowBox[{"$binPath", " ", "<>", " ", "\"\<outputR.dat\>\""}], " ", 
        "]"}]}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"Echo", "@", 
       RowBox[{"Row", "@", 
        RowBox[{"{", " ", 
         RowBox[{"\"\<output.dat size = \>\"", ",", " ", 
          RowBox[{"FileByteCount", "[", " ", 
           RowBox[{"$binPath", " ", "<>", " ", "\"\<output.dat\>\""}], " ", 
           "]"}], ",", " ", "\"\< bytes\>\"", ",", " ", "\n", "\t", 
          RowBox[{"Spacer", "[", "10", "]"}], ",", "\[IndentingNewLine]", 
          "\t", 
          RowBox[{"Button", "[", " ", 
           RowBox[{"\"\< Show Results \>\"", ",", "\n", "\t\t", 
            RowBox[{"(", "   ", 
             RowBox[{
              RowBox[{"nb$reader", " ", "=", " ", 
               RowBox[{"NotebookOpen", "[", " ", 
                RowBox[{"StringReplace", "[", " ", 
                 RowBox[{
                  RowBox[{"NotebookFileName", "[", "]"}], ",", " ", "\n", 
                  "\t\t\t\t", 
                  RowBox[{
                  "\"\<3+1 (solver)\>\"", " ", "\[Rule]", " ", 
                   "\"\<3+1 (reader)\>\""}]}], " ", "]"}], " ", "]"}]}], ";", 
              "\[IndentingNewLine]", "\t\t\t", 
              RowBox[{"SetSelectedNotebook", "[", "nb$reader", "]"}], ";", 
              "\[IndentingNewLine]", "\t\t\t", 
              RowBox[{"FrontEndExecute", "[", " ", 
               RowBox[{
               "FrontEndToken", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
               " ", "]"}], ";", "\[IndentingNewLine]", "\t\t\t", 
              RowBox[{"FrontEndExecute", "[", " ", 
               RowBox[{
               "FrontEndToken", "[", "\"\<EvaluateNotebook\>\"", "]"}], " ", 
               "]"}]}], "\n", "\t\t", ")"}], ",", "\[IndentingNewLine]", 
            "\t\t", 
            RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}], ",", " ", 
            RowBox[{"Appearance", "\[Rule]", "\"\<FramedPalette\>\""}]}], 
           "\n", "\t", "]"}]}], "}"}]}]}], ";"}]}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Code",
 InitializationCell->False]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
CellInsertionPointCell->Cell[],
InitializationCellEvaluation->False,
InitializationCellWarning->False,
WindowSize->{1232, 1102},
WindowMargins->{{184, Automatic}, {Automatic, 0}},
WindowStatusArea->Automatic,
DockedCells->Cell[
  BoxData[
   TemplateBox[{"\"Debug:\[MediumSpace]\"", 
     CheckboxBox[
      Dynamic[$CellContext`$debugMode]], 
     StyleBox["\" | \"", 
      GrayLevel[0.5], StripOnInput -> False], 
     ButtonBox[
     "\" Initialize \"", ButtonFunction :> 
      CheckAbort[NotebookLocate["initializationSection"]; SelectionMove[
          EvaluationNotebook[], All, CellGroup]; FrontEndExecute[
          FrontEndToken["EvaluateCells"]], Null], Method -> "Queued", 
      Appearance -> Automatic, Evaluator -> Automatic], 
     StyleBox["\" | Case:\[MediumSpace]\"", 
      GrayLevel[0.5], StripOnInput -> False], 
     PopupMenuBox[
      Dynamic[$CellContext`id$setup], {
      1 -> "\"1: Minkowski\"", 2 -> "\"2: Bim Minkowski\"", 3 -> 
       "\"3: Bim FLRW\"", 4 -> "\"4: GR dust\"", 5 -> "\"5: Bim dust\"", 6 -> 
       "\"6: Const K\""}], 
     ButtonBox[
     "\" Solve Constraints \"", ButtonFunction :> 
      CheckAbort[NotebookLocate["constraintEquations"]; SelectionMove[
          EvaluationNotebook[], All, CellGroup]; FrontEndExecute[
          FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
          FrontEndToken["EvaluateCells"]]; Null, Null], Method -> "Queued", 
      Appearance -> Automatic, Evaluator -> Automatic], 
     StyleBox["\" | \[MediumSpace]\"", 
      GrayLevel[0.5], StripOnInput -> False], 
     ButtonBox["\" Params \"", ButtonFunction :> CreateDialog[
        Row[{
          Spacer[20], 
          Grid[{{"r0", 
             InputField[
              Dynamic[$CellContext`r0], ImageSize -> 60], "t0", 
             InputField[
              Dynamic[$CellContext`t0], ImageSize -> 60]}, {"r1", 
             InputField[
              Dynamic[$CellContext`r1], ImageSize -> 60], "t1", 
             InputField[
              Dynamic[$CellContext`t1], ImageSize -> 60]}, {"n cells", 
             InputField[
              Dynamic[$CellContext`nLen], ImageSize -> 60], "m cells", 
             Dynamic[
              
              Round[($CellContext`t1 - $CellContext`t0)/$CellContext`\
\[CapitalDelta]t]]}, {"\[CapitalDelta]r", 
             Dynamic[
              N[$CellContext`\[CapitalDelta]r]], "\[CapitalDelta]t", 
             InputField[
              Dynamic[$CellContext`\[CapitalDelta]t], ImageSize -> 60]}, {
            "n skip", 
             InputField[
              Dynamic[$CellContext`nSkip], ImageSize -> 60], "m skip", 
             InputField[
              Dynamic[$CellContext`mSkip], ImageSize -> 60]}, {"CFDS order", 
             PopupMenu[
              Dynamic[$CellContext`$cfdsOrder], {2, 4, 6}, 
              ImageSize -> {60, 22}], "Method", 
             PopupMenu[
              Dynamic[$CellContext`iMethod], {
              "Euler" -> "FTCS\[ThinSpace](Euler)", "avgICN2" -> 
               "ICN-avg,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]2", "avgICN3" -> 
               "ICN-avg,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]3", "avgICN4" -> 
               "ICN-avg,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]4", "ICN2" -> 
               "ICN,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]2", "ICN3" -> 
               "ICN,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]3", "RK1" -> 
               "RK,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]1\[ThinSpace](Euler)\
", "RK2" -> "RK,\[ThinSpace]N=2", "RK3" -> 
               "RK,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]3", "RK4" -> 
               "RK,\[ThinSpace]N\[ThinSpace]=\[ThinSpace]4"}, 
              ImageSize -> {90, 22}]}, {"Ghost cells", 
             PopupMenu[
              Dynamic[$CellContext`ghostCells], 
              Range[1, 10], ImageSize -> {60, 22}], "Dissipation", 
             InputField[
              Dynamic[$CellContext`$dissipation], ImageSize -> 60]}, {"n out", 
             InputField[
              Dynamic[$CellContext`nOut], ImageSize -> 60], 
             Row[{"\[Rule]\[ThinSpace]", 
               Dynamic[
                If[NumericQ[$CellContext`fieldCount] === True, 
                 
                 Round[(((If[$CellContext`$intBackward, 2, 1] 
                    8) $CellContext`fieldCount) ((($CellContext`t1 - \
$CellContext`t0)/$CellContext`\[CapitalDelta]t)/$CellContext`mSkip)) \
(($CellContext`nOut/$CellContext`nSkip + 2 $CellContext`ghostCells)/10^6)], 
                 "?"]], "\[ThinSpace]MB"}]}}, Spacings -> {2, Automatic}, 
           Alignment -> {Left, Center}, 
           BaseStyle -> {FontFamily -> "Cambria", FontSize -> 14}], 
          Spacer[30], 
          Grid[{{"Slicing method:", 
             PopupMenu[
              Dynamic[$CellContext`slicingMethod], {
              "const", "constgf", "MS2OPT", "MS2", "MS4", "BM"}, 
              ImageSize -> {65, 22}]}, {"Smoothing?", 
             PopupMenu[
              Dynamic[$CellContext`smoothingMethod], {0, 1, 2, 3}, 
              ImageSize -> {65, 22}]}, {"Use OpenMP?", 
             Checkbox[
              Dynamic[$CellContext`$useOpenMP]]}, {"Recompile C++?", 
             Checkbox[
              Dynamic[$CellContext`$recompileCpp]]}, {"Out diagnostics?", 
             Checkbox[
              Dynamic[$CellContext`$outputDiagnostics]]}, {
            "Integrate backward?", 
             Checkbox[
              Dynamic[$CellContext`$intBackward]]}, {
             Row[{
               Spacer[10], 
               Button[
                Style[" Evolve ", Red], 
                CheckAbort[
                DialogReturn[]; 
                 SetSelectedNotebook[$CellContext`$bimNotebook]; 
                 FrontEndExecute[
                   FrontEndToken["DeleteGeneratedCells"]]; 
                 NotebookLocate[{$CellContext`$bimNotebook, 
                    "evolutionEquations"}]; 
                 SelectionMove[$CellContext`$bimNotebook, All, CellGroup]; 
                 FrontEndExecute[
                   FrontEndToken["EvaluateCells"]], Null], Method -> 
                "Queued"], 
               Spacer[10], 
               Button[" Cancel ", 
                DialogReturn[]]}]}}, Spacings -> {2, 1}, Alignment -> Left, 
           BaseStyle -> {FontFamily -> "Cambria", FontSize -> 14}]}], Modal -> 
        True, Magnification -> 1.3, WindowSize -> {890, 300}, WindowTitle -> 
        "Parameters"], Appearance -> Automatic, Evaluator -> Automatic, 
      Method -> "Preemptive"], 
     ButtonBox["\" Evolve \"", ButtonFunction :> CheckAbort[FrontEndExecute[
          FrontEndToken["DeleteGeneratedCells"]]; 
        NotebookLocate["evolutionEquations"]; SelectionMove[
          EvaluationNotebook[], All, CellGroup]; FrontEndExecute[
          FrontEndToken["EvaluateCells"]], Null], Method -> "Queued", 
      Appearance -> Automatic, Evaluator -> Automatic], 
     StyleBox["\" | \"", 
      GrayLevel[0.5], StripOnInput -> False], 
     ButtonBox[
     "\" Show Results \"", 
      ButtonFunction :> ($CellContext`nb$reader = NotebookOpen[
          StringReplace[
           NotebookFileName[], "3+1 (solver)" -> "3+1 (reader)"]]; 
       SetSelectedNotebook[$CellContext`nb$reader]; FrontEndExecute[
         FrontEndToken["DeleteGeneratedCells"]]; FrontEndExecute[
         FrontEndToken["EvaluateNotebook"]]), Method -> "Queued", Appearance -> 
      Automatic, Evaluator -> Automatic], 
     StyleBox["\" | \"", 
      GrayLevel[0.5], StripOnInput -> False], 
     ButtonBox["\" Delete Output \"", ButtonFunction :> FrontEndExecute[
        FrontEndToken["DeleteGeneratedCells"]], Method -> "Queued", 
      Appearance -> Automatic, Evaluator -> Automatic]}, "RowDefault"]], 
  "DockedCell", Background -> RGBColor[1, 0.99, 0.95], 
  CellFrameMargins -> {{5, 0}, {0, 0}}],
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04},
"PrintingMargins"->{{28.346456999999997`, 28.346456999999997`}, \
{28.346456999999997`, 42.519685499999994`}}},
TrackCellChangeTimes->False,
ShowSyntaxStyles->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], FontFamily -> "Arial", FontSize -> 28, FontWeight -> 
    "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsection"], CellMargins -> {{35, 3.}, {8., 12.}}, FontFamily -> 
    "Arial", FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], CellMargins -> {{40, Inherited}, {2, 10}}, 
    FontFamily -> "Arial", FontSize -> 19, FontWeight -> "Plain", FontSlant -> 
    "Plain", FontVariations -> {
     "StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Text"], CellMargins -> {{40, 10}, {7, 7}}, FontFamily -> 
    "Cambria", FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemParagraph"], FontFamily -> "Cambria", FontSize -> 14,
     FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["ItemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["SubsubitemNumbered"], FontFamily -> "Cambria", FontSize -> 14, 
    FontWeight -> "Plain", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["mk-test"], CellFrame -> {{0.3, 0}, {0, 0.3}}, PageBreakBelow -> 
    False, CellChangeTimes -> {3.704299599624503*^9}, MenuSortingValue -> 
    10000, FontFamily -> "Cambria", FontSize -> 14, FontWeight -> "Plain", 
    FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Code"], FontFamily -> "Times New Roman", FontSize -> 13, 
    FontWeight -> "Bold", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}, 
    Background -> 
    RGBColor[0.984313725490196, 0.984313725490196, 0.984313725490196]]}, 
  Visible -> False, FrontEndVersion -> 
  "10.3 for Microsoft Windows (64-bit) (October 9, 2015)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "initializationSection"->{
  Cell[14279, 600, 109, 2, 78, "Section",
   PageBreakAbove->True,
   CellTags->"initializationSection"]},
 "constraintEquations"->{
  Cell[141337, 3700, 96, 2, 78, "Section",
   PageBreakAbove->True,
   CellTags->"constraintEquations"]},
 "evolutionEquations"->{
  Cell[151805, 4009, 94, 2, 60, "Section",
   PageBreakAbove->True,
   CellTags->"evolutionEquations"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"initializationSection", 190141, 4872},
 {"constraintEquations", 190274, 4876},
 {"evolutionEquations", 190405, 4880}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 198, 6, 93, "Text"],
Cell[759, 28, 28, 0, 38, "Text"],
Cell[790, 30, 68, 0, 38, "Text"],
Cell[861, 32, 69, 1, 38, "Text"],
Cell[933, 35, 492, 14, 64, "Text"],
Cell[CellGroupData[{
Cell[1450, 53, 119, 2, 38, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1572, 57, 4129, 122, 113221, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[5738, 184, 114, 2, 33, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[5855, 188, 638, 18, 34641, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Closed]],
Cell[CellGroupData[{
Cell[6530, 211, 31, 0, 60, "Section"],
Cell[6564, 213, 868, 33, 134, "Text"],
Cell[7435, 248, 98, 2, 38, "Text"],
Cell[7536, 252, 148, 3, 38, "Text"],
Cell[CellGroupData[{
Cell[7709, 259, 48, 0, 53, "Subsection"],
Cell[7760, 261, 209, 7, 30441, "Text"],
Cell[7972, 270, 44, 0, 29378, "Text"],
Cell[8019, 272, 268, 14, 72235, "Text"],
Cell[8290, 288, 44, 0, 29378, "Text"],
Cell[8337, 290, 849, 42, 93077, "Text"],
Cell[9189, 334, 46, 0, 29378, "Text"],
Cell[9238, 336, 334, 15, 72235, "Text"],
Cell[9575, 353, 284, 14, 72235, "Text"],
Cell[9862, 369, 36, 0, 29378, "Text"],
Cell[9901, 371, 87, 5, 30441, "Text"],
Cell[9991, 378, 167, 8, 30441, "Text"],
Cell[10161, 388, 40, 0, 29378, "Text"],
Cell[10204, 390, 548, 24, 115421, "Text"],
Cell[10755, 416, 101, 2, 29378, "Text"],
Cell[10859, 420, 179, 10, 51590, "Text"],
Cell[11041, 432, 36, 0, 29378, "Text"],
Cell[11080, 434, 525, 22, 93077, "Text"],
Cell[11608, 458, 272, 12, 30441, "Text"],
Cell[11883, 472, 29, 0, 29378, "Text"],
Cell[11915, 474, 627, 26, 30441, "Text"],
Cell[12545, 502, 98, 2, 29378, "Text"],
Cell[12646, 506, 323, 18, 93077, "Text"],
Cell[12972, 526, 93, 2, 29378, "Text"],
Cell[13068, 530, 323, 18, 93077, "Text"],
Cell[13394, 550, 142, 6, 30441, "Text"],
Cell[13539, 558, 390, 16, 33078, "Text"],
Cell[13932, 576, 36, 0, 29378, "Text"],
Cell[13971, 578, 111, 6, 30441, "Text"],
Cell[14085, 586, 41, 0, 29378, "Text"],
Cell[14129, 588, 101, 6, 30441, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14279, 600, 109, 2, 78, "Section",
 PageBreakAbove->True,
 CellTags->"initializationSection"],
Cell[CellGroupData[{
Cell[14413, 606, 39, 0, 53, "Subsection"],
Cell[14455, 608, 138, 3, 2147483647, "Input"],
Cell[14596, 613, 820, 18, 2147483647, "Input"],
Cell[15419, 633, 55, 1, 2147483647, "Input"],
Cell[15477, 636, 90, 2, 2147483647, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[15604, 643, 35, 0, 42, "Subsection"],
Cell[15642, 645, 700, 17, 1293, "Text"],
Cell[16345, 664, 258, 7, 510, "Input"],
Cell[16606, 673, 142, 2, 531, "Text"],
Cell[16751, 677, 100, 2, 510, "Input"],
Cell[16854, 681, 137, 2, 531, "Text"],
Cell[16994, 685, 99, 2, 510, "Input"],
Cell[17096, 689, 125, 2, 531, "Text"],
Cell[17224, 693, 85, 2, 510, "Input"],
Cell[17312, 697, 148, 2, 531, "Text"],
Cell[17463, 701, 1050, 26, 2525, "Input"],
Cell[18516, 729, 252, 6, 531, "Text"],
Cell[18771, 737, 96, 2, 510, "Input"],
Cell[18870, 741, 331, 7, 921, "Text"],
Cell[19204, 750, 265, 7, 510, "Input"],
Cell[19472, 759, 192, 6, 550, "Text"],
Cell[19667, 767, 294, 9, 510, "Input"],
Cell[19964, 778, 180, 5, 531, "Text"],
Cell[20147, 785, 88, 2, 510, "Input"],
Cell[20238, 789, 118, 2, 531, "Text"],
Cell[20359, 793, 98, 2, 510, "Input"],
Cell[20460, 797, 253, 8, 550, "Text"],
Cell[20716, 807, 421, 11, 1187, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[21174, 823, 57, 0, 42, "Subsection"],
Cell[21234, 825, 59, 0, 3945, "Text"],
Cell[21296, 827, 369, 9, 3790, "Input"],
Cell[21668, 838, 180, 7, 3945, "Text"],
Cell[21851, 847, 127, 4, 4202, "Input"],
Cell[21981, 853, 197, 4, 3945, "Text"],
Cell[22181, 859, 103, 3, 3790, "Input"],
Cell[22287, 864, 14550, 384, 113700, "Input"],
Cell[36840, 1250, 382, 10, 6385, "Input"],
Cell[37225, 1262, 117, 5, 3945, "Text"],
Cell[37345, 1269, 149, 4, 3790, "Input"],
Cell[37497, 1275, 239, 6, 3790, "Input"],
Cell[37739, 1283, 157, 3, 3945, "Text"],
Cell[37899, 1288, 263, 8, 3790, "Input"],
Cell[38165, 1298, 82, 1, 3945, "Text"],
Cell[38250, 1301, 363, 11, 3790, "Input"],
Cell[38616, 1314, 92, 2, 3945, "Text"],
Cell[38711, 1318, 821, 22, 13831, "Input"],
Cell[39535, 1342, 143, 3, 3945, "Text"],
Cell[39681, 1347, 708, 18, 8831, "Input"],
Cell[40392, 1367, 880, 21, 13831, "Input"],
Cell[41275, 1390, 547, 14, 6385, "Input"],
Cell[41825, 1406, 58, 0, 3945, "Text"],
Cell[41886, 1408, 127, 3, 3945, "Text"],
Cell[42016, 1413, 1570, 34, 31283, "Input"],
Cell[43589, 1449, 147, 3, 3945, "Text"],
Cell[43739, 1454, 267, 8, 3790, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[44043, 1467, 29, 0, 42, "Subsection"],
Cell[44075, 1469, 574, 9, 72, "Text"],
Cell[44652, 1480, 27310, 536, 6176, "Code",
 Evaluatable->False,
 InitializationCell->False]
}, Closed]],
Cell[CellGroupData[{
Cell[71999, 2021, 61, 0, 42, "Subsection"],
Cell[72063, 2023, 3231, 76, 2147483647, "Input"],
Cell[75297, 2101, 2551, 68, 2147483647, "Input"],
Cell[77851, 2171, 341, 9, 2147483647, "Input"],
Cell[78195, 2182, 4365, 106, 2147483647, "Input"],
Cell[82563, 2290, 5376, 110, 2147483647, "Input"],
Cell[87942, 2402, 45, 0, 276252081, "Text"],
Cell[87990, 2404, 795, 17, 1670657020, "Input"],
Cell[88788, 2423, 39, 0, 276252081, "Text"],
Cell[88830, 2425, 3408, 80, 2147483647, "Input"],
Cell[92241, 2507, 33, 0, 276252081, "Text"],
Cell[92277, 2509, 2283, 57, 2018340822, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[94597, 2571, 62, 0, 42, "Subsection"],
Cell[94662, 2573, 21163, 534, 10502, "Input"],
Cell[115828, 3109, 25460, 585, 9422, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[141337, 3700, 96, 2, 78, "Section",
 PageBreakAbove->True,
 CellTags->"constraintEquations"],
Cell[141436, 3704, 123, 3, 23503, "Text"],
Cell[141562, 3709, 122, 1, 23503, "Text"],
Cell[141687, 3712, 565, 14, 52627, "Input"],
Cell[142255, 3728, 542, 10, 55960, "Text"],
Cell[142800, 3740, 363, 6, 39487, "Text"],
Cell[143166, 3748, 880, 32, 57788, "Text"],
Cell[CellGroupData[{
Cell[144071, 3784, 59, 0, 26415, "Subsubsection"],
Cell[144133, 3786, 1662, 43, 138812, "Input",
 InitializationCell->False],
Cell[145798, 3831, 2143, 57, 157437, "Input",
 InitializationCell->False],
Cell[147944, 3890, 1408, 37, 138812, "Input",
 InitializationCell->False],
Cell[149355, 3929, 513, 19, 29378, "Text"],
Cell[149871, 3950, 50, 0, 29378, "Text"],
Cell[149924, 3952, 142, 4, 28227, "Input"],
Cell[150069, 3958, 73, 0, 29378, "Text"],
Cell[150145, 3960, 119, 3, 28227, "Input"],
Cell[150267, 3965, 1058, 24, 140078, "Input"],
Cell[151328, 3991, 289, 7, 47563, "Input"],
Cell[151620, 4000, 136, 3, 28227, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[151805, 4009, 94, 2, 60, "Section",
 PageBreakAbove->True,
 CellTags->"evolutionEquations"],
Cell[151902, 4013, 101, 2, 38, "Text"],
Cell[152006, 4017, 72, 1, 36, "Input"],
Cell[CellGroupData[{
Cell[152103, 4022, 100, 2, 53, "Subsection"],
Cell[152206, 4026, 48, 0, 38, "Text"],
Cell[152257, 4028, 1645, 39, 175, "Input"],
Cell[153905, 4069, 169, 3, 38, "Text"],
Cell[154077, 4074, 4665, 105, 520, "Input"],
Cell[158745, 4181, 1037, 24, 152, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159819, 4210, 56, 0, 53, "Subsection"],
Cell[CellGroupData[{
Cell[159900, 4214, 87, 1, 42, "Subsubsection"],
Cell[159990, 4217, 18668, 413, 2778, "Code",
 InitializationCell->False]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
